import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:path/path.dart' as p;

/// Game icons (4122 icons)
///
/// - build svg for icony_gameicons icon libraries
/// - constants link to svg icon resources
class GameIcons extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  /// construct IconData
  const GameIcons(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  /// build widget for svg asset
  static Widget svgAsset(String assetName,
      {Key? key,
      bool matchTextDirection = false,
      AssetBundle? bundle,
      String? package,
      double? width,
      double? height,
      BoxFit fit = BoxFit.contain,
      AlignmentGeometry alignment = Alignment.center,
      bool allowDrawingOutsideViewBox = false,
      WidgetBuilder? placeholderBuilder,
      Color? color,
      BlendMode colorBlendMode = BlendMode.srcIn,
      String? semanticsLabel,
      bool excludeFromSemantics = false,
      Clip clipBehavior = Clip.hardEdge,
      bool cacheColorFilter = false,
      SvgTheme? theme}) {
    final path = p.join(
      // external library
      'packages/icony/assets/images/icony_gameicons/',
      // local library
      // 'assets/images/icony_gameicons/',
      assetName,
    );
    return SvgPicture.asset(
      path,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  @override
  Widget build(BuildContext context) {
    return svgAsset(
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  /// map constant $3d_glasses to 3d-glasses.svg file
  static const String $3d_glasses = '3d-glasses.svg';

  /// map constant $3d_hammer to 3d-hammer.svg file
  static const String $3d_hammer = '3d-hammer.svg';

  /// map constant $3d_meeple to 3d-meeple.svg file
  static const String $3d_meeple = '3d-meeple.svg';

  /// map constant $3d_stairs to 3d-stairs.svg file
  static const String $3d_stairs = '3d-stairs.svg';

  /// map constant abacus to abacus.svg file
  static const String abacus = 'abacus.svg';

  /// map constant abbot_meeple to abbot-meeple.svg file
  static const String abbot_meeple = 'abbot-meeple.svg';

  /// map constant abdominal_armor to abdominal-armor.svg file
  static const String abdominal_armor = 'abdominal-armor.svg';

  /// map constant abstract_001 to abstract-001.svg file
  static const String abstract_001 = 'abstract-001.svg';

  /// map constant abstract_002 to abstract-002.svg file
  static const String abstract_002 = 'abstract-002.svg';

  /// map constant abstract_003 to abstract-003.svg file
  static const String abstract_003 = 'abstract-003.svg';

  /// map constant abstract_004 to abstract-004.svg file
  static const String abstract_004 = 'abstract-004.svg';

  /// map constant abstract_005 to abstract-005.svg file
  static const String abstract_005 = 'abstract-005.svg';

  /// map constant abstract_006 to abstract-006.svg file
  static const String abstract_006 = 'abstract-006.svg';

  /// map constant abstract_007 to abstract-007.svg file
  static const String abstract_007 = 'abstract-007.svg';

  /// map constant abstract_008 to abstract-008.svg file
  static const String abstract_008 = 'abstract-008.svg';

  /// map constant abstract_009 to abstract-009.svg file
  static const String abstract_009 = 'abstract-009.svg';

  /// map constant abstract_010 to abstract-010.svg file
  static const String abstract_010 = 'abstract-010.svg';

  /// map constant abstract_011 to abstract-011.svg file
  static const String abstract_011 = 'abstract-011.svg';

  /// map constant abstract_012 to abstract-012.svg file
  static const String abstract_012 = 'abstract-012.svg';

  /// map constant abstract_013 to abstract-013.svg file
  static const String abstract_013 = 'abstract-013.svg';

  /// map constant abstract_014 to abstract-014.svg file
  static const String abstract_014 = 'abstract-014.svg';

  /// map constant abstract_015 to abstract-015.svg file
  static const String abstract_015 = 'abstract-015.svg';

  /// map constant abstract_016 to abstract-016.svg file
  static const String abstract_016 = 'abstract-016.svg';

  /// map constant abstract_017 to abstract-017.svg file
  static const String abstract_017 = 'abstract-017.svg';

  /// map constant abstract_018 to abstract-018.svg file
  static const String abstract_018 = 'abstract-018.svg';

  /// map constant abstract_019 to abstract-019.svg file
  static const String abstract_019 = 'abstract-019.svg';

  /// map constant abstract_020 to abstract-020.svg file
  static const String abstract_020 = 'abstract-020.svg';

  /// map constant abstract_021 to abstract-021.svg file
  static const String abstract_021 = 'abstract-021.svg';

  /// map constant abstract_022 to abstract-022.svg file
  static const String abstract_022 = 'abstract-022.svg';

  /// map constant abstract_023 to abstract-023.svg file
  static const String abstract_023 = 'abstract-023.svg';

  /// map constant abstract_024 to abstract-024.svg file
  static const String abstract_024 = 'abstract-024.svg';

  /// map constant abstract_025 to abstract-025.svg file
  static const String abstract_025 = 'abstract-025.svg';

  /// map constant abstract_026 to abstract-026.svg file
  static const String abstract_026 = 'abstract-026.svg';

  /// map constant abstract_027 to abstract-027.svg file
  static const String abstract_027 = 'abstract-027.svg';

  /// map constant abstract_028 to abstract-028.svg file
  static const String abstract_028 = 'abstract-028.svg';

  /// map constant abstract_029 to abstract-029.svg file
  static const String abstract_029 = 'abstract-029.svg';

  /// map constant abstract_030 to abstract-030.svg file
  static const String abstract_030 = 'abstract-030.svg';

  /// map constant abstract_031 to abstract-031.svg file
  static const String abstract_031 = 'abstract-031.svg';

  /// map constant abstract_032 to abstract-032.svg file
  static const String abstract_032 = 'abstract-032.svg';

  /// map constant abstract_033 to abstract-033.svg file
  static const String abstract_033 = 'abstract-033.svg';

  /// map constant abstract_034 to abstract-034.svg file
  static const String abstract_034 = 'abstract-034.svg';

  /// map constant abstract_035 to abstract-035.svg file
  static const String abstract_035 = 'abstract-035.svg';

  /// map constant abstract_036 to abstract-036.svg file
  static const String abstract_036 = 'abstract-036.svg';

  /// map constant abstract_037 to abstract-037.svg file
  static const String abstract_037 = 'abstract-037.svg';

  /// map constant abstract_038 to abstract-038.svg file
  static const String abstract_038 = 'abstract-038.svg';

  /// map constant abstract_039 to abstract-039.svg file
  static const String abstract_039 = 'abstract-039.svg';

  /// map constant abstract_040 to abstract-040.svg file
  static const String abstract_040 = 'abstract-040.svg';

  /// map constant abstract_041 to abstract-041.svg file
  static const String abstract_041 = 'abstract-041.svg';

  /// map constant abstract_042 to abstract-042.svg file
  static const String abstract_042 = 'abstract-042.svg';

  /// map constant abstract_043 to abstract-043.svg file
  static const String abstract_043 = 'abstract-043.svg';

  /// map constant abstract_044 to abstract-044.svg file
  static const String abstract_044 = 'abstract-044.svg';

  /// map constant abstract_045 to abstract-045.svg file
  static const String abstract_045 = 'abstract-045.svg';

  /// map constant abstract_046 to abstract-046.svg file
  static const String abstract_046 = 'abstract-046.svg';

  /// map constant abstract_047 to abstract-047.svg file
  static const String abstract_047 = 'abstract-047.svg';

  /// map constant abstract_048 to abstract-048.svg file
  static const String abstract_048 = 'abstract-048.svg';

  /// map constant abstract_049 to abstract-049.svg file
  static const String abstract_049 = 'abstract-049.svg';

  /// map constant abstract_050 to abstract-050.svg file
  static const String abstract_050 = 'abstract-050.svg';

  /// map constant abstract_051 to abstract-051.svg file
  static const String abstract_051 = 'abstract-051.svg';

  /// map constant abstract_052 to abstract-052.svg file
  static const String abstract_052 = 'abstract-052.svg';

  /// map constant abstract_053 to abstract-053.svg file
  static const String abstract_053 = 'abstract-053.svg';

  /// map constant abstract_054 to abstract-054.svg file
  static const String abstract_054 = 'abstract-054.svg';

  /// map constant abstract_055 to abstract-055.svg file
  static const String abstract_055 = 'abstract-055.svg';

  /// map constant abstract_056 to abstract-056.svg file
  static const String abstract_056 = 'abstract-056.svg';

  /// map constant abstract_057 to abstract-057.svg file
  static const String abstract_057 = 'abstract-057.svg';

  /// map constant abstract_058 to abstract-058.svg file
  static const String abstract_058 = 'abstract-058.svg';

  /// map constant abstract_059 to abstract-059.svg file
  static const String abstract_059 = 'abstract-059.svg';

  /// map constant abstract_060 to abstract-060.svg file
  static const String abstract_060 = 'abstract-060.svg';

  /// map constant abstract_061 to abstract-061.svg file
  static const String abstract_061 = 'abstract-061.svg';

  /// map constant abstract_062 to abstract-062.svg file
  static const String abstract_062 = 'abstract-062.svg';

  /// map constant abstract_063 to abstract-063.svg file
  static const String abstract_063 = 'abstract-063.svg';

  /// map constant abstract_064 to abstract-064.svg file
  static const String abstract_064 = 'abstract-064.svg';

  /// map constant abstract_065 to abstract-065.svg file
  static const String abstract_065 = 'abstract-065.svg';

  /// map constant abstract_066 to abstract-066.svg file
  static const String abstract_066 = 'abstract-066.svg';

  /// map constant abstract_067 to abstract-067.svg file
  static const String abstract_067 = 'abstract-067.svg';

  /// map constant abstract_068 to abstract-068.svg file
  static const String abstract_068 = 'abstract-068.svg';

  /// map constant abstract_069 to abstract-069.svg file
  static const String abstract_069 = 'abstract-069.svg';

  /// map constant abstract_070 to abstract-070.svg file
  static const String abstract_070 = 'abstract-070.svg';

  /// map constant abstract_071 to abstract-071.svg file
  static const String abstract_071 = 'abstract-071.svg';

  /// map constant abstract_072 to abstract-072.svg file
  static const String abstract_072 = 'abstract-072.svg';

  /// map constant abstract_073 to abstract-073.svg file
  static const String abstract_073 = 'abstract-073.svg';

  /// map constant abstract_074 to abstract-074.svg file
  static const String abstract_074 = 'abstract-074.svg';

  /// map constant abstract_075 to abstract-075.svg file
  static const String abstract_075 = 'abstract-075.svg';

  /// map constant abstract_076 to abstract-076.svg file
  static const String abstract_076 = 'abstract-076.svg';

  /// map constant abstract_077 to abstract-077.svg file
  static const String abstract_077 = 'abstract-077.svg';

  /// map constant abstract_078 to abstract-078.svg file
  static const String abstract_078 = 'abstract-078.svg';

  /// map constant abstract_079 to abstract-079.svg file
  static const String abstract_079 = 'abstract-079.svg';

  /// map constant abstract_080 to abstract-080.svg file
  static const String abstract_080 = 'abstract-080.svg';

  /// map constant abstract_081 to abstract-081.svg file
  static const String abstract_081 = 'abstract-081.svg';

  /// map constant abstract_082 to abstract-082.svg file
  static const String abstract_082 = 'abstract-082.svg';

  /// map constant abstract_083 to abstract-083.svg file
  static const String abstract_083 = 'abstract-083.svg';

  /// map constant abstract_084 to abstract-084.svg file
  static const String abstract_084 = 'abstract-084.svg';

  /// map constant abstract_085 to abstract-085.svg file
  static const String abstract_085 = 'abstract-085.svg';

  /// map constant abstract_086 to abstract-086.svg file
  static const String abstract_086 = 'abstract-086.svg';

  /// map constant abstract_087 to abstract-087.svg file
  static const String abstract_087 = 'abstract-087.svg';

  /// map constant abstract_088 to abstract-088.svg file
  static const String abstract_088 = 'abstract-088.svg';

  /// map constant abstract_089 to abstract-089.svg file
  static const String abstract_089 = 'abstract-089.svg';

  /// map constant abstract_090 to abstract-090.svg file
  static const String abstract_090 = 'abstract-090.svg';

  /// map constant abstract_091 to abstract-091.svg file
  static const String abstract_091 = 'abstract-091.svg';

  /// map constant abstract_092 to abstract-092.svg file
  static const String abstract_092 = 'abstract-092.svg';

  /// map constant abstract_093 to abstract-093.svg file
  static const String abstract_093 = 'abstract-093.svg';

  /// map constant abstract_094 to abstract-094.svg file
  static const String abstract_094 = 'abstract-094.svg';

  /// map constant abstract_095 to abstract-095.svg file
  static const String abstract_095 = 'abstract-095.svg';

  /// map constant abstract_096 to abstract-096.svg file
  static const String abstract_096 = 'abstract-096.svg';

  /// map constant abstract_097 to abstract-097.svg file
  static const String abstract_097 = 'abstract-097.svg';

  /// map constant abstract_098 to abstract-098.svg file
  static const String abstract_098 = 'abstract-098.svg';

  /// map constant abstract_099 to abstract-099.svg file
  static const String abstract_099 = 'abstract-099.svg';

  /// map constant abstract_100 to abstract-100.svg file
  static const String abstract_100 = 'abstract-100.svg';

  /// map constant abstract_101 to abstract-101.svg file
  static const String abstract_101 = 'abstract-101.svg';

  /// map constant abstract_102 to abstract-102.svg file
  static const String abstract_102 = 'abstract-102.svg';

  /// map constant abstract_103 to abstract-103.svg file
  static const String abstract_103 = 'abstract-103.svg';

  /// map constant abstract_104 to abstract-104.svg file
  static const String abstract_104 = 'abstract-104.svg';

  /// map constant abstract_105 to abstract-105.svg file
  static const String abstract_105 = 'abstract-105.svg';

  /// map constant abstract_106 to abstract-106.svg file
  static const String abstract_106 = 'abstract-106.svg';

  /// map constant abstract_107 to abstract-107.svg file
  static const String abstract_107 = 'abstract-107.svg';

  /// map constant abstract_108 to abstract-108.svg file
  static const String abstract_108 = 'abstract-108.svg';

  /// map constant abstract_109 to abstract-109.svg file
  static const String abstract_109 = 'abstract-109.svg';

  /// map constant abstract_110 to abstract-110.svg file
  static const String abstract_110 = 'abstract-110.svg';

  /// map constant abstract_111 to abstract-111.svg file
  static const String abstract_111 = 'abstract-111.svg';

  /// map constant abstract_112 to abstract-112.svg file
  static const String abstract_112 = 'abstract-112.svg';

  /// map constant abstract_113 to abstract-113.svg file
  static const String abstract_113 = 'abstract-113.svg';

  /// map constant abstract_114 to abstract-114.svg file
  static const String abstract_114 = 'abstract-114.svg';

  /// map constant abstract_115 to abstract-115.svg file
  static const String abstract_115 = 'abstract-115.svg';

  /// map constant abstract_116 to abstract-116.svg file
  static const String abstract_116 = 'abstract-116.svg';

  /// map constant abstract_117 to abstract-117.svg file
  static const String abstract_117 = 'abstract-117.svg';

  /// map constant abstract_118 to abstract-118.svg file
  static const String abstract_118 = 'abstract-118.svg';

  /// map constant abstract_119 to abstract-119.svg file
  static const String abstract_119 = 'abstract-119.svg';

  /// map constant abstract_120 to abstract-120.svg file
  static const String abstract_120 = 'abstract-120.svg';

  /// map constant abstract_121 to abstract-121.svg file
  static const String abstract_121 = 'abstract-121.svg';

  /// map constant accordion to accordion.svg file
  static const String accordion = 'accordion.svg';

  /// map constant ace to ace.svg file
  static const String ace = 'ace.svg';

  /// map constant achievement to achievement.svg file
  static const String achievement = 'achievement.svg';

  /// map constant achilles_heel to achilles-heel.svg file
  static const String achilles_heel = 'achilles-heel.svg';

  /// map constant acid_blob to acid-blob.svg file
  static const String acid_blob = 'acid-blob.svg';

  /// map constant acid_tube to acid-tube.svg file
  static const String acid_tube = 'acid-tube.svg';

  /// map constant acid to acid.svg file
  static const String acid = 'acid.svg';

  /// map constant acorn to acorn.svg file
  static const String acorn = 'acorn.svg';

  /// map constant acoustic_megaphone to acoustic-megaphone.svg file
  static const String acoustic_megaphone = 'acoustic-megaphone.svg';

  /// map constant acrobatic to acrobatic.svg file
  static const String acrobatic = 'acrobatic.svg';

  /// map constant aerial_signal to aerial-signal.svg file
  static const String aerial_signal = 'aerial-signal.svg';

  /// map constant aerodynamic_harpoon to aerodynamic-harpoon.svg file
  static const String aerodynamic_harpoon = 'aerodynamic-harpoon.svg';

  /// map constant aerosol to aerosol.svg file
  static const String aerosol = 'aerosol.svg';

  /// map constant africa to africa.svg file
  static const String africa = 'africa.svg';

  /// map constant afterburn to afterburn.svg file
  static const String afterburn = 'afterburn.svg';

  /// map constant agave to agave.svg file
  static const String agave = 'agave.svg';

  /// map constant ages to ages.svg file
  static const String ages = 'ages.svg';

  /// map constant air_balloon to air-balloon.svg file
  static const String air_balloon = 'air-balloon.svg';

  /// map constant air_force to air-force.svg file
  static const String air_force = 'air-force.svg';

  /// map constant air_man to air-man.svg file
  static const String air_man = 'air-man.svg';

  /// map constant air_zigzag to air-zigzag.svg file
  static const String air_zigzag = 'air-zigzag.svg';

  /// map constant airplane_arrival to airplane-arrival.svg file
  static const String airplane_arrival = 'airplane-arrival.svg';

  /// map constant airplane_departure to airplane-departure.svg file
  static const String airplane_departure = 'airplane-departure.svg';

  /// map constant airplane to airplane.svg file
  static const String airplane = 'airplane.svg';

  /// map constant airtight_hatch to airtight-hatch.svg file
  static const String airtight_hatch = 'airtight-hatch.svg';

  /// map constant ak47 to ak47.svg file
  static const String ak47 = 'ak47.svg';

  /// map constant ak47u to ak47u.svg file
  static const String ak47u = 'ak47u.svg';

  /// map constant akhet to akhet.svg file
  static const String akhet = 'akhet.svg';

  /// map constant alarm_clock to alarm-clock.svg file
  static const String alarm_clock = 'alarm-clock.svg';

  /// map constant algae to algae.svg file
  static const String algae = 'algae.svg';

  /// map constant algeria to algeria.svg file
  static const String algeria = 'algeria.svg';

  /// map constant alien_bug to alien-bug.svg file
  static const String alien_bug = 'alien-bug.svg';

  /// map constant alien_egg to alien-egg.svg file
  static const String alien_egg = 'alien-egg.svg';

  /// map constant alien_fire to alien-fire.svg file
  static const String alien_fire = 'alien-fire.svg';

  /// map constant alien_skull to alien-skull.svg file
  static const String alien_skull = 'alien-skull.svg';

  /// map constant alien_stare to alien-stare.svg file
  static const String alien_stare = 'alien-stare.svg';

  /// map constant all_for_one to all-for-one.svg file
  static const String all_for_one = 'all-for-one.svg';

  /// map constant all_seeing_eye to all-seeing-eye.svg file
  static const String all_seeing_eye = 'all-seeing-eye.svg';

  /// map constant allied_star to allied-star.svg file
  static const String allied_star = 'allied-star.svg';

  /// map constant alligator_clip to alligator-clip.svg file
  static const String alligator_clip = 'alligator-clip.svg';

  /// map constant almond to almond.svg file
  static const String almond = 'almond.svg';

  /// map constant amber_mosquito to amber-mosquito.svg file
  static const String amber_mosquito = 'amber-mosquito.svg';

  /// map constant ambulance to ambulance.svg file
  static const String ambulance = 'ambulance.svg';

  /// map constant american_football_ball to american-football-ball.svg file
  static const String american_football_ball = 'american-football-ball.svg';

  /// map constant american_football_helmet to american-football-helmet.svg file
  static const String american_football_helmet = 'american-football-helmet.svg';

  /// map constant american_football_player to american-football-player.svg file
  static const String american_football_player = 'american-football-player.svg';

  /// map constant american_shield to american-shield.svg file
  static const String american_shield = 'american-shield.svg';

  /// map constant amethyst to amethyst.svg file
  static const String amethyst = 'amethyst.svg';

  /// map constant ammo_box to ammo-box.svg file
  static const String ammo_box = 'ammo-box.svg';

  /// map constant ammonite_fossil to ammonite-fossil.svg file
  static const String ammonite_fossil = 'ammonite-fossil.svg';

  /// map constant ammonite to ammonite.svg file
  static const String ammonite = 'ammonite.svg';

  /// map constant amphora to amphora.svg file
  static const String amphora = 'amphora.svg';

  /// map constant ample_dress to ample-dress.svg file
  static const String ample_dress = 'ample-dress.svg';

  /// map constant amplitude to amplitude.svg file
  static const String amplitude = 'amplitude.svg';

  /// map constant amputation to amputation.svg file
  static const String amputation = 'amputation.svg';

  /// map constant anarchy to anarchy.svg file
  static const String anarchy = 'anarchy.svg';

  /// map constant anatomy to anatomy.svg file
  static const String anatomy = 'anatomy.svg';

  /// map constant anchor to anchor.svg file
  static const String anchor = 'anchor.svg';

  /// map constant ancient_columns to ancient-columns.svg file
  static const String ancient_columns = 'ancient-columns.svg';

  /// map constant ancient_ruins to ancient-ruins.svg file
  static const String ancient_ruins = 'ancient-ruins.svg';

  /// map constant ancient_screw to ancient-screw.svg file
  static const String ancient_screw = 'ancient-screw.svg';

  /// map constant ancient_sword to ancient-sword.svg file
  static const String ancient_sword = 'ancient-sword.svg';

  /// map constant android_mask to android-mask.svg file
  static const String android_mask = 'android-mask.svg';

  /// map constant andromeda_chain to andromeda-chain.svg file
  static const String andromeda_chain = 'andromeda-chain.svg';

  /// map constant angel_outfit to angel-outfit.svg file
  static const String angel_outfit = 'angel-outfit.svg';

  /// map constant angel_wings to angel-wings.svg file
  static const String angel_wings = 'angel-wings.svg';

  /// map constant angler_fish to angler-fish.svg file
  static const String angler_fish = 'angler-fish.svg';

  /// map constant angola to angola.svg file
  static const String angola = 'angola.svg';

  /// map constant angry_eyes to angry-eyes.svg file
  static const String angry_eyes = 'angry-eyes.svg';

  /// map constant angular_spider to angular-spider.svg file
  static const String angular_spider = 'angular-spider.svg';

  /// map constant animal_hide to animal-hide.svg file
  static const String animal_hide = 'animal-hide.svg';

  /// map constant animal_skull to animal-skull.svg file
  static const String animal_skull = 'animal-skull.svg';

  /// map constant ankh to ankh.svg file
  static const String ankh = 'ankh.svg';

  /// map constant annexation to annexation.svg file
  static const String annexation = 'annexation.svg';

  /// map constant ant to ant.svg file
  static const String ant = 'ant.svg';

  /// map constant antarctica to antarctica.svg file
  static const String antarctica = 'antarctica.svg';

  /// map constant anteater to anteater.svg file
  static const String anteater = 'anteater.svg';

  /// map constant anthem to anthem.svg file
  static const String anthem = 'anthem.svg';

  /// map constant anti_aircraft_gun to anti-aircraft-gun.svg file
  static const String anti_aircraft_gun = 'anti-aircraft-gun.svg';

  /// map constant antibody to antibody.svg file
  static const String antibody = 'antibody.svg';

  /// map constant anticlockwise_rotation to anticlockwise-rotation.svg file
  static const String anticlockwise_rotation = 'anticlockwise-rotation.svg';

  /// map constant ants to ants.svg file
  static const String ants = 'ants.svg';

  /// map constant anubis to anubis.svg file
  static const String anubis = 'anubis.svg';

  /// map constant anvil_impact to anvil-impact.svg file
  static const String anvil_impact = 'anvil-impact.svg';

  /// map constant anvil to anvil.svg file
  static const String anvil = 'anvil.svg';

  /// map constant apc to apc.svg file
  static const String apc = 'apc.svg';

  /// map constant apollo_capsule to apollo-capsule.svg file
  static const String apollo_capsule = 'apollo-capsule.svg';

  /// map constant apothecary to apothecary.svg file
  static const String apothecary = 'apothecary.svg';

  /// map constant apple_core to apple-core.svg file
  static const String apple_core = 'apple-core.svg';

  /// map constant apple_maggot to apple-maggot.svg file
  static const String apple_maggot = 'apple-maggot.svg';

  /// map constant apple_seeds to apple-seeds.svg file
  static const String apple_seeds = 'apple-seeds.svg';

  /// map constant aquarium to aquarium.svg file
  static const String aquarium = 'aquarium.svg';

  /// map constant aquarius to aquarius.svg file
  static const String aquarius = 'aquarius.svg';

  /// map constant aqueduct to aqueduct.svg file
  static const String aqueduct = 'aqueduct.svg';

  /// map constant arabic_door to arabic-door.svg file
  static const String arabic_door = 'arabic-door.svg';

  /// map constant arc_triomphe to arc-triomphe.svg file
  static const String arc_triomphe = 'arc-triomphe.svg';

  /// map constant arch_bridge to arch-bridge.svg file
  static const String arch_bridge = 'arch-bridge.svg';

  /// map constant archaeopteryx_fossil to archaeopteryx-fossil.svg file
  static const String archaeopteryx_fossil = 'archaeopteryx-fossil.svg';

  /// map constant archer to archer.svg file
  static const String archer = 'archer.svg';

  /// map constant archery_target to archery-target.svg file
  static const String archery_target = 'archery-target.svg';

  /// map constant architect_mask to architect-mask.svg file
  static const String architect_mask = 'architect-mask.svg';

  /// map constant archive_register to archive-register.svg file
  static const String archive_register = 'archive-register.svg';

  /// map constant archive_research to archive-research.svg file
  static const String archive_research = 'archive-research.svg';

  /// map constant arcing_bolt to arcing-bolt.svg file
  static const String arcing_bolt = 'arcing-bolt.svg';

  /// map constant arena to arena.svg file
  static const String arena = 'arena.svg';

  /// map constant aries to aries.svg file
  static const String aries = 'aries.svg';

  /// map constant arm_bandage to arm-bandage.svg file
  static const String arm_bandage = 'arm-bandage.svg';

  /// map constant arm_sling to arm-sling.svg file
  static const String arm_sling = 'arm-sling.svg';

  /// map constant arm to arm.svg file
  static const String arm = 'arm.svg';

  /// map constant armadillo_tail to armadillo-tail.svg file
  static const String armadillo_tail = 'armadillo-tail.svg';

  /// map constant armadillo to armadillo.svg file
  static const String armadillo = 'armadillo.svg';

  /// map constant armor_downgrade to armor-downgrade.svg file
  static const String armor_downgrade = 'armor-downgrade.svg';

  /// map constant armor_punch to armor-punch.svg file
  static const String armor_punch = 'armor-punch.svg';

  /// map constant armor_upgrade to armor-upgrade.svg file
  static const String armor_upgrade = 'armor-upgrade.svg';

  /// map constant armor_vest to armor-vest.svg file
  static const String armor_vest = 'armor-vest.svg';

  /// map constant armored_boomerang to armored-boomerang.svg file
  static const String armored_boomerang = 'armored-boomerang.svg';

  /// map constant armored_pants to armored-pants.svg file
  static const String armored_pants = 'armored-pants.svg';

  /// map constant armoured_shell to armoured-shell.svg file
  static const String armoured_shell = 'armoured-shell.svg';

  /// map constant arrest to arrest.svg file
  static const String arrest = 'arrest.svg';

  /// map constant arrow_cluster to arrow-cluster.svg file
  static const String arrow_cluster = 'arrow-cluster.svg';

  /// map constant arrow_cursor to arrow-cursor.svg file
  static const String arrow_cursor = 'arrow-cursor.svg';

  /// map constant arrow_dunk to arrow-dunk.svg file
  static const String arrow_dunk = 'arrow-dunk.svg';

  /// map constant arrow_flights to arrow-flights.svg file
  static const String arrow_flights = 'arrow-flights.svg';

  /// map constant arrow_scope to arrow-scope.svg file
  static const String arrow_scope = 'arrow-scope.svg';

  /// map constant arrow_wings to arrow-wings.svg file
  static const String arrow_wings = 'arrow-wings.svg';

  /// map constant arrowed to arrowed.svg file
  static const String arrowed = 'arrowed.svg';

  /// map constant arrowhead to arrowhead.svg file
  static const String arrowhead = 'arrowhead.svg';

  /// map constant arrows_shield to arrows-shield.svg file
  static const String arrows_shield = 'arrows-shield.svg';

  /// map constant arson to arson.svg file
  static const String arson = 'arson.svg';

  /// map constant artichoke to artichoke.svg file
  static const String artichoke = 'artichoke.svg';

  /// map constant artificial_hive to artificial-hive.svg file
  static const String artificial_hive = 'artificial-hive.svg';

  /// map constant artificial_intelligence to artificial-intelligence.svg file
  static const String artificial_intelligence = 'artificial-intelligence.svg';

  /// map constant artillery_shell to artillery-shell.svg file
  static const String artillery_shell = 'artillery-shell.svg';

  /// map constant ascending_block to ascending-block.svg file
  static const String ascending_block = 'ascending-block.svg';

  /// map constant asian_lantern to asian-lantern.svg file
  static const String asian_lantern = 'asian-lantern.svg';

  /// map constant asparagus to asparagus.svg file
  static const String asparagus = 'asparagus.svg';

  /// map constant aspergillum to aspergillum.svg file
  static const String aspergillum = 'aspergillum.svg';

  /// map constant assassin_pocket to assassin-pocket.svg file
  static const String assassin_pocket = 'assassin-pocket.svg';

  /// map constant asteroid to asteroid.svg file
  static const String asteroid = 'asteroid.svg';

  /// map constant astrolabe to astrolabe.svg file
  static const String astrolabe = 'astrolabe.svg';

  /// map constant astronaut_helmet to astronaut-helmet.svg file
  static const String astronaut_helmet = 'astronaut-helmet.svg';

  /// map constant at_sea to at-sea.svg file
  static const String at_sea = 'at-sea.svg';

  /// map constant atlas to atlas.svg file
  static const String atlas = 'atlas.svg';

  /// map constant atom_core to atom-core.svg file
  static const String atom_core = 'atom-core.svg';

  /// map constant atom to atom.svg file
  static const String atom = 'atom.svg';

  /// map constant atomic_slashes to atomic-slashes.svg file
  static const String atomic_slashes = 'atomic-slashes.svg';

  /// map constant attached_shield to attached-shield.svg file
  static const String attached_shield = 'attached-shield.svg';

  /// map constant aubergine to aubergine.svg file
  static const String aubergine = 'aubergine.svg';

  /// map constant audio_cassette to audio-cassette.svg file
  static const String audio_cassette = 'audio-cassette.svg';

  /// map constant aura to aura.svg file
  static const String aura = 'aura.svg';

  /// map constant australia to australia.svg file
  static const String australia = 'australia.svg';

  /// map constant auto_repair to auto-repair.svg file
  static const String auto_repair = 'auto-repair.svg';

  /// map constant autogun to autogun.svg file
  static const String autogun = 'autogun.svg';

  /// map constant automatic_sas to automatic-sas.svg file
  static const String automatic_sas = 'automatic-sas.svg';

  /// map constant avocado to avocado.svg file
  static const String avocado = 'avocado.svg';

  /// map constant avoidance to avoidance.svg file
  static const String avoidance = 'avoidance.svg';

  /// map constant awareness to awareness.svg file
  static const String awareness = 'awareness.svg';

  /// map constant axe_in_log to axe-in-log.svg file
  static const String axe_in_log = 'axe-in-log.svg';

  /// map constant axe_in_stump to axe-in-stump.svg file
  static const String axe_in_stump = 'axe-in-stump.svg';

  /// map constant axe_swing to axe-swing.svg file
  static const String axe_swing = 'axe-swing.svg';

  /// map constant axe_sword to axe-sword.svg file
  static const String axe_sword = 'axe-sword.svg';

  /// map constant axolotl to axolotl.svg file
  static const String axolotl = 'axolotl.svg';

  /// map constant aztec_calendar_sun to aztec-calendar-sun.svg file
  static const String aztec_calendar_sun = 'aztec-calendar-sun.svg';

  /// map constant azul_flake to azul-flake.svg file
  static const String azul_flake = 'azul-flake.svg';

  /// map constant baby_bottle to baby-bottle.svg file
  static const String baby_bottle = 'baby-bottle.svg';

  /// map constant baby_face to baby-face.svg file
  static const String baby_face = 'baby-face.svg';

  /// map constant babyfoot_players to babyfoot-players.svg file
  static const String babyfoot_players = 'babyfoot-players.svg';

  /// map constant back_forth to back-forth.svg file
  static const String back_forth = 'back-forth.svg';

  /// map constant back_pain to back-pain.svg file
  static const String back_pain = 'back-pain.svg';

  /// map constant backbone_shell to backbone-shell.svg file
  static const String backbone_shell = 'backbone-shell.svg';

  /// map constant backgammon to backgammon.svg file
  static const String backgammon = 'backgammon.svg';

  /// map constant backpack to backpack.svg file
  static const String backpack = 'backpack.svg';

  /// map constant backstab to backstab.svg file
  static const String backstab = 'backstab.svg';

  /// map constant backup to backup.svg file
  static const String backup = 'backup.svg';

  /// map constant backward_time to backward-time.svg file
  static const String backward_time = 'backward-time.svg';

  /// map constant bacon to bacon.svg file
  static const String bacon = 'bacon.svg';

  /// map constant bad_breath to bad-breath.svg file
  static const String bad_breath = 'bad-breath.svg';

  /// map constant bad_gnome to bad-gnome.svg file
  static const String bad_gnome = 'bad-gnome.svg';

  /// map constant badger to badger.svg file
  static const String badger = 'badger.svg';

  /// map constant bagpipes to bagpipes.svg file
  static const String bagpipes = 'bagpipes.svg';

  /// map constant balaclava to balaclava.svg file
  static const String balaclava = 'balaclava.svg';

  /// map constant balkenkreuz to balkenkreuz.svg file
  static const String balkenkreuz = 'balkenkreuz.svg';

  /// map constant ball_glow to ball-glow.svg file
  static const String ball_glow = 'ball-glow.svg';

  /// map constant ball_heart to ball-heart.svg file
  static const String ball_heart = 'ball-heart.svg';

  /// map constant ball_pyramid to ball-pyramid.svg file
  static const String ball_pyramid = 'ball-pyramid.svg';

  /// map constant ballerina_shoes to ballerina-shoes.svg file
  static const String ballerina_shoes = 'ballerina-shoes.svg';

  /// map constant ballista to ballista.svg file
  static const String ballista = 'ballista.svg';

  /// map constant balloon_dog to balloon-dog.svg file
  static const String balloon_dog = 'balloon-dog.svg';

  /// map constant balloons to balloons.svg file
  static const String balloons = 'balloons.svg';

  /// map constant bamboo_fountain to bamboo-fountain.svg file
  static const String bamboo_fountain = 'bamboo-fountain.svg';

  /// map constant bamboo to bamboo.svg file
  static const String bamboo = 'bamboo.svg';

  /// map constant banana_bunch to banana-bunch.svg file
  static const String banana_bunch = 'banana-bunch.svg';

  /// map constant banana_peel to banana-peel.svg file
  static const String banana_peel = 'banana-peel.svg';

  /// map constant banana_peeled to banana-peeled.svg file
  static const String banana_peeled = 'banana-peeled.svg';

  /// map constant banana to banana.svg file
  static const String banana = 'banana.svg';

  /// map constant bandage_roll to bandage-roll.svg file
  static const String bandage_roll = 'bandage-roll.svg';

  /// map constant bandaged to bandaged.svg file
  static const String bandaged = 'bandaged.svg';

  /// map constant bandana to bandana.svg file
  static const String bandana = 'bandana.svg';

  /// map constant bandit to bandit.svg file
  static const String bandit = 'bandit.svg';

  /// map constant banging_gavel to banging-gavel.svg file
  static const String banging_gavel = 'banging-gavel.svg';

  /// map constant banjo to banjo.svg file
  static const String banjo = 'banjo.svg';

  /// map constant bank to bank.svg file
  static const String bank = 'bank.svg';

  /// map constant banknote to banknote.svg file
  static const String banknote = 'banknote.svg';

  /// map constant baobab to baobab.svg file
  static const String baobab = 'baobab.svg';

  /// map constant bar_stool to bar-stool.svg file
  static const String bar_stool = 'bar-stool.svg';

  /// map constant barbarian to barbarian.svg file
  static const String barbarian = 'barbarian.svg';

  /// map constant barbecue to barbecue.svg file
  static const String barbecue = 'barbecue.svg';

  /// map constant barbed_arrow to barbed-arrow.svg file
  static const String barbed_arrow = 'barbed-arrow.svg';

  /// map constant barbed_coil to barbed-coil.svg file
  static const String barbed_coil = 'barbed-coil.svg';

  /// map constant barbed_nails to barbed-nails.svg file
  static const String barbed_nails = 'barbed-nails.svg';

  /// map constant barbed_spear to barbed-spear.svg file
  static const String barbed_spear = 'barbed-spear.svg';

  /// map constant barbed_star to barbed-star.svg file
  static const String barbed_star = 'barbed-star.svg';

  /// map constant barbed_sun to barbed-sun.svg file
  static const String barbed_sun = 'barbed-sun.svg';

  /// map constant barbed_wire to barbed-wire.svg file
  static const String barbed_wire = 'barbed-wire.svg';

  /// map constant barbute to barbute.svg file
  static const String barbute = 'barbute.svg';

  /// map constant barefoot to barefoot.svg file
  static const String barefoot = 'barefoot.svg';

  /// map constant barn_owl to barn-owl.svg file
  static const String barn_owl = 'barn-owl.svg';

  /// map constant barn to barn.svg file
  static const String barn = 'barn.svg';

  /// map constant barracks_tent to barracks-tent.svg file
  static const String barracks_tent = 'barracks-tent.svg';

  /// map constant barracks to barracks.svg file
  static const String barracks = 'barracks.svg';

  /// map constant barrel_leak to barrel-leak.svg file
  static const String barrel_leak = 'barrel-leak.svg';

  /// map constant barrel to barrel.svg file
  static const String barrel = 'barrel.svg';

  /// map constant barricade to barricade.svg file
  static const String barricade = 'barricade.svg';

  /// map constant barrier to barrier.svg file
  static const String barrier = 'barrier.svg';

  /// map constant base_dome to base-dome.svg file
  static const String base_dome = 'base-dome.svg';

  /// map constant baseball_bat to baseball-bat.svg file
  static const String baseball_bat = 'baseball-bat.svg';

  /// map constant baseball_glove to baseball-glove.svg file
  static const String baseball_glove = 'baseball-glove.svg';

  /// map constant basket to basket.svg file
  static const String basket = 'basket.svg';

  /// map constant basketball_ball to basketball-ball.svg file
  static const String basketball_ball = 'basketball-ball.svg';

  /// map constant basketball_basket to basketball-basket.svg file
  static const String basketball_basket = 'basketball-basket.svg';

  /// map constant basketball_jersey to basketball-jersey.svg file
  static const String basketball_jersey = 'basketball-jersey.svg';

  /// map constant basset_hound_head to basset-hound-head.svg file
  static const String basset_hound_head = 'basset-hound-head.svg';

  /// map constant bassoon to bassoon.svg file
  static const String bassoon = 'bassoon.svg';

  /// map constant bastet to bastet.svg file
  static const String bastet = 'bastet.svg';

  /// map constant bat2 to bat 2.svg file
  static const String bat2 = 'bat 2.svg';

  /// map constant bat_blade to bat-blade.svg file
  static const String bat_blade = 'bat-blade.svg';

  /// map constant bat_leth to bat-leth.svg file
  static const String bat_leth = 'bat-leth.svg';

  /// map constant bat_mask to bat-mask.svg file
  static const String bat_mask = 'bat-mask.svg';

  /// map constant bat_wing to bat-wing.svg file
  static const String bat_wing = 'bat-wing.svg';

  /// map constant bat to bat.svg file
  static const String bat = 'bat.svg';

  /// map constant bathtub to bathtub.svg file
  static const String bathtub = 'bathtub.svg';

  /// map constant baton to baton.svg file
  static const String baton = 'baton.svg';

  /// map constant battered_axe to battered-axe.svg file
  static const String battered_axe = 'battered-axe.svg';

  /// map constant batteries to batteries.svg file
  static const String batteries = 'batteries.svg';

  /// map constant battery_0 to battery-0.svg file
  static const String battery_0 = 'battery-0.svg';

  /// map constant battery_100 to battery-100.svg file
  static const String battery_100 = 'battery-100.svg';

  /// map constant battery_25 to battery-25.svg file
  static const String battery_25 = 'battery-25.svg';

  /// map constant battery_50 to battery-50.svg file
  static const String battery_50 = 'battery-50.svg';

  /// map constant battery_75 to battery-75.svg file
  static const String battery_75 = 'battery-75.svg';

  /// map constant battery_minus to battery-minus.svg file
  static const String battery_minus = 'battery-minus.svg';

  /// map constant battery_pack_alt to battery-pack-alt.svg file
  static const String battery_pack_alt = 'battery-pack-alt.svg';

  /// map constant battery_pack to battery-pack.svg file
  static const String battery_pack = 'battery-pack.svg';

  /// map constant battery_plus to battery-plus.svg file
  static const String battery_plus = 'battery-plus.svg';

  /// map constant battle_axe to battle-axe.svg file
  static const String battle_axe = 'battle-axe.svg';

  /// map constant battle_gear to battle-gear.svg file
  static const String battle_gear = 'battle-gear.svg';

  /// map constant battle_mech to battle-mech.svg file
  static const String battle_mech = 'battle-mech.svg';

  /// map constant battle_tank to battle-tank.svg file
  static const String battle_tank = 'battle-tank.svg';

  /// map constant battleship to battleship.svg file
  static const String battleship = 'battleship.svg';

  /// map constant batwing_emblem to batwing-emblem.svg file
  static const String batwing_emblem = 'batwing-emblem.svg';

  /// map constant bayonet to bayonet.svg file
  static const String bayonet = 'bayonet.svg';

  /// map constant beach_bag to beach-bag.svg file
  static const String beach_bag = 'beach-bag.svg';

  /// map constant beach_ball to beach-ball.svg file
  static const String beach_ball = 'beach-ball.svg';

  /// map constant beach_bucket to beach-bucket.svg file
  static const String beach_bucket = 'beach-bucket.svg';

  /// map constant beam_satellite to beam-satellite.svg file
  static const String beam_satellite = 'beam-satellite.svg';

  /// map constant beam_wake to beam-wake.svg file
  static const String beam_wake = 'beam-wake.svg';

  /// map constant beams_aura to beams-aura.svg file
  static const String beams_aura = 'beams-aura.svg';

  /// map constant beanstalk to beanstalk.svg file
  static const String beanstalk = 'beanstalk.svg';

  /// map constant bear_face to bear-face.svg file
  static const String bear_face = 'bear-face.svg';

  /// map constant bear_head to bear-head.svg file
  static const String bear_head = 'bear-head.svg';

  /// map constant beard to beard.svg file
  static const String beard = 'beard.svg';

  /// map constant beast_eye to beast-eye.svg file
  static const String beast_eye = 'beast-eye.svg';

  /// map constant beaver to beaver.svg file
  static const String beaver = 'beaver.svg';

  /// map constant bed_lamp to bed-lamp.svg file
  static const String bed_lamp = 'bed-lamp.svg';

  /// map constant bed to bed.svg file
  static const String bed = 'bed.svg';

  /// map constant bee to bee.svg file
  static const String bee = 'bee.svg';

  /// map constant beech to beech.svg file
  static const String beech = 'beech.svg';

  /// map constant beehive to beehive.svg file
  static const String beehive = 'beehive.svg';

  /// map constant beer_bottle to beer-bottle.svg file
  static const String beer_bottle = 'beer-bottle.svg';

  /// map constant beer_horn to beer-horn.svg file
  static const String beer_horn = 'beer-horn.svg';

  /// map constant beer_stein to beer-stein.svg file
  static const String beer_stein = 'beer-stein.svg';

  /// map constant beet to beet.svg file
  static const String beet = 'beet.svg';

  /// map constant beetle_shell to beetle-shell.svg file
  static const String beetle_shell = 'beetle-shell.svg';

  /// map constant behold to behold.svg file
  static const String behold = 'behold.svg';

  /// map constant belgium to belgium.svg file
  static const String belgium = 'belgium.svg';

  /// map constant bell_pepper to bell-pepper.svg file
  static const String bell_pepper = 'bell-pepper.svg';

  /// map constant bell_shield to bell-shield.svg file
  static const String bell_shield = 'bell-shield.svg';

  /// map constant bellows to bellows.svg file
  static const String bellows = 'bellows.svg';

  /// map constant belt_armor to belt-armor.svg file
  static const String belt_armor = 'belt-armor.svg';

  /// map constant belt_buckles to belt-buckles.svg file
  static const String belt_buckles = 'belt-buckles.svg';

  /// map constant belt to belt.svg file
  static const String belt = 'belt.svg';

  /// map constant berries_bowl to berries-bowl.svg file
  static const String berries_bowl = 'berries-bowl.svg';

  /// map constant berry_bush to berry-bush.svg file
  static const String berry_bush = 'berry-bush.svg';

  /// map constant bestial_fangs to bestial-fangs.svg file
  static const String bestial_fangs = 'bestial-fangs.svg';

  /// map constant beveled_star to beveled-star.svg file
  static const String beveled_star = 'beveled-star.svg';

  /// map constant biceps to biceps.svg file
  static const String biceps = 'biceps.svg';

  /// map constant big_diamond_ring to big-diamond-ring.svg file
  static const String big_diamond_ring = 'big-diamond-ring.svg';

  /// map constant big_egg to big-egg.svg file
  static const String big_egg = 'big-egg.svg';

  /// map constant big_gear to big-gear.svg file
  static const String big_gear = 'big-gear.svg';

  /// map constant big_wave to big-wave.svg file
  static const String big_wave = 'big-wave.svg';

  /// map constant billed_cap to billed-cap.svg file
  static const String billed_cap = 'billed-cap.svg';

  /// map constant bindle to bindle.svg file
  static const String bindle = 'bindle.svg';

  /// map constant binoculars to binoculars.svg file
  static const String binoculars = 'binoculars.svg';

  /// map constant biohazard to biohazard.svg file
  static const String biohazard = 'biohazard.svg';

  /// map constant biplane to biplane.svg file
  static const String biplane = 'biplane.svg';

  /// map constant birch_trees to birch-trees.svg file
  static const String birch_trees = 'birch-trees.svg';

  /// map constant bird_cage to bird-cage.svg file
  static const String bird_cage = 'bird-cage.svg';

  /// map constant bird_claw to bird-claw.svg file
  static const String bird_claw = 'bird-claw.svg';

  /// map constant bird_house to bird-house.svg file
  static const String bird_house = 'bird-house.svg';

  /// map constant bird_limb to bird-limb.svg file
  static const String bird_limb = 'bird-limb.svg';

  /// map constant bird_mask to bird-mask.svg file
  static const String bird_mask = 'bird-mask.svg';

  /// map constant bird_twitter to bird-twitter.svg file
  static const String bird_twitter = 'bird-twitter.svg';

  /// map constant bison to bison.svg file
  static const String bison = 'bison.svg';

  /// map constant black_bar to black-bar.svg file
  static const String black_bar = 'black-bar.svg';

  /// map constant black_belt to black-belt.svg file
  static const String black_belt = 'black-belt.svg';

  /// map constant black_book to black-book.svg file
  static const String black_book = 'black-book.svg';

  /// map constant black_bridge to black-bridge.svg file
  static const String black_bridge = 'black-bridge.svg';

  /// map constant black_flag to black-flag.svg file
  static const String black_flag = 'black-flag.svg';

  /// map constant black_hand_shield to black-hand-shield.svg file
  static const String black_hand_shield = 'black-hand-shield.svg';

  /// map constant black_hole_bolas to black-hole-bolas.svg file
  static const String black_hole_bolas = 'black-hole-bolas.svg';

  /// map constant black_knight_helm to black-knight-helm.svg file
  static const String black_knight_helm = 'black-knight-helm.svg';

  /// map constant black_sea to black-sea.svg file
  static const String black_sea = 'black-sea.svg';

  /// map constant blackball to blackball.svg file
  static const String blackball = 'blackball.svg';

  /// map constant blackcurrant to blackcurrant.svg file
  static const String blackcurrant = 'blackcurrant.svg';

  /// map constant blacksmith to blacksmith.svg file
  static const String blacksmith = 'blacksmith.svg';

  /// map constant blade_bite to blade-bite.svg file
  static const String blade_bite = 'blade-bite.svg';

  /// map constant blade_drag to blade-drag.svg file
  static const String blade_drag = 'blade-drag.svg';

  /// map constant blade_fall to blade-fall.svg file
  static const String blade_fall = 'blade-fall.svg';

  /// map constant blast to blast.svg file
  static const String blast = 'blast.svg';

  /// map constant blaster to blaster.svg file
  static const String blaster = 'blaster.svg';

  /// map constant bleeding_eye to bleeding-eye.svg file
  static const String bleeding_eye = 'bleeding-eye.svg';

  /// map constant bleeding_heart to bleeding-heart.svg file
  static const String bleeding_heart = 'bleeding-heart.svg';

  /// map constant bleeding_wound to bleeding-wound.svg file
  static const String bleeding_wound = 'bleeding-wound.svg';

  /// map constant blender to blender.svg file
  static const String blender = 'blender.svg';

  /// map constant blindfold to blindfold.svg file
  static const String blindfold = 'blindfold.svg';

  /// map constant block_house to block-house.svg file
  static const String block_house = 'block-house.svg';

  /// map constant blood to blood.svg file
  static const String blood = 'blood.svg';

  /// map constant bloody_stash to bloody-stash.svg file
  static const String bloody_stash = 'bloody-stash.svg';

  /// map constant bloody_sword to bloody-sword.svg file
  static const String bloody_sword = 'bloody-sword.svg';

  /// map constant blunderbuss to blunderbuss.svg file
  static const String blunderbuss = 'blunderbuss.svg';

  /// map constant bo to bo.svg file
  static const String bo = 'bo.svg';

  /// map constant boar_ensign to boar-ensign.svg file
  static const String boar_ensign = 'boar-ensign.svg';

  /// map constant boar_tusks to boar-tusks.svg file
  static const String boar_tusks = 'boar-tusks.svg';

  /// map constant boar to boar.svg file
  static const String boar = 'boar.svg';

  /// map constant boarding_pass to boarding-pass.svg file
  static const String boarding_pass = 'boarding-pass.svg';

  /// map constant boat_engine to boat-engine.svg file
  static const String boat_engine = 'boat-engine.svg';

  /// map constant boat_fishing to boat-fishing.svg file
  static const String boat_fishing = 'boat-fishing.svg';

  /// map constant boat_horizon to boat-horizon.svg file
  static const String boat_horizon = 'boat-horizon.svg';

  /// map constant boat_propeller to boat-propeller.svg file
  static const String boat_propeller = 'boat-propeller.svg';

  /// map constant boba to boba.svg file
  static const String boba = 'boba.svg';

  /// map constant body_balance to body-balance.svg file
  static const String body_balance = 'body-balance.svg';

  /// map constant body_height to body-height.svg file
  static const String body_height = 'body-height.svg';

  /// map constant body_swapping to body-swapping.svg file
  static const String body_swapping = 'body-swapping.svg';

  /// map constant boiling_bubbles to boiling-bubbles.svg file
  static const String boiling_bubbles = 'boiling-bubbles.svg';

  /// map constant bok_choy to bok-choy.svg file
  static const String bok_choy = 'bok-choy.svg';

  /// map constant bolas to bolas.svg file
  static const String bolas = 'bolas.svg';

  /// map constant bolivia to bolivia.svg file
  static const String bolivia = 'bolivia.svg';

  /// map constant bolt_bomb to bolt-bomb.svg file
  static const String bolt_bomb = 'bolt-bomb.svg';

  /// map constant bolt_cutter to bolt-cutter.svg file
  static const String bolt_cutter = 'bolt-cutter.svg';

  /// map constant bolt_drop to bolt-drop.svg file
  static const String bolt_drop = 'bolt-drop.svg';

  /// map constant bolt_eye to bolt-eye.svg file
  static const String bolt_eye = 'bolt-eye.svg';

  /// map constant bolt_saw to bolt-saw.svg file
  static const String bolt_saw = 'bolt-saw.svg';

  /// map constant bolt_shield to bolt-shield.svg file
  static const String bolt_shield = 'bolt-shield.svg';

  /// map constant bolt_spell_cast to bolt-spell-cast.svg file
  static const String bolt_spell_cast = 'bolt-spell-cast.svg';

  /// map constant bolter_gun to bolter-gun.svg file
  static const String bolter_gun = 'bolter-gun.svg';

  /// map constant bomber to bomber.svg file
  static const String bomber = 'bomber.svg';

  /// map constant bombing_run to bombing-run.svg file
  static const String bombing_run = 'bombing-run.svg';

  /// map constant bone_gnawer to bone-gnawer.svg file
  static const String bone_gnawer = 'bone-gnawer.svg';

  /// map constant bone_knife2 to bone-knife 2.svg file
  static const String bone_knife2 = 'bone-knife 2.svg';

  /// map constant bone_knife to bone-knife.svg file
  static const String bone_knife = 'bone-knife.svg';

  /// map constant bone_mace to bone-mace.svg file
  static const String bone_mace = 'bone-mace.svg';

  /// map constant bonsai_tree to bonsai-tree.svg file
  static const String bonsai_tree = 'bonsai-tree.svg';

  /// map constant book_aura to book-aura.svg file
  static const String book_aura = 'book-aura.svg';

  /// map constant book_cover2 to book-cover 2.svg file
  static const String book_cover2 = 'book-cover 2.svg';

  /// map constant book_cover to book-cover.svg file
  static const String book_cover = 'book-cover.svg';

  /// map constant book_pile to book-pile.svg file
  static const String book_pile = 'book-pile.svg';

  /// map constant book_storm to book-storm.svg file
  static const String book_storm = 'book-storm.svg';

  /// map constant bookmark to bookmark.svg file
  static const String bookmark = 'bookmark.svg';

  /// map constant bookmarklet to bookmarklet.svg file
  static const String bookmarklet = 'bookmarklet.svg';

  /// map constant bookshelf to bookshelf.svg file
  static const String bookshelf = 'bookshelf.svg';

  /// map constant boombox to boombox.svg file
  static const String boombox = 'boombox.svg';

  /// map constant boomerang_cross to boomerang-cross.svg file
  static const String boomerang_cross = 'boomerang-cross.svg';

  /// map constant boomerang_sun to boomerang-sun.svg file
  static const String boomerang_sun = 'boomerang-sun.svg';

  /// map constant boomerang to boomerang.svg file
  static const String boomerang = 'boomerang.svg';

  /// map constant boot_kick to boot-kick.svg file
  static const String boot_kick = 'boot-kick.svg';

  /// map constant boot_prints to boot-prints.svg file
  static const String boot_prints = 'boot-prints.svg';

  /// map constant boot_stomp to boot-stomp.svg file
  static const String boot_stomp = 'boot-stomp.svg';

  /// map constant boots to boots.svg file
  static const String boots = 'boots.svg';

  /// map constant booze to booze.svg file
  static const String booze = 'booze.svg';

  /// map constant bordered_shield to bordered-shield.svg file
  static const String bordered_shield = 'bordered-shield.svg';

  /// map constant boss_key to boss-key.svg file
  static const String boss_key = 'boss-key.svg';

  /// map constant bottle_cap to bottle-cap.svg file
  static const String bottle_cap = 'bottle-cap.svg';

  /// map constant bottle_vapors to bottle-vapors.svg file
  static const String bottle_vapors = 'bottle-vapors.svg';

  /// map constant bottled_bolt to bottled-bolt.svg file
  static const String bottled_bolt = 'bottled-bolt.svg';

  /// map constant bottled_shadow to bottled-shadow.svg file
  static const String bottled_shadow = 'bottled-shadow.svg';

  /// map constant bottom_right_3d_arrow to bottom-right-3d-arrow.svg file
  static const String bottom_right_3d_arrow = 'bottom-right-3d-arrow.svg';

  /// map constant boulder_dash to boulder-dash.svg file
  static const String boulder_dash = 'boulder-dash.svg';

  /// map constant bouncing_spring to bouncing-spring.svg file
  static const String bouncing_spring = 'bouncing-spring.svg';

  /// map constant bouncing_sword to bouncing-sword.svg file
  static const String bouncing_sword = 'bouncing-sword.svg';

  /// map constant bow_arrow to bow-arrow.svg file
  static const String bow_arrow = 'bow-arrow.svg';

  /// map constant bow_string to bow-string.svg file
  static const String bow_string = 'bow-string.svg';

  /// map constant bow_tie_ribbon to bow-tie-ribbon.svg file
  static const String bow_tie_ribbon = 'bow-tie-ribbon.svg';

  /// map constant bow_tie to bow-tie.svg file
  static const String bow_tie = 'bow-tie.svg';

  /// map constant bowels to bowels.svg file
  static const String bowels = 'bowels.svg';

  /// map constant bowen_knot to bowen-knot.svg file
  static const String bowen_knot = 'bowen-knot.svg';

  /// map constant bowie_knife2 to bowie-knife 2.svg file
  static const String bowie_knife2 = 'bowie-knife 2.svg';

  /// map constant bowie_knife to bowie-knife.svg file
  static const String bowie_knife = 'bowie-knife.svg';

  /// map constant bowl_of_rice to bowl-of-rice.svg file
  static const String bowl_of_rice = 'bowl-of-rice.svg';

  /// map constant bowl_spiral to bowl-spiral.svg file
  static const String bowl_spiral = 'bowl-spiral.svg';

  /// map constant bowling_alley to bowling-alley.svg file
  static const String bowling_alley = 'bowling-alley.svg';

  /// map constant bowling_pin to bowling-pin.svg file
  static const String bowling_pin = 'bowling-pin.svg';

  /// map constant bowling_propulsion to bowling-propulsion.svg file
  static const String bowling_propulsion = 'bowling-propulsion.svg';

  /// map constant bowling_strike to bowling-strike.svg file
  static const String bowling_strike = 'bowling-strike.svg';

  /// map constant bowman to bowman.svg file
  static const String bowman = 'bowman.svg';

  /// map constant box_cutter to box-cutter.svg file
  static const String box_cutter = 'box-cutter.svg';

  /// map constant box_trap to box-trap.svg file
  static const String box_trap = 'box-trap.svg';

  /// map constant box_unpacking to box-unpacking.svg file
  static const String box_unpacking = 'box-unpacking.svg';

  /// map constant boxing_glove_surprise to boxing-glove-surprise.svg file
  static const String boxing_glove_surprise = 'boxing-glove-surprise.svg';

  /// map constant boxing_glove to boxing-glove.svg file
  static const String boxing_glove = 'boxing-glove.svg';

  /// map constant boxing_ring to boxing-ring.svg file
  static const String boxing_ring = 'boxing-ring.svg';

  /// map constant bracer to bracer.svg file
  static const String bracer = 'bracer.svg';

  /// map constant bracers to bracers.svg file
  static const String bracers = 'bracers.svg';

  /// map constant brain_dump to brain-dump.svg file
  static const String brain_dump = 'brain-dump.svg';

  /// map constant brain_freeze to brain-freeze.svg file
  static const String brain_freeze = 'brain-freeze.svg';

  /// map constant brain_leak to brain-leak.svg file
  static const String brain_leak = 'brain-leak.svg';

  /// map constant brain_stem to brain-stem.svg file
  static const String brain_stem = 'brain-stem.svg';

  /// map constant brain_tentacle to brain-tentacle.svg file
  static const String brain_tentacle = 'brain-tentacle.svg';

  /// map constant brain to brain.svg file
  static const String brain = 'brain.svg';

  /// map constant brainstorm to brainstorm.svg file
  static const String brainstorm = 'brainstorm.svg';

  /// map constant branch_arrow to branch-arrow.svg file
  static const String branch_arrow = 'branch-arrow.svg';

  /// map constant brandy_bottle to brandy-bottle.svg file
  static const String brandy_bottle = 'brandy-bottle.svg';

  /// map constant brasero to brasero.svg file
  static const String brasero = 'brasero.svg';

  /// map constant brass_eye to brass-eye.svg file
  static const String brass_eye = 'brass-eye.svg';

  /// map constant brass_knuckles to brass-knuckles.svg file
  static const String brass_knuckles = 'brass-knuckles.svg';

  /// map constant brazil_flag to brazil-flag.svg file
  static const String brazil_flag = 'brazil-flag.svg';

  /// map constant brazil to brazil.svg file
  static const String brazil = 'brazil.svg';

  /// map constant bread_slice to bread-slice.svg file
  static const String bread_slice = 'bread-slice.svg';

  /// map constant bread to bread.svg file
  static const String bread = 'bread.svg';

  /// map constant breaking_chain to breaking-chain.svg file
  static const String breaking_chain = 'breaking-chain.svg';

  /// map constant breastplate to breastplate.svg file
  static const String breastplate = 'breastplate.svg';

  /// map constant brick_pile to brick-pile.svg file
  static const String brick_pile = 'brick-pile.svg';

  /// map constant brick_wall to brick-wall.svg file
  static const String brick_wall = 'brick-wall.svg';

  /// map constant bridge to bridge.svg file
  static const String bridge = 'bridge.svg';

  /// map constant briefcase to briefcase.svg file
  static const String briefcase = 'briefcase.svg';

  /// map constant bright_explosion to bright-explosion.svg file
  static const String bright_explosion = 'bright-explosion.svg';

  /// map constant broad_dagger to broad-dagger.svg file
  static const String broad_dagger = 'broad-dagger.svg';

  /// map constant broadhead_arrow to broadhead-arrow.svg file
  static const String broadhead_arrow = 'broadhead-arrow.svg';

  /// map constant broadsword to broadsword.svg file
  static const String broadsword = 'broadsword.svg';

  /// map constant broccoli to broccoli.svg file
  static const String broccoli = 'broccoli.svg';

  /// map constant brodie_helmet to brodie-helmet.svg file
  static const String brodie_helmet = 'brodie-helmet.svg';

  /// map constant broken_arrow to broken-arrow.svg file
  static const String broken_arrow = 'broken-arrow.svg';

  /// map constant broken_axe to broken-axe.svg file
  static const String broken_axe = 'broken-axe.svg';

  /// map constant broken_bone to broken-bone.svg file
  static const String broken_bone = 'broken-bone.svg';

  /// map constant broken_bottle to broken-bottle.svg file
  static const String broken_bottle = 'broken-bottle.svg';

  /// map constant broken_heart_zone to broken-heart-zone.svg file
  static const String broken_heart_zone = 'broken-heart-zone.svg';

  /// map constant broken_heart to broken-heart.svg file
  static const String broken_heart = 'broken-heart.svg';

  /// map constant broken_pottery to broken-pottery.svg file
  static const String broken_pottery = 'broken-pottery.svg';

  /// map constant broken_ribbon to broken-ribbon.svg file
  static const String broken_ribbon = 'broken-ribbon.svg';

  /// map constant broken_shield to broken-shield.svg file
  static const String broken_shield = 'broken-shield.svg';

  /// map constant broken_skull to broken-skull.svg file
  static const String broken_skull = 'broken-skull.svg';

  /// map constant broken_tablet to broken-tablet.svg file
  static const String broken_tablet = 'broken-tablet.svg';

  /// map constant broken_wall to broken-wall.svg file
  static const String broken_wall = 'broken-wall.svg';

  /// map constant broom to broom.svg file
  static const String broom = 'broom.svg';

  /// map constant brutal_helm to brutal-helm.svg file
  static const String brutal_helm = 'brutal-helm.svg';

  /// map constant brute to brute.svg file
  static const String brute = 'brute.svg';

  /// map constant bubble_field to bubble-field.svg file
  static const String bubble_field = 'bubble-field.svg';

  /// map constant bubbles to bubbles.svg file
  static const String bubbles = 'bubbles.svg';

  /// map constant bubbling_beam to bubbling-beam.svg file
  static const String bubbling_beam = 'bubbling-beam.svg';

  /// map constant bubbling_bowl to bubbling-bowl.svg file
  static const String bubbling_bowl = 'bubbling-bowl.svg';

  /// map constant bubbling_flask to bubbling-flask.svg file
  static const String bubbling_flask = 'bubbling-flask.svg';

  /// map constant bud to bud.svg file
  static const String bud = 'bud.svg';

  /// map constant buffalo_head to buffalo-head.svg file
  static const String buffalo_head = 'buffalo-head.svg';

  /// map constant bug_net to bug-net.svg file
  static const String bug_net = 'bug-net.svg';

  /// map constant bugle_call to bugle-call.svg file
  static const String bugle_call = 'bugle-call.svg';

  /// map constant bulb to bulb.svg file
  static const String bulb = 'bulb.svg';

  /// map constant bulgaria to bulgaria.svg file
  static const String bulgaria = 'bulgaria.svg';

  /// map constant bull_horns to bull-horns.svg file
  static const String bull_horns = 'bull-horns.svg';

  /// map constant bull to bull.svg file
  static const String bull = 'bull.svg';

  /// map constant bulldozer to bulldozer.svg file
  static const String bulldozer = 'bulldozer.svg';

  /// map constant bullet_bill to bullet-bill.svg file
  static const String bullet_bill = 'bullet-bill.svg';

  /// map constant bullet_impacts to bullet-impacts.svg file
  static const String bullet_impacts = 'bullet-impacts.svg';

  /// map constant bullets to bullets.svg file
  static const String bullets = 'bullets.svg';

  /// map constant bullseye to bullseye.svg file
  static const String bullseye = 'bullseye.svg';

  /// map constant bully_minion to bully-minion.svg file
  static const String bully_minion = 'bully-minion.svg';

  /// map constant bundle_grenade to bundle-grenade.svg file
  static const String bundle_grenade = 'bundle-grenade.svg';

  /// map constant bunk_beds to bunk-beds.svg file
  static const String bunk_beds = 'bunk-beds.svg';

  /// map constant bunker_assault to bunker-assault.svg file
  static const String bunker_assault = 'bunker-assault.svg';

  /// map constant bunker to bunker.svg file
  static const String bunker = 'bunker.svg';

  /// map constant bunny_slippers to bunny-slippers.svg file
  static const String bunny_slippers = 'bunny-slippers.svg';

  /// map constant buoy to buoy.svg file
  static const String buoy = 'buoy.svg';

  /// map constant burn to burn.svg file
  static const String burn = 'burn.svg';

  /// map constant burning_blobs to burning-blobs.svg file
  static const String burning_blobs = 'burning-blobs.svg';

  /// map constant burning_book to burning-book.svg file
  static const String burning_book = 'burning-book.svg';

  /// map constant burning_dot to burning-dot.svg file
  static const String burning_dot = 'burning-dot.svg';

  /// map constant burning_embers to burning-embers.svg file
  static const String burning_embers = 'burning-embers.svg';

  /// map constant burning_eye to burning-eye.svg file
  static const String burning_eye = 'burning-eye.svg';

  /// map constant burning_forest to burning-forest.svg file
  static const String burning_forest = 'burning-forest.svg';

  /// map constant burning_meteor to burning-meteor.svg file
  static const String burning_meteor = 'burning-meteor.svg';

  /// map constant burning_passion to burning-passion.svg file
  static const String burning_passion = 'burning-passion.svg';

  /// map constant burning_round_shot to burning-round-shot.svg file
  static const String burning_round_shot = 'burning-round-shot.svg';

  /// map constant burning_skull to burning-skull.svg file
  static const String burning_skull = 'burning-skull.svg';

  /// map constant burning_tree to burning-tree.svg file
  static const String burning_tree = 'burning-tree.svg';

  /// map constant burst_blob to burst-blob.svg file
  static const String burst_blob = 'burst-blob.svg';

  /// map constant bus_doors to bus-doors.svg file
  static const String bus_doors = 'bus-doors.svg';

  /// map constant bus_stop to bus-stop.svg file
  static const String bus_stop = 'bus-stop.svg';

  /// map constant bus to bus.svg file
  static const String bus = 'bus.svg';

  /// map constant butter_toast to butter-toast.svg file
  static const String butter_toast = 'butter-toast.svg';

  /// map constant butter to butter.svg file
  static const String butter = 'butter.svg';

  /// map constant butterfly_flower to butterfly-flower.svg file
  static const String butterfly_flower = 'butterfly-flower.svg';

  /// map constant butterfly_knife2 to butterfly-knife 2.svg file
  static const String butterfly_knife2 = 'butterfly-knife 2.svg';

  /// map constant butterfly_knife to butterfly-knife.svg file
  static const String butterfly_knife = 'butterfly-knife.svg';

  /// map constant butterfly_warning to butterfly-warning.svg file
  static const String butterfly_warning = 'butterfly-warning.svg';

  /// map constant butterfly to butterfly.svg file
  static const String butterfly = 'butterfly.svg';

  /// map constant button_finger to button-finger.svg file
  static const String button_finger = 'button-finger.svg';

  /// map constant buy_card to buy-card.svg file
  static const String buy_card = 'buy-card.svg';

  /// map constant byzantin_temple to byzantin-temple.svg file
  static const String byzantin_temple = 'byzantin-temple.svg';

  /// map constant c96 to c96.svg file
  static const String c96 = 'c96.svg';

  /// map constant cabbage to cabbage.svg file
  static const String cabbage = 'cabbage.svg';

  /// map constant cable_stayed_bridge to cable-stayed-bridge.svg file
  static const String cable_stayed_bridge = 'cable-stayed-bridge.svg';

  /// map constant cactus_pot to cactus-pot.svg file
  static const String cactus_pot = 'cactus-pot.svg';

  /// map constant cactus_tap to cactus-tap.svg file
  static const String cactus_tap = 'cactus-tap.svg';

  /// map constant cactus to cactus.svg file
  static const String cactus = 'cactus.svg';

  /// map constant cadillac_helm to cadillac-helm.svg file
  static const String cadillac_helm = 'cadillac-helm.svg';

  /// map constant caduceus to caduceus.svg file
  static const String caduceus = 'caduceus.svg';

  /// map constant caesar to caesar.svg file
  static const String caesar = 'caesar.svg';

  /// map constant cage to cage.svg file
  static const String cage = 'cage.svg';

  /// map constant caged_ball to caged-ball.svg file
  static const String caged_ball = 'caged-ball.svg';

  /// map constant cake_slice to cake-slice.svg file
  static const String cake_slice = 'cake-slice.svg';

  /// map constant calavera to calavera.svg file
  static const String calavera = 'calavera.svg';

  /// map constant calculator to calculator.svg file
  static const String calculator = 'calculator.svg';

  /// map constant caldera to caldera.svg file
  static const String caldera = 'caldera.svg';

  /// map constant calendar_half_year to calendar-half-year.svg file
  static const String calendar_half_year = 'calendar-half-year.svg';

  /// map constant calendar to calendar.svg file
  static const String calendar = 'calendar.svg';

  /// map constant caltrops to caltrops.svg file
  static const String caltrops = 'caltrops.svg';

  /// map constant camargue_cross to camargue-cross.svg file
  static const String camargue_cross = 'camargue-cross.svg';

  /// map constant cambodia to cambodia.svg file
  static const String cambodia = 'cambodia.svg';

  /// map constant camel_head to camel-head.svg file
  static const String camel_head = 'camel-head.svg';

  /// map constant camel to camel.svg file
  static const String camel = 'camel.svg';

  /// map constant camp_cooking_pot to camp-cooking-pot.svg file
  static const String camp_cooking_pot = 'camp-cooking-pot.svg';

  /// map constant campfire to campfire.svg file
  static const String campfire = 'campfire.svg';

  /// map constant camping_tent to camping-tent.svg file
  static const String camping_tent = 'camping-tent.svg';

  /// map constant canadian_goose to canadian-goose.svg file
  static const String canadian_goose = 'canadian-goose.svg';

  /// map constant cancel to cancel.svg file
  static const String cancel = 'cancel.svg';

  /// map constant cancer to cancer.svg file
  static const String cancer = 'cancer.svg';

  /// map constant candle_flame to candle-flame.svg file
  static const String candle_flame = 'candle-flame.svg';

  /// map constant candle_holder to candle-holder.svg file
  static const String candle_holder = 'candle-holder.svg';

  /// map constant candle_light to candle-light.svg file
  static const String candle_light = 'candle-light.svg';

  /// map constant candle_skull to candle-skull.svg file
  static const String candle_skull = 'candle-skull.svg';

  /// map constant candlebright to candlebright.svg file
  static const String candlebright = 'candlebright.svg';

  /// map constant candles to candles.svg file
  static const String candles = 'candles.svg';

  /// map constant candlestick_phone to candlestick-phone.svg file
  static const String candlestick_phone = 'candlestick-phone.svg';

  /// map constant candy_canes to candy-canes.svg file
  static const String candy_canes = 'candy-canes.svg';

  /// map constant canned_fish to canned-fish.svg file
  static const String canned_fish = 'canned-fish.svg';

  /// map constant cannister to cannister.svg file
  static const String cannister = 'cannister.svg';

  /// map constant cannon_ball to cannon-ball.svg file
  static const String cannon_ball = 'cannon-ball.svg';

  /// map constant cannon_shot to cannon-shot.svg file
  static const String cannon_shot = 'cannon-shot.svg';

  /// map constant cannon to cannon.svg file
  static const String cannon = 'cannon.svg';

  /// map constant canoe to canoe.svg file
  static const String canoe = 'canoe.svg';

  /// map constant cantua to cantua.svg file
  static const String cantua = 'cantua.svg';

  /// map constant cape_armor to cape-armor.svg file
  static const String cape_armor = 'cape-armor.svg';

  /// map constant cape to cape.svg file
  static const String cape = 'cape.svg';

  /// map constant capitol to capitol.svg file
  static const String capitol = 'capitol.svg';

  /// map constant capricorn to capricorn.svg file
  static const String capricorn = 'capricorn.svg';

  /// map constant captain_hat_profile to captain-hat-profile.svg file
  static const String captain_hat_profile = 'captain-hat-profile.svg';

  /// map constant capybara to capybara.svg file
  static const String capybara = 'capybara.svg';

  /// map constant car_battery to car-battery.svg file
  static const String car_battery = 'car-battery.svg';

  /// map constant car_door to car-door.svg file
  static const String car_door = 'car-door.svg';

  /// map constant car_key to car-key.svg file
  static const String car_key = 'car-key.svg';

  /// map constant car_seat to car-seat.svg file
  static const String car_seat = 'car-seat.svg';

  /// map constant car_wheel to car-wheel.svg file
  static const String car_wheel = 'car-wheel.svg';

  /// map constant carabiner to carabiner.svg file
  static const String carabiner = 'carabiner.svg';

  /// map constant carambola to carambola.svg file
  static const String carambola = 'carambola.svg';

  /// map constant caravan to caravan.svg file
  static const String caravan = 'caravan.svg';

  /// map constant caravel to caravel.svg file
  static const String caravel = 'caravel.svg';

  /// map constant card_10_clubs to card-10-clubs.svg file
  static const String card_10_clubs = 'card-10-clubs.svg';

  /// map constant card_10_diamonds to card-10-diamonds.svg file
  static const String card_10_diamonds = 'card-10-diamonds.svg';

  /// map constant card_10_hearts to card-10-hearts.svg file
  static const String card_10_hearts = 'card-10-hearts.svg';

  /// map constant card_10_spades to card-10-spades.svg file
  static const String card_10_spades = 'card-10-spades.svg';

  /// map constant card_2_clubs to card-2-clubs.svg file
  static const String card_2_clubs = 'card-2-clubs.svg';

  /// map constant card_2_diamonds to card-2-diamonds.svg file
  static const String card_2_diamonds = 'card-2-diamonds.svg';

  /// map constant card_2_hearts to card-2-hearts.svg file
  static const String card_2_hearts = 'card-2-hearts.svg';

  /// map constant card_2_spades to card-2-spades.svg file
  static const String card_2_spades = 'card-2-spades.svg';

  /// map constant card_3_clubs to card-3-clubs.svg file
  static const String card_3_clubs = 'card-3-clubs.svg';

  /// map constant card_3_diamonds to card-3-diamonds.svg file
  static const String card_3_diamonds = 'card-3-diamonds.svg';

  /// map constant card_3_hearts to card-3-hearts.svg file
  static const String card_3_hearts = 'card-3-hearts.svg';

  /// map constant card_3_spades to card-3-spades.svg file
  static const String card_3_spades = 'card-3-spades.svg';

  /// map constant card_4_clubs to card-4-clubs.svg file
  static const String card_4_clubs = 'card-4-clubs.svg';

  /// map constant card_4_diamonds to card-4-diamonds.svg file
  static const String card_4_diamonds = 'card-4-diamonds.svg';

  /// map constant card_4_hearts to card-4-hearts.svg file
  static const String card_4_hearts = 'card-4-hearts.svg';

  /// map constant card_4_spades to card-4-spades.svg file
  static const String card_4_spades = 'card-4-spades.svg';

  /// map constant card_5_clubs to card-5-clubs.svg file
  static const String card_5_clubs = 'card-5-clubs.svg';

  /// map constant card_5_diamonds to card-5-diamonds.svg file
  static const String card_5_diamonds = 'card-5-diamonds.svg';

  /// map constant card_5_hearts to card-5-hearts.svg file
  static const String card_5_hearts = 'card-5-hearts.svg';

  /// map constant card_5_spades to card-5-spades.svg file
  static const String card_5_spades = 'card-5-spades.svg';

  /// map constant card_6_clubs to card-6-clubs.svg file
  static const String card_6_clubs = 'card-6-clubs.svg';

  /// map constant card_6_diamonds to card-6-diamonds.svg file
  static const String card_6_diamonds = 'card-6-diamonds.svg';

  /// map constant card_6_hearts to card-6-hearts.svg file
  static const String card_6_hearts = 'card-6-hearts.svg';

  /// map constant card_6_spades to card-6-spades.svg file
  static const String card_6_spades = 'card-6-spades.svg';

  /// map constant card_7_clubs to card-7-clubs.svg file
  static const String card_7_clubs = 'card-7-clubs.svg';

  /// map constant card_7_diamonds to card-7-diamonds.svg file
  static const String card_7_diamonds = 'card-7-diamonds.svg';

  /// map constant card_7_hearts to card-7-hearts.svg file
  static const String card_7_hearts = 'card-7-hearts.svg';

  /// map constant card_7_spades to card-7-spades.svg file
  static const String card_7_spades = 'card-7-spades.svg';

  /// map constant card_8_clubs to card-8-clubs.svg file
  static const String card_8_clubs = 'card-8-clubs.svg';

  /// map constant card_8_diamonds to card-8-diamonds.svg file
  static const String card_8_diamonds = 'card-8-diamonds.svg';

  /// map constant card_8_hearts to card-8-hearts.svg file
  static const String card_8_hearts = 'card-8-hearts.svg';

  /// map constant card_8_spades to card-8-spades.svg file
  static const String card_8_spades = 'card-8-spades.svg';

  /// map constant card_9_clubs to card-9-clubs.svg file
  static const String card_9_clubs = 'card-9-clubs.svg';

  /// map constant card_9_diamonds to card-9-diamonds.svg file
  static const String card_9_diamonds = 'card-9-diamonds.svg';

  /// map constant card_9_hearts to card-9-hearts.svg file
  static const String card_9_hearts = 'card-9-hearts.svg';

  /// map constant card_9_spades to card-9-spades.svg file
  static const String card_9_spades = 'card-9-spades.svg';

  /// map constant card_ace_clubs to card-ace-clubs.svg file
  static const String card_ace_clubs = 'card-ace-clubs.svg';

  /// map constant card_ace_diamonds to card-ace-diamonds.svg file
  static const String card_ace_diamonds = 'card-ace-diamonds.svg';

  /// map constant card_ace_hearts to card-ace-hearts.svg file
  static const String card_ace_hearts = 'card-ace-hearts.svg';

  /// map constant card_ace_spades to card-ace-spades.svg file
  static const String card_ace_spades = 'card-ace-spades.svg';

  /// map constant card_burn to card-burn.svg file
  static const String card_burn = 'card-burn.svg';

  /// map constant card_discard to card-discard.svg file
  static const String card_discard = 'card-discard.svg';

  /// map constant card_draw to card-draw.svg file
  static const String card_draw = 'card-draw.svg';

  /// map constant card_exchange to card-exchange.svg file
  static const String card_exchange = 'card-exchange.svg';

  /// map constant card_jack_clubs to card-jack-clubs.svg file
  static const String card_jack_clubs = 'card-jack-clubs.svg';

  /// map constant card_jack_diamonds to card-jack-diamonds.svg file
  static const String card_jack_diamonds = 'card-jack-diamonds.svg';

  /// map constant card_jack_hearts to card-jack-hearts.svg file
  static const String card_jack_hearts = 'card-jack-hearts.svg';

  /// map constant card_jack_spades to card-jack-spades.svg file
  static const String card_jack_spades = 'card-jack-spades.svg';

  /// map constant card_joker to card-joker.svg file
  static const String card_joker = 'card-joker.svg';

  /// map constant card_king_clubs to card-king-clubs.svg file
  static const String card_king_clubs = 'card-king-clubs.svg';

  /// map constant card_king_diamonds to card-king-diamonds.svg file
  static const String card_king_diamonds = 'card-king-diamonds.svg';

  /// map constant card_king_hearts to card-king-hearts.svg file
  static const String card_king_hearts = 'card-king-hearts.svg';

  /// map constant card_king_spades to card-king-spades.svg file
  static const String card_king_spades = 'card-king-spades.svg';

  /// map constant card_pick to card-pick.svg file
  static const String card_pick = 'card-pick.svg';

  /// map constant card_pickup to card-pickup.svg file
  static const String card_pickup = 'card-pickup.svg';

  /// map constant card_play to card-play.svg file
  static const String card_play = 'card-play.svg';

  /// map constant card_queen_clubs to card-queen-clubs.svg file
  static const String card_queen_clubs = 'card-queen-clubs.svg';

  /// map constant card_queen_diamonds to card-queen-diamonds.svg file
  static const String card_queen_diamonds = 'card-queen-diamonds.svg';

  /// map constant card_queen_hearts to card-queen-hearts.svg file
  static const String card_queen_hearts = 'card-queen-hearts.svg';

  /// map constant card_queen_spades to card-queen-spades.svg file
  static const String card_queen_spades = 'card-queen-spades.svg';

  /// map constant card_random to card-random.svg file
  static const String card_random = 'card-random.svg';

  /// map constant cardboard_box_closed to cardboard-box-closed.svg file
  static const String cardboard_box_closed = 'cardboard-box-closed.svg';

  /// map constant cardboard_box to cardboard-box.svg file
  static const String cardboard_box = 'cardboard-box.svg';

  /// map constant cargo_crane to cargo-crane.svg file
  static const String cargo_crane = 'cargo-crane.svg';

  /// map constant cargo_crate to cargo-crate.svg file
  static const String cargo_crate = 'cargo-crate.svg';

  /// map constant cargo_ship to cargo-ship.svg file
  static const String cargo_ship = 'cargo-ship.svg';

  /// map constant carillon to carillon.svg file
  static const String carillon = 'carillon.svg';

  /// map constant carnival_mask to carnival-mask.svg file
  static const String carnival_mask = 'carnival-mask.svg';

  /// map constant carnivore_mouth to carnivore-mouth.svg file
  static const String carnivore_mouth = 'carnivore-mouth.svg';

  /// map constant carnivorous_plant to carnivorous-plant.svg file
  static const String carnivorous_plant = 'carnivorous-plant.svg';

  /// map constant carnyx to carnyx.svg file
  static const String carnyx = 'carnyx.svg';

  /// map constant carousel to carousel.svg file
  static const String carousel = 'carousel.svg';

  /// map constant carpet_bombing to carpet-bombing.svg file
  static const String carpet_bombing = 'carpet-bombing.svg';

  /// map constant carrier to carrier.svg file
  static const String carrier = 'carrier.svg';

  /// map constant carrion to carrion.svg file
  static const String carrion = 'carrion.svg';

  /// map constant carrot to carrot.svg file
  static const String carrot = 'carrot.svg';

  /// map constant cartwheel to cartwheel.svg file
  static const String cartwheel = 'cartwheel.svg';

  /// map constant cash to cash.svg file
  static const String cash = 'cash.svg';

  /// map constant cassowary_head to cassowary-head.svg file
  static const String cassowary_head = 'cassowary-head.svg';

  /// map constant castle2 to castle 2.svg file
  static const String castle2 = 'castle 2.svg';

  /// map constant castle_ruins to castle-ruins.svg file
  static const String castle_ruins = 'castle-ruins.svg';

  /// map constant castle to castle.svg file
  static const String castle = 'castle.svg';

  /// map constant cat to cat.svg file
  static const String cat = 'cat.svg';

  /// map constant catapult to catapult.svg file
  static const String catapult = 'catapult.svg';

  /// map constant catch_ to catch.svg file
  static const String catch_ = 'catch.svg';

  /// map constant caterpillar to caterpillar.svg file
  static const String caterpillar = 'caterpillar.svg';

  /// map constant cauldron2 to cauldron 2.svg file
  static const String cauldron2 = 'cauldron 2.svg';

  /// map constant cauldron to cauldron.svg file
  static const String cauldron = 'cauldron.svg';

  /// map constant cavalry to cavalry.svg file
  static const String cavalry = 'cavalry.svg';

  /// map constant cave_entrance to cave-entrance.svg file
  static const String cave_entrance = 'cave-entrance.svg';

  /// map constant caveman to caveman.svg file
  static const String caveman = 'caveman.svg';

  /// map constant cctv_camera to cctv-camera.svg file
  static const String cctv_camera = 'cctv-camera.svg';

  /// map constant ceiling_barnacle to ceiling-barnacle.svg file
  static const String ceiling_barnacle = 'ceiling-barnacle.svg';

  /// map constant ceiling_light to ceiling-light.svg file
  static const String ceiling_light = 'ceiling-light.svg';

  /// map constant celebration_fire to celebration-fire.svg file
  static const String celebration_fire = 'celebration-fire.svg';

  /// map constant cellar_barrels to cellar-barrels.svg file
  static const String cellar_barrels = 'cellar-barrels.svg';

  /// map constant cement_shoes to cement-shoes.svg file
  static const String cement_shoes = 'cement-shoes.svg';

  /// map constant centaur_heart to centaur-heart.svg file
  static const String centaur_heart = 'centaur-heart.svg';

  /// map constant centaur to centaur.svg file
  static const String centaur = 'centaur.svg';

  /// map constant centipede to centipede.svg file
  static const String centipede = 'centipede.svg';

  /// map constant centurion_helmet to centurion-helmet.svg file
  static const String centurion_helmet = 'centurion-helmet.svg';

  /// map constant ceremonial_mask to ceremonial-mask.svg file
  static const String ceremonial_mask = 'ceremonial-mask.svg';

  /// map constant chain_lightning to chain-lightning.svg file
  static const String chain_lightning = 'chain-lightning.svg';

  /// map constant chain_mail to chain-mail.svg file
  static const String chain_mail = 'chain-mail.svg';

  /// map constant chained_arrow_heads to chained-arrow-heads.svg file
  static const String chained_arrow_heads = 'chained-arrow-heads.svg';

  /// map constant chained_heart to chained-heart.svg file
  static const String chained_heart = 'chained-heart.svg';

  /// map constant chaingun to chaingun.svg file
  static const String chaingun = 'chaingun.svg';

  /// map constant chainsaw to chainsaw.svg file
  static const String chainsaw = 'chainsaw.svg';

  /// map constant chakram to chakram.svg file
  static const String chakram = 'chakram.svg';

  /// map constant chalice_drops to chalice-drops.svg file
  static const String chalice_drops = 'chalice-drops.svg';

  /// map constant chalk_outline_murder to chalk-outline-murder.svg file
  static const String chalk_outline_murder = 'chalk-outline-murder.svg';

  /// map constant chameleon_glyph to chameleon-glyph.svg file
  static const String chameleon_glyph = 'chameleon-glyph.svg';

  /// map constant champagne_cork to champagne-cork.svg file
  static const String champagne_cork = 'champagne-cork.svg';

  /// map constant champions to champions.svg file
  static const String champions = 'champions.svg';

  /// map constant chanterelles to chanterelles.svg file
  static const String chanterelles = 'chanterelles.svg';

  /// map constant character to character.svg file
  static const String character = 'character.svg';

  /// map constant charcuterie to charcuterie.svg file
  static const String charcuterie = 'charcuterie.svg';

  /// map constant charged_arrow to charged-arrow.svg file
  static const String charged_arrow = 'charged-arrow.svg';

  /// map constant charging_bull to charging-bull.svg file
  static const String charging_bull = 'charging-bull.svg';

  /// map constant charging to charging.svg file
  static const String charging = 'charging.svg';

  /// map constant chariot to chariot.svg file
  static const String chariot = 'chariot.svg';

  /// map constant charm to charm.svg file
  static const String charm = 'charm.svg';

  /// map constant chart to chart.svg file
  static const String chart = 'chart.svg';

  /// map constant chat_bubble to chat-bubble.svg file
  static const String chat_bubble = 'chat-bubble.svg';

  /// map constant check_mark to check-mark.svg file
  static const String check_mark = 'check-mark.svg';

  /// map constant checkbox_tree to checkbox-tree.svg file
  static const String checkbox_tree = 'checkbox-tree.svg';

  /// map constant checked_shield to checked-shield.svg file
  static const String checked_shield = 'checked-shield.svg';

  /// map constant checkered_diamond to checkered-diamond.svg file
  static const String checkered_diamond = 'checkered-diamond.svg';

  /// map constant checkered_flag to checkered-flag.svg file
  static const String checkered_flag = 'checkered-flag.svg';

  /// map constant checklist to checklist.svg file
  static const String checklist = 'checklist.svg';

  /// map constant cheerful to cheerful.svg file
  static const String cheerful = 'cheerful.svg';

  /// map constant cheese_wedge to cheese-wedge.svg file
  static const String cheese_wedge = 'cheese-wedge.svg';

  /// map constant chef_toque to chef-toque.svg file
  static const String chef_toque = 'chef-toque.svg';

  /// map constant chelsea_boot to chelsea-boot.svg file
  static const String chelsea_boot = 'chelsea-boot.svg';

  /// map constant chemical_arrow to chemical-arrow.svg file
  static const String chemical_arrow = 'chemical-arrow.svg';

  /// map constant chemical_bolt to chemical-bolt.svg file
  static const String chemical_bolt = 'chemical-bolt.svg';

  /// map constant chemical_drop to chemical-drop.svg file
  static const String chemical_drop = 'chemical-drop.svg';

  /// map constant chemical_tank to chemical-tank.svg file
  static const String chemical_tank = 'chemical-tank.svg';

  /// map constant cherish to cherish.svg file
  static const String cherish = 'cherish.svg';

  /// map constant cherry to cherry.svg file
  static const String cherry = 'cherry.svg';

  /// map constant chess_bishop to chess-bishop.svg file
  static const String chess_bishop = 'chess-bishop.svg';

  /// map constant chess_king to chess-king.svg file
  static const String chess_king = 'chess-king.svg';

  /// map constant chess_knight to chess-knight.svg file
  static const String chess_knight = 'chess-knight.svg';

  /// map constant chess_pawn to chess-pawn.svg file
  static const String chess_pawn = 'chess-pawn.svg';

  /// map constant chess_queen to chess-queen.svg file
  static const String chess_queen = 'chess-queen.svg';

  /// map constant chess_rook to chess-rook.svg file
  static const String chess_rook = 'chess-rook.svg';

  /// map constant chest_armor to chest-armor.svg file
  static const String chest_armor = 'chest-armor.svg';

  /// map constant chest to chest.svg file
  static const String chest = 'chest.svg';

  /// map constant chestnut_leaf to chestnut-leaf.svg file
  static const String chestnut_leaf = 'chestnut-leaf.svg';

  /// map constant chewed_heart to chewed-heart.svg file
  static const String chewed_heart = 'chewed-heart.svg';

  /// map constant chewed_skull to chewed-skull.svg file
  static const String chewed_skull = 'chewed-skull.svg';

  /// map constant chicken_leg to chicken-leg.svg file
  static const String chicken_leg = 'chicken-leg.svg';

  /// map constant chicken_oven to chicken-oven.svg file
  static const String chicken_oven = 'chicken-oven.svg';

  /// map constant chicken to chicken.svg file
  static const String chicken = 'chicken.svg';

  /// map constant chili_pepper to chili-pepper.svg file
  static const String chili_pepper = 'chili-pepper.svg';

  /// map constant chimney to chimney.svg file
  static const String chimney = 'chimney.svg';

  /// map constant chips_bag to chips-bag.svg file
  static const String chips_bag = 'chips-bag.svg';

  /// map constant chisel to chisel.svg file
  static const String chisel = 'chisel.svg';

  /// map constant chocolate_bar to chocolate-bar.svg file
  static const String chocolate_bar = 'chocolate-bar.svg';

  /// map constant choice to choice.svg file
  static const String choice = 'choice.svg';

  /// map constant chopped_skull to chopped-skull.svg file
  static const String chopped_skull = 'chopped-skull.svg';

  /// map constant chopsticks to chopsticks.svg file
  static const String chopsticks = 'chopsticks.svg';

  /// map constant church to church.svg file
  static const String church = 'church.svg';

  /// map constant cigale to cigale.svg file
  static const String cigale = 'cigale.svg';

  /// map constant cigar to cigar.svg file
  static const String cigar = 'cigar.svg';

  /// map constant cigarette to cigarette.svg file
  static const String cigarette = 'cigarette.svg';

  /// map constant circle_cage to circle-cage.svg file
  static const String circle_cage = 'circle-cage.svg';

  /// map constant circle_claws to circle-claws.svg file
  static const String circle_claws = 'circle-claws.svg';

  /// map constant circle_forest to circle-forest.svg file
  static const String circle_forest = 'circle-forest.svg';

  /// map constant circle_sparks to circle-sparks.svg file
  static const String circle_sparks = 'circle-sparks.svg';

  /// map constant circle to circle.svg file
  static const String circle = 'circle.svg';

  /// map constant circling_fish to circling-fish.svg file
  static const String circling_fish = 'circling-fish.svg';

  /// map constant circuitry to circuitry.svg file
  static const String circuitry = 'circuitry.svg';

  /// map constant circular_saw to circular-saw.svg file
  static const String circular_saw = 'circular-saw.svg';

  /// map constant circular_sawblade to circular-sawblade.svg file
  static const String circular_sawblade = 'circular-sawblade.svg';

  /// map constant city_car to city-car.svg file
  static const String city_car = 'city-car.svg';

  /// map constant clamp to clamp.svg file
  static const String clamp = 'clamp.svg';

  /// map constant clapperboard to clapperboard.svg file
  static const String clapperboard = 'clapperboard.svg';

  /// map constant clarinet to clarinet.svg file
  static const String clarinet = 'clarinet.svg';

  /// map constant classical_knowledge to classical-knowledge.svg file
  static const String classical_knowledge = 'classical-knowledge.svg';

  /// map constant claw_hammer to claw-hammer.svg file
  static const String claw_hammer = 'claw-hammer.svg';

  /// map constant claw_slashes to claw-slashes.svg file
  static const String claw_slashes = 'claw-slashes.svg';

  /// map constant claw_string to claw-string.svg file
  static const String claw_string = 'claw-string.svg';

  /// map constant claw to claw.svg file
  static const String claw = 'claw.svg';

  /// map constant claws to claws.svg file
  static const String claws = 'claws.svg';

  /// map constant clay_brick to clay-brick.svg file
  static const String clay_brick = 'clay-brick.svg';

  /// map constant claymore_explosive to claymore-explosive.svg file
  static const String claymore_explosive = 'claymore-explosive.svg';

  /// map constant cleaver to cleaver.svg file
  static const String cleaver = 'cleaver.svg';

  /// map constant cleopatra to cleopatra.svg file
  static const String cleopatra = 'cleopatra.svg';

  /// map constant click to click.svg file
  static const String click = 'click.svg';

  /// map constant cliff_crossing to cliff-crossing.svg file
  static const String cliff_crossing = 'cliff-crossing.svg';

  /// map constant cloak_dagger to cloak-dagger.svg file
  static const String cloak_dagger = 'cloak-dagger.svg';

  /// map constant cloak to cloak.svg file
  static const String cloak = 'cloak.svg';

  /// map constant cloaked_figure_on_horseback to cloaked-figure-on-horseback.svg file
  static const String cloaked_figure_on_horseback = 'cloaked-figure-on-horseback.svg';

  /// map constant clock_tower to clock-tower.svg file
  static const String clock_tower = 'clock-tower.svg';

  /// map constant clockwise_rotation to clockwise-rotation.svg file
  static const String clockwise_rotation = 'clockwise-rotation.svg';

  /// map constant clockwork to clockwork.svg file
  static const String clockwork = 'clockwork.svg';

  /// map constant closed_barbute to closed-barbute.svg file
  static const String closed_barbute = 'closed-barbute.svg';

  /// map constant closed_doors to closed-doors.svg file
  static const String closed_doors = 'closed-doors.svg';

  /// map constant cloth_jar to cloth-jar.svg file
  static const String cloth_jar = 'cloth-jar.svg';

  /// map constant clothes to clothes.svg file
  static const String clothes = 'clothes.svg';

  /// map constant clothesline to clothesline.svg file
  static const String clothesline = 'clothesline.svg';

  /// map constant clothespin to clothespin.svg file
  static const String clothespin = 'clothespin.svg';

  /// map constant cloud_download to cloud-download.svg file
  static const String cloud_download = 'cloud-download.svg';

  /// map constant cloud_ring to cloud-ring.svg file
  static const String cloud_ring = 'cloud-ring.svg';

  /// map constant cloud_upload to cloud-upload.svg file
  static const String cloud_upload = 'cloud-upload.svg';

  /// map constant cloudy_fork to cloudy-fork.svg file
  static const String cloudy_fork = 'cloudy-fork.svg';

  /// map constant clout to clout.svg file
  static const String clout = 'clout.svg';

  /// map constant clover2 to clover 2.svg file
  static const String clover2 = 'clover 2.svg';

  /// map constant clover_spiked to clover-spiked.svg file
  static const String clover_spiked = 'clover-spiked.svg';

  /// map constant clover to clover.svg file
  static const String clover = 'clover.svg';

  /// map constant clown to clown.svg file
  static const String clown = 'clown.svg';

  /// map constant clownfish to clownfish.svg file
  static const String clownfish = 'clownfish.svg';

  /// map constant clubs to clubs.svg file
  static const String clubs = 'clubs.svg';

  /// map constant cluster_bomb to cluster-bomb.svg file
  static const String cluster_bomb = 'cluster-bomb.svg';

  /// map constant coa_de_jima to coa-de-jima.svg file
  static const String coa_de_jima = 'coa-de-jima.svg';

  /// map constant coal_pile to coal-pile.svg file
  static const String coal_pile = 'coal-pile.svg';

  /// map constant coal_wagon to coal-wagon.svg file
  static const String coal_wagon = 'coal-wagon.svg';

  /// map constant cobra2 to cobra 2.svg file
  static const String cobra2 = 'cobra 2.svg';

  /// map constant cobra to cobra.svg file
  static const String cobra = 'cobra.svg';

  /// map constant cobweb to cobweb.svg file
  static const String cobweb = 'cobweb.svg';

  /// map constant coconuts to coconuts.svg file
  static const String coconuts = 'coconuts.svg';

  /// map constant coffee_beans to coffee-beans.svg file
  static const String coffee_beans = 'coffee-beans.svg';

  /// map constant coffee_cup to coffee-cup.svg file
  static const String coffee_cup = 'coffee-cup.svg';

  /// map constant coffee_mug to coffee-mug.svg file
  static const String coffee_mug = 'coffee-mug.svg';

  /// map constant coffee_pot to coffee-pot.svg file
  static const String coffee_pot = 'coffee-pot.svg';

  /// map constant coffin to coffin.svg file
  static const String coffin = 'coffin.svg';

  /// map constant cog_lock to cog-lock.svg file
  static const String cog_lock = 'cog-lock.svg';

  /// map constant cog to cog.svg file
  static const String cog = 'cog.svg';

  /// map constant cogsplosion to cogsplosion.svg file
  static const String cogsplosion = 'cogsplosion.svg';

  /// map constant coiled_nail to coiled-nail.svg file
  static const String coiled_nail = 'coiled-nail.svg';

  /// map constant coiling_curl to coiling-curl.svg file
  static const String coiling_curl = 'coiling-curl.svg';

  /// map constant coinflip to coinflip.svg file
  static const String coinflip = 'coinflip.svg';

  /// map constant coins_pile to coins-pile.svg file
  static const String coins_pile = 'coins-pile.svg';

  /// map constant coins to coins.svg file
  static const String coins = 'coins.svg';

  /// map constant cold_heart to cold-heart.svg file
  static const String cold_heart = 'cold-heart.svg';

  /// map constant coliseum to coliseum.svg file
  static const String coliseum = 'coliseum.svg';

  /// map constant colombia to colombia.svg file
  static const String colombia = 'colombia.svg';

  /// map constant colombian_statue to colombian-statue.svg file
  static const String colombian_statue = 'colombian-statue.svg';

  /// map constant colt_m1911 to colt-m1911.svg file
  static const String colt_m1911 = 'colt-m1911.svg';

  /// map constant column_vase to column-vase.svg file
  static const String column_vase = 'column-vase.svg';

  /// map constant coma to coma.svg file
  static const String coma = 'coma.svg';

  /// map constant comb to comb.svg file
  static const String comb = 'comb.svg';

  /// map constant combination_lock to combination-lock.svg file
  static const String combination_lock = 'combination-lock.svg';

  /// map constant comet_spark to comet-spark.svg file
  static const String comet_spark = 'comet-spark.svg';

  /// map constant commercial_airplane to commercial-airplane.svg file
  static const String commercial_airplane = 'commercial-airplane.svg';

  /// map constant compact_disc to compact-disc.svg file
  static const String compact_disc = 'compact-disc.svg';

  /// map constant companion_cube to companion-cube.svg file
  static const String companion_cube = 'companion-cube.svg';

  /// map constant compass to compass.svg file
  static const String compass = 'compass.svg';

  /// map constant computer_fan to computer-fan.svg file
  static const String computer_fan = 'computer-fan.svg';

  /// map constant computing to computing.svg file
  static const String computing = 'computing.svg';

  /// map constant concentration_orb to concentration-orb.svg file
  static const String concentration_orb = 'concentration-orb.svg';

  /// map constant concentric_crescents to concentric-crescents.svg file
  static const String concentric_crescents = 'concentric-crescents.svg';

  /// map constant concrete_bag to concrete-bag.svg file
  static const String concrete_bag = 'concrete-bag.svg';

  /// map constant condor_emblem to condor-emblem.svg file
  static const String condor_emblem = 'condor-emblem.svg';

  /// map constant condylura_skull to condylura-skull.svg file
  static const String condylura_skull = 'condylura-skull.svg';

  /// map constant confirmed to confirmed.svg file
  static const String confirmed = 'confirmed.svg';

  /// map constant confrontation to confrontation.svg file
  static const String confrontation = 'confrontation.svg';

  /// map constant congress to congress.svg file
  static const String congress = 'congress.svg';

  /// map constant conqueror to conqueror.svg file
  static const String conqueror = 'conqueror.svg';

  /// map constant console_controller to console-controller.svg file
  static const String console_controller = 'console-controller.svg';

  /// map constant contortionist to contortionist.svg file
  static const String contortionist = 'contortionist.svg';

  /// map constant contract to contract.svg file
  static const String contract = 'contract.svg';

  /// map constant control_tower to control-tower.svg file
  static const String control_tower = 'control-tower.svg';

  /// map constant convergence_target to convergence-target.svg file
  static const String convergence_target = 'convergence-target.svg';

  /// map constant conversation to conversation.svg file
  static const String conversation = 'conversation.svg';

  /// map constant converse_shoe to converse-shoe.svg file
  static const String converse_shoe = 'converse-shoe.svg';

  /// map constant convict to convict.svg file
  static const String convict = 'convict.svg';

  /// map constant convince to convince.svg file
  static const String convince = 'convince.svg';

  /// map constant conway_life_glider to conway-life-glider.svg file
  static const String conway_life_glider = 'conway-life-glider.svg';

  /// map constant cook to cook.svg file
  static const String cook = 'cook.svg';

  /// map constant cookie to cookie.svg file
  static const String cookie = 'cookie.svg';

  /// map constant cooking_glove to cooking-glove.svg file
  static const String cooking_glove = 'cooking-glove.svg';

  /// map constant cooking_pot to cooking-pot.svg file
  static const String cooking_pot = 'cooking-pot.svg';

  /// map constant cool_spices to cool-spices.svg file
  static const String cool_spices = 'cool-spices.svg';

  /// map constant cooler to cooler.svg file
  static const String cooler = 'cooler.svg';

  /// map constant cootie_catcher to cootie-catcher.svg file
  static const String cootie_catcher = 'cootie-catcher.svg';

  /// map constant coral to coral.svg file
  static const String coral = 'coral.svg';

  /// map constant cork_hat to cork-hat.svg file
  static const String cork_hat = 'cork-hat.svg';

  /// map constant corked_tube to corked-tube.svg file
  static const String corked_tube = 'corked-tube.svg';

  /// map constant corkscrew to corkscrew.svg file
  static const String corkscrew = 'corkscrew.svg';

  /// map constant corn to corn.svg file
  static const String corn = 'corn.svg';

  /// map constant corner_explosion to corner-explosion.svg file
  static const String corner_explosion = 'corner-explosion.svg';

  /// map constant corner_flag to corner-flag.svg file
  static const String corner_flag = 'corner-flag.svg';

  /// map constant cornucopia to cornucopia.svg file
  static const String cornucopia = 'cornucopia.svg';

  /// map constant coronation to coronation.svg file
  static const String coronation = 'coronation.svg';

  /// map constant corporal to corporal.svg file
  static const String corporal = 'corporal.svg';

  /// map constant corset to corset.svg file
  static const String corset = 'corset.svg';

  /// map constant corsica to corsica.svg file
  static const String corsica = 'corsica.svg';

  /// map constant cosmic_egg to cosmic-egg.svg file
  static const String cosmic_egg = 'cosmic-egg.svg';

  /// map constant cotton_flower to cotton-flower.svg file
  static const String cotton_flower = 'cotton-flower.svg';

  /// map constant covered_jar to covered-jar.svg file
  static const String covered_jar = 'covered-jar.svg';

  /// map constant cow to cow.svg file
  static const String cow = 'cow.svg';

  /// map constant cowboy_boot to cowboy-boot.svg file
  static const String cowboy_boot = 'cowboy-boot.svg';

  /// map constant cowboy_holster to cowboy-holster.svg file
  static const String cowboy_holster = 'cowboy-holster.svg';

  /// map constant cowled to cowled.svg file
  static const String cowled = 'cowled.svg';

  /// map constant cpu_shot to cpu-shot.svg file
  static const String cpu_shot = 'cpu-shot.svg';

  /// map constant cpu to cpu.svg file
  static const String cpu = 'cpu.svg';

  /// map constant crab_claw to crab-claw.svg file
  static const String crab_claw = 'crab-claw.svg';

  /// map constant crab to crab.svg file
  static const String crab = 'crab.svg';

  /// map constant cracked_alien_skull to cracked-alien-skull.svg file
  static const String cracked_alien_skull = 'cracked-alien-skull.svg';

  /// map constant cracked_ball_dunk to cracked-ball-dunk.svg file
  static const String cracked_ball_dunk = 'cracked-ball-dunk.svg';

  /// map constant cracked_disc to cracked-disc.svg file
  static const String cracked_disc = 'cracked-disc.svg';

  /// map constant cracked_glass to cracked-glass.svg file
  static const String cracked_glass = 'cracked-glass.svg';

  /// map constant cracked_helm to cracked-helm.svg file
  static const String cracked_helm = 'cracked-helm.svg';

  /// map constant cracked_mask to cracked-mask.svg file
  static const String cracked_mask = 'cracked-mask.svg';

  /// map constant cracked_saber to cracked-saber.svg file
  static const String cracked_saber = 'cracked-saber.svg';

  /// map constant cracked_shield to cracked-shield.svg file
  static const String cracked_shield = 'cracked-shield.svg';

  /// map constant crafting to crafting.svg file
  static const String crafting = 'crafting.svg';

  /// map constant crags to crags.svg file
  static const String crags = 'crags.svg';

  /// map constant crane to crane.svg file
  static const String crane = 'crane.svg';

  /// map constant credits_currency to credits-currency.svg file
  static const String credits_currency = 'credits-currency.svg';

  /// map constant crenel_crown to crenel-crown.svg file
  static const String crenel_crown = 'crenel-crown.svg';

  /// map constant crenulated_shield to crenulated-shield.svg file
  static const String crenulated_shield = 'crenulated-shield.svg';

  /// map constant crescent_blade2 to crescent-blade 2.svg file
  static const String crescent_blade2 = 'crescent-blade 2.svg';

  /// map constant crescent_blade to crescent-blade.svg file
  static const String crescent_blade = 'crescent-blade.svg';

  /// map constant crescent_staff to crescent-staff.svg file
  static const String crescent_staff = 'crescent-staff.svg';

  /// map constant crested_helmet to crested-helmet.svg file
  static const String crested_helmet = 'crested-helmet.svg';

  /// map constant cricket_bat to cricket-bat.svg file
  static const String cricket_bat = 'cricket-bat.svg';

  /// map constant cricket to cricket.svg file
  static const String cricket = 'cricket.svg';

  /// map constant crime_scene_tape to crime-scene-tape.svg file
  static const String crime_scene_tape = 'crime-scene-tape.svg';

  /// map constant croc_jaws to croc-jaws.svg file
  static const String croc_jaws = 'croc-jaws.svg';

  /// map constant croc_sword to croc-sword.svg file
  static const String croc_sword = 'croc-sword.svg';

  /// map constant croissant to croissant.svg file
  static const String croissant = 'croissant.svg';

  /// map constant croissants_pupil to croissants-pupil.svg file
  static const String croissants_pupil = 'croissants-pupil.svg';

  /// map constant crook_flail to crook-flail.svg file
  static const String crook_flail = 'crook-flail.svg';

  /// map constant cross_flare to cross-flare.svg file
  static const String cross_flare = 'cross-flare.svg';

  /// map constant cross_mark to cross-mark.svg file
  static const String cross_mark = 'cross-mark.svg';

  /// map constant cross_shield to cross-shield.svg file
  static const String cross_shield = 'cross-shield.svg';

  /// map constant crossbow to crossbow.svg file
  static const String crossbow = 'crossbow.svg';

  /// map constant crosscut_saw to crosscut-saw.svg file
  static const String crosscut_saw = 'crosscut-saw.svg';

  /// map constant crossed_air_flows to crossed-air-flows.svg file
  static const String crossed_air_flows = 'crossed-air-flows.svg';

  /// map constant crossed_axes to crossed-axes.svg file
  static const String crossed_axes = 'crossed-axes.svg';

  /// map constant crossed_bones to crossed-bones.svg file
  static const String crossed_bones = 'crossed-bones.svg';

  /// map constant crossed_chains to crossed-chains.svg file
  static const String crossed_chains = 'crossed-chains.svg';

  /// map constant crossed_claws to crossed-claws.svg file
  static const String crossed_claws = 'crossed-claws.svg';

  /// map constant crossed_pistols to crossed-pistols.svg file
  static const String crossed_pistols = 'crossed-pistols.svg';

  /// map constant crossed_sabres to crossed-sabres.svg file
  static const String crossed_sabres = 'crossed-sabres.svg';

  /// map constant crossed_slashes to crossed-slashes.svg file
  static const String crossed_slashes = 'crossed-slashes.svg';

  /// map constant crossed_swords to crossed-swords.svg file
  static const String crossed_swords = 'crossed-swords.svg';

  /// map constant crosshair_arrow to crosshair-arrow.svg file
  static const String crosshair_arrow = 'crosshair-arrow.svg';

  /// map constant crosshair to crosshair.svg file
  static const String crosshair = 'crosshair.svg';

  /// map constant crossroad to crossroad.svg file
  static const String crossroad = 'crossroad.svg';

  /// map constant crow_dive to crow-dive.svg file
  static const String crow_dive = 'crow-dive.svg';

  /// map constant crow_nest to crow-nest.svg file
  static const String crow_nest = 'crow-nest.svg';

  /// map constant crowbar to crowbar.svg file
  static const String crowbar = 'crowbar.svg';

  /// map constant crown_coin to crown-coin.svg file
  static const String crown_coin = 'crown-coin.svg';

  /// map constant crown_of_thorns to crown-of-thorns.svg file
  static const String crown_of_thorns = 'crown-of-thorns.svg';

  /// map constant crown to crown.svg file
  static const String crown = 'crown.svg';

  /// map constant crowned_explosion to crowned-explosion.svg file
  static const String crowned_explosion = 'crowned-explosion.svg';

  /// map constant crowned_heart to crowned-heart.svg file
  static const String crowned_heart = 'crowned-heart.svg';

  /// map constant crowned_skull to crowned-skull.svg file
  static const String crowned_skull = 'crowned-skull.svg';

  /// map constant crucifix to crucifix.svg file
  static const String crucifix = 'crucifix.svg';

  /// map constant cruiser to cruiser.svg file
  static const String cruiser = 'cruiser.svg';

  /// map constant crumbling_ball to crumbling-ball.svg file
  static const String crumbling_ball = 'crumbling-ball.svg';

  /// map constant crush to crush.svg file
  static const String crush = 'crush.svg';

  /// map constant cryo_chamber to cryo-chamber.svg file
  static const String cryo_chamber = 'cryo-chamber.svg';

  /// map constant crypt_entrance to crypt-entrance.svg file
  static const String crypt_entrance = 'crypt-entrance.svg';

  /// map constant crystal_ball to crystal-ball.svg file
  static const String crystal_ball = 'crystal-ball.svg';

  /// map constant crystal_bars to crystal-bars.svg file
  static const String crystal_bars = 'crystal-bars.svg';

  /// map constant crystal_cluster to crystal-cluster.svg file
  static const String crystal_cluster = 'crystal-cluster.svg';

  /// map constant crystal_earrings to crystal-earrings.svg file
  static const String crystal_earrings = 'crystal-earrings.svg';

  /// map constant crystal_eye to crystal-eye.svg file
  static const String crystal_eye = 'crystal-eye.svg';

  /// map constant crystal_growth to crystal-growth.svg file
  static const String crystal_growth = 'crystal-growth.svg';

  /// map constant crystal_shine to crystal-shine.svg file
  static const String crystal_shine = 'crystal-shine.svg';

  /// map constant crystal_shrine to crystal-shrine.svg file
  static const String crystal_shrine = 'crystal-shrine.svg';

  /// map constant crystal_wand to crystal-wand.svg file
  static const String crystal_wand = 'crystal-wand.svg';

  /// map constant crystalize to crystalize.svg file
  static const String crystalize = 'crystalize.svg';

  /// map constant cuauhtli to cuauhtli.svg file
  static const String cuauhtli = 'cuauhtli.svg';

  /// map constant cube to cube.svg file
  static const String cube = 'cube.svg';

  /// map constant cubeforce to cubeforce.svg file
  static const String cubeforce = 'cubeforce.svg';

  /// map constant cubes to cubes.svg file
  static const String cubes = 'cubes.svg';

  /// map constant cuckoo_clock to cuckoo-clock.svg file
  static const String cuckoo_clock = 'cuckoo-clock.svg';

  /// map constant cultist2 to cultist 2.svg file
  static const String cultist2 = 'cultist 2.svg';

  /// map constant cultist to cultist.svg file
  static const String cultist = 'cultist.svg';

  /// map constant cupcake to cupcake.svg file
  static const String cupcake = 'cupcake.svg';

  /// map constant cupidon_arrow to cupidon-arrow.svg file
  static const String cupidon_arrow = 'cupidon-arrow.svg';

  /// map constant curled_leaf to curled-leaf.svg file
  static const String curled_leaf = 'curled-leaf.svg';

  /// map constant curled_tentacle to curled-tentacle.svg file
  static const String curled_tentacle = 'curled-tentacle.svg';

  /// map constant curling_stone to curling-stone.svg file
  static const String curling_stone = 'curling-stone.svg';

  /// map constant curling_vines to curling-vines.svg file
  static const String curling_vines = 'curling-vines.svg';

  /// map constant curly_mask to curly-mask.svg file
  static const String curly_mask = 'curly-mask.svg';

  /// map constant curly_wing to curly-wing.svg file
  static const String curly_wing = 'curly-wing.svg';

  /// map constant cursed_star to cursed-star.svg file
  static const String cursed_star = 'cursed-star.svg';

  /// map constant curvy_knife to curvy-knife.svg file
  static const String curvy_knife = 'curvy-knife.svg';

  /// map constant custodian_helmet to custodian-helmet.svg file
  static const String custodian_helmet = 'custodian-helmet.svg';

  /// map constant cut_diamond to cut-diamond.svg file
  static const String cut_diamond = 'cut-diamond.svg';

  /// map constant cut_lemon to cut-lemon.svg file
  static const String cut_lemon = 'cut-lemon.svg';

  /// map constant cut_palm to cut-palm.svg file
  static const String cut_palm = 'cut-palm.svg';

  /// map constant cyber_eye to cyber-eye.svg file
  static const String cyber_eye = 'cyber-eye.svg';

  /// map constant cyborg_face to cyborg-face.svg file
  static const String cyborg_face = 'cyborg-face.svg';

  /// map constant cycle to cycle.svg file
  static const String cycle = 'cycle.svg';

  /// map constant cycling to cycling.svg file
  static const String cycling = 'cycling.svg';

  /// map constant cyclops to cyclops.svg file
  static const String cyclops = 'cyclops.svg';

  /// map constant cz_skorpion to cz-skorpion.svg file
  static const String cz_skorpion = 'cz-skorpion.svg';

  /// map constant d10 to d10.svg file
  static const String d10 = 'd10.svg';

  /// map constant d12 to d12.svg file
  static const String d12 = 'd12.svg';

  /// map constant d4 to d4.svg file
  static const String d4 = 'd4.svg';

  /// map constant daemon_pull to daemon-pull.svg file
  static const String daemon_pull = 'daemon-pull.svg';

  /// map constant daemon_skull to daemon-skull.svg file
  static const String daemon_skull = 'daemon-skull.svg';

  /// map constant dagger_rose to dagger-rose.svg file
  static const String dagger_rose = 'dagger-rose.svg';

  /// map constant daggers to daggers.svg file
  static const String daggers = 'daggers.svg';

  /// map constant daisy to daisy.svg file
  static const String daisy = 'daisy.svg';

  /// map constant dam to dam.svg file
  static const String dam = 'dam.svg';

  /// map constant damaged_house to damaged-house.svg file
  static const String damaged_house = 'damaged-house.svg';

  /// map constant dandelion_flower to dandelion-flower.svg file
  static const String dandelion_flower = 'dandelion-flower.svg';

  /// map constant dango to dango.svg file
  static const String dango = 'dango.svg';

  /// map constant dark_squad to dark-squad.svg file
  static const String dark_squad = 'dark-squad.svg';

  /// map constant dart to dart.svg file
  static const String dart = 'dart.svg';

  /// map constant database to database.svg file
  static const String database = 'database.svg';

  /// map constant dead_eye to dead-eye.svg file
  static const String dead_eye = 'dead-eye.svg';

  /// map constant dead_head to dead-head.svg file
  static const String dead_head = 'dead-head.svg';

  /// map constant dead_wood to dead-wood.svg file
  static const String dead_wood = 'dead-wood.svg';

  /// map constant deadly_strike to deadly-strike.svg file
  static const String deadly_strike = 'deadly-strike.svg';

  /// map constant death_juice to death-juice.svg file
  static const String death_juice = 'death-juice.svg';

  /// map constant death_note to death-note.svg file
  static const String death_note = 'death-note.svg';

  /// map constant death_skull to death-skull.svg file
  static const String death_skull = 'death-skull.svg';

  /// map constant death_star to death-star.svg file
  static const String death_star = 'death-star.svg';

  /// map constant death_zone to death-zone.svg file
  static const String death_zone = 'death-zone.svg';

  /// map constant deathcab to deathcab.svg file
  static const String deathcab = 'deathcab.svg';

  /// map constant decapitation to decapitation.svg file
  static const String decapitation = 'decapitation.svg';

  /// map constant deer_head to deer-head.svg file
  static const String deer_head = 'deer-head.svg';

  /// map constant deer_track to deer-track.svg file
  static const String deer_track = 'deer-track.svg';

  /// map constant deer to deer.svg file
  static const String deer = 'deer.svg';

  /// map constant defense_satellite to defense-satellite.svg file
  static const String defense_satellite = 'defense-satellite.svg';

  /// map constant defensive_wall to defensive-wall.svg file
  static const String defensive_wall = 'defensive-wall.svg';

  /// map constant defibrilate to defibrilate.svg file
  static const String defibrilate = 'defibrilate.svg';

  /// map constant deku_tree to deku-tree.svg file
  static const String deku_tree = 'deku-tree.svg';

  /// map constant delicate_perfume to delicate-perfume.svg file
  static const String delicate_perfume = 'delicate-perfume.svg';

  /// map constant delighted to delighted.svg file
  static const String delighted = 'delighted.svg';

  /// map constant delivery_drone to delivery-drone.svg file
  static const String delivery_drone = 'delivery-drone.svg';

  /// map constant demolish to demolish.svg file
  static const String demolish = 'demolish.svg';

  /// map constant dervish_swords to dervish-swords.svg file
  static const String dervish_swords = 'dervish-swords.svg';

  /// map constant desert_camp to desert-camp.svg file
  static const String desert_camp = 'desert-camp.svg';

  /// map constant desert_eagle to desert-eagle.svg file
  static const String desert_eagle = 'desert-eagle.svg';

  /// map constant desert_skull to desert-skull.svg file
  static const String desert_skull = 'desert-skull.svg';

  /// map constant desert to desert.svg file
  static const String desert = 'desert.svg';

  /// map constant deshret_red_crown to deshret-red-crown.svg file
  static const String deshret_red_crown = 'deshret-red-crown.svg';

  /// map constant desk_lamp to desk-lamp.svg file
  static const String desk_lamp = 'desk-lamp.svg';

  /// map constant desk to desk.svg file
  static const String desk = 'desk.svg';

  /// map constant despair to despair.svg file
  static const String despair = 'despair.svg';

  /// map constant detonator to detonator.svg file
  static const String detonator = 'detonator.svg';

  /// map constant detour to detour.svg file
  static const String detour = 'detour.svg';

  /// map constant devil_mask to devil-mask.svg file
  static const String devil_mask = 'devil-mask.svg';

  /// map constant dew to dew.svg file
  static const String dew = 'dew.svg';

  /// map constant diablo_skull to diablo-skull.svg file
  static const String diablo_skull = 'diablo-skull.svg';

  /// map constant diagram to diagram.svg file
  static const String diagram = 'diagram.svg';

  /// map constant dial_padlock to dial-padlock.svg file
  static const String dial_padlock = 'dial-padlock.svg';

  /// map constant diamond_hard to diamond-hard.svg file
  static const String diamond_hard = 'diamond-hard.svg';

  /// map constant diamond_hilt to diamond-hilt.svg file
  static const String diamond_hilt = 'diamond-hilt.svg';

  /// map constant diamond_ring to diamond-ring.svg file
  static const String diamond_ring = 'diamond-ring.svg';

  /// map constant diamond_trophy to diamond-trophy.svg file
  static const String diamond_trophy = 'diamond-trophy.svg';

  /// map constant diamonds_smile to diamonds-smile.svg file
  static const String diamonds_smile = 'diamonds-smile.svg';

  /// map constant diamonds to diamonds.svg file
  static const String diamonds = 'diamonds.svg';

  /// map constant dice_eight_faces_eight to dice-eight-faces-eight.svg file
  static const String dice_eight_faces_eight = 'dice-eight-faces-eight.svg';

  /// map constant dice_fire to dice-fire.svg file
  static const String dice_fire = 'dice-fire.svg';

  /// map constant dice_shield to dice-shield.svg file
  static const String dice_shield = 'dice-shield.svg';

  /// map constant dice_six_faces_five to dice-six-faces-five.svg file
  static const String dice_six_faces_five = 'dice-six-faces-five.svg';

  /// map constant dice_six_faces_four to dice-six-faces-four.svg file
  static const String dice_six_faces_four = 'dice-six-faces-four.svg';

  /// map constant dice_six_faces_one to dice-six-faces-one.svg file
  static const String dice_six_faces_one = 'dice-six-faces-one.svg';

  /// map constant dice_six_faces_six to dice-six-faces-six.svg file
  static const String dice_six_faces_six = 'dice-six-faces-six.svg';

  /// map constant dice_six_faces_three to dice-six-faces-three.svg file
  static const String dice_six_faces_three = 'dice-six-faces-three.svg';

  /// map constant dice_six_faces_two to dice-six-faces-two.svg file
  static const String dice_six_faces_two = 'dice-six-faces-two.svg';

  /// map constant dice_target to dice-target.svg file
  static const String dice_target = 'dice-target.svg';

  /// map constant dice_twenty_faces_one to dice-twenty-faces-one.svg file
  static const String dice_twenty_faces_one = 'dice-twenty-faces-one.svg';

  /// map constant dice_twenty_faces_twenty to dice-twenty-faces-twenty.svg file
  static const String dice_twenty_faces_twenty = 'dice-twenty-faces-twenty.svg';

  /// map constant dig_dug to dig-dug.svg file
  static const String dig_dug = 'dig-dug.svg';

  /// map constant dig_hole to dig-hole.svg file
  static const String dig_hole = 'dig-hole.svg';

  /// map constant digital_trace to digital-trace.svg file
  static const String digital_trace = 'digital-trace.svg';

  /// map constant dimetrodon to dimetrodon.svg file
  static const String dimetrodon = 'dimetrodon.svg';

  /// map constant dinosaur_bones to dinosaur-bones.svg file
  static const String dinosaur_bones = 'dinosaur-bones.svg';

  /// map constant dinosaur_egg to dinosaur-egg.svg file
  static const String dinosaur_egg = 'dinosaur-egg.svg';

  /// map constant dinosaur_rex to dinosaur-rex.svg file
  static const String dinosaur_rex = 'dinosaur-rex.svg';

  /// map constant diplodocus to diplodocus.svg file
  static const String diplodocus = 'diplodocus.svg';

  /// map constant diploma to diploma.svg file
  static const String diploma = 'diploma.svg';

  /// map constant direction_sign to direction-sign.svg file
  static const String direction_sign = 'direction-sign.svg';

  /// map constant direction_signs to direction-signs.svg file
  static const String direction_signs = 'direction-signs.svg';

  /// map constant director_chair to director-chair.svg file
  static const String director_chair = 'director-chair.svg';

  /// map constant direwolf to direwolf.svg file
  static const String direwolf = 'direwolf.svg';

  /// map constant disc_golf_bag to disc-golf-bag.svg file
  static const String disc_golf_bag = 'disc-golf-bag.svg';

  /// map constant disc_golf_basket to disc-golf-basket.svg file
  static const String disc_golf_basket = 'disc-golf-basket.svg';

  /// map constant disc to disc.svg file
  static const String disc = 'disc.svg';

  /// map constant discobolus to discobolus.svg file
  static const String discobolus = 'discobolus.svg';

  /// map constant discussion to discussion.svg file
  static const String discussion = 'discussion.svg';

  /// map constant disintegrate to disintegrate.svg file
  static const String disintegrate = 'disintegrate.svg';

  /// map constant distraction2 to distraction 2.svg file
  static const String distraction2 = 'distraction 2.svg';

  /// map constant distraction to distraction.svg file
  static const String distraction = 'distraction.svg';

  /// map constant distress_signal to distress-signal.svg file
  static const String distress_signal = 'distress-signal.svg';

  /// map constant divergence to divergence.svg file
  static const String divergence = 'divergence.svg';

  /// map constant divert to divert.svg file
  static const String divert = 'divert.svg';

  /// map constant divided_spiral to divided-spiral.svg file
  static const String divided_spiral = 'divided-spiral.svg';

  /// map constant divided_square to divided-square.svg file
  static const String divided_square = 'divided-square.svg';

  /// map constant diving_dagger to diving-dagger.svg file
  static const String diving_dagger = 'diving-dagger.svg';

  /// map constant diving_helmet to diving-helmet.svg file
  static const String diving_helmet = 'diving-helmet.svg';

  /// map constant djed_pillar to djed-pillar.svg file
  static const String djed_pillar = 'djed-pillar.svg';

  /// map constant djembe to djembe.svg file
  static const String djembe = 'djembe.svg';

  /// map constant djinn to djinn.svg file
  static const String djinn = 'djinn.svg';

  /// map constant dna1 to dna1.svg file
  static const String dna1 = 'dna1.svg';

  /// map constant dna2 to dna2.svg file
  static const String dna2 = 'dna2.svg';

  /// map constant doctor_face to doctor-face.svg file
  static const String doctor_face = 'doctor-face.svg';

  /// map constant dodge to dodge.svg file
  static const String dodge = 'dodge.svg';

  /// map constant dodging to dodging.svg file
  static const String dodging = 'dodging.svg';

  /// map constant dog_bowl to dog-bowl.svg file
  static const String dog_bowl = 'dog-bowl.svg';

  /// map constant dog_house to dog-house.svg file
  static const String dog_house = 'dog-house.svg';

  /// map constant dolmen to dolmen.svg file
  static const String dolmen = 'dolmen.svg';

  /// map constant dolphin to dolphin.svg file
  static const String dolphin = 'dolphin.svg';

  /// map constant domino_mask to domino-mask.svg file
  static const String domino_mask = 'domino-mask.svg';

  /// map constant domino_tiles to domino-tiles.svg file
  static const String domino_tiles = 'domino-tiles.svg';

  /// map constant doner_kebab to doner-kebab.svg file
  static const String doner_kebab = 'doner-kebab.svg';

  /// map constant donkey to donkey.svg file
  static const String donkey = 'donkey.svg';

  /// map constant donut to donut.svg file
  static const String donut = 'donut.svg';

  /// map constant door_handle to door-handle.svg file
  static const String door_handle = 'door-handle.svg';

  /// map constant door_ring_handle to door-ring-handle.svg file
  static const String door_ring_handle = 'door-ring-handle.svg';

  /// map constant door_watcher to door-watcher.svg file
  static const String door_watcher = 'door-watcher.svg';

  /// map constant door to door.svg file
  static const String door = 'door.svg';

  /// map constant doorway to doorway.svg file
  static const String doorway = 'doorway.svg';

  /// map constant dorsal_scales to dorsal-scales.svg file
  static const String dorsal_scales = 'dorsal-scales.svg';

  /// map constant double_diaphragm to double-diaphragm.svg file
  static const String double_diaphragm = 'double-diaphragm.svg';

  /// map constant double_dragon to double-dragon.svg file
  static const String double_dragon = 'double-dragon.svg';

  /// map constant double_face_mask to double-face-mask.svg file
  static const String double_face_mask = 'double-face-mask.svg';

  /// map constant double_fish to double-fish.svg file
  static const String double_fish = 'double-fish.svg';

  /// map constant double_necklace to double-necklace.svg file
  static const String double_necklace = 'double-necklace.svg';

  /// map constant double_quaver to double-quaver.svg file
  static const String double_quaver = 'double-quaver.svg';

  /// map constant double_ringed_orb to double-ringed-orb.svg file
  static const String double_ringed_orb = 'double-ringed-orb.svg';

  /// map constant double_shot to double-shot.svg file
  static const String double_shot = 'double-shot.svg';

  /// map constant double_street_lights to double-street-lights.svg file
  static const String double_street_lights = 'double-street-lights.svg';

  /// map constant doubled to doubled.svg file
  static const String doubled = 'doubled.svg';

  /// map constant dough_roller to dough-roller.svg file
  static const String dough_roller = 'dough-roller.svg';

  /// map constant dove to dove.svg file
  static const String dove = 'dove.svg';

  /// map constant dozen to dozen.svg file
  static const String dozen = 'dozen.svg';

  /// map constant dragon_balls to dragon-balls.svg file
  static const String dragon_balls = 'dragon-balls.svg';

  /// map constant dragon_breath to dragon-breath.svg file
  static const String dragon_breath = 'dragon-breath.svg';

  /// map constant dragon_head2 to dragon-head 2.svg file
  static const String dragon_head2 = 'dragon-head 2.svg';

  /// map constant dragon_head to dragon-head.svg file
  static const String dragon_head = 'dragon-head.svg';

  /// map constant dragon_orb to dragon-orb.svg file
  static const String dragon_orb = 'dragon-orb.svg';

  /// map constant dragon_shield to dragon-shield.svg file
  static const String dragon_shield = 'dragon-shield.svg';

  /// map constant dragon_spiral to dragon-spiral.svg file
  static const String dragon_spiral = 'dragon-spiral.svg';

  /// map constant dragonfly to dragonfly.svg file
  static const String dragonfly = 'dragonfly.svg';

  /// map constant drakkar_dragon to drakkar-dragon.svg file
  static const String drakkar_dragon = 'drakkar-dragon.svg';

  /// map constant drakkar to drakkar.svg file
  static const String drakkar = 'drakkar.svg';

  /// map constant drama_masks to drama-masks.svg file
  static const String drama_masks = 'drama-masks.svg';

  /// map constant drawbridge to drawbridge.svg file
  static const String drawbridge = 'drawbridge.svg';

  /// map constant dread_skull to dread-skull.svg file
  static const String dread_skull = 'dread-skull.svg';

  /// map constant dread to dread.svg file
  static const String dread = 'dread.svg';

  /// map constant dreadnought to dreadnought.svg file
  static const String dreadnought = 'dreadnought.svg';

  /// map constant dream_catcher to dream-catcher.svg file
  static const String dream_catcher = 'dream-catcher.svg';

  /// map constant dress to dress.svg file
  static const String dress = 'dress.svg';

  /// map constant drill2 to drill 2.svg file
  static const String drill2 = 'drill 2.svg';

  /// map constant drill to drill.svg file
  static const String drill = 'drill.svg';

  /// map constant drink_me to drink-me.svg file
  static const String drink_me = 'drink-me.svg';

  /// map constant drinking to drinking.svg file
  static const String drinking = 'drinking.svg';

  /// map constant dripping_blade to dripping-blade.svg file
  static const String dripping_blade = 'dripping-blade.svg';

  /// map constant dripping_goo to dripping-goo.svg file
  static const String dripping_goo = 'dripping-goo.svg';

  /// map constant dripping_honey to dripping-honey.svg file
  static const String dripping_honey = 'dripping-honey.svg';

  /// map constant dripping_knife to dripping-knife.svg file
  static const String dripping_knife = 'dripping-knife.svg';

  /// map constant dripping_star to dripping-star.svg file
  static const String dripping_star = 'dripping-star.svg';

  /// map constant dripping_stone to dripping-stone.svg file
  static const String dripping_stone = 'dripping-stone.svg';

  /// map constant dripping_sword to dripping-sword.svg file
  static const String dripping_sword = 'dripping-sword.svg';

  /// map constant dripping_tube to dripping-tube.svg file
  static const String dripping_tube = 'dripping-tube.svg';

  /// map constant drop_earrings to drop-earrings.svg file
  static const String drop_earrings = 'drop-earrings.svg';

  /// map constant drop_weapon to drop-weapon.svg file
  static const String drop_weapon = 'drop-weapon.svg';

  /// map constant drop to drop.svg file
  static const String drop = 'drop.svg';

  /// map constant droplet_splash to droplet-splash.svg file
  static const String droplet_splash = 'droplet-splash.svg';

  /// map constant droplets to droplets.svg file
  static const String droplets = 'droplets.svg';

  /// map constant drowning to drowning.svg file
  static const String drowning = 'drowning.svg';

  /// map constant drum_kit to drum-kit.svg file
  static const String drum_kit = 'drum-kit.svg';

  /// map constant drum to drum.svg file
  static const String drum = 'drum.svg';

  /// map constant duality_mask to duality-mask.svg file
  static const String duality_mask = 'duality-mask.svg';

  /// map constant duality to duality.svg file
  static const String duality = 'duality.svg';

  /// map constant duck_palm to duck-palm.svg file
  static const String duck_palm = 'duck-palm.svg';

  /// map constant duck to duck.svg file
  static const String duck = 'duck.svg';

  /// map constant duel to duel.svg file
  static const String duel = 'duel.svg';

  /// map constant duffel_bag to duffel-bag.svg file
  static const String duffel_bag = 'duffel-bag.svg';

  /// map constant dumpling_bao to dumpling-bao.svg file
  static const String dumpling_bao = 'dumpling-bao.svg';

  /// map constant dumpling to dumpling.svg file
  static const String dumpling = 'dumpling.svg';

  /// map constant dunce_cap to dunce-cap.svg file
  static const String dunce_cap = 'dunce-cap.svg';

  /// map constant dungeon_gate to dungeon-gate.svg file
  static const String dungeon_gate = 'dungeon-gate.svg';

  /// map constant dungeon_light to dungeon-light.svg file
  static const String dungeon_light = 'dungeon-light.svg';

  /// map constant duration to duration.svg file
  static const String duration = 'duration.svg';

  /// map constant dust_cloud to dust-cloud.svg file
  static const String dust_cloud = 'dust-cloud.svg';

  /// map constant dutch_bike to dutch-bike.svg file
  static const String dutch_bike = 'dutch-bike.svg';

  /// map constant dwarf_face to dwarf-face.svg file
  static const String dwarf_face = 'dwarf-face.svg';

  /// map constant dwarf_helmet to dwarf-helmet.svg file
  static const String dwarf_helmet = 'dwarf-helmet.svg';

  /// map constant dwarf_king to dwarf-king.svg file
  static const String dwarf_king = 'dwarf-king.svg';

  /// map constant dwennimmen to dwennimmen.svg file
  static const String dwennimmen = 'dwennimmen.svg';

  /// map constant dynamite to dynamite.svg file
  static const String dynamite = 'dynamite.svg';

  /// map constant eagle_emblem to eagle-emblem.svg file
  static const String eagle_emblem = 'eagle-emblem.svg';

  /// map constant eagle_head to eagle-head.svg file
  static const String eagle_head = 'eagle-head.svg';

  /// map constant earbuds to earbuds.svg file
  static const String earbuds = 'earbuds.svg';

  /// map constant earrings to earrings.svg file
  static const String earrings = 'earrings.svg';

  /// map constant earth_africa_europe to earth-africa-europe.svg file
  static const String earth_africa_europe = 'earth-africa-europe.svg';

  /// map constant earth_america to earth-america.svg file
  static const String earth_america = 'earth-america.svg';

  /// map constant earth_asia_oceania to earth-asia-oceania.svg file
  static const String earth_asia_oceania = 'earth-asia-oceania.svg';

  /// map constant earth_crack to earth-crack.svg file
  static const String earth_crack = 'earth-crack.svg';

  /// map constant earth_spit to earth-spit.svg file
  static const String earth_spit = 'earth-spit.svg';

  /// map constant earth_worm to earth-worm.svg file
  static const String earth_worm = 'earth-worm.svg';

  /// map constant earwig to earwig.svg file
  static const String earwig = 'earwig.svg';

  /// map constant easel to easel.svg file
  static const String easel = 'easel.svg';

  /// map constant easter_egg to easter-egg.svg file
  static const String easter_egg = 'easter-egg.svg';

  /// map constant eating_pelican to eating-pelican.svg file
  static const String eating_pelican = 'eating-pelican.svg';

  /// map constant eating to eating.svg file
  static const String eating = 'eating.svg';

  /// map constant echo_ripples to echo-ripples.svg file
  static const String echo_ripples = 'echo-ripples.svg';

  /// map constant eclipse_flare to eclipse-flare.svg file
  static const String eclipse_flare = 'eclipse-flare.svg';

  /// map constant eclipse_saw to eclipse-saw.svg file
  static const String eclipse_saw = 'eclipse-saw.svg';

  /// map constant eclipse to eclipse.svg file
  static const String eclipse = 'eclipse.svg';

  /// map constant ecology to ecology.svg file
  static const String ecology = 'ecology.svg';

  /// map constant edge_crack to edge-crack.svg file
  static const String edge_crack = 'edge-crack.svg';

  /// map constant edged_shield to edged-shield.svg file
  static const String edged_shield = 'edged-shield.svg';

  /// map constant eel to eel.svg file
  static const String eel = 'eel.svg';

  /// map constant egg_clutch to egg-clutch.svg file
  static const String egg_clutch = 'egg-clutch.svg';

  /// map constant egg_defense to egg-defense.svg file
  static const String egg_defense = 'egg-defense.svg';

  /// map constant egg_eye to egg-eye.svg file
  static const String egg_eye = 'egg-eye.svg';

  /// map constant egg_pod to egg-pod.svg file
  static const String egg_pod = 'egg-pod.svg';

  /// map constant egypt to egypt.svg file
  static const String egypt = 'egypt.svg';

  /// map constant egyptian_bird to egyptian-bird.svg file
  static const String egyptian_bird = 'egyptian-bird.svg';

  /// map constant egyptian_profile to egyptian-profile.svg file
  static const String egyptian_profile = 'egyptian-profile.svg';

  /// map constant egyptian_pyramids to egyptian-pyramids.svg file
  static const String egyptian_pyramids = 'egyptian-pyramids.svg';

  /// map constant egyptian_sphinx to egyptian-sphinx.svg file
  static const String egyptian_sphinx = 'egyptian-sphinx.svg';

  /// map constant egyptian_temple to egyptian-temple.svg file
  static const String egyptian_temple = 'egyptian-temple.svg';

  /// map constant egyptian_urns to egyptian-urns.svg file
  static const String egyptian_urns = 'egyptian-urns.svg';

  /// map constant egyptian_walk to egyptian-walk.svg file
  static const String egyptian_walk = 'egyptian-walk.svg';

  /// map constant eight_ball to eight-ball.svg file
  static const String eight_ball = 'eight-ball.svg';

  /// map constant elbow_pad to elbow-pad.svg file
  static const String elbow_pad = 'elbow-pad.svg';

  /// map constant elderberry to elderberry.svg file
  static const String elderberry = 'elderberry.svg';

  /// map constant electric_whip to electric-whip.svg file
  static const String electric_whip = 'electric-whip.svg';

  /// map constant electric to electric.svg file
  static const String electric = 'electric.svg';

  /// map constant electrical_crescent to electrical-crescent.svg file
  static const String electrical_crescent = 'electrical-crescent.svg';

  /// map constant electrical_resistance to electrical-resistance.svg file
  static const String electrical_resistance = 'electrical-resistance.svg';

  /// map constant electrical_socket to electrical-socket.svg file
  static const String electrical_socket = 'electrical-socket.svg';

  /// map constant elephant_head to elephant-head.svg file
  static const String elephant_head = 'elephant-head.svg';

  /// map constant elephant to elephant.svg file
  static const String elephant = 'elephant.svg';

  /// map constant elevator to elevator.svg file
  static const String elevator = 'elevator.svg';

  /// map constant elf_ear to elf-ear.svg file
  static const String elf_ear = 'elf-ear.svg';

  /// map constant elf_helmet to elf-helmet.svg file
  static const String elf_helmet = 'elf-helmet.svg';

  /// map constant elven_castle to elven-castle.svg file
  static const String elven_castle = 'elven-castle.svg';

  /// map constant elysium_shade to elysium-shade.svg file
  static const String elysium_shade = 'elysium-shade.svg';

  /// map constant ember_shot to ember-shot.svg file
  static const String ember_shot = 'ember-shot.svg';

  /// map constant embrassed_energy to embrassed-energy.svg file
  static const String embrassed_energy = 'embrassed-energy.svg';

  /// map constant embryo to embryo.svg file
  static const String embryo = 'embryo.svg';

  /// map constant emerald_necklace to emerald-necklace.svg file
  static const String emerald_necklace = 'emerald-necklace.svg';

  /// map constant emerald to emerald.svg file
  static const String emerald = 'emerald.svg';

  /// map constant empty_chessboard to empty-chessboard.svg file
  static const String empty_chessboard = 'empty-chessboard.svg';

  /// map constant empty_hourglass to empty-hourglass.svg file
  static const String empty_hourglass = 'empty-hourglass.svg';

  /// map constant empty_metal_bucket_handle to empty-metal-bucket-handle.svg file
  static const String empty_metal_bucket_handle = 'empty-metal-bucket-handle.svg';

  /// map constant empty_metal_bucket to empty-metal-bucket.svg file
  static const String empty_metal_bucket = 'empty-metal-bucket.svg';

  /// map constant empty_wood_bucket_handle to empty-wood-bucket-handle.svg file
  static const String empty_wood_bucket_handle = 'empty-wood-bucket-handle.svg';

  /// map constant empty_wood_bucket to empty-wood-bucket.svg file
  static const String empty_wood_bucket = 'empty-wood-bucket.svg';

  /// map constant encirclement to encirclement.svg file
  static const String encirclement = 'encirclement.svg';

  /// map constant energise to energise.svg file
  static const String energise = 'energise.svg';

  /// map constant energy_arrow to energy-arrow.svg file
  static const String energy_arrow = 'energy-arrow.svg';

  /// map constant energy_breath to energy-breath.svg file
  static const String energy_breath = 'energy-breath.svg';

  /// map constant energy_shield to energy-shield.svg file
  static const String energy_shield = 'energy-shield.svg';

  /// map constant energy_sword to energy-sword.svg file
  static const String energy_sword = 'energy-sword.svg';

  /// map constant energy_tank to energy-tank.svg file
  static const String energy_tank = 'energy-tank.svg';

  /// map constant engagement_ring to engagement-ring.svg file
  static const String engagement_ring = 'engagement-ring.svg';

  /// map constant enlightenment to enlightenment.svg file
  static const String enlightenment = 'enlightenment.svg';

  /// map constant enrage to enrage.svg file
  static const String enrage = 'enrage.svg';

  /// map constant ent_mouth to ent-mouth.svg file
  static const String ent_mouth = 'ent-mouth.svg';

  /// map constant entangled_typhoon to entangled-typhoon.svg file
  static const String entangled_typhoon = 'entangled-typhoon.svg';

  /// map constant entry_door to entry-door.svg file
  static const String entry_door = 'entry-door.svg';

  /// map constant envelope to envelope.svg file
  static const String envelope = 'envelope.svg';

  /// map constant erlenmeyer to erlenmeyer.svg file
  static const String erlenmeyer = 'erlenmeyer.svg';

  /// map constant ermine to ermine.svg file
  static const String ermine = 'ermine.svg';

  /// map constant eruption to eruption.svg file
  static const String eruption = 'eruption.svg';

  /// map constant escalator to escalator.svg file
  static const String escalator = 'escalator.svg';

  /// map constant eskimo to eskimo.svg file
  static const String eskimo = 'eskimo.svg';

  /// map constant eternal_love to eternal-love.svg file
  static const String eternal_love = 'eternal-love.svg';

  /// map constant european_flag to european-flag.svg file
  static const String european_flag = 'european-flag.svg';

  /// map constant evasion to evasion.svg file
  static const String evasion = 'evasion.svg';

  /// map constant evil_bat to evil-bat.svg file
  static const String evil_bat = 'evil-bat.svg';

  /// map constant evil_book to evil-book.svg file
  static const String evil_book = 'evil-book.svg';

  /// map constant evil_bud to evil-bud.svg file
  static const String evil_bud = 'evil-bud.svg';

  /// map constant evil_comet to evil-comet.svg file
  static const String evil_comet = 'evil-comet.svg';

  /// map constant evil_eyes to evil-eyes.svg file
  static const String evil_eyes = 'evil-eyes.svg';

  /// map constant evil_fork to evil-fork.svg file
  static const String evil_fork = 'evil-fork.svg';

  /// map constant evil_hand to evil-hand.svg file
  static const String evil_hand = 'evil-hand.svg';

  /// map constant evil_love to evil-love.svg file
  static const String evil_love = 'evil-love.svg';

  /// map constant evil_minion to evil-minion.svg file
  static const String evil_minion = 'evil-minion.svg';

  /// map constant evil_moon to evil-moon.svg file
  static const String evil_moon = 'evil-moon.svg';

  /// map constant evil_tower to evil-tower.svg file
  static const String evil_tower = 'evil-tower.svg';

  /// map constant evil_tree to evil-tree.svg file
  static const String evil_tree = 'evil-tree.svg';

  /// map constant evil_wings to evil-wings.svg file
  static const String evil_wings = 'evil-wings.svg';

  /// map constant executioner_hood to executioner-hood.svg file
  static const String executioner_hood = 'executioner-hood.svg';

  /// map constant exit_door to exit-door.svg file
  static const String exit_door = 'exit-door.svg';

  /// map constant expand to expand.svg file
  static const String expand = 'expand.svg';

  /// map constant expanded_rays to expanded-rays.svg file
  static const String expanded_rays = 'expanded-rays.svg';

  /// map constant expander to expander.svg file
  static const String expander = 'expander.svg';

  /// map constant expense to expense.svg file
  static const String expense = 'expense.svg';

  /// map constant exploding_planet to exploding-planet.svg file
  static const String exploding_planet = 'exploding-planet.svg';

  /// map constant explosion_rays to explosion-rays.svg file
  static const String explosion_rays = 'explosion-rays.svg';

  /// map constant explosive_materials to explosive-materials.svg file
  static const String explosive_materials = 'explosive-materials.svg';

  /// map constant explosive_meeting to explosive-meeting.svg file
  static const String explosive_meeting = 'explosive-meeting.svg';

  /// map constant extra_lucid to extra-lucid.svg file
  static const String extra_lucid = 'extra-lucid.svg';

  /// map constant extra_time to extra-time.svg file
  static const String extra_time = 'extra-time.svg';

  /// map constant extraction_orb to extraction-orb.svg file
  static const String extraction_orb = 'extraction-orb.svg';

  /// map constant eye_of_horus to eye-of-horus.svg file
  static const String eye_of_horus = 'eye-of-horus.svg';

  /// map constant eye_shield to eye-shield.svg file
  static const String eye_shield = 'eye-shield.svg';

  /// map constant eye_target to eye-target.svg file
  static const String eye_target = 'eye-target.svg';

  /// map constant eyeball to eyeball.svg file
  static const String eyeball = 'eyeball.svg';

  /// map constant eyedropper to eyedropper.svg file
  static const String eyedropper = 'eyedropper.svg';

  /// map constant eyelashes to eyelashes.svg file
  static const String eyelashes = 'eyelashes.svg';

  /// map constant eyepatch to eyepatch.svg file
  static const String eyepatch = 'eyepatch.svg';

  /// map constant eyestalk to eyestalk.svg file
  static const String eyestalk = 'eyestalk.svg';

  /// map constant f_clef to f-clef.svg file
  static const String f_clef = 'f-clef.svg';

  /// map constant f1_car to f1-car.svg file
  static const String f1_car = 'f1-car.svg';

  /// map constant face_to_face to face-to-face.svg file
  static const String face_to_face = 'face-to-face.svg';

  /// map constant factory_arm to factory-arm.svg file
  static const String factory_arm = 'factory-arm.svg';

  /// map constant factory_ to factory.svg file
  static const String factory_ = 'factory.svg';

  /// map constant fairy2 to fairy 2.svg file
  static const String fairy2 = 'fairy 2.svg';

  /// map constant fairy_wand to fairy-wand.svg file
  static const String fairy_wand = 'fairy-wand.svg';

  /// map constant fairy_wings to fairy-wings.svg file
  static const String fairy_wings = 'fairy-wings.svg';

  /// map constant fairy to fairy.svg file
  static const String fairy = 'fairy.svg';

  /// map constant falcon_moon to falcon-moon.svg file
  static const String falcon_moon = 'falcon-moon.svg';

  /// map constant fall_down to fall-down.svg file
  static const String fall_down = 'fall-down.svg';

  /// map constant falling_blob to falling-blob.svg file
  static const String falling_blob = 'falling-blob.svg';

  /// map constant falling_bomb to falling-bomb.svg file
  static const String falling_bomb = 'falling-bomb.svg';

  /// map constant falling_boulder to falling-boulder.svg file
  static const String falling_boulder = 'falling-boulder.svg';

  /// map constant falling_eye to falling-eye.svg file
  static const String falling_eye = 'falling-eye.svg';

  /// map constant falling_leaf to falling-leaf.svg file
  static const String falling_leaf = 'falling-leaf.svg';

  /// map constant falling_ovoid to falling-ovoid.svg file
  static const String falling_ovoid = 'falling-ovoid.svg';

  /// map constant falling_rocks to falling-rocks.svg file
  static const String falling_rocks = 'falling-rocks.svg';

  /// map constant falling_star to falling-star.svg file
  static const String falling_star = 'falling-star.svg';

  /// map constant falling to falling.svg file
  static const String falling = 'falling.svg';

  /// map constant fallout_shelter to fallout-shelter.svg file
  static const String fallout_shelter = 'fallout-shelter.svg';

  /// map constant famas to famas.svg file
  static const String famas = 'famas.svg';

  /// map constant family_house to family-house.svg file
  static const String family_house = 'family-house.svg';

  /// map constant family_tree to family-tree.svg file
  static const String family_tree = 'family-tree.svg';

  /// map constant fanged_skull to fanged-skull.svg file
  static const String fanged_skull = 'fanged-skull.svg';

  /// map constant fangs_circle to fangs-circle.svg file
  static const String fangs_circle = 'fangs-circle.svg';

  /// map constant fangs to fangs.svg file
  static const String fangs = 'fangs.svg';

  /// map constant farm_tractor to farm-tractor.svg file
  static const String farm_tractor = 'farm-tractor.svg';

  /// map constant farmer to farmer.svg file
  static const String farmer = 'farmer.svg';

  /// map constant fast_arrow to fast-arrow.svg file
  static const String fast_arrow = 'fast-arrow.svg';

  /// map constant fast_backward_button to fast-backward-button.svg file
  static const String fast_backward_button = 'fast-backward-button.svg';

  /// map constant fast_forward_button to fast-forward-button.svg file
  static const String fast_forward_button = 'fast-forward-button.svg';

  /// map constant fast_noodles to fast-noodles.svg file
  static const String fast_noodles = 'fast-noodles.svg';

  /// map constant fat to fat.svg file
  static const String fat = 'fat.svg';

  /// map constant feather_necklace to feather-necklace.svg file
  static const String feather_necklace = 'feather-necklace.svg';

  /// map constant feather_wound to feather-wound.svg file
  static const String feather_wound = 'feather-wound.svg';

  /// map constant feather to feather.svg file
  static const String feather = 'feather.svg';

  /// map constant feathered_wing to feathered-wing.svg file
  static const String feathered_wing = 'feathered-wing.svg';

  /// map constant fedora to fedora.svg file
  static const String fedora = 'fedora.svg';

  /// map constant feline to feline.svg file
  static const String feline = 'feline.svg';

  /// map constant female_legs to female-legs.svg file
  static const String female_legs = 'female-legs.svg';

  /// map constant female_vampire to female-vampire.svg file
  static const String female_vampire = 'female-vampire.svg';

  /// map constant female to female.svg file
  static const String female = 'female.svg';

  /// map constant fencer to fencer.svg file
  static const String fencer = 'fencer.svg';

  /// map constant fern to fern.svg file
  static const String fern = 'fern.svg';

  /// map constant fertilizer_bag to fertilizer-bag.svg file
  static const String fertilizer_bag = 'fertilizer-bag.svg';

  /// map constant fetus to fetus.svg file
  static const String fetus = 'fetus.svg';

  /// map constant fez to fez.svg file
  static const String fez = 'fez.svg';

  /// map constant field_gun to field-gun.svg file
  static const String field_gun = 'field-gun.svg';

  /// map constant field to field.svg file
  static const String field = 'field.svg';

  /// map constant figurehead to figurehead.svg file
  static const String figurehead = 'figurehead.svg';

  /// map constant files to files.svg file
  static const String files = 'files.svg';

  /// map constant film_projector to film-projector.svg file
  static const String film_projector = 'film-projector.svg';

  /// map constant film_spool to film-spool.svg file
  static const String film_spool = 'film-spool.svg';

  /// map constant film_strip to film-strip.svg file
  static const String film_strip = 'film-strip.svg';

  /// map constant finch to finch.svg file
  static const String finch = 'finch.svg';

  /// map constant finger_print to finger-print.svg file
  static const String finger_print = 'finger-print.svg';

  /// map constant fingernail to fingernail.svg file
  static const String fingernail = 'fingernail.svg';

  /// map constant fingers_crossed to fingers-crossed.svg file
  static const String fingers_crossed = 'fingers-crossed.svg';

  /// map constant finish_line to finish-line.svg file
  static const String finish_line = 'finish-line.svg';

  /// map constant fire_ace to fire-ace.svg file
  static const String fire_ace = 'fire-ace.svg';

  /// map constant fire_axe to fire-axe.svg file
  static const String fire_axe = 'fire-axe.svg';

  /// map constant fire_bomb to fire-bomb.svg file
  static const String fire_bomb = 'fire-bomb.svg';

  /// map constant fire_bottle to fire-bottle.svg file
  static const String fire_bottle = 'fire-bottle.svg';

  /// map constant fire_bowl to fire-bowl.svg file
  static const String fire_bowl = 'fire-bowl.svg';

  /// map constant fire_breath to fire-breath.svg file
  static const String fire_breath = 'fire-breath.svg';

  /// map constant fire_dash to fire-dash.svg file
  static const String fire_dash = 'fire-dash.svg';

  /// map constant fire_extinguisher to fire-extinguisher.svg file
  static const String fire_extinguisher = 'fire-extinguisher.svg';

  /// map constant fire_flower to fire-flower.svg file
  static const String fire_flower = 'fire-flower.svg';

  /// map constant fire_gem to fire-gem.svg file
  static const String fire_gem = 'fire-gem.svg';

  /// map constant fire_punch to fire-punch.svg file
  static const String fire_punch = 'fire-punch.svg';

  /// map constant fire_ray to fire-ray.svg file
  static const String fire_ray = 'fire-ray.svg';

  /// map constant fire_ring to fire-ring.svg file
  static const String fire_ring = 'fire-ring.svg';

  /// map constant fire_shield to fire-shield.svg file
  static const String fire_shield = 'fire-shield.svg';

  /// map constant fire_shrine to fire-shrine.svg file
  static const String fire_shrine = 'fire-shrine.svg';

  /// map constant fire_silhouette to fire-silhouette.svg file
  static const String fire_silhouette = 'fire-silhouette.svg';

  /// map constant fire_spell_cast to fire-spell-cast.svg file
  static const String fire_spell_cast = 'fire-spell-cast.svg';

  /// map constant fire_tail to fire-tail.svg file
  static const String fire_tail = 'fire-tail.svg';

  /// map constant fire_wave to fire-wave.svg file
  static const String fire_wave = 'fire-wave.svg';

  /// map constant fire_zone to fire-zone.svg file
  static const String fire_zone = 'fire-zone.svg';

  /// map constant fire to fire.svg file
  static const String fire = 'fire.svg';

  /// map constant fireball to fireball.svg file
  static const String fireball = 'fireball.svg';

  /// map constant fireflake to fireflake.svg file
  static const String fireflake = 'fireflake.svg';

  /// map constant fireplace to fireplace.svg file
  static const String fireplace = 'fireplace.svg';

  /// map constant firewall to firewall.svg file
  static const String firewall = 'firewall.svg';

  /// map constant firework_rocket to firework-rocket.svg file
  static const String firework_rocket = 'firework-rocket.svg';

  /// map constant first_aid_kit to first-aid-kit.svg file
  static const String first_aid_kit = 'first-aid-kit.svg';

  /// map constant fish_bucket to fish-bucket.svg file
  static const String fish_bucket = 'fish-bucket.svg';

  /// map constant fish_cooked to fish-cooked.svg file
  static const String fish_cooked = 'fish-cooked.svg';

  /// map constant fish_corpse to fish-corpse.svg file
  static const String fish_corpse = 'fish-corpse.svg';

  /// map constant fish_eggs to fish-eggs.svg file
  static const String fish_eggs = 'fish-eggs.svg';

  /// map constant fish_escape to fish-escape.svg file
  static const String fish_escape = 'fish-escape.svg';

  /// map constant fish_monster to fish-monster.svg file
  static const String fish_monster = 'fish-monster.svg';

  /// map constant fish_scales to fish-scales.svg file
  static const String fish_scales = 'fish-scales.svg';

  /// map constant fish_smoking to fish-smoking.svg file
  static const String fish_smoking = 'fish-smoking.svg';

  /// map constant fishbone to fishbone.svg file
  static const String fishbone = 'fishbone.svg';

  /// map constant fishhook_fork to fishhook-fork.svg file
  static const String fishhook_fork = 'fishhook-fork.svg';

  /// map constant fishing_boat to fishing-boat.svg file
  static const String fishing_boat = 'fishing-boat.svg';

  /// map constant fishing_hook to fishing-hook.svg file
  static const String fishing_hook = 'fishing-hook.svg';

  /// map constant fishing_jig to fishing-jig.svg file
  static const String fishing_jig = 'fishing-jig.svg';

  /// map constant fishing_lure to fishing-lure.svg file
  static const String fishing_lure = 'fishing-lure.svg';

  /// map constant fishing_net to fishing-net.svg file
  static const String fishing_net = 'fishing-net.svg';

  /// map constant fishing_pole to fishing-pole.svg file
  static const String fishing_pole = 'fishing-pole.svg';

  /// map constant fishing_spoon to fishing-spoon.svg file
  static const String fishing_spoon = 'fishing-spoon.svg';

  /// map constant fishing to fishing.svg file
  static const String fishing = 'fishing.svg';

  /// map constant fission to fission.svg file
  static const String fission = 'fission.svg';

  /// map constant fist2 to fist 2.svg file
  static const String fist2 = 'fist 2.svg';

  /// map constant fist to fist.svg file
  static const String fist = 'fist.svg';

  /// map constant fizzing_flask to fizzing-flask.svg file
  static const String fizzing_flask = 'fizzing-flask.svg';

  /// map constant flag_objective to flag-objective.svg file
  static const String flag_objective = 'flag-objective.svg';

  /// map constant flail to flail.svg file
  static const String flail = 'flail.svg';

  /// map constant flake to flake.svg file
  static const String flake = 'flake.svg';

  /// map constant flame_claws to flame-claws.svg file
  static const String flame_claws = 'flame-claws.svg';

  /// map constant flame_spin to flame-spin.svg file
  static const String flame_spin = 'flame-spin.svg';

  /// map constant flame_tunnel to flame-tunnel.svg file
  static const String flame_tunnel = 'flame-tunnel.svg';

  /// map constant flame to flame.svg file
  static const String flame = 'flame.svg';

  /// map constant flamed_leaf to flamed-leaf.svg file
  static const String flamed_leaf = 'flamed-leaf.svg';

  /// map constant flamer to flamer.svg file
  static const String flamer = 'flamer.svg';

  /// map constant flamethrower_soldier to flamethrower-soldier.svg file
  static const String flamethrower_soldier = 'flamethrower-soldier.svg';

  /// map constant flamethrower to flamethrower.svg file
  static const String flamethrower = 'flamethrower.svg';

  /// map constant flaming_arrow to flaming-arrow.svg file
  static const String flaming_arrow = 'flaming-arrow.svg';

  /// map constant flaming_claw to flaming-claw.svg file
  static const String flaming_claw = 'flaming-claw.svg';

  /// map constant flaming_sheet to flaming-sheet.svg file
  static const String flaming_sheet = 'flaming-sheet.svg';

  /// map constant flaming_trident to flaming-trident.svg file
  static const String flaming_trident = 'flaming-trident.svg';

  /// map constant flamingo to flamingo.svg file
  static const String flamingo = 'flamingo.svg';

  /// map constant flanged_mace to flanged-mace.svg file
  static const String flanged_mace = 'flanged-mace.svg';

  /// map constant flash_grenade to flash-grenade.svg file
  static const String flash_grenade = 'flash-grenade.svg';

  /// map constant flashlight to flashlight.svg file
  static const String flashlight = 'flashlight.svg';

  /// map constant flat_hammer to flat-hammer.svg file
  static const String flat_hammer = 'flat-hammer.svg';

  /// map constant flat_paw_print to flat-paw-print.svg file
  static const String flat_paw_print = 'flat-paw-print.svg';

  /// map constant flat_platform to flat-platform.svg file
  static const String flat_platform = 'flat-platform.svg';

  /// map constant flat_star to flat-star.svg file
  static const String flat_star = 'flat-star.svg';

  /// map constant flat_tire to flat-tire.svg file
  static const String flat_tire = 'flat-tire.svg';

  /// map constant flatbed_covered to flatbed-covered.svg file
  static const String flatbed_covered = 'flatbed-covered.svg';

  /// map constant flatbed to flatbed.svg file
  static const String flatbed = 'flatbed.svg';

  /// map constant flatfish to flatfish.svg file
  static const String flatfish = 'flatfish.svg';

  /// map constant flax to flax.svg file
  static const String flax = 'flax.svg';

  /// map constant fleshy_mass to fleshy-mass.svg file
  static const String fleshy_mass = 'fleshy-mass.svg';

  /// map constant fleur_de_lys to fleur-de-lys.svg file
  static const String fleur_de_lys = 'fleur-de-lys.svg';

  /// map constant flexible_lamp to flexible-lamp.svg file
  static const String flexible_lamp = 'flexible-lamp.svg';

  /// map constant flexible_star to flexible-star.svg file
  static const String flexible_star = 'flexible-star.svg';

  /// map constant flint_spark to flint-spark.svg file
  static const String flint_spark = 'flint-spark.svg';

  /// map constant flip_flops to flip-flops.svg file
  static const String flip_flops = 'flip-flops.svg';

  /// map constant floating_crystal to floating-crystal.svg file
  static const String floating_crystal = 'floating-crystal.svg';

  /// map constant floating_ghost to floating-ghost.svg file
  static const String floating_ghost = 'floating-ghost.svg';

  /// map constant floating_platforms to floating-platforms.svg file
  static const String floating_platforms = 'floating-platforms.svg';

  /// map constant floating_tentacles to floating-tentacles.svg file
  static const String floating_tentacles = 'floating-tentacles.svg';

  /// map constant flood to flood.svg file
  static const String flood = 'flood.svg';

  /// map constant floor_hatch to floor-hatch.svg file
  static const String floor_hatch = 'floor-hatch.svg';

  /// map constant floor_polisher to floor-polisher.svg file
  static const String floor_polisher = 'floor-polisher.svg';

  /// map constant flour to flour.svg file
  static const String flour = 'flour.svg';

  /// map constant flower_emblem to flower-emblem.svg file
  static const String flower_emblem = 'flower-emblem.svg';

  /// map constant flower_hat to flower-hat.svg file
  static const String flower_hat = 'flower-hat.svg';

  /// map constant flower_pot to flower-pot.svg file
  static const String flower_pot = 'flower-pot.svg';

  /// map constant flower_star to flower-star.svg file
  static const String flower_star = 'flower-star.svg';

  /// map constant flower_twirl to flower-twirl.svg file
  static const String flower_twirl = 'flower-twirl.svg';

  /// map constant flowers to flowers.svg file
  static const String flowers = 'flowers.svg';

  /// map constant fluffy_cloud to fluffy-cloud.svg file
  static const String fluffy_cloud = 'fluffy-cloud.svg';

  /// map constant fluffy_flame to fluffy-flame.svg file
  static const String fluffy_flame = 'fluffy-flame.svg';

  /// map constant fluffy_swirl to fluffy-swirl.svg file
  static const String fluffy_swirl = 'fluffy-swirl.svg';

  /// map constant fluffy_trefoil to fluffy-trefoil.svg file
  static const String fluffy_trefoil = 'fluffy-trefoil.svg';

  /// map constant fluffy_wing to fluffy-wing.svg file
  static const String fluffy_wing = 'fluffy-wing.svg';

  /// map constant flute to flute.svg file
  static const String flute = 'flute.svg';

  /// map constant fly to fly.svg file
  static const String fly = 'fly.svg';

  /// map constant flying_beetle to flying-beetle.svg file
  static const String flying_beetle = 'flying-beetle.svg';

  /// map constant flying_dagger to flying-dagger.svg file
  static const String flying_dagger = 'flying-dagger.svg';

  /// map constant flying_flag to flying-flag.svg file
  static const String flying_flag = 'flying-flag.svg';

  /// map constant flying_fox to flying-fox.svg file
  static const String flying_fox = 'flying-fox.svg';

  /// map constant flying_shuriken to flying-shuriken.svg file
  static const String flying_shuriken = 'flying-shuriken.svg';

  /// map constant flying_target to flying-target.svg file
  static const String flying_target = 'flying-target.svg';

  /// map constant flying_trout to flying-trout.svg file
  static const String flying_trout = 'flying-trout.svg';

  /// map constant fn_fal to fn-fal.svg file
  static const String fn_fal = 'fn-fal.svg';

  /// map constant foam to foam.svg file
  static const String foam = 'foam.svg';

  /// map constant foamy_disc to foamy-disc.svg file
  static const String foamy_disc = 'foamy-disc.svg';

  /// map constant focused_lightning to focused-lightning.svg file
  static const String focused_lightning = 'focused-lightning.svg';

  /// map constant fog_light to fog-light.svg file
  static const String fog_light = 'fog-light.svg';

  /// map constant fog to fog.svg file
  static const String fog = 'fog.svg';

  /// map constant folded_paper to folded-paper.svg file
  static const String folded_paper = 'folded-paper.svg';

  /// map constant fomorian to fomorian.svg file
  static const String fomorian = 'fomorian.svg';

  /// map constant food_chain to food-chain.svg file
  static const String food_chain = 'food-chain.svg';

  /// map constant food_truck to food-truck.svg file
  static const String food_truck = 'food-truck.svg';

  /// map constant foot_plaster to foot-plaster.svg file
  static const String foot_plaster = 'foot-plaster.svg';

  /// map constant foot_trip to foot-trip.svg file
  static const String foot_trip = 'foot-trip.svg';

  /// map constant footprint to footprint.svg file
  static const String footprint = 'footprint.svg';

  /// map constant footsteps to footsteps.svg file
  static const String footsteps = 'footsteps.svg';

  /// map constant footy_field to footy-field.svg file
  static const String footy_field = 'footy-field.svg';

  /// map constant forearm to forearm.svg file
  static const String forearm = 'forearm.svg';

  /// map constant forest_camp to forest-camp.svg file
  static const String forest_camp = 'forest-camp.svg';

  /// map constant forest_entrance to forest-entrance.svg file
  static const String forest_entrance = 'forest-entrance.svg';

  /// map constant forest to forest.svg file
  static const String forest = 'forest.svg';

  /// map constant fork_knife_spoon to fork-knife-spoon.svg file
  static const String fork_knife_spoon = 'fork-knife-spoon.svg';

  /// map constant forklift to forklift.svg file
  static const String forklift = 'forklift.svg';

  /// map constant forward_field to forward-field.svg file
  static const String forward_field = 'forward-field.svg';

  /// map constant forward_sun to forward-sun.svg file
  static const String forward_sun = 'forward-sun.svg';

  /// map constant fossil to fossil.svg file
  static const String fossil = 'fossil.svg';

  /// map constant foundry_bucket to foundry-bucket.svg file
  static const String foundry_bucket = 'foundry-bucket.svg';

  /// map constant fountain_pen to fountain-pen.svg file
  static const String fountain_pen = 'fountain-pen.svg';

  /// map constant fountain to fountain.svg file
  static const String fountain = 'fountain.svg';

  /// map constant fox_head to fox-head.svg file
  static const String fox_head = 'fox-head.svg';

  /// map constant fox_tail to fox-tail.svg file
  static const String fox_tail = 'fox-tail.svg';

  /// map constant fox to fox.svg file
  static const String fox = 'fox.svg';

  /// map constant fragmented_meteor to fragmented-meteor.svg file
  static const String fragmented_meteor = 'fragmented-meteor.svg';

  /// map constant fragmented_sword to fragmented-sword.svg file
  static const String fragmented_sword = 'fragmented-sword.svg';

  /// map constant fragrance to fragrance.svg file
  static const String fragrance = 'fragrance.svg';

  /// map constant france to france.svg file
  static const String france = 'france.svg';

  /// map constant frankenstein_creature to frankenstein-creature.svg file
  static const String frankenstein_creature = 'frankenstein-creature.svg';

  /// map constant frayed_arrow to frayed-arrow.svg file
  static const String frayed_arrow = 'frayed-arrow.svg';

  /// map constant freedom_dove to freedom-dove.svg file
  static const String freedom_dove = 'freedom-dove.svg';

  /// map constant freemasonry to freemasonry.svg file
  static const String freemasonry = 'freemasonry.svg';

  /// map constant french_fries to french-fries.svg file
  static const String french_fries = 'french-fries.svg';

  /// map constant french_horn to french-horn.svg file
  static const String french_horn = 'french-horn.svg';

  /// map constant fridge to fridge.svg file
  static const String fridge = 'fridge.svg';

  /// map constant fried_eggs to fried-eggs.svg file
  static const String fried_eggs = 'fried-eggs.svg';

  /// map constant fried_fish to fried-fish.svg file
  static const String fried_fish = 'fried-fish.svg';

  /// map constant frisbee to frisbee.svg file
  static const String frisbee = 'frisbee.svg';

  /// map constant froe_and_mallet to froe-and-mallet.svg file
  static const String froe_and_mallet = 'froe-and-mallet.svg';

  /// map constant frog_foot to frog-foot.svg file
  static const String frog_foot = 'frog-foot.svg';

  /// map constant frog_mouth_helm to frog-mouth-helm.svg file
  static const String frog_mouth_helm = 'frog-mouth-helm.svg';

  /// map constant frog_prince to frog-prince.svg file
  static const String frog_prince = 'frog-prince.svg';

  /// map constant frog to frog.svg file
  static const String frog = 'frog.svg';

  /// map constant front_teeth to front-teeth.svg file
  static const String front_teeth = 'front-teeth.svg';

  /// map constant frontal_lobe to frontal-lobe.svg file
  static const String frontal_lobe = 'frontal-lobe.svg';

  /// map constant frostfire to frostfire.svg file
  static const String frostfire = 'frostfire.svg';

  /// map constant frozen_arrow to frozen-arrow.svg file
  static const String frozen_arrow = 'frozen-arrow.svg';

  /// map constant frozen_block to frozen-block.svg file
  static const String frozen_block = 'frozen-block.svg';

  /// map constant frozen_body to frozen-body.svg file
  static const String frozen_body = 'frozen-body.svg';

  /// map constant frozen_orb to frozen-orb.svg file
  static const String frozen_orb = 'frozen-orb.svg';

  /// map constant frozen_ring to frozen-ring.svg file
  static const String frozen_ring = 'frozen-ring.svg';

  /// map constant fruit_bowl to fruit-bowl.svg file
  static const String fruit_bowl = 'fruit-bowl.svg';

  /// map constant fruit_tree to fruit-tree.svg file
  static const String fruit_tree = 'fruit-tree.svg';

  /// map constant fruiting to fruiting.svg file
  static const String fruiting = 'fruiting.svg';

  /// map constant fuel_tank to fuel-tank.svg file
  static const String fuel_tank = 'fuel-tank.svg';

  /// map constant fuji to fuji.svg file
  static const String fuji = 'fuji.svg';

  /// map constant fulguro_punch to fulguro-punch.svg file
  static const String fulguro_punch = 'fulguro-punch.svg';

  /// map constant full_folder to full-folder.svg file
  static const String full_folder = 'full-folder.svg';

  /// map constant full_metal_bucket_handle to full-metal-bucket-handle.svg file
  static const String full_metal_bucket_handle = 'full-metal-bucket-handle.svg';

  /// map constant full_metal_bucket to full-metal-bucket.svg file
  static const String full_metal_bucket = 'full-metal-bucket.svg';

  /// map constant full_motorcycle_helmet to full-motorcycle-helmet.svg file
  static const String full_motorcycle_helmet = 'full-motorcycle-helmet.svg';

  /// map constant full_pizza to full-pizza.svg file
  static const String full_pizza = 'full-pizza.svg';

  /// map constant full_wood_bucket_handle to full-wood-bucket-handle.svg file
  static const String full_wood_bucket_handle = 'full-wood-bucket-handle.svg';

  /// map constant full_wood_bucket to full-wood-bucket.svg file
  static const String full_wood_bucket = 'full-wood-bucket.svg';

  /// map constant funnel to funnel.svg file
  static const String funnel = 'funnel.svg';

  /// map constant fur_boot to fur-boot.svg file
  static const String fur_boot = 'fur-boot.svg';

  /// map constant fur_shirt to fur-shirt.svg file
  static const String fur_shirt = 'fur-shirt.svg';

  /// map constant furnace to furnace.svg file
  static const String furnace = 'furnace.svg';

  /// map constant g_clef to g-clef.svg file
  static const String g_clef = 'g-clef.svg';

  /// map constant galaxy to galaxy.svg file
  static const String galaxy = 'galaxy.svg';

  /// map constant galea to galea.svg file
  static const String galea = 'galea.svg';

  /// map constant galleon to galleon.svg file
  static const String galleon = 'galleon.svg';

  /// map constant galley to galley.svg file
  static const String galley = 'galley.svg';

  /// map constant game_console to game-console.svg file
  static const String game_console = 'game-console.svg';

  /// map constant gamepad_cross to gamepad-cross.svg file
  static const String gamepad_cross = 'gamepad-cross.svg';

  /// map constant gamepad to gamepad.svg file
  static const String gamepad = 'gamepad.svg';

  /// map constant gardening_shears to gardening-shears.svg file
  static const String gardening_shears = 'gardening-shears.svg';

  /// map constant gargoyle to gargoyle.svg file
  static const String gargoyle = 'gargoyle.svg';

  /// map constant garlic to garlic.svg file
  static const String garlic = 'garlic.svg';

  /// map constant gas_mask2 to gas-mask 2.svg file
  static const String gas_mask2 = 'gas-mask 2.svg';

  /// map constant gas_mask to gas-mask.svg file
  static const String gas_mask = 'gas-mask.svg';

  /// map constant gas_pump to gas-pump.svg file
  static const String gas_pump = 'gas-pump.svg';

  /// map constant gas_stove to gas-stove.svg file
  static const String gas_stove = 'gas-stove.svg';

  /// map constant gate to gate.svg file
  static const String gate = 'gate.svg';

  /// map constant gauls_helm to gauls-helm.svg file
  static const String gauls_helm = 'gauls-helm.svg';

  /// map constant gauntlet to gauntlet.svg file
  static const String gauntlet = 'gauntlet.svg';

  /// map constant gavel to gavel.svg file
  static const String gavel = 'gavel.svg';

  /// map constant gaze to gaze.svg file
  static const String gaze = 'gaze.svg';

  /// map constant gear_hammer to gear-hammer.svg file
  static const String gear_hammer = 'gear-hammer.svg';

  /// map constant gear_stick_pattern to gear-stick-pattern.svg file
  static const String gear_stick_pattern = 'gear-stick-pattern.svg';

  /// map constant gear_stick to gear-stick.svg file
  static const String gear_stick = 'gear-stick.svg';

  /// map constant gears to gears.svg file
  static const String gears = 'gears.svg';

  /// map constant gecko to gecko.svg file
  static const String gecko = 'gecko.svg';

  /// map constant gem_chain to gem-chain.svg file
  static const String gem_chain = 'gem-chain.svg';

  /// map constant gem_necklace to gem-necklace.svg file
  static const String gem_necklace = 'gem-necklace.svg';

  /// map constant gem_pendant to gem-pendant.svg file
  static const String gem_pendant = 'gem-pendant.svg';

  /// map constant gemini to gemini.svg file
  static const String gemini = 'gemini.svg';

  /// map constant gems to gems.svg file
  static const String gems = 'gems.svg';

  /// map constant ghost_ally to ghost-ally.svg file
  static const String ghost_ally = 'ghost-ally.svg';

  /// map constant ghost to ghost.svg file
  static const String ghost = 'ghost.svg';

  /// map constant giant_squid to giant-squid.svg file
  static const String giant_squid = 'giant-squid.svg';

  /// map constant giant to giant.svg file
  static const String giant = 'giant.svg';

  /// map constant gibbet to gibbet.svg file
  static const String gibbet = 'gibbet.svg';

  /// map constant gift_of_knowledge to gift-of-knowledge.svg file
  static const String gift_of_knowledge = 'gift-of-knowledge.svg';

  /// map constant gift_trap to gift-trap.svg file
  static const String gift_trap = 'gift-trap.svg';

  /// map constant gingerbread_man to gingerbread-man.svg file
  static const String gingerbread_man = 'gingerbread-man.svg';

  /// map constant ginkgo_leaf to ginkgo-leaf.svg file
  static const String ginkgo_leaf = 'ginkgo-leaf.svg';

  /// map constant gladius to gladius.svg file
  static const String gladius = 'gladius.svg';

  /// map constant glaive to glaive.svg file
  static const String glaive = 'glaive.svg';

  /// map constant glass_ball to glass-ball.svg file
  static const String glass_ball = 'glass-ball.svg';

  /// map constant glass_celebration to glass-celebration.svg file
  static const String glass_celebration = 'glass-celebration.svg';

  /// map constant glass_heart to glass-heart.svg file
  static const String glass_heart = 'glass-heart.svg';

  /// map constant glass_shot to glass-shot.svg file
  static const String glass_shot = 'glass-shot.svg';

  /// map constant glider to glider.svg file
  static const String glider = 'glider.svg';

  /// map constant globe_ring to globe-ring.svg file
  static const String globe_ring = 'globe-ring.svg';

  /// map constant globe to globe.svg file
  static const String globe = 'globe.svg';

  /// map constant glock to glock.svg file
  static const String glock = 'glock.svg';

  /// map constant gloop to gloop.svg file
  static const String gloop = 'gloop.svg';

  /// map constant gloves to gloves.svg file
  static const String gloves = 'gloves.svg';

  /// map constant glowing_artifact to glowing-artifact.svg file
  static const String glowing_artifact = 'glowing-artifact.svg';

  /// map constant glowing_hands to glowing-hands.svg file
  static const String glowing_hands = 'glowing-hands.svg';

  /// map constant gluttonous_smile to gluttonous-smile.svg file
  static const String gluttonous_smile = 'gluttonous-smile.svg';

  /// map constant gluttony to gluttony.svg file
  static const String gluttony = 'gluttony.svg';

  /// map constant goal_keeper to goal-keeper.svg file
  static const String goal_keeper = 'goal-keeper.svg';

  /// map constant goat to goat.svg file
  static const String goat = 'goat.svg';

  /// map constant goblin_camp to goblin-camp.svg file
  static const String goblin_camp = 'goblin-camp.svg';

  /// map constant goblin_head to goblin-head.svg file
  static const String goblin_head = 'goblin-head.svg';

  /// map constant goblin to goblin.svg file
  static const String goblin = 'goblin.svg';

  /// map constant gold_bar to gold-bar.svg file
  static const String gold_bar = 'gold-bar.svg';

  /// map constant gold_mine to gold-mine.svg file
  static const String gold_mine = 'gold-mine.svg';

  /// map constant gold_nuggets to gold-nuggets.svg file
  static const String gold_nuggets = 'gold-nuggets.svg';

  /// map constant gold_scarab to gold-scarab.svg file
  static const String gold_scarab = 'gold-scarab.svg';

  /// map constant gold_shell to gold-shell.svg file
  static const String gold_shell = 'gold-shell.svg';

  /// map constant gold_stack to gold-stack.svg file
  static const String gold_stack = 'gold-stack.svg';

  /// map constant golem_head to golem-head.svg file
  static const String golem_head = 'golem-head.svg';

  /// map constant golf_flag to golf-flag.svg file
  static const String golf_flag = 'golf-flag.svg';

  /// map constant golf_tee to golf-tee.svg file
  static const String golf_tee = 'golf-tee.svg';

  /// map constant gong to gong.svg file
  static const String gong = 'gong.svg';

  /// map constant goo_explosion to goo-explosion.svg file
  static const String goo_explosion = 'goo-explosion.svg';

  /// map constant goo_skull to goo-skull.svg file
  static const String goo_skull = 'goo-skull.svg';

  /// map constant goo_spurt to goo-spurt.svg file
  static const String goo_spurt = 'goo-spurt.svg';

  /// map constant gooey_daemon to gooey-daemon.svg file
  static const String gooey_daemon = 'gooey-daemon.svg';

  /// map constant gooey_eyed_sun to gooey-eyed-sun.svg file
  static const String gooey_eyed_sun = 'gooey-eyed-sun.svg';

  /// map constant gooey_impact to gooey-impact.svg file
  static const String gooey_impact = 'gooey-impact.svg';

  /// map constant gooey_molecule to gooey-molecule.svg file
  static const String gooey_molecule = 'gooey-molecule.svg';

  /// map constant gooey_sword to gooey-sword.svg file
  static const String gooey_sword = 'gooey-sword.svg';

  /// map constant goose to goose.svg file
  static const String goose = 'goose.svg';

  /// map constant gorilla to gorilla.svg file
  static const String gorilla = 'gorilla.svg';

  /// map constant gothic_cross to gothic-cross.svg file
  static const String gothic_cross = 'gothic-cross.svg';

  /// map constant gps to gps.svg file
  static const String gps = 'gps.svg';

  /// map constant grab to grab.svg file
  static const String grab = 'grab.svg';

  /// map constant graduate_cap to graduate-cap.svg file
  static const String graduate_cap = 'graduate-cap.svg';

  /// map constant grain_bundle to grain-bundle.svg file
  static const String grain_bundle = 'grain-bundle.svg';

  /// map constant grain to grain.svg file
  static const String grain = 'grain.svg';

  /// map constant granary to granary.svg file
  static const String granary = 'granary.svg';

  /// map constant grand_piano to grand-piano.svg file
  static const String grand_piano = 'grand-piano.svg';

  /// map constant grapes to grapes.svg file
  static const String grapes = 'grapes.svg';

  /// map constant grapple to grapple.svg file
  static const String grapple = 'grapple.svg';

  /// map constant grasping_claws to grasping-claws.svg file
  static const String grasping_claws = 'grasping-claws.svg';

  /// map constant grasping_slug to grasping-slug.svg file
  static const String grasping_slug = 'grasping-slug.svg';

  /// map constant grass_mushroom to grass-mushroom.svg file
  static const String grass_mushroom = 'grass-mushroom.svg';

  /// map constant grass to grass.svg file
  static const String grass = 'grass.svg';

  /// map constant grave_flowers to grave-flowers.svg file
  static const String grave_flowers = 'grave-flowers.svg';

  /// map constant graveyard to graveyard.svg file
  static const String graveyard = 'graveyard.svg';

  /// map constant grease_trap to grease-trap.svg file
  static const String grease_trap = 'grease-trap.svg';

  /// map constant great_pyramid to great-pyramid.svg file
  static const String great_pyramid = 'great-pyramid.svg';

  /// map constant great_war_tank to great-war-tank.svg file
  static const String great_war_tank = 'great-war-tank.svg';

  /// map constant greaves to greaves.svg file
  static const String greaves = 'greaves.svg';

  /// map constant greek_sphinx to greek-sphinx.svg file
  static const String greek_sphinx = 'greek-sphinx.svg';

  /// map constant greek_temple to greek-temple.svg file
  static const String greek_temple = 'greek-temple.svg';

  /// map constant green_power to green-power.svg file
  static const String green_power = 'green-power.svg';

  /// map constant greenhouse to greenhouse.svg file
  static const String greenhouse = 'greenhouse.svg';

  /// map constant grenade2 to grenade 2.svg file
  static const String grenade2 = 'grenade 2.svg';

  /// map constant grenade to grenade.svg file
  static const String grenade = 'grenade.svg';

  /// map constant griffin_shield to griffin-shield.svg file
  static const String griffin_shield = 'griffin-shield.svg';

  /// map constant griffin_symbol to griffin-symbol.svg file
  static const String griffin_symbol = 'griffin-symbol.svg';

  /// map constant grim_reaper to grim-reaper.svg file
  static const String grim_reaper = 'grim-reaper.svg';

  /// map constant ground_sprout to ground-sprout.svg file
  static const String ground_sprout = 'ground-sprout.svg';

  /// map constant groundbreaker to groundbreaker.svg file
  static const String groundbreaker = 'groundbreaker.svg';

  /// map constant grouped_drops to grouped-drops.svg file
  static const String grouped_drops = 'grouped-drops.svg';

  /// map constant growth to growth.svg file
  static const String growth = 'growth.svg';

  /// map constant guarded_tower to guarded-tower.svg file
  static const String guarded_tower = 'guarded-tower.svg';

  /// map constant guards to guards.svg file
  static const String guards = 'guards.svg';

  /// map constant guatemala to guatemala.svg file
  static const String guatemala = 'guatemala.svg';

  /// map constant guillotine to guillotine.svg file
  static const String guillotine = 'guillotine.svg';

  /// map constant guitar_bass_head to guitar-bass-head.svg file
  static const String guitar_bass_head = 'guitar-bass-head.svg';

  /// map constant guitar_head to guitar-head.svg file
  static const String guitar_head = 'guitar-head.svg';

  /// map constant guitar to guitar.svg file
  static const String guitar = 'guitar.svg';

  /// map constant gun_rose to gun-rose.svg file
  static const String gun_rose = 'gun-rose.svg';

  /// map constant gun_stock to gun-stock.svg file
  static const String gun_stock = 'gun-stock.svg';

  /// map constant gunshot to gunshot.svg file
  static const String gunshot = 'gunshot.svg';

  /// map constant gym_bag to gym-bag.svg file
  static const String gym_bag = 'gym-bag.svg';

  /// map constant gyroscope to gyroscope.svg file
  static const String gyroscope = 'gyroscope.svg';

  /// map constant h2o to h2o.svg file
  static const String h2o = 'h2o.svg';

  /// map constant habitat_dome to habitat-dome.svg file
  static const String habitat_dome = 'habitat-dome.svg';

  /// map constant hades_symbol to hades-symbol.svg file
  static const String hades_symbol = 'hades-symbol.svg';

  /// map constant hair_strands to hair-strands.svg file
  static const String hair_strands = 'hair-strands.svg';

  /// map constant halberd_shuriken to halberd-shuriken.svg file
  static const String halberd_shuriken = 'halberd-shuriken.svg';

  /// map constant halberd to halberd.svg file
  static const String halberd = 'halberd.svg';

  /// map constant half_body_crawling to half-body-crawling.svg file
  static const String half_body_crawling = 'half-body-crawling.svg';

  /// map constant half_dead to half-dead.svg file
  static const String half_dead = 'half-dead.svg';

  /// map constant half_heart to half-heart.svg file
  static const String half_heart = 'half-heart.svg';

  /// map constant half_log to half-log.svg file
  static const String half_log = 'half-log.svg';

  /// map constant half_tornado to half-tornado.svg file
  static const String half_tornado = 'half-tornado.svg';

  /// map constant halt to halt.svg file
  static const String halt = 'halt.svg';

  /// map constant ham_shank to ham-shank.svg file
  static const String ham_shank = 'ham-shank.svg';

  /// map constant hamburger_menu to hamburger-menu.svg file
  static const String hamburger_menu = 'hamburger-menu.svg';

  /// map constant hamburger to hamburger.svg file
  static const String hamburger = 'hamburger.svg';

  /// map constant hammer_break to hammer-break.svg file
  static const String hammer_break = 'hammer-break.svg';

  /// map constant hammer_drop to hammer-drop.svg file
  static const String hammer_drop = 'hammer-drop.svg';

  /// map constant hammer_nails to hammer-nails.svg file
  static const String hammer_nails = 'hammer-nails.svg';

  /// map constant hammer_sickle to hammer-sickle.svg file
  static const String hammer_sickle = 'hammer-sickle.svg';

  /// map constant hand2 to hand 2.svg file
  static const String hand2 = 'hand 2.svg';

  /// map constant hand_bag to hand-bag.svg file
  static const String hand_bag = 'hand-bag.svg';

  /// map constant hand_bandage to hand-bandage.svg file
  static const String hand_bandage = 'hand-bandage.svg';

  /// map constant hand_grip to hand-grip.svg file
  static const String hand_grip = 'hand-grip.svg';

  /// map constant hand_of_god to hand-of-god.svg file
  static const String hand_of_god = 'hand-of-god.svg';

  /// map constant hand_ok to hand-ok.svg file
  static const String hand_ok = 'hand-ok.svg';

  /// map constant hand_saw to hand-saw.svg file
  static const String hand_saw = 'hand-saw.svg';

  /// map constant hand_truck to hand-truck.svg file
  static const String hand_truck = 'hand-truck.svg';

  /// map constant hand_wing to hand-wing.svg file
  static const String hand_wing = 'hand-wing.svg';

  /// map constant hand to hand.svg file
  static const String hand = 'hand.svg';

  /// map constant handcuffed to handcuffed.svg file
  static const String handcuffed = 'handcuffed.svg';

  /// map constant handcuffs to handcuffs.svg file
  static const String handcuffs = 'handcuffs.svg';

  /// map constant handheld_fan to handheld-fan.svg file
  static const String handheld_fan = 'handheld-fan.svg';

  /// map constant hang_glider2 to hang-glider 2.svg file
  static const String hang_glider2 = 'hang-glider 2.svg';

  /// map constant hang_glider to hang-glider.svg file
  static const String hang_glider = 'hang-glider.svg';

  /// map constant hanger to hanger.svg file
  static const String hanger = 'hanger.svg';

  /// map constant hanging_sign to hanging-sign.svg file
  static const String hanging_sign = 'hanging-sign.svg';

  /// map constant hanging_spider to hanging-spider.svg file
  static const String hanging_spider = 'hanging-spider.svg';

  /// map constant happy_skull to happy-skull.svg file
  static const String happy_skull = 'happy-skull.svg';

  /// map constant harbor_dock to harbor-dock.svg file
  static const String harbor_dock = 'harbor-dock.svg';

  /// map constant harp to harp.svg file
  static const String harp = 'harp.svg';

  /// map constant harpoon_chain to harpoon-chain.svg file
  static const String harpoon_chain = 'harpoon-chain.svg';

  /// map constant harpoon_trident to harpoon-trident.svg file
  static const String harpoon_trident = 'harpoon-trident.svg';

  /// map constant harpy to harpy.svg file
  static const String harpy = 'harpy.svg';

  /// map constant harry_potter_skull to harry-potter-skull.svg file
  static const String harry_potter_skull = 'harry-potter-skull.svg';

  /// map constant hasty_grave to hasty-grave.svg file
  static const String hasty_grave = 'hasty-grave.svg';

  /// map constant hatchet to hatchet.svg file
  static const String hatchet = 'hatchet.svg';

  /// map constant hatchets to hatchets.svg file
  static const String hatchets = 'hatchets.svg';

  /// map constant haunting to haunting.svg file
  static const String haunting = 'haunting.svg';

  /// map constant hawk_emblem to hawk-emblem.svg file
  static const String hawk_emblem = 'hawk-emblem.svg';

  /// map constant hazard_sign to hazard-sign.svg file
  static const String hazard_sign = 'hazard-sign.svg';

  /// map constant hazmat_suit to hazmat-suit.svg file
  static const String hazmat_suit = 'hazmat-suit.svg';

  /// map constant head_shot to head-shot.svg file
  static const String head_shot = 'head-shot.svg';

  /// map constant headband_knot to headband-knot.svg file
  static const String headband_knot = 'headband-knot.svg';

  /// map constant headphones to headphones.svg file
  static const String headphones = 'headphones.svg';

  /// map constant headshot2 to headshot 2.svg file
  static const String headshot2 = 'headshot 2.svg';

  /// map constant headshot to headshot.svg file
  static const String headshot = 'headshot.svg';

  /// map constant healing_shield to healing-shield.svg file
  static const String healing_shield = 'healing-shield.svg';

  /// map constant healing to healing.svg file
  static const String healing = 'healing.svg';

  /// map constant health_capsule to health-capsule.svg file
  static const String health_capsule = 'health-capsule.svg';

  /// map constant health_decrease to health-decrease.svg file
  static const String health_decrease = 'health-decrease.svg';

  /// map constant health_increase to health-increase.svg file
  static const String health_increase = 'health-increase.svg';

  /// map constant health_normal to health-normal.svg file
  static const String health_normal = 'health-normal.svg';

  /// map constant health_potion to health-potion.svg file
  static const String health_potion = 'health-potion.svg';

  /// map constant hearing_disabled to hearing-disabled.svg file
  static const String hearing_disabled = 'hearing-disabled.svg';

  /// map constant heart_armor to heart-armor.svg file
  static const String heart_armor = 'heart-armor.svg';

  /// map constant heart_battery to heart-battery.svg file
  static const String heart_battery = 'heart-battery.svg';

  /// map constant heart_beats to heart-beats.svg file
  static const String heart_beats = 'heart-beats.svg';

  /// map constant heart_bottle to heart-bottle.svg file
  static const String heart_bottle = 'heart-bottle.svg';

  /// map constant heart_drop to heart-drop.svg file
  static const String heart_drop = 'heart-drop.svg';

  /// map constant heart_earrings to heart-earrings.svg file
  static const String heart_earrings = 'heart-earrings.svg';

  /// map constant heart_inside to heart-inside.svg file
  static const String heart_inside = 'heart-inside.svg';

  /// map constant heart_key to heart-key.svg file
  static const String heart_key = 'heart-key.svg';

  /// map constant heart_minus to heart-minus.svg file
  static const String heart_minus = 'heart-minus.svg';

  /// map constant heart_necklace to heart-necklace.svg file
  static const String heart_necklace = 'heart-necklace.svg';

  /// map constant heart_organ to heart-organ.svg file
  static const String heart_organ = 'heart-organ.svg';

  /// map constant heart_plus to heart-plus.svg file
  static const String heart_plus = 'heart-plus.svg';

  /// map constant heart_shield to heart-shield.svg file
  static const String heart_shield = 'heart-shield.svg';

  /// map constant heart_stake to heart-stake.svg file
  static const String heart_stake = 'heart-stake.svg';

  /// map constant heart_tower to heart-tower.svg file
  static const String heart_tower = 'heart-tower.svg';

  /// map constant heart_wings to heart-wings.svg file
  static const String heart_wings = 'heart-wings.svg';

  /// map constant heartburn to heartburn.svg file
  static const String heartburn = 'heartburn.svg';

  /// map constant hearts to hearts.svg file
  static const String hearts = 'hearts.svg';

  /// map constant heat_haze to heat-haze.svg file
  static const String heat_haze = 'heat-haze.svg';

  /// map constant heaven_gate to heaven-gate.svg file
  static const String heaven_gate = 'heaven-gate.svg';

  /// map constant heavy_arrow to heavy-arrow.svg file
  static const String heavy_arrow = 'heavy-arrow.svg';

  /// map constant heavy_bullets to heavy-bullets.svg file
  static const String heavy_bullets = 'heavy-bullets.svg';

  /// map constant heavy_collar to heavy-collar.svg file
  static const String heavy_collar = 'heavy-collar.svg';

  /// map constant heavy_fall to heavy-fall.svg file
  static const String heavy_fall = 'heavy-fall.svg';

  /// map constant heavy_fighter to heavy-fighter.svg file
  static const String heavy_fighter = 'heavy-fighter.svg';

  /// map constant heavy_helm to heavy-helm.svg file
  static const String heavy_helm = 'heavy-helm.svg';

  /// map constant heavy_lightning to heavy-lightning.svg file
  static const String heavy_lightning = 'heavy-lightning.svg';

  /// map constant heavy_rain to heavy-rain.svg file
  static const String heavy_rain = 'heavy-rain.svg';

  /// map constant heavy_thorny_triskelion to heavy-thorny-triskelion.svg file
  static const String heavy_thorny_triskelion = 'heavy-thorny-triskelion.svg';

  /// map constant heavy_timer to heavy-timer.svg file
  static const String heavy_timer = 'heavy-timer.svg';

  /// map constant hedgehog to hedgehog.svg file
  static const String hedgehog = 'hedgehog.svg';

  /// map constant hedjet_white_crown to hedjet-white-crown.svg file
  static const String hedjet_white_crown = 'hedjet-white-crown.svg';

  /// map constant helicoprion to helicoprion.svg file
  static const String helicoprion = 'helicoprion.svg';

  /// map constant helicopter_tail to helicopter-tail.svg file
  static const String helicopter_tail = 'helicopter-tail.svg';

  /// map constant helicopter to helicopter.svg file
  static const String helicopter = 'helicopter.svg';

  /// map constant hell_crosses to hell-crosses.svg file
  static const String hell_crosses = 'hell-crosses.svg';

  /// map constant helmet_head_shot to helmet-head-shot.svg file
  static const String helmet_head_shot = 'helmet-head-shot.svg';

  /// map constant helmet to helmet.svg file
  static const String helmet = 'helmet.svg';

  /// map constant help to help.svg file
  static const String help = 'help.svg';

  /// map constant hemp to hemp.svg file
  static const String hemp = 'hemp.svg';

  /// map constant heptagram to heptagram.svg file
  static const String heptagram = 'heptagram.svg';

  /// map constant heraldic_sun to heraldic-sun.svg file
  static const String heraldic_sun = 'heraldic-sun.svg';

  /// map constant herbs_bundle to herbs-bundle.svg file
  static const String herbs_bundle = 'herbs-bundle.svg';

  /// map constant heron to heron.svg file
  static const String heron = 'heron.svg';

  /// map constant hexagonal_nut to hexagonal-nut.svg file
  static const String hexagonal_nut = 'hexagonal-nut.svg';

  /// map constant hexes to hexes.svg file
  static const String hexes = 'hexes.svg';

  /// map constant hidden to hidden.svg file
  static const String hidden = 'hidden.svg';

  /// map constant hieroglyph_legs to hieroglyph-legs.svg file
  static const String hieroglyph_legs = 'hieroglyph-legs.svg';

  /// map constant hieroglyph_y to hieroglyph-y.svg file
  static const String hieroglyph_y = 'hieroglyph-y.svg';

  /// map constant high_five to high-five.svg file
  static const String high_five = 'high-five.svg';

  /// map constant high_grass to high-grass.svg file
  static const String high_grass = 'high-grass.svg';

  /// map constant high_heel to high-heel.svg file
  static const String high_heel = 'high-heel.svg';

  /// map constant high_kick to high-kick.svg file
  static const String high_kick = 'high-kick.svg';

  /// map constant high_punch to high-punch.svg file
  static const String high_punch = 'high-punch.svg';

  /// map constant high_shot to high-shot.svg file
  static const String high_shot = 'high-shot.svg';

  /// map constant high_tide to high-tide.svg file
  static const String high_tide = 'high-tide.svg';

  /// map constant highlighter to highlighter.svg file
  static const String highlighter = 'highlighter.svg';

  /// map constant hiking to hiking.svg file
  static const String hiking = 'hiking.svg';

  /// map constant hill_conquest to hill-conquest.svg file
  static const String hill_conquest = 'hill-conquest.svg';

  /// map constant hill_fort to hill-fort.svg file
  static const String hill_fort = 'hill-fort.svg';

  /// map constant hills to hills.svg file
  static const String hills = 'hills.svg';

  /// map constant histogram to histogram.svg file
  static const String histogram = 'histogram.svg';

  /// map constant hive_mind to hive-mind.svg file
  static const String hive_mind = 'hive-mind.svg';

  /// map constant hive to hive.svg file
  static const String hive = 'hive.svg';

  /// map constant hobbit_door to hobbit-door.svg file
  static const String hobbit_door = 'hobbit-door.svg';

  /// map constant hobbit_dwelling to hobbit-dwelling.svg file
  static const String hobbit_dwelling = 'hobbit-dwelling.svg';

  /// map constant hockey to hockey.svg file
  static const String hockey = 'hockey.svg';

  /// map constant hole_ladder to hole-ladder.svg file
  static const String hole_ladder = 'hole-ladder.svg';

  /// map constant hole to hole.svg file
  static const String hole = 'hole.svg';

  /// map constant hollow_cat to hollow-cat.svg file
  static const String hollow_cat = 'hollow-cat.svg';

  /// map constant holosphere to holosphere.svg file
  static const String holosphere = 'holosphere.svg';

  /// map constant holy_grail to holy-grail.svg file
  static const String holy_grail = 'holy-grail.svg';

  /// map constant holy_hand_grenade to holy-hand-grenade.svg file
  static const String holy_hand_grenade = 'holy-hand-grenade.svg';

  /// map constant holy_oak to holy-oak.svg file
  static const String holy_oak = 'holy-oak.svg';

  /// map constant holy_symbol to holy-symbol.svg file
  static const String holy_symbol = 'holy-symbol.svg';

  /// map constant holy_water to holy-water.svg file
  static const String holy_water = 'holy-water.svg';

  /// map constant home_garage to home-garage.svg file
  static const String home_garage = 'home-garage.svg';

  /// map constant honey_jar to honey-jar.svg file
  static const String honey_jar = 'honey-jar.svg';

  /// map constant honeycomb to honeycomb.svg file
  static const String honeycomb = 'honeycomb.svg';

  /// map constant honeypot to honeypot.svg file
  static const String honeypot = 'honeypot.svg';

  /// map constant hood to hood.svg file
  static const String hood = 'hood.svg';

  /// map constant hooded_assassin to hooded-assassin.svg file
  static const String hooded_assassin = 'hooded-assassin.svg';

  /// map constant hooded_figure to hooded-figure.svg file
  static const String hooded_figure = 'hooded-figure.svg';

  /// map constant hoodie to hoodie.svg file
  static const String hoodie = 'hoodie.svg';

  /// map constant hoof to hoof.svg file
  static const String hoof = 'hoof.svg';

  /// map constant hook to hook.svg file
  static const String hook = 'hook.svg';

  /// map constant hops to hops.svg file
  static const String hops = 'hops.svg';

  /// map constant horizon_road to horizon-road.svg file
  static const String horizon_road = 'horizon-road.svg';

  /// map constant horizontal_flip to horizontal-flip.svg file
  static const String horizontal_flip = 'horizontal-flip.svg';

  /// map constant horn_internal to horn-internal.svg file
  static const String horn_internal = 'horn-internal.svg';

  /// map constant horned_helm to horned-helm.svg file
  static const String horned_helm = 'horned-helm.svg';

  /// map constant horned_reptile to horned-reptile.svg file
  static const String horned_reptile = 'horned-reptile.svg';

  /// map constant horned_skull to horned-skull.svg file
  static const String horned_skull = 'horned-skull.svg';

  /// map constant horse_head2 to horse-head 2.svg file
  static const String horse_head2 = 'horse-head 2.svg';

  /// map constant horse_head to horse-head.svg file
  static const String horse_head = 'horse-head.svg';

  /// map constant horseshoe to horseshoe.svg file
  static const String horseshoe = 'horseshoe.svg';

  /// map constant horus to horus.svg file
  static const String horus = 'horus.svg';

  /// map constant hospital_cross to hospital-cross.svg file
  static const String hospital_cross = 'hospital-cross.svg';

  /// map constant hospital to hospital.svg file
  static const String hospital = 'hospital.svg';

  /// map constant hot_dog to hot-dog.svg file
  static const String hot_dog = 'hot-dog.svg';

  /// map constant hot_meal to hot-meal.svg file
  static const String hot_meal = 'hot-meal.svg';

  /// map constant hot_spices to hot-spices.svg file
  static const String hot_spices = 'hot-spices.svg';

  /// map constant hot_surface to hot-surface.svg file
  static const String hot_surface = 'hot-surface.svg';

  /// map constant hound to hound.svg file
  static const String hound = 'hound.svg';

  /// map constant hourglass to hourglass.svg file
  static const String hourglass = 'hourglass.svg';

  /// map constant house_keys to house-keys.svg file
  static const String house_keys = 'house-keys.svg';

  /// map constant house to house.svg file
  static const String house = 'house.svg';

  /// map constant human_cannonball to human-cannonball.svg file
  static const String human_cannonball = 'human-cannonball.svg';

  /// map constant human_ear to human-ear.svg file
  static const String human_ear = 'human-ear.svg';

  /// map constant human_pyramid to human-pyramid.svg file
  static const String human_pyramid = 'human-pyramid.svg';

  /// map constant human_target to human-target.svg file
  static const String human_target = 'human-target.svg';

  /// map constant hummingbird to hummingbird.svg file
  static const String hummingbird = 'hummingbird.svg';

  /// map constant hungary to hungary.svg file
  static const String hungary = 'hungary.svg';

  /// map constant hunter_eyes to hunter-eyes.svg file
  static const String hunter_eyes = 'hunter-eyes.svg';

  /// map constant hunting_bolas to hunting-bolas.svg file
  static const String hunting_bolas = 'hunting-bolas.svg';

  /// map constant hunting_horn to hunting-horn.svg file
  static const String hunting_horn = 'hunting-horn.svg';

  /// map constant hut to hut.svg file
  static const String hut = 'hut.svg';

  /// map constant huts_village to huts-village.svg file
  static const String huts_village = 'huts-village.svg';

  /// map constant hydra_shot to hydra-shot.svg file
  static const String hydra_shot = 'hydra-shot.svg';

  /// map constant hydra to hydra.svg file
  static const String hydra = 'hydra.svg';

  /// map constant hyena_head to hyena-head.svg file
  static const String hyena_head = 'hyena-head.svg';

  /// map constant hypersonic_bolt to hypersonic-bolt.svg file
  static const String hypersonic_bolt = 'hypersonic-bolt.svg';

  /// map constant hypersonic_melon to hypersonic-melon.svg file
  static const String hypersonic_melon = 'hypersonic-melon.svg';

  /// map constant hypodermic_test to hypodermic-test.svg file
  static const String hypodermic_test = 'hypodermic-test.svg';

  /// map constant i_beam to i-beam.svg file
  static const String i_beam = 'i-beam.svg';

  /// map constant i_brick to i-brick.svg file
  static const String i_brick = 'i-brick.svg';

  /// map constant ibis to ibis.svg file
  static const String ibis = 'ibis.svg';

  /// map constant icarus to icarus.svg file
  static const String icarus = 'icarus.svg';

  /// map constant ice_bolt to ice-bolt.svg file
  static const String ice_bolt = 'ice-bolt.svg';

  /// map constant ice_bomb to ice-bomb.svg file
  static const String ice_bomb = 'ice-bomb.svg';

  /// map constant ice_cream_cone to ice-cream-cone.svg file
  static const String ice_cream_cone = 'ice-cream-cone.svg';

  /// map constant ice_cream_scoop to ice-cream-scoop.svg file
  static const String ice_cream_scoop = 'ice-cream-scoop.svg';

  /// map constant ice_cube to ice-cube.svg file
  static const String ice_cube = 'ice-cube.svg';

  /// map constant ice_cubes to ice-cubes.svg file
  static const String ice_cubes = 'ice-cubes.svg';

  /// map constant ice_golem to ice-golem.svg file
  static const String ice_golem = 'ice-golem.svg';

  /// map constant ice_iris to ice-iris.svg file
  static const String ice_iris = 'ice-iris.svg';

  /// map constant ice_pop to ice-pop.svg file
  static const String ice_pop = 'ice-pop.svg';

  /// map constant ice_shield to ice-shield.svg file
  static const String ice_shield = 'ice-shield.svg';

  /// map constant ice_skate to ice-skate.svg file
  static const String ice_skate = 'ice-skate.svg';

  /// map constant ice_spear to ice-spear.svg file
  static const String ice_spear = 'ice-spear.svg';

  /// map constant ice_spell_cast to ice-spell-cast.svg file
  static const String ice_spell_cast = 'ice-spell-cast.svg';

  /// map constant iceberg to iceberg.svg file
  static const String iceberg = 'iceberg.svg';

  /// map constant icebergs to icebergs.svg file
  static const String icebergs = 'icebergs.svg';

  /// map constant iceland to iceland.svg file
  static const String iceland = 'iceland.svg';

  /// map constant icicles_aura to icicles-aura.svg file
  static const String icicles_aura = 'icicles-aura.svg';

  /// map constant icicles_fence to icicles-fence.svg file
  static const String icicles_fence = 'icicles-fence.svg';

  /// map constant id_card to id-card.svg file
  static const String id_card = 'id-card.svg';

  /// map constant idea to idea.svg file
  static const String idea = 'idea.svg';

  /// map constant ifrit to ifrit.svg file
  static const String ifrit = 'ifrit.svg';

  /// map constant igloo to igloo.svg file
  static const String igloo = 'igloo.svg';

  /// map constant imbricated_arrows to imbricated-arrows.svg file
  static const String imbricated_arrows = 'imbricated-arrows.svg';

  /// map constant imp_laugh to imp-laugh.svg file
  static const String imp_laugh = 'imp-laugh.svg';

  /// map constant imp to imp.svg file
  static const String imp = 'imp.svg';

  /// map constant impact_point to impact-point.svg file
  static const String impact_point = 'impact-point.svg';

  /// map constant imperial_crown to imperial-crown.svg file
  static const String imperial_crown = 'imperial-crown.svg';

  /// map constant implosion to implosion.svg file
  static const String implosion = 'implosion.svg';

  /// map constant imprisoned to imprisoned.svg file
  static const String imprisoned = 'imprisoned.svg';

  /// map constant inauguration to inauguration.svg file
  static const String inauguration = 'inauguration.svg';

  /// map constant incense to incense.svg file
  static const String incense = 'incense.svg';

  /// map constant incisors to incisors.svg file
  static const String incisors = 'incisors.svg';

  /// map constant incoming_rocket to incoming-rocket.svg file
  static const String incoming_rocket = 'incoming-rocket.svg';

  /// map constant incubator to incubator.svg file
  static const String incubator = 'incubator.svg';

  /// map constant india_gate to india-gate.svg file
  static const String india_gate = 'india-gate.svg';

  /// map constant indian_palace to indian-palace.svg file
  static const String indian_palace = 'indian-palace.svg';

  /// map constant inferno_bomb to inferno-bomb.svg file
  static const String inferno_bomb = 'inferno-bomb.svg';

  /// map constant infested_mass to infested-mass.svg file
  static const String infested_mass = 'infested-mass.svg';

  /// map constant infinity to infinity.svg file
  static const String infinity = 'infinity.svg';

  /// map constant info to info.svg file
  static const String info = 'info.svg';

  /// map constant injustice to injustice.svg file
  static const String injustice = 'injustice.svg';

  /// map constant ink_swirl to ink-swirl.svg file
  static const String ink_swirl = 'ink-swirl.svg';

  /// map constant inner_self to inner-self.svg file
  static const String inner_self = 'inner-self.svg';

  /// map constant insect_jaws to insect-jaws.svg file
  static const String insect_jaws = 'insect-jaws.svg';

  /// map constant inspiration to inspiration.svg file
  static const String inspiration = 'inspiration.svg';

  /// map constant interceptor_ship to interceptor-ship.svg file
  static const String interceptor_ship = 'interceptor-ship.svg';

  /// map constant interdiction to interdiction.svg file
  static const String interdiction = 'interdiction.svg';

  /// map constant interlaced_tentacles to interlaced-tentacles.svg file
  static const String interlaced_tentacles = 'interlaced-tentacles.svg';

  /// map constant interleaved_arrows to interleaved-arrows.svg file
  static const String interleaved_arrows = 'interleaved-arrows.svg';

  /// map constant interleaved_claws to interleaved-claws.svg file
  static const String interleaved_claws = 'interleaved-claws.svg';

  /// map constant internal_injury to internal-injury.svg file
  static const String internal_injury = 'internal-injury.svg';

  /// map constant internal_organ to internal-organ.svg file
  static const String internal_organ = 'internal-organ.svg';

  /// map constant interstellar_path to interstellar-path.svg file
  static const String interstellar_path = 'interstellar-path.svg';

  /// map constant intricate_necklace to intricate-necklace.svg file
  static const String intricate_necklace = 'intricate-necklace.svg';

  /// map constant inverted_dice_1 to inverted-dice-1.svg file
  static const String inverted_dice_1 = 'inverted-dice-1.svg';

  /// map constant inverted_dice_2 to inverted-dice-2.svg file
  static const String inverted_dice_2 = 'inverted-dice-2.svg';

  /// map constant inverted_dice_3 to inverted-dice-3.svg file
  static const String inverted_dice_3 = 'inverted-dice-3.svg';

  /// map constant inverted_dice_4 to inverted-dice-4.svg file
  static const String inverted_dice_4 = 'inverted-dice-4.svg';

  /// map constant inverted_dice_5 to inverted-dice-5.svg file
  static const String inverted_dice_5 = 'inverted-dice-5.svg';

  /// map constant inverted_dice_6 to inverted-dice-6.svg file
  static const String inverted_dice_6 = 'inverted-dice-6.svg';

  /// map constant invisible_face to invisible-face.svg file
  static const String invisible_face = 'invisible-face.svg';

  /// map constant invisible to invisible.svg file
  static const String invisible = 'invisible.svg';

  /// map constant ion_cannon_blast to ion-cannon-blast.svg file
  static const String ion_cannon_blast = 'ion-cannon-blast.svg';

  /// map constant ionic_column to ionic-column.svg file
  static const String ionic_column = 'ionic-column.svg';

  /// map constant iraq to iraq.svg file
  static const String iraq = 'iraq.svg';

  /// map constant iron_cross to iron-cross.svg file
  static const String iron_cross = 'iron-cross.svg';

  /// map constant iron_hulled_warship to iron-hulled-warship.svg file
  static const String iron_hulled_warship = 'iron-hulled-warship.svg';

  /// map constant iron_mask to iron-mask.svg file
  static const String iron_mask = 'iron-mask.svg';

  /// map constant island to island.svg file
  static const String island = 'island.svg';

  /// map constant italia to italia.svg file
  static const String italia = 'italia.svg';

  /// map constant ivory_tusks to ivory-tusks.svg file
  static const String ivory_tusks = 'ivory-tusks.svg';

  /// map constant j_brick to j-brick.svg file
  static const String j_brick = 'j-brick.svg';

  /// map constant jack_plug to jack-plug.svg file
  static const String jack_plug = 'jack-plug.svg';

  /// map constant james_bond_aperture to james-bond-aperture.svg file
  static const String james_bond_aperture = 'james-bond-aperture.svg';

  /// map constant japan to japan.svg file
  static const String japan = 'japan.svg';

  /// map constant japanese_bridge to japanese-bridge.svg file
  static const String japanese_bridge = 'japanese-bridge.svg';

  /// map constant jasmine to jasmine.svg file
  static const String jasmine = 'jasmine.svg';

  /// map constant jason_mask to jason-mask.svg file
  static const String jason_mask = 'jason-mask.svg';

  /// map constant jawbone to jawbone.svg file
  static const String jawbone = 'jawbone.svg';

  /// map constant jawless_cyclop to jawless-cyclop.svg file
  static const String jawless_cyclop = 'jawless-cyclop.svg';

  /// map constant jeep2 to jeep 2.svg file
  static const String jeep2 = 'jeep 2.svg';

  /// map constant jeep to jeep.svg file
  static const String jeep = 'jeep.svg';

  /// map constant jelly_beans to jelly-beans.svg file
  static const String jelly_beans = 'jelly-beans.svg';

  /// map constant jelly to jelly.svg file
  static const String jelly = 'jelly.svg';

  /// map constant jellyfish to jellyfish.svg file
  static const String jellyfish = 'jellyfish.svg';

  /// map constant jerrycan to jerrycan.svg file
  static const String jerrycan = 'jerrycan.svg';

  /// map constant jerusalem_cross to jerusalem-cross.svg file
  static const String jerusalem_cross = 'jerusalem-cross.svg';

  /// map constant jester_hat to jester-hat.svg file
  static const String jester_hat = 'jester-hat.svg';

  /// map constant jet_fighter to jet-fighter.svg file
  static const String jet_fighter = 'jet-fighter.svg';

  /// map constant jet_pack to jet-pack.svg file
  static const String jet_pack = 'jet-pack.svg';

  /// map constant jetpack to jetpack.svg file
  static const String jetpack = 'jetpack.svg';

  /// map constant jewel_crown to jewel-crown.svg file
  static const String jewel_crown = 'jewel-crown.svg';

  /// map constant jeweled_chalice to jeweled-chalice.svg file
  static const String jeweled_chalice = 'jeweled-chalice.svg';

  /// map constant jigsaw_box to jigsaw-box.svg file
  static const String jigsaw_box = 'jigsaw-box.svg';

  /// map constant jigsaw_piece to jigsaw-piece.svg file
  static const String jigsaw_piece = 'jigsaw-piece.svg';

  /// map constant join to join.svg file
  static const String join = 'join.svg';

  /// map constant joint to joint.svg file
  static const String joint = 'joint.svg';

  /// map constant journey to journey.svg file
  static const String journey = 'journey.svg';

  /// map constant joystick to joystick.svg file
  static const String joystick = 'joystick.svg';

  /// map constant jug to jug.svg file
  static const String jug = 'jug.svg';

  /// map constant juggler to juggler.svg file
  static const String juggler = 'juggler.svg';

  /// map constant juggling_clubs to juggling-clubs.svg file
  static const String juggling_clubs = 'juggling-clubs.svg';

  /// map constant juggling_seal to juggling-seal.svg file
  static const String juggling_seal = 'juggling-seal.svg';

  /// map constant jump_across to jump-across.svg file
  static const String jump_across = 'jump-across.svg';

  /// map constant jumping_dog to jumping-dog.svg file
  static const String jumping_dog = 'jumping-dog.svg';

  /// map constant jumping_rope to jumping-rope.svg file
  static const String jumping_rope = 'jumping-rope.svg';

  /// map constant jungle to jungle.svg file
  static const String jungle = 'jungle.svg';

  /// map constant jupiter to jupiter.svg file
  static const String jupiter = 'jupiter.svg';

  /// map constant justice_star to justice-star.svg file
  static const String justice_star = 'justice-star.svg';

  /// map constant kaleidoscope_pearls to kaleidoscope-pearls.svg file
  static const String kaleidoscope_pearls = 'kaleidoscope-pearls.svg';

  /// map constant kangaroo to kangaroo.svg file
  static const String kangaroo = 'kangaroo.svg';

  /// map constant katana to katana.svg file
  static const String katana = 'katana.svg';

  /// map constant kebab_spit to kebab-spit.svg file
  static const String kebab_spit = 'kebab-spit.svg';

  /// map constant kenku_head to kenku-head.svg file
  static const String kenku_head = 'kenku-head.svg';

  /// map constant kenya to kenya.svg file
  static const String kenya = 'kenya.svg';

  /// map constant ketchup to ketchup.svg file
  static const String ketchup = 'ketchup.svg';

  /// map constant kevlar_vest to kevlar-vest.svg file
  static const String kevlar_vest = 'kevlar-vest.svg';

  /// map constant kevlar to kevlar.svg file
  static const String kevlar = 'kevlar.svg';

  /// map constant key2 to key 2.svg file
  static const String key2 = 'key 2.svg';

  /// map constant key_card to key-card.svg file
  static const String key_card = 'key-card.svg';

  /// map constant key_lock to key-lock.svg file
  static const String key_lock = 'key-lock.svg';

  /// map constant key_ to key.svg file
  static const String key_ = 'key.svg';

  /// map constant keyboard to keyboard.svg file
  static const String keyboard = 'keyboard.svg';

  /// map constant keyring to keyring.svg file
  static const String keyring = 'keyring.svg';

  /// map constant kick_scooter to kick-scooter.svg file
  static const String kick_scooter = 'kick-scooter.svg';

  /// map constant kid_slide to kid-slide.svg file
  static const String kid_slide = 'kid-slide.svg';

  /// map constant kidneys to kidneys.svg file
  static const String kidneys = 'kidneys.svg';

  /// map constant kimono to kimono.svg file
  static const String kimono = 'kimono.svg';

  /// map constant kindle to kindle.svg file
  static const String kindle = 'kindle.svg';

  /// map constant king_ju_mask to king-ju-mask.svg file
  static const String king_ju_mask = 'king-ju-mask.svg';

  /// map constant king to king.svg file
  static const String king = 'king.svg';

  /// map constant kitchen_knives to kitchen-knives.svg file
  static const String kitchen_knives = 'kitchen-knives.svg';

  /// map constant kitchen_scale to kitchen-scale.svg file
  static const String kitchen_scale = 'kitchen-scale.svg';

  /// map constant kitchen_tap to kitchen-tap.svg file
  static const String kitchen_tap = 'kitchen-tap.svg';

  /// map constant kite to kite.svg file
  static const String kite = 'kite.svg';

  /// map constant kiwi_bird to kiwi-bird.svg file
  static const String kiwi_bird = 'kiwi-bird.svg';

  /// map constant kiwi_fruit to kiwi-fruit.svg file
  static const String kiwi_fruit = 'kiwi-fruit.svg';

  /// map constant klingon to klingon.svg file
  static const String klingon = 'klingon.svg';

  /// map constant knapsack to knapsack.svg file
  static const String knapsack = 'knapsack.svg';

  /// map constant knee_bandage to knee-bandage.svg file
  static const String knee_bandage = 'knee-bandage.svg';

  /// map constant knee_cap to knee-cap.svg file
  static const String knee_cap = 'knee-cap.svg';

  /// map constant knee_pad to knee-pad.svg file
  static const String knee_pad = 'knee-pad.svg';

  /// map constant kneeling to kneeling.svg file
  static const String kneeling = 'kneeling.svg';

  /// map constant knife_fork to knife-fork.svg file
  static const String knife_fork = 'knife-fork.svg';

  /// map constant knife_thrust to knife-thrust.svg file
  static const String knife_thrust = 'knife-thrust.svg';

  /// map constant knight_banner to knight-banner.svg file
  static const String knight_banner = 'knight-banner.svg';

  /// map constant knocked_out_stars to knocked-out-stars.svg file
  static const String knocked_out_stars = 'knocked-out-stars.svg';

  /// map constant knockout to knockout.svg file
  static const String knockout = 'knockout.svg';

  /// map constant knot to knot.svg file
  static const String knot = 'knot.svg';

  /// map constant koala to koala.svg file
  static const String koala = 'koala.svg';

  /// map constant koholint_egg to koholint-egg.svg file
  static const String koholint_egg = 'koholint-egg.svg';

  /// map constant kraken_tentacle to kraken-tentacle.svg file
  static const String kraken_tentacle = 'kraken-tentacle.svg';

  /// map constant kusarigama to kusarigama.svg file
  static const String kusarigama = 'kusarigama.svg';

  /// map constant l_brick to l-brick.svg file
  static const String l_brick = 'l-brick.svg';

  /// map constant lab_coat to lab-coat.svg file
  static const String lab_coat = 'lab-coat.svg';

  /// map constant labrador_head to labrador-head.svg file
  static const String labrador_head = 'labrador-head.svg';

  /// map constant ladder to ladder.svg file
  static const String ladder = 'ladder.svg';

  /// map constant ladders_platform to ladders-platform.svg file
  static const String ladders_platform = 'ladders-platform.svg';

  /// map constant ladle to ladle.svg file
  static const String ladle = 'ladle.svg';

  /// map constant ladybug to ladybug.svg file
  static const String ladybug = 'ladybug.svg';

  /// map constant lamellar to lamellar.svg file
  static const String lamellar = 'lamellar.svg';

  /// map constant lamprey_mouth to lamprey-mouth.svg file
  static const String lamprey_mouth = 'lamprey-mouth.svg';

  /// map constant land_mine to land-mine.svg file
  static const String land_mine = 'land-mine.svg';

  /// map constant lantern_flame to lantern-flame.svg file
  static const String lantern_flame = 'lantern-flame.svg';

  /// map constant lantern to lantern.svg file
  static const String lantern = 'lantern.svg';

  /// map constant laptop to laptop.svg file
  static const String laptop = 'laptop.svg';

  /// map constant large_dress to large-dress.svg file
  static const String large_dress = 'large-dress.svg';

  /// map constant large_paint_brush to large-paint-brush.svg file
  static const String large_paint_brush = 'large-paint-brush.svg';

  /// map constant large_wound to large-wound.svg file
  static const String large_wound = 'large-wound.svg';

  /// map constant laser_blast to laser-blast.svg file
  static const String laser_blast = 'laser-blast.svg';

  /// map constant laser_burst to laser-burst.svg file
  static const String laser_burst = 'laser-burst.svg';

  /// map constant laser_gun to laser-gun.svg file
  static const String laser_gun = 'laser-gun.svg';

  /// map constant laser_precision to laser-precision.svg file
  static const String laser_precision = 'laser-precision.svg';

  /// map constant laser_sparks to laser-sparks.svg file
  static const String laser_sparks = 'laser-sparks.svg';

  /// map constant laser_turret to laser-turret.svg file
  static const String laser_turret = 'laser-turret.svg';

  /// map constant laser_warning to laser-warning.svg file
  static const String laser_warning = 'laser-warning.svg';

  /// map constant laserburn to laserburn.svg file
  static const String laserburn = 'laserburn.svg';

  /// map constant lasso to lasso.svg file
  static const String lasso = 'lasso.svg';

  /// map constant latvia to latvia.svg file
  static const String latvia = 'latvia.svg';

  /// map constant laurel_crown to laurel-crown.svg file
  static const String laurel_crown = 'laurel-crown.svg';

  /// map constant laurels_trophy to laurels-trophy.svg file
  static const String laurels_trophy = 'laurels-trophy.svg';

  /// map constant laurels to laurels.svg file
  static const String laurels = 'laurels.svg';

  /// map constant lava to lava.svg file
  static const String lava = 'lava.svg';

  /// map constant law_star to law-star.svg file
  static const String law_star = 'law-star.svg';

  /// map constant layered_armor to layered-armor.svg file
  static const String layered_armor = 'layered-armor.svg';

  /// map constant lead_pipe to lead-pipe.svg file
  static const String lead_pipe = 'lead-pipe.svg';

  /// map constant leaf_skeleton to leaf-skeleton.svg file
  static const String leaf_skeleton = 'leaf-skeleton.svg';

  /// map constant leaf_swirl to leaf-swirl.svg file
  static const String leaf_swirl = 'leaf-swirl.svg';

  /// map constant leak to leak.svg file
  static const String leak = 'leak.svg';

  /// map constant leaky_skull to leaky-skull.svg file
  static const String leaky_skull = 'leaky-skull.svg';

  /// map constant leapfrog to leapfrog.svg file
  static const String leapfrog = 'leapfrog.svg';

  /// map constant leather_armor to leather-armor.svg file
  static const String leather_armor = 'leather-armor.svg';

  /// map constant leather_boot to leather-boot.svg file
  static const String leather_boot = 'leather-boot.svg';

  /// map constant leather_vest to leather-vest.svg file
  static const String leather_vest = 'leather-vest.svg';

  /// map constant led to led.svg file
  static const String led = 'led.svg';

  /// map constant lee_enfield to lee-enfield.svg file
  static const String lee_enfield = 'lee-enfield.svg';

  /// map constant leeching_worm to leeching-worm.svg file
  static const String leeching_worm = 'leeching-worm.svg';

  /// map constant leek to leek.svg file
  static const String leek = 'leek.svg';

  /// map constant leg_armor to leg-armor.svg file
  static const String leg_armor = 'leg-armor.svg';

  /// map constant leg to leg.svg file
  static const String leg = 'leg.svg';

  /// map constant lemon to lemon.svg file
  static const String lemon = 'lemon.svg';

  /// map constant leo to leo.svg file
  static const String leo = 'leo.svg';

  /// map constant letter_bomb to letter-bomb.svg file
  static const String letter_bomb = 'letter-bomb.svg';

  /// map constant level_crossing to level-crossing.svg file
  static const String level_crossing = 'level-crossing.svg';

  /// map constant level_end_flag to level-end-flag.svg file
  static const String level_end_flag = 'level-end-flag.svg';

  /// map constant level_four_advanced to level-four-advanced.svg file
  static const String level_four_advanced = 'level-four-advanced.svg';

  /// map constant level_four to level-four.svg file
  static const String level_four = 'level-four.svg';

  /// map constant level_three_advanced to level-three-advanced.svg file
  static const String level_three_advanced = 'level-three-advanced.svg';

  /// map constant level_three to level-three.svg file
  static const String level_three = 'level-three.svg';

  /// map constant level_two_advanced to level-two-advanced.svg file
  static const String level_two_advanced = 'level-two-advanced.svg';

  /// map constant level_two to level-two.svg file
  static const String level_two = 'level-two.svg';

  /// map constant lever to lever.svg file
  static const String lever = 'lever.svg';

  /// map constant liar to liar.svg file
  static const String liar = 'liar.svg';

  /// map constant liberty_wing to liberty-wing.svg file
  static const String liberty_wing = 'liberty-wing.svg';

  /// map constant libra to libra.svg file
  static const String libra = 'libra.svg';

  /// map constant libya to libya.svg file
  static const String libya = 'libya.svg';

  /// map constant life_bar to life-bar.svg file
  static const String life_bar = 'life-bar.svg';

  /// map constant life_buoy to life-buoy.svg file
  static const String life_buoy = 'life-buoy.svg';

  /// map constant life_in_the_balance to life-in-the-balance.svg file
  static const String life_in_the_balance = 'life-in-the-balance.svg';

  /// map constant life_jacket to life-jacket.svg file
  static const String life_jacket = 'life-jacket.svg';

  /// map constant life_support to life-support.svg file
  static const String life_support = 'life-support.svg';

  /// map constant life_tap to life-tap.svg file
  static const String life_tap = 'life-tap.svg';

  /// map constant lift to lift.svg file
  static const String lift = 'lift.svg';

  /// map constant light_backpack to light-backpack.svg file
  static const String light_backpack = 'light-backpack.svg';

  /// map constant light_bulb to light-bulb.svg file
  static const String light_bulb = 'light-bulb.svg';

  /// map constant light_fighter to light-fighter.svg file
  static const String light_fighter = 'light-fighter.svg';

  /// map constant light_helm to light-helm.svg file
  static const String light_helm = 'light-helm.svg';

  /// map constant light_projector to light-projector.svg file
  static const String light_projector = 'light-projector.svg';

  /// map constant light_sabers to light-sabers.svg file
  static const String light_sabers = 'light-sabers.svg';

  /// map constant light_thorny_triskelion to light-thorny-triskelion.svg file
  static const String light_thorny_triskelion = 'light-thorny-triskelion.svg';

  /// map constant lighter to lighter.svg file
  static const String lighter = 'lighter.svg';

  /// map constant lighthouse to lighthouse.svg file
  static const String lighthouse = 'lighthouse.svg';

  /// map constant lightning_arc to lightning-arc.svg file
  static const String lightning_arc = 'lightning-arc.svg';

  /// map constant lightning_bow to lightning-bow.svg file
  static const String lightning_bow = 'lightning-bow.svg';

  /// map constant lightning_branches to lightning-branches.svg file
  static const String lightning_branches = 'lightning-branches.svg';

  /// map constant lightning_dissipation to lightning-dissipation.svg file
  static const String lightning_dissipation = 'lightning-dissipation.svg';

  /// map constant lightning_dome to lightning-dome.svg file
  static const String lightning_dome = 'lightning-dome.svg';

  /// map constant lightning_electron to lightning-electron.svg file
  static const String lightning_electron = 'lightning-electron.svg';

  /// map constant lightning_flame to lightning-flame.svg file
  static const String lightning_flame = 'lightning-flame.svg';

  /// map constant lightning_frequency to lightning-frequency.svg file
  static const String lightning_frequency = 'lightning-frequency.svg';

  /// map constant lightning_helix to lightning-helix.svg file
  static const String lightning_helix = 'lightning-helix.svg';

  /// map constant lightning_mask to lightning-mask.svg file
  static const String lightning_mask = 'lightning-mask.svg';

  /// map constant lightning_saber to lightning-saber.svg file
  static const String lightning_saber = 'lightning-saber.svg';

  /// map constant lightning_shadow to lightning-shadow.svg file
  static const String lightning_shadow = 'lightning-shadow.svg';

  /// map constant lightning_shield to lightning-shield.svg file
  static const String lightning_shield = 'lightning-shield.svg';

  /// map constant lightning_shout to lightning-shout.svg file
  static const String lightning_shout = 'lightning-shout.svg';

  /// map constant lightning_slashes to lightning-slashes.svg file
  static const String lightning_slashes = 'lightning-slashes.svg';

  /// map constant lightning_spanner to lightning-spanner.svg file
  static const String lightning_spanner = 'lightning-spanner.svg';

  /// map constant lightning_storm to lightning-storm.svg file
  static const String lightning_storm = 'lightning-storm.svg';

  /// map constant lightning_tear to lightning-tear.svg file
  static const String lightning_tear = 'lightning-tear.svg';

  /// map constant lightning_tree to lightning-tree.svg file
  static const String lightning_tree = 'lightning-tree.svg';

  /// map constant lightning_trio to lightning-trio.svg file
  static const String lightning_trio = 'lightning-trio.svg';

  /// map constant lily_pads to lily-pads.svg file
  static const String lily_pads = 'lily-pads.svg';

  /// map constant linden_leaf to linden-leaf.svg file
  static const String linden_leaf = 'linden-leaf.svg';

  /// map constant linked_rings to linked-rings.svg file
  static const String linked_rings = 'linked-rings.svg';

  /// map constant lion to lion.svg file
  static const String lion = 'lion.svg';

  /// map constant lips to lips.svg file
  static const String lips = 'lips.svg';

  /// map constant lipstick to lipstick.svg file
  static const String lipstick = 'lipstick.svg';

  /// map constant liquid_soap to liquid-soap.svg file
  static const String liquid_soap = 'liquid-soap.svg';

  /// map constant lit_candelabra to lit-candelabra.svg file
  static const String lit_candelabra = 'lit-candelabra.svg';

  /// map constant liver to liver.svg file
  static const String liver = 'liver.svg';

  /// map constant lizard_tongue to lizard-tongue.svg file
  static const String lizard_tongue = 'lizard-tongue.svg';

  /// map constant lizardman to lizardman.svg file
  static const String lizardman = 'lizardman.svg';

  /// map constant load to load.svg file
  static const String load = 'load.svg';

  /// map constant lob_arrow to lob-arrow.svg file
  static const String lob_arrow = 'lob-arrow.svg';

  /// map constant lock_picking to lock-picking.svg file
  static const String lock_picking = 'lock-picking.svg';

  /// map constant lock_spy to lock-spy.svg file
  static const String lock_spy = 'lock-spy.svg';

  /// map constant locked_box to locked-box.svg file
  static const String locked_box = 'locked-box.svg';

  /// map constant locked_chest to locked-chest.svg file
  static const String locked_chest = 'locked-chest.svg';

  /// map constant locked_door to locked-door.svg file
  static const String locked_door = 'locked-door.svg';

  /// map constant locked_fortress to locked-fortress.svg file
  static const String locked_fortress = 'locked-fortress.svg';

  /// map constant locked_heart to locked-heart.svg file
  static const String locked_heart = 'locked-heart.svg';

  /// map constant lockers to lockers.svg file
  static const String lockers = 'lockers.svg';

  /// map constant lockpicks to lockpicks.svg file
  static const String lockpicks = 'lockpicks.svg';

  /// map constant log to log.svg file
  static const String log = 'log.svg';

  /// map constant logging to logging.svg file
  static const String logging = 'logging.svg';

  /// map constant logic_gate_and to logic-gate-and.svg file
  static const String logic_gate_and = 'logic-gate-and.svg';

  /// map constant logic_gate_nand to logic-gate-nand.svg file
  static const String logic_gate_nand = 'logic-gate-nand.svg';

  /// map constant logic_gate_nor to logic-gate-nor.svg file
  static const String logic_gate_nor = 'logic-gate-nor.svg';

  /// map constant logic_gate_not to logic-gate-not.svg file
  static const String logic_gate_not = 'logic-gate-not.svg';

  /// map constant logic_gate_nxor to logic-gate-nxor.svg file
  static const String logic_gate_nxor = 'logic-gate-nxor.svg';

  /// map constant logic_gate_or to logic-gate-or.svg file
  static const String logic_gate_or = 'logic-gate-or.svg';

  /// map constant logic_gate_xor to logic-gate-xor.svg file
  static const String logic_gate_xor = 'logic-gate-xor.svg';

  /// map constant loincloth to loincloth.svg file
  static const String loincloth = 'loincloth.svg';

  /// map constant long_antennae_bug to long-antennae-bug.svg file
  static const String long_antennae_bug = 'long-antennae-bug.svg';

  /// map constant long_legged_spider to long-legged-spider.svg file
  static const String long_legged_spider = 'long-legged-spider.svg';

  /// map constant look_at to look-at.svg file
  static const String look_at = 'look-at.svg';

  /// map constant lorgnette to lorgnette.svg file
  static const String lorgnette = 'lorgnette.svg';

  /// map constant lost_limb to lost-limb.svg file
  static const String lost_limb = 'lost-limb.svg';

  /// map constant lotus_flower to lotus-flower.svg file
  static const String lotus_flower = 'lotus-flower.svg';

  /// map constant lotus to lotus.svg file
  static const String lotus = 'lotus.svg';

  /// map constant louvre_pyramid to louvre-pyramid.svg file
  static const String louvre_pyramid = 'louvre-pyramid.svg';

  /// map constant love_howl to love-howl.svg file
  static const String love_howl = 'love-howl.svg';

  /// map constant love_injection to love-injection.svg file
  static const String love_injection = 'love-injection.svg';

  /// map constant love_letter to love-letter.svg file
  static const String love_letter = 'love-letter.svg';

  /// map constant love_mystery to love-mystery.svg file
  static const String love_mystery = 'love-mystery.svg';

  /// map constant love_song to love-song.svg file
  static const String love_song = 'love-song.svg';

  /// map constant lovers to lovers.svg file
  static const String lovers = 'lovers.svg';

  /// map constant low_tide to low-tide.svg file
  static const String low_tide = 'low-tide.svg';

  /// map constant luchador to luchador.svg file
  static const String luchador = 'luchador.svg';

  /// map constant lucifer_cannon to lucifer-cannon.svg file
  static const String lucifer_cannon = 'lucifer-cannon.svg';

  /// map constant lucky_fisherman to lucky-fisherman.svg file
  static const String lucky_fisherman = 'lucky-fisherman.svg';

  /// map constant luger to luger.svg file
  static const String luger = 'luger.svg';

  /// map constant lunar_module to lunar-module.svg file
  static const String lunar_module = 'lunar-module.svg';

  /// map constant lunar_wand to lunar-wand.svg file
  static const String lunar_wand = 'lunar-wand.svg';

  /// map constant lungs to lungs.svg file
  static const String lungs = 'lungs.svg';

  /// map constant lynx_head to lynx-head.svg file
  static const String lynx_head = 'lynx-head.svg';

  /// map constant lyre to lyre.svg file
  static const String lyre = 'lyre.svg';

  /// map constant m3_grease_gun to m3-grease-gun.svg file
  static const String m3_grease_gun = 'm3-grease-gun.svg';

  /// map constant mac_10 to mac-10.svg file
  static const String mac_10 = 'mac-10.svg';

  /// map constant mace_head to mace-head.svg file
  static const String mace_head = 'mace-head.svg';

  /// map constant machete to machete.svg file
  static const String machete = 'machete.svg';

  /// map constant machine_gun_magazine to machine-gun-magazine.svg file
  static const String machine_gun_magazine = 'machine-gun-magazine.svg';

  /// map constant machine_gun to machine-gun.svg file
  static const String machine_gun = 'machine-gun.svg';

  /// map constant mad_scientist to mad-scientist.svg file
  static const String mad_scientist = 'mad-scientist.svg';

  /// map constant maggot to maggot.svg file
  static const String maggot = 'maggot.svg';

  /// map constant magic_axe to magic-axe.svg file
  static const String magic_axe = 'magic-axe.svg';

  /// map constant magic_broom to magic-broom.svg file
  static const String magic_broom = 'magic-broom.svg';

  /// map constant magic_gate to magic-gate.svg file
  static const String magic_gate = 'magic-gate.svg';

  /// map constant magic_hat to magic-hat.svg file
  static const String magic_hat = 'magic-hat.svg';

  /// map constant magic_lamp to magic-lamp.svg file
  static const String magic_lamp = 'magic-lamp.svg';

  /// map constant magic_palm to magic-palm.svg file
  static const String magic_palm = 'magic-palm.svg';

  /// map constant magic_portal to magic-portal.svg file
  static const String magic_portal = 'magic-portal.svg';

  /// map constant magic_potion to magic-potion.svg file
  static const String magic_potion = 'magic-potion.svg';

  /// map constant magic_shield to magic-shield.svg file
  static const String magic_shield = 'magic-shield.svg';

  /// map constant magic_swirl to magic-swirl.svg file
  static const String magic_swirl = 'magic-swirl.svg';

  /// map constant magic_trident to magic-trident.svg file
  static const String magic_trident = 'magic-trident.svg';

  /// map constant magick_trick to magick-trick.svg file
  static const String magick_trick = 'magick-trick.svg';

  /// map constant magnet_blast to magnet-blast.svg file
  static const String magnet_blast = 'magnet-blast.svg';

  /// map constant magnet_man to magnet-man.svg file
  static const String magnet_man = 'magnet-man.svg';

  /// map constant magnet to magnet.svg file
  static const String magnet = 'magnet.svg';

  /// map constant magnifying_glass to magnifying-glass.svg file
  static const String magnifying_glass = 'magnifying-glass.svg';

  /// map constant mail_shirt to mail-shirt.svg file
  static const String mail_shirt = 'mail-shirt.svg';

  /// map constant mailbox to mailbox.svg file
  static const String mailbox = 'mailbox.svg';

  /// map constant mailed_fist to mailed-fist.svg file
  static const String mailed_fist = 'mailed-fist.svg';

  /// map constant male to male.svg file
  static const String male = 'male.svg';

  /// map constant mammoth to mammoth.svg file
  static const String mammoth = 'mammoth.svg';

  /// map constant manacles to manacles.svg file
  static const String manacles = 'manacles.svg';

  /// map constant mandrill_head to mandrill-head.svg file
  static const String mandrill_head = 'mandrill-head.svg';

  /// map constant manta_ray to manta-ray.svg file
  static const String manta_ray = 'manta-ray.svg';

  /// map constant mantrap to mantrap.svg file
  static const String mantrap = 'mantrap.svg';

  /// map constant manual_juicer to manual-juicer.svg file
  static const String manual_juicer = 'manual-juicer.svg';

  /// map constant manual_meat_grinder to manual-meat-grinder.svg file
  static const String manual_meat_grinder = 'manual-meat-grinder.svg';

  /// map constant maple_leaf to maple-leaf.svg file
  static const String maple_leaf = 'maple-leaf.svg';

  /// map constant maracas to maracas.svg file
  static const String maracas = 'maracas.svg';

  /// map constant marble_tap to marble-tap.svg file
  static const String marble_tap = 'marble-tap.svg';

  /// map constant marbles to marbles.svg file
  static const String marbles = 'marbles.svg';

  /// map constant marrow_drain to marrow-drain.svg file
  static const String marrow_drain = 'marrow-drain.svg';

  /// map constant mars_curiosity to mars-curiosity.svg file
  static const String mars_curiosity = 'mars-curiosity.svg';

  /// map constant mars_pathfinder to mars-pathfinder.svg file
  static const String mars_pathfinder = 'mars-pathfinder.svg';

  /// map constant marshmallows to marshmallows.svg file
  static const String marshmallows = 'marshmallows.svg';

  /// map constant martini to martini.svg file
  static const String martini = 'martini.svg';

  /// map constant martyr_memorial to martyr-memorial.svg file
  static const String martyr_memorial = 'martyr-memorial.svg';

  /// map constant masked_spider to masked-spider.svg file
  static const String masked_spider = 'masked-spider.svg';

  /// map constant mason_jar to mason-jar.svg file
  static const String mason_jar = 'mason-jar.svg';

  /// map constant mass_driver to mass-driver.svg file
  static const String mass_driver = 'mass-driver.svg';

  /// map constant master_of_arms to master-of-arms.svg file
  static const String master_of_arms = 'master-of-arms.svg';

  /// map constant match_head to match-head.svg file
  static const String match_head = 'match-head.svg';

  /// map constant match_tip to match-tip.svg file
  static const String match_tip = 'match-tip.svg';

  /// map constant matchbox to matchbox.svg file
  static const String matchbox = 'matchbox.svg';

  /// map constant materials_science to materials-science.svg file
  static const String materials_science = 'materials-science.svg';

  /// map constant matryoshka_dolls to matryoshka-dolls.svg file
  static const String matryoshka_dolls = 'matryoshka-dolls.svg';

  /// map constant matter_states to matter-states.svg file
  static const String matter_states = 'matter-states.svg';

  /// map constant mayan_pyramid to mayan-pyramid.svg file
  static const String mayan_pyramid = 'mayan-pyramid.svg';

  /// map constant maze_cornea to maze-cornea.svg file
  static const String maze_cornea = 'maze-cornea.svg';

  /// map constant maze_saw to maze-saw.svg file
  static const String maze_saw = 'maze-saw.svg';

  /// map constant maze to maze.svg file
  static const String maze = 'maze.svg';

  /// map constant meal to meal.svg file
  static const String meal = 'meal.svg';

  /// map constant measure_tape to measure-tape.svg file
  static const String measure_tape = 'measure-tape.svg';

  /// map constant meat_cleaver to meat-cleaver.svg file
  static const String meat_cleaver = 'meat-cleaver.svg';

  /// map constant meat_hook to meat-hook.svg file
  static const String meat_hook = 'meat-hook.svg';

  /// map constant meat to meat.svg file
  static const String meat = 'meat.svg';

  /// map constant mecha_head to mecha-head.svg file
  static const String mecha_head = 'mecha-head.svg';

  /// map constant mecha_mask to mecha-mask.svg file
  static const String mecha_mask = 'mecha-mask.svg';

  /// map constant mechanic_garage to mechanic-garage.svg file
  static const String mechanic_garage = 'mechanic-garage.svg';

  /// map constant mechanical_arm to mechanical-arm.svg file
  static const String mechanical_arm = 'mechanical-arm.svg';

  /// map constant medal_skull to medal-skull.svg file
  static const String medal_skull = 'medal-skull.svg';

  /// map constant medal to medal.svg file
  static const String medal = 'medal.svg';

  /// map constant medallist to medallist.svg file
  static const String medallist = 'medallist.svg';

  /// map constant medical_drip to medical-drip.svg file
  static const String medical_drip = 'medical-drip.svg';

  /// map constant medical_pack_alt to medical-pack-alt.svg file
  static const String medical_pack_alt = 'medical-pack-alt.svg';

  /// map constant medical_pack to medical-pack.svg file
  static const String medical_pack = 'medical-pack.svg';

  /// map constant medical_thermometer to medical-thermometer.svg file
  static const String medical_thermometer = 'medical-thermometer.svg';

  /// map constant medicine_pills to medicine-pills.svg file
  static const String medicine_pills = 'medicine-pills.svg';

  /// map constant medicines to medicines.svg file
  static const String medicines = 'medicines.svg';

  /// map constant medieval_barracks to medieval-barracks.svg file
  static const String medieval_barracks = 'medieval-barracks.svg';

  /// map constant medieval_gate to medieval-gate.svg file
  static const String medieval_gate = 'medieval-gate.svg';

  /// map constant medieval_pavilion to medieval-pavilion.svg file
  static const String medieval_pavilion = 'medieval-pavilion.svg';

  /// map constant meditation to meditation.svg file
  static const String meditation = 'meditation.svg';

  /// map constant medusa_head to medusa-head.svg file
  static const String medusa_head = 'medusa-head.svg';

  /// map constant meeple_army to meeple-army.svg file
  static const String meeple_army = 'meeple-army.svg';

  /// map constant meeple_circle to meeple-circle.svg file
  static const String meeple_circle = 'meeple-circle.svg';

  /// map constant meeple_group to meeple-group.svg file
  static const String meeple_group = 'meeple-group.svg';

  /// map constant meeple_king to meeple-king.svg file
  static const String meeple_king = 'meeple-king.svg';

  /// map constant meeple to meeple.svg file
  static const String meeple = 'meeple.svg';

  /// map constant megabot to megabot.svg file
  static const String megabot = 'megabot.svg';

  /// map constant megaphone to megaphone.svg file
  static const String megaphone = 'megaphone.svg';

  /// map constant melting_ice_cube to melting-ice-cube.svg file
  static const String melting_ice_cube = 'melting-ice-cube.svg';

  /// map constant melting_metal to melting-metal.svg file
  static const String melting_metal = 'melting-metal.svg';

  /// map constant menhir to menhir.svg file
  static const String menhir = 'menhir.svg';

  /// map constant mermaid to mermaid.svg file
  static const String mermaid = 'mermaid.svg';

  /// map constant mesh_ball to mesh-ball.svg file
  static const String mesh_ball = 'mesh-ball.svg';

  /// map constant mesh_network to mesh-network.svg file
  static const String mesh_network = 'mesh-network.svg';

  /// map constant metal_bar to metal-bar.svg file
  static const String metal_bar = 'metal-bar.svg';

  /// map constant metal_boot to metal-boot.svg file
  static const String metal_boot = 'metal-boot.svg';

  /// map constant metal_detector to metal-detector.svg file
  static const String metal_detector = 'metal-detector.svg';

  /// map constant metal_disc to metal-disc.svg file
  static const String metal_disc = 'metal-disc.svg';

  /// map constant metal_golem_head to metal-golem-head.svg file
  static const String metal_golem_head = 'metal-golem-head.svg';

  /// map constant metal_hand to metal-hand.svg file
  static const String metal_hand = 'metal-hand.svg';

  /// map constant metal_plate to metal-plate.svg file
  static const String metal_plate = 'metal-plate.svg';

  /// map constant metal_scales to metal-scales.svg file
  static const String metal_scales = 'metal-scales.svg';

  /// map constant metal_skirt to metal-skirt.svg file
  static const String metal_skirt = 'metal-skirt.svg';

  /// map constant meteor_impact to meteor-impact.svg file
  static const String meteor_impact = 'meteor-impact.svg';

  /// map constant metroid to metroid.svg file
  static const String metroid = 'metroid.svg';

  /// map constant metronome to metronome.svg file
  static const String metronome = 'metronome.svg';

  /// map constant mexico to mexico.svg file
  static const String mexico = 'mexico.svg';

  /// map constant microchip to microchip.svg file
  static const String microchip = 'microchip.svg';

  /// map constant microphone to microphone.svg file
  static const String microphone = 'microphone.svg';

  /// map constant microscope_lens to microscope-lens.svg file
  static const String microscope_lens = 'microscope-lens.svg';

  /// map constant microscope to microscope.svg file
  static const String microscope = 'microscope.svg';

  /// map constant middle_arrow to middle-arrow.svg file
  static const String middle_arrow = 'middle-arrow.svg';

  /// map constant midnight_claw to midnight-claw.svg file
  static const String midnight_claw = 'midnight-claw.svg';

  /// map constant mighty_boosh to mighty-boosh.svg file
  static const String mighty_boosh = 'mighty-boosh.svg';

  /// map constant mighty_force to mighty-force.svg file
  static const String mighty_force = 'mighty-force.svg';

  /// map constant mighty_horn to mighty-horn.svg file
  static const String mighty_horn = 'mighty-horn.svg';

  /// map constant mighty_spanner to mighty-spanner.svg file
  static const String mighty_spanner = 'mighty-spanner.svg';

  /// map constant military_ambulance to military-ambulance.svg file
  static const String military_ambulance = 'military-ambulance.svg';

  /// map constant military_fort to military-fort.svg file
  static const String military_fort = 'military-fort.svg';

  /// map constant milk_carton to milk-carton.svg file
  static const String milk_carton = 'milk-carton.svg';

  /// map constant millenium_key to millenium-key.svg file
  static const String millenium_key = 'millenium-key.svg';

  /// map constant mimic_chest to mimic-chest.svg file
  static const String mimic_chest = 'mimic-chest.svg';

  /// map constant mine_explosion to mine-explosion.svg file
  static const String mine_explosion = 'mine-explosion.svg';

  /// map constant mine_truck to mine-truck.svg file
  static const String mine_truck = 'mine-truck.svg';

  /// map constant mine_wagon to mine-wagon.svg file
  static const String mine_wagon = 'mine-wagon.svg';

  /// map constant minefield to minefield.svg file
  static const String minefield = 'minefield.svg';

  /// map constant miner to miner.svg file
  static const String miner = 'miner.svg';

  /// map constant mineral_heart to mineral-heart.svg file
  static const String mineral_heart = 'mineral-heart.svg';

  /// map constant mineral_pearls to mineral-pearls.svg file
  static const String mineral_pearls = 'mineral-pearls.svg';

  /// map constant minerals to minerals.svg file
  static const String minerals = 'minerals.svg';

  /// map constant mini_submarine to mini-submarine.svg file
  static const String mini_submarine = 'mini-submarine.svg';

  /// map constant minigun to minigun.svg file
  static const String minigun = 'minigun.svg';

  /// map constant mining_helmet to mining-helmet.svg file
  static const String mining_helmet = 'mining-helmet.svg';

  /// map constant mining to mining.svg file
  static const String mining = 'mining.svg';

  /// map constant minions to minions.svg file
  static const String minions = 'minions.svg';

  /// map constant minotaur to minotaur.svg file
  static const String minotaur = 'minotaur.svg';

  /// map constant miracle_medecine to miracle-medecine.svg file
  static const String miracle_medecine = 'miracle-medecine.svg';

  /// map constant mirror_mirror to mirror-mirror.svg file
  static const String mirror_mirror = 'mirror-mirror.svg';

  /// map constant misdirection to misdirection.svg file
  static const String misdirection = 'misdirection.svg';

  /// map constant missile_launcher to missile-launcher.svg file
  static const String missile_launcher = 'missile-launcher.svg';

  /// map constant missile_mech to missile-mech.svg file
  static const String missile_mech = 'missile-mech.svg';

  /// map constant missile_pod to missile-pod.svg file
  static const String missile_pod = 'missile-pod.svg';

  /// map constant missile_swarm to missile-swarm.svg file
  static const String missile_swarm = 'missile-swarm.svg';

  /// map constant mite_alt to mite-alt.svg file
  static const String mite_alt = 'mite-alt.svg';

  /// map constant mite to mite.svg file
  static const String mite = 'mite.svg';

  /// map constant moai to moai.svg file
  static const String moai = 'moai.svg';

  /// map constant modern_city to modern-city.svg file
  static const String modern_city = 'modern-city.svg';

  /// map constant moebius_star to moebius-star.svg file
  static const String moebius_star = 'moebius-star.svg';

  /// map constant moebius_trefoil to moebius-trefoil.svg file
  static const String moebius_trefoil = 'moebius-trefoil.svg';

  /// map constant moebius_triangle to moebius-triangle.svg file
  static const String moebius_triangle = 'moebius-triangle.svg';

  /// map constant moka_pot to moka-pot.svg file
  static const String moka_pot = 'moka-pot.svg';

  /// map constant moldova to moldova.svg file
  static const String moldova = 'moldova.svg';

  /// map constant mole to mole.svg file
  static const String mole = 'mole.svg';

  /// map constant molecule2 to molecule 2.svg file
  static const String molecule2 = 'molecule 2.svg';

  /// map constant molecule to molecule.svg file
  static const String molecule = 'molecule.svg';

  /// map constant molotov to molotov.svg file
  static const String molotov = 'molotov.svg';

  /// map constant mona_lisa to mona-lisa.svg file
  static const String mona_lisa = 'mona-lisa.svg';

  /// map constant moncler_jacket to moncler-jacket.svg file
  static const String moncler_jacket = 'moncler-jacket.svg';

  /// map constant money_stack to money-stack.svg file
  static const String money_stack = 'money-stack.svg';

  /// map constant mongolia to mongolia.svg file
  static const String mongolia = 'mongolia.svg';

  /// map constant monk_face to monk-face.svg file
  static const String monk_face = 'monk-face.svg';

  /// map constant monkey_wrench to monkey-wrench.svg file
  static const String monkey_wrench = 'monkey-wrench.svg';

  /// map constant monkey to monkey.svg file
  static const String monkey = 'monkey.svg';

  /// map constant mono_wheel_robot to mono-wheel-robot.svg file
  static const String mono_wheel_robot = 'mono-wheel-robot.svg';

  /// map constant monster_grasp to monster-grasp.svg file
  static const String monster_grasp = 'monster-grasp.svg';

  /// map constant monstera_leaf to monstera-leaf.svg file
  static const String monstera_leaf = 'monstera-leaf.svg';

  /// map constant monument_valley to monument-valley.svg file
  static const String monument_valley = 'monument-valley.svg';

  /// map constant moon_bats to moon-bats.svg file
  static const String moon_bats = 'moon-bats.svg';

  /// map constant moon_claws to moon-claws.svg file
  static const String moon_claws = 'moon-claws.svg';

  /// map constant moon_orbit to moon-orbit.svg file
  static const String moon_orbit = 'moon-orbit.svg';

  /// map constant moon to moon.svg file
  static const String moon = 'moon.svg';

  /// map constant mooring_bollard to mooring-bollard.svg file
  static const String mooring_bollard = 'mooring-bollard.svg';

  /// map constant morbid_humour to morbid-humour.svg file
  static const String morbid_humour = 'morbid-humour.svg';

  /// map constant morgue_feet to morgue-feet.svg file
  static const String morgue_feet = 'morgue-feet.svg';

  /// map constant morph_ball to morph-ball.svg file
  static const String morph_ball = 'morph-ball.svg';

  /// map constant mortar to mortar.svg file
  static const String mortar = 'mortar.svg';

  /// map constant mountain_cave to mountain-cave.svg file
  static const String mountain_cave = 'mountain-cave.svg';

  /// map constant mountain_climbing to mountain-climbing.svg file
  static const String mountain_climbing = 'mountain-climbing.svg';

  /// map constant mountain_road to mountain-road.svg file
  static const String mountain_road = 'mountain-road.svg';

  /// map constant mountains to mountains.svg file
  static const String mountains = 'mountains.svg';

  /// map constant mountaintop to mountaintop.svg file
  static const String mountaintop = 'mountaintop.svg';

  /// map constant mounted_knight to mounted-knight.svg file
  static const String mounted_knight = 'mounted-knight.svg';

  /// map constant mouse2 to mouse 2.svg file
  static const String mouse2 = 'mouse 2.svg';

  /// map constant mouse to mouse.svg file
  static const String mouse = 'mouse.svg';

  /// map constant mouth_watering to mouth-watering.svg file
  static const String mouth_watering = 'mouth-watering.svg';

  /// map constant move to move.svg file
  static const String move = 'move.svg';

  /// map constant movement_sensor to movement-sensor.svg file
  static const String movement_sensor = 'movement-sensor.svg';

  /// map constant mp_40 to mp-40.svg file
  static const String mp_40 = 'mp-40.svg';

  /// map constant mp52 to mp5 2.svg file
  static const String mp52 = 'mp5 2.svg';

  /// map constant mp5 to mp5.svg file
  static const String mp5 = 'mp5.svg';

  /// map constant mp5k to mp5k.svg file
  static const String mp5k = 'mp5k.svg';

  /// map constant mucous_pillar to mucous-pillar.svg file
  static const String mucous_pillar = 'mucous-pillar.svg';

  /// map constant mug_shot to mug-shot.svg file
  static const String mug_shot = 'mug-shot.svg';

  /// map constant multi_directions to multi-directions.svg file
  static const String multi_directions = 'multi-directions.svg';

  /// map constant multiple_targets to multiple-targets.svg file
  static const String multiple_targets = 'multiple-targets.svg';

  /// map constant mummy_head to mummy-head.svg file
  static const String mummy_head = 'mummy-head.svg';

  /// map constant muscle_fat to muscle-fat.svg file
  static const String muscle_fat = 'muscle-fat.svg';

  /// map constant muscle_up to muscle-up.svg file
  static const String muscle_up = 'muscle-up.svg';

  /// map constant muscular_torso to muscular-torso.svg file
  static const String muscular_torso = 'muscular-torso.svg';

  /// map constant mushroom_cloud to mushroom-cloud.svg file
  static const String mushroom_cloud = 'mushroom-cloud.svg';

  /// map constant mushroom_gills to mushroom-gills.svg file
  static const String mushroom_gills = 'mushroom-gills.svg';

  /// map constant mushroom_house to mushroom-house.svg file
  static const String mushroom_house = 'mushroom-house.svg';

  /// map constant mushroom to mushroom.svg file
  static const String mushroom = 'mushroom.svg';

  /// map constant mushrooms_cluster to mushrooms-cluster.svg file
  static const String mushrooms_cluster = 'mushrooms-cluster.svg';

  /// map constant mushrooms to mushrooms.svg file
  static const String mushrooms = 'mushrooms.svg';

  /// map constant music_spell to music-spell.svg file
  static const String music_spell = 'music-spell.svg';

  /// map constant musical_keyboard to musical-keyboard.svg file
  static const String musical_keyboard = 'musical-keyboard.svg';

  /// map constant musical_notes to musical-notes.svg file
  static const String musical_notes = 'musical-notes.svg';

  /// map constant musical_score to musical-score.svg file
  static const String musical_score = 'musical-score.svg';

  /// map constant musket to musket.svg file
  static const String musket = 'musket.svg';

  /// map constant mussel to mussel.svg file
  static const String mussel = 'mussel.svg';

  /// map constant mustache to mustache.svg file
  static const String mustache = 'mustache.svg';

  /// map constant mute to mute.svg file
  static const String mute = 'mute.svg';

  /// map constant nachos to nachos.svg file
  static const String nachos = 'nachos.svg';

  /// map constant nailed_foot to nailed-foot.svg file
  static const String nailed_foot = 'nailed-foot.svg';

  /// map constant nailed_head to nailed-head.svg file
  static const String nailed_head = 'nailed-head.svg';

  /// map constant nails to nails.svg file
  static const String nails = 'nails.svg';

  /// map constant nano_bot to nano-bot.svg file
  static const String nano_bot = 'nano-bot.svg';

  /// map constant nautilus_shell to nautilus-shell.svg file
  static const String nautilus_shell = 'nautilus-shell.svg';

  /// map constant neck_bite to neck-bite.svg file
  static const String neck_bite = 'neck-bite.svg';

  /// map constant necklace_display to necklace-display.svg file
  static const String necklace_display = 'necklace-display.svg';

  /// map constant necklace to necklace.svg file
  static const String necklace = 'necklace.svg';

  /// map constant nectar to nectar.svg file
  static const String nectar = 'nectar.svg';

  /// map constant needle_drill to needle-drill.svg file
  static const String needle_drill = 'needle-drill.svg';

  /// map constant needle_jaws to needle-jaws.svg file
  static const String needle_jaws = 'needle-jaws.svg';

  /// map constant nefertiti to nefertiti.svg file
  static const String nefertiti = 'nefertiti.svg';

  /// map constant nest_birds to nest-birds.svg file
  static const String nest_birds = 'nest-birds.svg';

  /// map constant nest_eggs to nest-eggs.svg file
  static const String nest_eggs = 'nest-eggs.svg';

  /// map constant nested_eclipses to nested-eclipses.svg file
  static const String nested_eclipses = 'nested-eclipses.svg';

  /// map constant nested_hearts to nested-hearts.svg file
  static const String nested_hearts = 'nested-hearts.svg';

  /// map constant nested_hexagons to nested-hexagons.svg file
  static const String nested_hexagons = 'nested-hexagons.svg';

  /// map constant network_bars to network-bars.svg file
  static const String network_bars = 'network-bars.svg';

  /// map constant new_born to new-born.svg file
  static const String new_born = 'new-born.svg';

  /// map constant new_shoot to new-shoot.svg file
  static const String new_shoot = 'new-shoot.svg';

  /// map constant newspaper to newspaper.svg file
  static const String newspaper = 'newspaper.svg';

  /// map constant next_button to next-button.svg file
  static const String next_button = 'next-button.svg';

  /// map constant nigeria to nigeria.svg file
  static const String nigeria = 'nigeria.svg';

  /// map constant night_sky to night-sky.svg file
  static const String night_sky = 'night-sky.svg';

  /// map constant night_sleep to night-sleep.svg file
  static const String night_sleep = 'night-sleep.svg';

  /// map constant night_vision to night-vision.svg file
  static const String night_vision = 'night-vision.svg';

  /// map constant ninja_armor to ninja-armor.svg file
  static const String ninja_armor = 'ninja-armor.svg';

  /// map constant ninja_head to ninja-head.svg file
  static const String ninja_head = 'ninja-head.svg';

  /// map constant ninja_heroic_stance to ninja-heroic-stance.svg file
  static const String ninja_heroic_stance = 'ninja-heroic-stance.svg';

  /// map constant ninja_mask to ninja-mask.svg file
  static const String ninja_mask = 'ninja-mask.svg';

  /// map constant ninja_star to ninja-star.svg file
  static const String ninja_star = 'ninja-star.svg';

  /// map constant ninja_velociraptor to ninja-velociraptor.svg file
  static const String ninja_velociraptor = 'ninja-velociraptor.svg';

  /// map constant nodular to nodular.svg file
  static const String nodular = 'nodular.svg';

  /// map constant noodle_ball to noodle-ball.svg file
  static const String noodle_ball = 'noodle-ball.svg';

  /// map constant noodles to noodles.svg file
  static const String noodles = 'noodles.svg';

  /// map constant north_star_shuriken to north-star-shuriken.svg file
  static const String north_star_shuriken = 'north-star-shuriken.svg';

  /// map constant nose_front to nose-front.svg file
  static const String nose_front = 'nose-front.svg';

  /// map constant nose_side to nose-side.svg file
  static const String nose_side = 'nose-side.svg';

  /// map constant notebook to notebook.svg file
  static const String notebook = 'notebook.svg';

  /// map constant nothing_to_say to nothing-to-say.svg file
  static const String nothing_to_say = 'nothing-to-say.svg';

  /// map constant nuclear_bomb to nuclear-bomb.svg file
  static const String nuclear_bomb = 'nuclear-bomb.svg';

  /// map constant nuclear_plant to nuclear-plant.svg file
  static const String nuclear_plant = 'nuclear-plant.svg';

  /// map constant nuclear_waste to nuclear-waste.svg file
  static const String nuclear_waste = 'nuclear-waste.svg';

  /// map constant nuclear to nuclear.svg file
  static const String nuclear = 'nuclear.svg';

  /// map constant nun_face to nun-face.svg file
  static const String nun_face = 'nun-face.svg';

  /// map constant nunchaku to nunchaku.svg file
  static const String nunchaku = 'nunchaku.svg';

  /// map constant nurse_female to nurse-female.svg file
  static const String nurse_female = 'nurse-female.svg';

  /// map constant nurse_male to nurse-male.svg file
  static const String nurse_male = 'nurse-male.svg';

  /// map constant o_brick to o-brick.svg file
  static const String o_brick = 'o-brick.svg';

  /// map constant oak_leaf to oak-leaf.svg file
  static const String oak_leaf = 'oak-leaf.svg';

  /// map constant oak to oak.svg file
  static const String oak = 'oak.svg';

  /// map constant oasis to oasis.svg file
  static const String oasis = 'oasis.svg';

  /// map constant oat to oat.svg file
  static const String oat = 'oat.svg';

  /// map constant obelisk to obelisk.svg file
  static const String obelisk = 'obelisk.svg';

  /// map constant observatory to observatory.svg file
  static const String observatory = 'observatory.svg';

  /// map constant ocarina to ocarina.svg file
  static const String ocarina = 'ocarina.svg';

  /// map constant occupy to occupy.svg file
  static const String occupy = 'occupy.svg';

  /// map constant octogonal_eye to octogonal-eye.svg file
  static const String octogonal_eye = 'octogonal-eye.svg';

  /// map constant octoman to octoman.svg file
  static const String octoman = 'octoman.svg';

  /// map constant octopus to octopus.svg file
  static const String octopus = 'octopus.svg';

  /// map constant oden to oden.svg file
  static const String oden = 'oden.svg';

  /// map constant office_chair to office-chair.svg file
  static const String office_chair = 'office-chair.svg';

  /// map constant offshore_platform to offshore-platform.svg file
  static const String offshore_platform = 'offshore-platform.svg';

  /// map constant ogre to ogre.svg file
  static const String ogre = 'ogre.svg';

  /// map constant oil_drum to oil-drum.svg file
  static const String oil_drum = 'oil-drum.svg';

  /// map constant oil_pump to oil-pump.svg file
  static const String oil_pump = 'oil-pump.svg';

  /// map constant oil_rig to oil-rig.svg file
  static const String oil_rig = 'oil-rig.svg';

  /// map constant oily_spiral to oily-spiral.svg file
  static const String oily_spiral = 'oily-spiral.svg';

  /// map constant old_king to old-king.svg file
  static const String old_king = 'old-king.svg';

  /// map constant old_lantern to old-lantern.svg file
  static const String old_lantern = 'old-lantern.svg';

  /// map constant old_microphone to old-microphone.svg file
  static const String old_microphone = 'old-microphone.svg';

  /// map constant old_wagon to old-wagon.svg file
  static const String old_wagon = 'old-wagon.svg';

  /// map constant olive to olive.svg file
  static const String olive = 'olive.svg';

  /// map constant omega to omega.svg file
  static const String omega = 'omega.svg';

  /// map constant on_sight to on-sight.svg file
  static const String on_sight = 'on-sight.svg';

  /// map constant on_target to on-target.svg file
  static const String on_target = 'on-target.svg';

  /// map constant one_eyed to one-eyed.svg file
  static const String one_eyed = 'one-eyed.svg';

  /// map constant oni to oni.svg file
  static const String oni = 'oni.svg';

  /// map constant onigori to onigori.svg file
  static const String onigori = 'onigori.svg';

  /// map constant open_book to open-book.svg file
  static const String open_book = 'open-book.svg';

  /// map constant open_chest to open-chest.svg file
  static const String open_chest = 'open-chest.svg';

  /// map constant open_folder to open-folder.svg file
  static const String open_folder = 'open-folder.svg';

  /// map constant open_gate to open-gate.svg file
  static const String open_gate = 'open-gate.svg';

  /// map constant open_palm to open-palm.svg file
  static const String open_palm = 'open-palm.svg';

  /// map constant open_treasure_chest to open-treasure-chest.svg file
  static const String open_treasure_chest = 'open-treasure-chest.svg';

  /// map constant open_wound to open-wound.svg file
  static const String open_wound = 'open-wound.svg';

  /// map constant opened_food_can to opened-food-can.svg file
  static const String opened_food_can = 'opened-food-can.svg';

  /// map constant opening_shell to opening-shell.svg file
  static const String opening_shell = 'opening-shell.svg';

  /// map constant ophanim to ophanim.svg file
  static const String ophanim = 'ophanim.svg';

  /// map constant ophiuchus to ophiuchus.svg file
  static const String ophiuchus = 'ophiuchus.svg';

  /// map constant oppidum to oppidum.svg file
  static const String oppidum = 'oppidum.svg';

  /// map constant opposite_hearts to opposite-hearts.svg file
  static const String opposite_hearts = 'opposite-hearts.svg';

  /// map constant oppression to oppression.svg file
  static const String oppression = 'oppression.svg';

  /// map constant orange_slice to orange-slice.svg file
  static const String orange_slice = 'orange-slice.svg';

  /// map constant orange to orange.svg file
  static const String orange = 'orange.svg';

  /// map constant orb_direction to orb-direction.svg file
  static const String orb_direction = 'orb-direction.svg';

  /// map constant orb_wand to orb-wand.svg file
  static const String orb_wand = 'orb-wand.svg';

  /// map constant orbit to orbit.svg file
  static const String orbit = 'orbit.svg';

  /// map constant orbital_rays to orbital-rays.svg file
  static const String orbital_rays = 'orbital-rays.svg';

  /// map constant orbital to orbital.svg file
  static const String orbital = 'orbital.svg';

  /// map constant orc_head to orc-head.svg file
  static const String orc_head = 'orc-head.svg';

  /// map constant ore to ore.svg file
  static const String ore = 'ore.svg';

  /// map constant organigram to organigram.svg file
  static const String organigram = 'organigram.svg';

  /// map constant orrery to orrery.svg file
  static const String orrery = 'orrery.svg';

  /// map constant ostrich to ostrich.svg file
  static const String ostrich = 'ostrich.svg';

  /// map constant ouroboros to ouroboros.svg file
  static const String ouroboros = 'ouroboros.svg';

  /// map constant outback_hat to outback-hat.svg file
  static const String outback_hat = 'outback-hat.svg';

  /// map constant over_infinity to over-infinity.svg file
  static const String over_infinity = 'over-infinity.svg';

  /// map constant overdose to overdose.svg file
  static const String overdose = 'overdose.svg';

  /// map constant overdrive to overdrive.svg file
  static const String overdrive = 'overdrive.svg';

  /// map constant overhead to overhead.svg file
  static const String overhead = 'overhead.svg';

  /// map constant overkill to overkill.svg file
  static const String overkill = 'overkill.svg';

  /// map constant overlord_helm to overlord-helm.svg file
  static const String overlord_helm = 'overlord-helm.svg';

  /// map constant overmind to overmind.svg file
  static const String overmind = 'overmind.svg';

  /// map constant owl to owl.svg file
  static const String owl = 'owl.svg';

  /// map constant oyster_pearl to oyster-pearl.svg file
  static const String oyster_pearl = 'oyster-pearl.svg';

  /// map constant oyster to oyster.svg file
  static const String oyster = 'oyster.svg';

  /// map constant p90 to p90.svg file
  static const String p90 = 'p90.svg';

  /// map constant packed_planks to packed-planks.svg file
  static const String packed_planks = 'packed-planks.svg';

  /// map constant paddle_steamer to paddle-steamer.svg file
  static const String paddle_steamer = 'paddle-steamer.svg';

  /// map constant paddles to paddles.svg file
  static const String paddles = 'paddles.svg';

  /// map constant padlock_open to padlock-open.svg file
  static const String padlock_open = 'padlock-open.svg';

  /// map constant padlock to padlock.svg file
  static const String padlock = 'padlock.svg';

  /// map constant pagoda to pagoda.svg file
  static const String pagoda = 'pagoda.svg';

  /// map constant paint_brush to paint-brush.svg file
  static const String paint_brush = 'paint-brush.svg';

  /// map constant paint_bucket to paint-bucket.svg file
  static const String paint_bucket = 'paint-bucket.svg';

  /// map constant paint_roller to paint-roller.svg file
  static const String paint_roller = 'paint-roller.svg';

  /// map constant painted_pottery to painted-pottery.svg file
  static const String painted_pottery = 'painted-pottery.svg';

  /// map constant palette to palette.svg file
  static const String palette = 'palette.svg';

  /// map constant palisade to palisade.svg file
  static const String palisade = 'palisade.svg';

  /// map constant palm_tree to palm-tree.svg file
  static const String palm_tree = 'palm-tree.svg';

  /// map constant palm to palm.svg file
  static const String palm = 'palm.svg';

  /// map constant pan_flute to pan-flute.svg file
  static const String pan_flute = 'pan-flute.svg';

  /// map constant panda to panda.svg file
  static const String panda = 'panda.svg';

  /// map constant pangolin to pangolin.svg file
  static const String pangolin = 'pangolin.svg';

  /// map constant panzerfaust to panzerfaust.svg file
  static const String panzerfaust = 'panzerfaust.svg';

  /// map constant paper_arrow to paper-arrow.svg file
  static const String paper_arrow = 'paper-arrow.svg';

  /// map constant paper_bag_crumpled to paper-bag-crumpled.svg file
  static const String paper_bag_crumpled = 'paper-bag-crumpled.svg';

  /// map constant paper_bag_folded to paper-bag-folded.svg file
  static const String paper_bag_folded = 'paper-bag-folded.svg';

  /// map constant paper_bag_open to paper-bag-open.svg file
  static const String paper_bag_open = 'paper-bag-open.svg';

  /// map constant paper_boat to paper-boat.svg file
  static const String paper_boat = 'paper-boat.svg';

  /// map constant paper_bomb to paper-bomb.svg file
  static const String paper_bomb = 'paper-bomb.svg';

  /// map constant paper_clip to paper-clip.svg file
  static const String paper_clip = 'paper-clip.svg';

  /// map constant paper_crane to paper-crane.svg file
  static const String paper_crane = 'paper-crane.svg';

  /// map constant paper_frog to paper-frog.svg file
  static const String paper_frog = 'paper-frog.svg';

  /// map constant paper_lantern to paper-lantern.svg file
  static const String paper_lantern = 'paper-lantern.svg';

  /// map constant paper_plane to paper-plane.svg file
  static const String paper_plane = 'paper-plane.svg';

  /// map constant paper_tray to paper-tray.svg file
  static const String paper_tray = 'paper-tray.svg';

  /// map constant paper_windmill to paper-windmill.svg file
  static const String paper_windmill = 'paper-windmill.svg';

  /// map constant paper to paper.svg file
  static const String paper = 'paper.svg';

  /// map constant papers to papers.svg file
  static const String papers = 'papers.svg';

  /// map constant papyrus to papyrus.svg file
  static const String papyrus = 'papyrus.svg';

  /// map constant parachute to parachute.svg file
  static const String parachute = 'parachute.svg';

  /// map constant paraguay to paraguay.svg file
  static const String paraguay = 'paraguay.svg';

  /// map constant paranoia to paranoia.svg file
  static const String paranoia = 'paranoia.svg';

  /// map constant parasaurolophus to parasaurolophus.svg file
  static const String parasaurolophus = 'parasaurolophus.svg';

  /// map constant park_bench to park-bench.svg file
  static const String park_bench = 'park-bench.svg';

  /// map constant parmecia to parmecia.svg file
  static const String parmecia = 'parmecia.svg';

  /// map constant parrot_head to parrot-head.svg file
  static const String parrot_head = 'parrot-head.svg';

  /// map constant party_flags to party-flags.svg file
  static const String party_flags = 'party-flags.svg';

  /// map constant party_hat to party-hat.svg file
  static const String party_hat = 'party-hat.svg';

  /// map constant party_popper to party-popper.svg file
  static const String party_popper = 'party-popper.svg';

  /// map constant passport to passport.svg file
  static const String passport = 'passport.svg';

  /// map constant path_distance to path-distance.svg file
  static const String path_distance = 'path-distance.svg';

  /// map constant path_tile to path-tile.svg file
  static const String path_tile = 'path-tile.svg';

  /// map constant pauldrons to pauldrons.svg file
  static const String pauldrons = 'pauldrons.svg';

  /// map constant pause_button to pause-button.svg file
  static const String pause_button = 'pause-button.svg';

  /// map constant paw_front to paw-front.svg file
  static const String paw_front = 'paw-front.svg';

  /// map constant paw_heart to paw-heart.svg file
  static const String paw_heart = 'paw-heart.svg';

  /// map constant paw_print to paw-print.svg file
  static const String paw_print = 'paw-print.svg';

  /// map constant paw to paw.svg file
  static const String paw = 'paw.svg';

  /// map constant pawn to pawn.svg file
  static const String pawn = 'pawn.svg';

  /// map constant pay_money to pay-money.svg file
  static const String pay_money = 'pay-money.svg';

  /// map constant pc to pc.svg file
  static const String pc = 'pc.svg';

  /// map constant peace_dove to peace-dove.svg file
  static const String peace_dove = 'peace-dove.svg';

  /// map constant peach to peach.svg file
  static const String peach = 'peach.svg';

  /// map constant peaks to peaks.svg file
  static const String peaks = 'peaks.svg';

  /// map constant peanut to peanut.svg file
  static const String peanut = 'peanut.svg';

  /// map constant pear to pear.svg file
  static const String pear = 'pear.svg';

  /// map constant pearl_earring to pearl-earring.svg file
  static const String pearl_earring = 'pearl-earring.svg';

  /// map constant pearl_necklace to pearl-necklace.svg file
  static const String pearl_necklace = 'pearl-necklace.svg';

  /// map constant peas to peas.svg file
  static const String peas = 'peas.svg';

  /// map constant pegasus to pegasus.svg file
  static const String pegasus = 'pegasus.svg';

  /// map constant pelvis_bone to pelvis-bone.svg file
  static const String pelvis_bone = 'pelvis-bone.svg';

  /// map constant pencil_brush to pencil-brush.svg file
  static const String pencil_brush = 'pencil-brush.svg';

  /// map constant pencil_ruler to pencil-ruler.svg file
  static const String pencil_ruler = 'pencil-ruler.svg';

  /// map constant pencil to pencil.svg file
  static const String pencil = 'pencil.svg';

  /// map constant pendant_key to pendant-key.svg file
  static const String pendant_key = 'pendant-key.svg';

  /// map constant pendulum_swing to pendulum-swing.svg file
  static const String pendulum_swing = 'pendulum-swing.svg';

  /// map constant penguin to penguin.svg file
  static const String penguin = 'penguin.svg';

  /// map constant pentacle to pentacle.svg file
  static const String pentacle = 'pentacle.svg';

  /// map constant pentagram_rose to pentagram-rose.svg file
  static const String pentagram_rose = 'pentagram-rose.svg';

  /// map constant pentarrows_tornado to pentarrows-tornado.svg file
  static const String pentarrows_tornado = 'pentarrows-tornado.svg';

  /// map constant perfume_bottle to perfume-bottle.svg file
  static const String perfume_bottle = 'perfume-bottle.svg';

  /// map constant periscope to periscope.svg file
  static const String periscope = 'periscope.svg';

  /// map constant perpendicular_rings to perpendicular-rings.svg file
  static const String perpendicular_rings = 'perpendicular-rings.svg';

  /// map constant person_in_bed to person-in-bed.svg file
  static const String person_in_bed = 'person-in-bed.svg';

  /// map constant person to person.svg file
  static const String person = 'person.svg';

  /// map constant perspective_dice_five to perspective-dice-five.svg file
  static const String perspective_dice_five = 'perspective-dice-five.svg';

  /// map constant perspective_dice_four to perspective-dice-four.svg file
  static const String perspective_dice_four = 'perspective-dice-four.svg';

  /// map constant perspective_dice_one to perspective-dice-one.svg file
  static const String perspective_dice_one = 'perspective-dice-one.svg';

  /// map constant perspective_dice_six_faces_five to perspective-dice-six-faces-five.svg file
  static const String perspective_dice_six_faces_five = 'perspective-dice-six-faces-five.svg';

  /// map constant perspective_dice_six_faces_four to perspective-dice-six-faces-four.svg file
  static const String perspective_dice_six_faces_four = 'perspective-dice-six-faces-four.svg';

  /// map constant perspective_dice_six_faces_one to perspective-dice-six-faces-one.svg file
  static const String perspective_dice_six_faces_one = 'perspective-dice-six-faces-one.svg';

  /// map constant perspective_dice_six_faces_random to perspective-dice-six-faces-random.svg file
  static const String perspective_dice_six_faces_random = 'perspective-dice-six-faces-random.svg';

  /// map constant perspective_dice_six_faces_six to perspective-dice-six-faces-six.svg file
  static const String perspective_dice_six_faces_six = 'perspective-dice-six-faces-six.svg';

  /// map constant perspective_dice_six_faces_three to perspective-dice-six-faces-three.svg file
  static const String perspective_dice_six_faces_three = 'perspective-dice-six-faces-three.svg';

  /// map constant perspective_dice_six_faces_two to perspective-dice-six-faces-two.svg file
  static const String perspective_dice_six_faces_two = 'perspective-dice-six-faces-two.svg';

  /// map constant perspective_dice_six to perspective-dice-six.svg file
  static const String perspective_dice_six = 'perspective-dice-six.svg';

  /// map constant perspective_dice_three to perspective-dice-three.svg file
  static const String perspective_dice_three = 'perspective-dice-three.svg';

  /// map constant perspective_dice_two to perspective-dice-two.svg file
  static const String perspective_dice_two = 'perspective-dice-two.svg';

  /// map constant peru to peru.svg file
  static const String peru = 'peru.svg';

  /// map constant pestle_mortar to pestle-mortar.svg file
  static const String pestle_mortar = 'pestle-mortar.svg';

  /// map constant pharoah to pharoah.svg file
  static const String pharoah = 'pharoah.svg';

  /// map constant philosopher_bust to philosopher-bust.svg file
  static const String philosopher_bust = 'philosopher-bust.svg';

  /// map constant phone to phone.svg file
  static const String phone = 'phone.svg';

  /// map constant photo_camera to photo-camera.svg file
  static const String photo_camera = 'photo-camera.svg';

  /// map constant phrygian_cap to phrygian-cap.svg file
  static const String phrygian_cap = 'phrygian-cap.svg';

  /// map constant pianist to pianist.svg file
  static const String pianist = 'pianist.svg';

  /// map constant piano_keys to piano-keys.svg file
  static const String piano_keys = 'piano-keys.svg';

  /// map constant pick_of_destiny to pick-of-destiny.svg file
  static const String pick_of_destiny = 'pick-of-destiny.svg';

  /// map constant pickelhaube to pickelhaube.svg file
  static const String pickelhaube = 'pickelhaube.svg';

  /// map constant pickle to pickle.svg file
  static const String pickle = 'pickle.svg';

  /// map constant pie_chart to pie-chart.svg file
  static const String pie_chart = 'pie-chart.svg';

  /// map constant pie_slice to pie-slice.svg file
  static const String pie_slice = 'pie-slice.svg';

  /// map constant piece_skull to piece-skull.svg file
  static const String piece_skull = 'piece-skull.svg';

  /// map constant pierced_body to pierced-body.svg file
  static const String pierced_body = 'pierced-body.svg';

  /// map constant pierced_heart to pierced-heart.svg file
  static const String pierced_heart = 'pierced-heart.svg';

  /// map constant piercing_sword to piercing-sword.svg file
  static const String piercing_sword = 'piercing-sword.svg';

  /// map constant pig_face to pig-face.svg file
  static const String pig_face = 'pig-face.svg';

  /// map constant pig to pig.svg file
  static const String pig = 'pig.svg';

  /// map constant piggy_bank to piggy-bank.svg file
  static const String piggy_bank = 'piggy-bank.svg';

  /// map constant pikeman to pikeman.svg file
  static const String pikeman = 'pikeman.svg';

  /// map constant pilgrim_hat to pilgrim-hat.svg file
  static const String pilgrim_hat = 'pilgrim-hat.svg';

  /// map constant pill_drop to pill-drop.svg file
  static const String pill_drop = 'pill-drop.svg';

  /// map constant pill to pill.svg file
  static const String pill = 'pill.svg';

  /// map constant pillow to pillow.svg file
  static const String pillow = 'pillow.svg';

  /// map constant pimiento to pimiento.svg file
  static const String pimiento = 'pimiento.svg';

  /// map constant pin to pin.svg file
  static const String pin = 'pin.svg';

  /// map constant pinata to pinata.svg file
  static const String pinata = 'pinata.svg';

  /// map constant pinball_flipper to pinball-flipper.svg file
  static const String pinball_flipper = 'pinball-flipper.svg';

  /// map constant pincers to pincers.svg file
  static const String pincers = 'pincers.svg';

  /// map constant pine_tree to pine-tree.svg file
  static const String pine_tree = 'pine-tree.svg';

  /// map constant pineapple to pineapple.svg file
  static const String pineapple = 'pineapple.svg';

  /// map constant ping_pong_bat to ping-pong-bat.svg file
  static const String ping_pong_bat = 'ping-pong-bat.svg';

  /// map constant pipe_organ to pipe-organ.svg file
  static const String pipe_organ = 'pipe-organ.svg';

  /// map constant pipes to pipes.svg file
  static const String pipes = 'pipes.svg';

  /// map constant piranha to piranha.svg file
  static const String piranha = 'piranha.svg';

  /// map constant pirate_cannon to pirate-cannon.svg file
  static const String pirate_cannon = 'pirate-cannon.svg';

  /// map constant pirate_captain to pirate-captain.svg file
  static const String pirate_captain = 'pirate-captain.svg';

  /// map constant pirate_coat to pirate-coat.svg file
  static const String pirate_coat = 'pirate-coat.svg';

  /// map constant pirate_flag to pirate-flag.svg file
  static const String pirate_flag = 'pirate-flag.svg';

  /// map constant pirate_grave to pirate-grave.svg file
  static const String pirate_grave = 'pirate-grave.svg';

  /// map constant pirate_hat to pirate-hat.svg file
  static const String pirate_hat = 'pirate-hat.svg';

  /// map constant pirate_hook to pirate-hook.svg file
  static const String pirate_hook = 'pirate-hook.svg';

  /// map constant pirate_skull to pirate-skull.svg file
  static const String pirate_skull = 'pirate-skull.svg';

  /// map constant pisa_tower to pisa-tower.svg file
  static const String pisa_tower = 'pisa-tower.svg';

  /// map constant pisces to pisces.svg file
  static const String pisces = 'pisces.svg';

  /// map constant pistol_gun to pistol-gun.svg file
  static const String pistol_gun = 'pistol-gun.svg';

  /// map constant pitchfork to pitchfork.svg file
  static const String pitchfork = 'pitchfork.svg';

  /// map constant pizza_cutter to pizza-cutter.svg file
  static const String pizza_cutter = 'pizza-cutter.svg';

  /// map constant pizza_slice to pizza-slice.svg file
  static const String pizza_slice = 'pizza-slice.svg';

  /// map constant plague_doctor_profile to plague-doctor-profile.svg file
  static const String plague_doctor_profile = 'plague-doctor-profile.svg';

  /// map constant plain_arrow to plain-arrow.svg file
  static const String plain_arrow = 'plain-arrow.svg';

  /// map constant plain_circle to plain-circle.svg file
  static const String plain_circle = 'plain-circle.svg';

  /// map constant plain_dagger to plain-dagger.svg file
  static const String plain_dagger = 'plain-dagger.svg';

  /// map constant plain_square to plain-square.svg file
  static const String plain_square = 'plain-square.svg';

  /// map constant plane_pilot to plane-pilot.svg file
  static const String plane_pilot = 'plane-pilot.svg';

  /// map constant plane_wing to plane-wing.svg file
  static const String plane_wing = 'plane-wing.svg';

  /// map constant planet_conquest to planet-conquest.svg file
  static const String planet_conquest = 'planet-conquest.svg';

  /// map constant planet_core to planet-core.svg file
  static const String planet_core = 'planet-core.svg';

  /// map constant planks to planks.svg file
  static const String planks = 'planks.svg';

  /// map constant plant_roots to plant-roots.svg file
  static const String plant_roots = 'plant-roots.svg';

  /// map constant plant_seed to plant-seed.svg file
  static const String plant_seed = 'plant-seed.svg';

  /// map constant plant_watering to plant-watering.svg file
  static const String plant_watering = 'plant-watering.svg';

  /// map constant plants_and_animals to plants-and-animals.svg file
  static const String plants_and_animals = 'plants-and-animals.svg';

  /// map constant plasma_bolt to plasma-bolt.svg file
  static const String plasma_bolt = 'plasma-bolt.svg';

  /// map constant plastic_duck to plastic-duck.svg file
  static const String plastic_duck = 'plastic-duck.svg';

  /// map constant plastron to plastron.svg file
  static const String plastron = 'plastron.svg';

  /// map constant plate_claw to plate-claw.svg file
  static const String plate_claw = 'plate-claw.svg';

  /// map constant platform to platform.svg file
  static const String platform = 'platform.svg';

  /// map constant play_button to play-button.svg file
  static const String play_button = 'play-button.svg';

  /// map constant player_base to player-base.svg file
  static const String player_base = 'player-base.svg';

  /// map constant player_next to player-next.svg file
  static const String player_next = 'player-next.svg';

  /// map constant player_previous to player-previous.svg file
  static const String player_previous = 'player-previous.svg';

  /// map constant player_time to player-time.svg file
  static const String player_time = 'player-time.svg';

  /// map constant plesiosaurus to plesiosaurus.svg file
  static const String plesiosaurus = 'plesiosaurus.svg';

  /// map constant plow to plow.svg file
  static const String plow = 'plow.svg';

  /// map constant plug to plug.svg file
  static const String plug = 'plug.svg';

  /// map constant plunger to plunger.svg file
  static const String plunger = 'plunger.svg';

  /// map constant pocket_bow to pocket-bow.svg file
  static const String pocket_bow = 'pocket-bow.svg';

  /// map constant pocket_radio to pocket-radio.svg file
  static const String pocket_radio = 'pocket-radio.svg';

  /// map constant pocket_watch to pocket-watch.svg file
  static const String pocket_watch = 'pocket-watch.svg';

  /// map constant podium_second to podium-second.svg file
  static const String podium_second = 'podium-second.svg';

  /// map constant podium_third to podium-third.svg file
  static const String podium_third = 'podium-third.svg';

  /// map constant podium_winner to podium-winner.svg file
  static const String podium_winner = 'podium-winner.svg';

  /// map constant podium to podium.svg file
  static const String podium = 'podium.svg';

  /// map constant pointing to pointing.svg file
  static const String pointing = 'pointing.svg';

  /// map constant pointy_hat to pointy-hat.svg file
  static const String pointy_hat = 'pointy-hat.svg';

  /// map constant pointy_sword to pointy-sword.svg file
  static const String pointy_sword = 'pointy-sword.svg';

  /// map constant poison_bottle to poison-bottle.svg file
  static const String poison_bottle = 'poison-bottle.svg';

  /// map constant poison_cloud to poison-cloud.svg file
  static const String poison_cloud = 'poison-cloud.svg';

  /// map constant poison_gas to poison-gas.svg file
  static const String poison_gas = 'poison-gas.svg';

  /// map constant poison to poison.svg file
  static const String poison = 'poison.svg';

  /// map constant pokecog to pokecog.svg file
  static const String pokecog = 'pokecog.svg';

  /// map constant poker_hand to poker-hand.svg file
  static const String poker_hand = 'poker-hand.svg';

  /// map constant poland to poland.svg file
  static const String poland = 'poland.svg';

  /// map constant polar_bear to polar-bear.svg file
  static const String polar_bear = 'polar-bear.svg';

  /// map constant polar_star to polar-star.svg file
  static const String polar_star = 'polar-star.svg';

  /// map constant police_badge to police-badge.svg file
  static const String police_badge = 'police-badge.svg';

  /// map constant police_car to police-car.svg file
  static const String police_car = 'police-car.svg';

  /// map constant police_officer_head to police-officer-head.svg file
  static const String police_officer_head = 'police-officer-head.svg';

  /// map constant police_target to police-target.svg file
  static const String police_target = 'police-target.svg';

  /// map constant pollen_dust to pollen-dust.svg file
  static const String pollen_dust = 'pollen-dust.svg';

  /// map constant polo_shirt to polo-shirt.svg file
  static const String polo_shirt = 'polo-shirt.svg';

  /// map constant poncho to poncho.svg file
  static const String poncho = 'poncho.svg';

  /// map constant pool_dive to pool-dive.svg file
  static const String pool_dive = 'pool-dive.svg';

  /// map constant pool_table_corner to pool-table-corner.svg file
  static const String pool_table_corner = 'pool-table-corner.svg';

  /// map constant pool_triangle to pool-triangle.svg file
  static const String pool_triangle = 'pool-triangle.svg';

  /// map constant popcorn to popcorn.svg file
  static const String popcorn = 'popcorn.svg';

  /// map constant pope_crown to pope-crown.svg file
  static const String pope_crown = 'pope-crown.svg';

  /// map constant poppy to poppy.svg file
  static const String poppy = 'poppy.svg';

  /// map constant porcelain_vase to porcelain-vase.svg file
  static const String porcelain_vase = 'porcelain-vase.svg';

  /// map constant porcupine to porcupine.svg file
  static const String porcupine = 'porcupine.svg';

  /// map constant porcupinefish to porcupinefish.svg file
  static const String porcupinefish = 'porcupinefish.svg';

  /// map constant portal to portal.svg file
  static const String portal = 'portal.svg';

  /// map constant portculis to portculis.svg file
  static const String portculis = 'portculis.svg';

  /// map constant portrait to portrait.svg file
  static const String portrait = 'portrait.svg';

  /// map constant portugal to portugal.svg file
  static const String portugal = 'portugal.svg';

  /// map constant position_marker to position-marker.svg file
  static const String position_marker = 'position-marker.svg';

  /// map constant post_office to post-office.svg file
  static const String post_office = 'post-office.svg';

  /// map constant post_stamp to post-stamp.svg file
  static const String post_stamp = 'post-stamp.svg';

  /// map constant potato to potato.svg file
  static const String potato = 'potato.svg';

  /// map constant potion_ball to potion-ball.svg file
  static const String potion_ball = 'potion-ball.svg';

  /// map constant potion_of_madness to potion-of-madness.svg file
  static const String potion_of_madness = 'potion-of-madness.svg';

  /// map constant pounce to pounce.svg file
  static const String pounce = 'pounce.svg';

  /// map constant pouring_chalice to pouring-chalice.svg file
  static const String pouring_chalice = 'pouring-chalice.svg';

  /// map constant pouring_pot to pouring-pot.svg file
  static const String pouring_pot = 'pouring-pot.svg';

  /// map constant powder_bag to powder-bag.svg file
  static const String powder_bag = 'powder-bag.svg';

  /// map constant powder to powder.svg file
  static const String powder = 'powder.svg';

  /// map constant power_button to power-button.svg file
  static const String power_button = 'power-button.svg';

  /// map constant power_generator to power-generator.svg file
  static const String power_generator = 'power-generator.svg';

  /// map constant power_lightning to power-lightning.svg file
  static const String power_lightning = 'power-lightning.svg';

  /// map constant power_ring to power-ring.svg file
  static const String power_ring = 'power-ring.svg';

  /// map constant prank_glasses to prank-glasses.svg file
  static const String prank_glasses = 'prank-glasses.svg';

  /// map constant prayer_beads to prayer-beads.svg file
  static const String prayer_beads = 'prayer-beads.svg';

  /// map constant prayer to prayer.svg file
  static const String prayer = 'prayer.svg';

  /// map constant praying_mantis to praying-mantis.svg file
  static const String praying_mantis = 'praying-mantis.svg';

  /// map constant present to present.svg file
  static const String present = 'present.svg';

  /// map constant pressure_cooker to pressure-cooker.svg file
  static const String pressure_cooker = 'pressure-cooker.svg';

  /// map constant pretty_fangs to pretty-fangs.svg file
  static const String pretty_fangs = 'pretty-fangs.svg';

  /// map constant pretzel to pretzel.svg file
  static const String pretzel = 'pretzel.svg';

  /// map constant previous_button to previous-button.svg file
  static const String previous_button = 'previous-button.svg';

  /// map constant price_tag to price-tag.svg file
  static const String price_tag = 'price-tag.svg';

  /// map constant primitive_necklace to primitive-necklace.svg file
  static const String primitive_necklace = 'primitive-necklace.svg';

  /// map constant primitive_torch to primitive-torch.svg file
  static const String primitive_torch = 'primitive-torch.svg';

  /// map constant prism to prism.svg file
  static const String prism = 'prism.svg';

  /// map constant prisoner to prisoner.svg file
  static const String prisoner = 'prisoner.svg';

  /// map constant private_first_class to private-first-class.svg file
  static const String private_first_class = 'private-first-class.svg';

  /// map constant private to private.svg file
  static const String private = 'private.svg';

  /// map constant processor to processor.svg file
  static const String processor = 'processor.svg';

  /// map constant profit to profit.svg file
  static const String profit = 'profit.svg';

  /// map constant progression to progression.svg file
  static const String progression = 'progression.svg';

  /// map constant propeller_beanie to propeller-beanie.svg file
  static const String propeller_beanie = 'propeller-beanie.svg';

  /// map constant protection_glasses to protection-glasses.svg file
  static const String protection_glasses = 'protection-glasses.svg';

  /// map constant pschent_double_crown to pschent-double-crown.svg file
  static const String pschent_double_crown = 'pschent-double-crown.svg';

  /// map constant psychic_waves to psychic-waves.svg file
  static const String psychic_waves = 'psychic-waves.svg';

  /// map constant pterodactylus to pterodactylus.svg file
  static const String pterodactylus = 'pterodactylus.svg';

  /// map constant pteruges to pteruges.svg file
  static const String pteruges = 'pteruges.svg';

  /// map constant public_speaker to public-speaker.svg file
  static const String public_speaker = 'public-speaker.svg';

  /// map constant pull to pull.svg file
  static const String pull = 'pull.svg';

  /// map constant pulley_hook to pulley-hook.svg file
  static const String pulley_hook = 'pulley-hook.svg';

  /// map constant pulse to pulse.svg file
  static const String pulse = 'pulse.svg';

  /// map constant pummeled to pummeled.svg file
  static const String pummeled = 'pummeled.svg';

  /// map constant pumpkin_lantern to pumpkin-lantern.svg file
  static const String pumpkin_lantern = 'pumpkin-lantern.svg';

  /// map constant pumpkin_mask to pumpkin-mask.svg file
  static const String pumpkin_mask = 'pumpkin-mask.svg';

  /// map constant pumpkin to pumpkin.svg file
  static const String pumpkin = 'pumpkin.svg';

  /// map constant punch_blast to punch-blast.svg file
  static const String punch_blast = 'punch-blast.svg';

  /// map constant punch to punch.svg file
  static const String punch = 'punch.svg';

  /// map constant punching_bag to punching-bag.svg file
  static const String punching_bag = 'punching-bag.svg';

  /// map constant puppet to puppet.svg file
  static const String puppet = 'puppet.svg';

  /// map constant purple_tentacle to purple-tentacle.svg file
  static const String purple_tentacle = 'purple-tentacle.svg';

  /// map constant push to push.svg file
  static const String push = 'push.svg';

  /// map constant puzzle to puzzle.svg file
  static const String puzzle = 'puzzle.svg';

  /// map constant pylon to pylon.svg file
  static const String pylon = 'pylon.svg';

  /// map constant pyre to pyre.svg file
  static const String pyre = 'pyre.svg';

  /// map constant pyromaniac to pyromaniac.svg file
  static const String pyromaniac = 'pyromaniac.svg';

  /// map constant qaitbay_citadel to qaitbay-citadel.svg file
  static const String qaitbay_citadel = 'qaitbay-citadel.svg';

  /// map constant quake_stomp to quake-stomp.svg file
  static const String quake_stomp = 'quake-stomp.svg';

  /// map constant queen_crown to queen-crown.svg file
  static const String queen_crown = 'queen-crown.svg';

  /// map constant quick_man to quick-man.svg file
  static const String quick_man = 'quick-man.svg';

  /// map constant quick_slash to quick-slash.svg file
  static const String quick_slash = 'quick-slash.svg';

  /// map constant quicksand to quicksand.svg file
  static const String quicksand = 'quicksand.svg';

  /// map constant quill_ink to quill-ink.svg file
  static const String quill_ink = 'quill-ink.svg';

  /// map constant quill to quill.svg file
  static const String quill = 'quill.svg';

  /// map constant quiver to quiver.svg file
  static const String quiver = 'quiver.svg';

  /// map constant rabbit_head to rabbit-head.svg file
  static const String rabbit_head = 'rabbit-head.svg';

  /// map constant rabbit to rabbit.svg file
  static const String rabbit = 'rabbit.svg';

  /// map constant raccoon_head to raccoon-head.svg file
  static const String raccoon_head = 'raccoon-head.svg';

  /// map constant race_car to race-car.svg file
  static const String race_car = 'race-car.svg';

  /// map constant radar_cross_section to radar-cross-section.svg file
  static const String radar_cross_section = 'radar-cross-section.svg';

  /// map constant radar_dish to radar-dish.svg file
  static const String radar_dish = 'radar-dish.svg';

  /// map constant radar_sweep to radar-sweep.svg file
  static const String radar_sweep = 'radar-sweep.svg';

  /// map constant raddish to raddish.svg file
  static const String raddish = 'raddish.svg';

  /// map constant radial_balance to radial-balance.svg file
  static const String radial_balance = 'radial-balance.svg';

  /// map constant radiations to radiations.svg file
  static const String radiations = 'radiations.svg';

  /// map constant radio_tower to radio-tower.svg file
  static const String radio_tower = 'radio-tower.svg';

  /// map constant radioactive to radioactive.svg file
  static const String radioactive = 'radioactive.svg';

  /// map constant raft to raft.svg file
  static const String raft = 'raft.svg';

  /// map constant ragged_wound to ragged-wound.svg file
  static const String ragged_wound = 'ragged-wound.svg';

  /// map constant rail_road to rail-road.svg file
  static const String rail_road = 'rail-road.svg';

  /// map constant railway to railway.svg file
  static const String railway = 'railway.svg';

  /// map constant rainbow_star to rainbow-star.svg file
  static const String rainbow_star = 'rainbow-star.svg';

  /// map constant raining to raining.svg file
  static const String raining = 'raining.svg';

  /// map constant raise_skeleton to raise-skeleton.svg file
  static const String raise_skeleton = 'raise-skeleton.svg';

  /// map constant raise_zombie to raise-zombie.svg file
  static const String raise_zombie = 'raise-zombie.svg';

  /// map constant rake to rake.svg file
  static const String rake = 'rake.svg';

  /// map constant rally_the_troops to rally-the-troops.svg file
  static const String rally_the_troops = 'rally-the-troops.svg';

  /// map constant ram2 to ram 2.svg file
  static const String ram2 = 'ram 2.svg';

  /// map constant ram_profile to ram-profile.svg file
  static const String ram_profile = 'ram-profile.svg';

  /// map constant ram to ram.svg file
  static const String ram = 'ram.svg';

  /// map constant ranch_gate to ranch-gate.svg file
  static const String ranch_gate = 'ranch-gate.svg';

  /// map constant rank_1 to rank-1.svg file
  static const String rank_1 = 'rank-1.svg';

  /// map constant rank_2 to rank-2.svg file
  static const String rank_2 = 'rank-2.svg';

  /// map constant rank_3 to rank-3.svg file
  static const String rank_3 = 'rank-3.svg';

  /// map constant rapidshare_arrow to rapidshare-arrow.svg file
  static const String rapidshare_arrow = 'rapidshare-arrow.svg';

  /// map constant raspberry to raspberry.svg file
  static const String raspberry = 'raspberry.svg';

  /// map constant rat to rat.svg file
  static const String rat = 'rat.svg';

  /// map constant rattlesnake to rattlesnake.svg file
  static const String rattlesnake = 'rattlesnake.svg';

  /// map constant raven to raven.svg file
  static const String raven = 'raven.svg';

  /// map constant raw_egg to raw-egg.svg file
  static const String raw_egg = 'raw-egg.svg';

  /// map constant ray_gun to ray-gun.svg file
  static const String ray_gun = 'ray-gun.svg';

  /// map constant razor_blade to razor-blade.svg file
  static const String razor_blade = 'razor-blade.svg';

  /// map constant razor to razor.svg file
  static const String razor = 'razor.svg';

  /// map constant reactor to reactor.svg file
  static const String reactor = 'reactor.svg';

  /// map constant read to read.svg file
  static const String read = 'read.svg';

  /// map constant reaper_scythe to reaper-scythe.svg file
  static const String reaper_scythe = 'reaper-scythe.svg';

  /// map constant rear_aura to rear-aura.svg file
  static const String rear_aura = 'rear-aura.svg';

  /// map constant receive_money to receive-money.svg file
  static const String receive_money = 'receive-money.svg';

  /// map constant recycle to recycle.svg file
  static const String recycle = 'recycle.svg';

  /// map constant red_carpet to red-carpet.svg file
  static const String red_carpet = 'red-carpet.svg';

  /// map constant reed to reed.svg file
  static const String reed = 'reed.svg';

  /// map constant refinery to refinery.svg file
  static const String refinery = 'refinery.svg';

  /// map constant regeneration to regeneration.svg file
  static const String regeneration = 'regeneration.svg';

  /// map constant relationship_bounds to relationship-bounds.svg file
  static const String relationship_bounds = 'relationship-bounds.svg';

  /// map constant relic_blade to relic-blade.svg file
  static const String relic_blade = 'relic-blade.svg';

  /// map constant reload_gun_barrel to reload-gun-barrel.svg file
  static const String reload_gun_barrel = 'reload-gun-barrel.svg';

  /// map constant remedy to remedy.svg file
  static const String remedy = 'remedy.svg';

  /// map constant rempart to rempart.svg file
  static const String rempart = 'rempart.svg';

  /// map constant reptile_tail to reptile-tail.svg file
  static const String reptile_tail = 'reptile-tail.svg';

  /// map constant resize to resize.svg file
  static const String resize = 'resize.svg';

  /// map constant resonance to resonance.svg file
  static const String resonance = 'resonance.svg';

  /// map constant resting_vampire to resting-vampire.svg file
  static const String resting_vampire = 'resting-vampire.svg';

  /// map constant reticule to reticule.svg file
  static const String reticule = 'reticule.svg';

  /// map constant retro_controller to retro-controller.svg file
  static const String retro_controller = 'retro-controller.svg';

  /// map constant return_arrow to return-arrow.svg file
  static const String return_arrow = 'return-arrow.svg';

  /// map constant revolt2 to revolt 2.svg file
  static const String revolt2 = 'revolt 2.svg';

  /// map constant revolt to revolt.svg file
  static const String revolt = 'revolt.svg';

  /// map constant revolver2 to revolver 2.svg file
  static const String revolver2 = 'revolver 2.svg';

  /// map constant revolver to revolver.svg file
  static const String revolver = 'revolver.svg';

  /// map constant rhinoceros_horn to rhinoceros-horn.svg file
  static const String rhinoceros_horn = 'rhinoceros-horn.svg';

  /// map constant rialto_bridge to rialto-bridge.svg file
  static const String rialto_bridge = 'rialto-bridge.svg';

  /// map constant ribbon_medal to ribbon-medal.svg file
  static const String ribbon_medal = 'ribbon-medal.svg';

  /// map constant ribbon_shield to ribbon-shield.svg file
  static const String ribbon_shield = 'ribbon-shield.svg';

  /// map constant ribbon to ribbon.svg file
  static const String ribbon = 'ribbon.svg';

  /// map constant ribcage to ribcage.svg file
  static const String ribcage = 'ribcage.svg';

  /// map constant rice_cooker to rice-cooker.svg file
  static const String rice_cooker = 'rice-cooker.svg';

  /// map constant ricochet to ricochet.svg file
  static const String ricochet = 'ricochet.svg';

  /// map constant rifle to rifle.svg file
  static const String rifle = 'rifle.svg';

  /// map constant ring_box to ring-box.svg file
  static const String ring_box = 'ring-box.svg';

  /// map constant ring_mould to ring-mould.svg file
  static const String ring_mould = 'ring-mould.svg';

  /// map constant ring to ring.svg file
  static const String ring = 'ring.svg';

  /// map constant ringed_beam to ringed-beam.svg file
  static const String ringed_beam = 'ringed-beam.svg';

  /// map constant ringed_planet to ringed-planet.svg file
  static const String ringed_planet = 'ringed-planet.svg';

  /// map constant ringing_alarm to ringing-alarm.svg file
  static const String ringing_alarm = 'ringing-alarm.svg';

  /// map constant ringing_bell to ringing-bell.svg file
  static const String ringing_bell = 'ringing-bell.svg';

  /// map constant ringmaster to ringmaster.svg file
  static const String ringmaster = 'ringmaster.svg';

  /// map constant riot_shield to riot-shield.svg file
  static const String riot_shield = 'riot-shield.svg';

  /// map constant riposte to riposte.svg file
  static const String riposte = 'riposte.svg';

  /// map constant river to river.svg file
  static const String river = 'river.svg';

  /// map constant road to road.svg file
  static const String road = 'road.svg';

  /// map constant roast_chicken to roast-chicken.svg file
  static const String roast_chicken = 'roast-chicken.svg';

  /// map constant robber_hand to robber-hand.svg file
  static const String robber_hand = 'robber-hand.svg';

  /// map constant robber_mask to robber-mask.svg file
  static const String robber_mask = 'robber-mask.svg';

  /// map constant robber to robber.svg file
  static const String robber = 'robber.svg';

  /// map constant robe to robe.svg file
  static const String robe = 'robe.svg';

  /// map constant robin_hood_hat to robin-hood-hat.svg file
  static const String robin_hood_hat = 'robin-hood-hat.svg';

  /// map constant robot_antennas to robot-antennas.svg file
  static const String robot_antennas = 'robot-antennas.svg';

  /// map constant robot_golem to robot-golem.svg file
  static const String robot_golem = 'robot-golem.svg';

  /// map constant robot_grab to robot-grab.svg file
  static const String robot_grab = 'robot-grab.svg';

  /// map constant robot_helmet to robot-helmet.svg file
  static const String robot_helmet = 'robot-helmet.svg';

  /// map constant robot_leg to robot-leg.svg file
  static const String robot_leg = 'robot-leg.svg';

  /// map constant rock2 to rock 2.svg file
  static const String rock2 = 'rock 2.svg';

  /// map constant rock_golem to rock-golem.svg file
  static const String rock_golem = 'rock-golem.svg';

  /// map constant rock to rock.svg file
  static const String rock = 'rock.svg';

  /// map constant rocket_flight to rocket-flight.svg file
  static const String rocket_flight = 'rocket-flight.svg';

  /// map constant rocket_thruster to rocket-thruster.svg file
  static const String rocket_thruster = 'rocket-thruster.svg';

  /// map constant rocket to rocket.svg file
  static const String rocket = 'rocket.svg';

  /// map constant rocking_chair to rocking-chair.svg file
  static const String rocking_chair = 'rocking-chair.svg';

  /// map constant rod_of_asclepius to rod-of-asclepius.svg file
  static const String rod_of_asclepius = 'rod-of-asclepius.svg';

  /// map constant rogue to rogue.svg file
  static const String rogue = 'rogue.svg';

  /// map constant rolled_cloth to rolled-cloth.svg file
  static const String rolled_cloth = 'rolled-cloth.svg';

  /// map constant roller_skate to roller-skate.svg file
  static const String roller_skate = 'roller-skate.svg';

  /// map constant rolling_bomb to rolling-bomb.svg file
  static const String rolling_bomb = 'rolling-bomb.svg';

  /// map constant rolling_dice_cup to rolling-dice-cup.svg file
  static const String rolling_dice_cup = 'rolling-dice-cup.svg';

  /// map constant rolling_dices to rolling-dices.svg file
  static const String rolling_dices = 'rolling-dices.svg';

  /// map constant rolling_energy to rolling-energy.svg file
  static const String rolling_energy = 'rolling-energy.svg';

  /// map constant rolling_suitcase to rolling-suitcase.svg file
  static const String rolling_suitcase = 'rolling-suitcase.svg';

  /// map constant roman_shield to roman-shield.svg file
  static const String roman_shield = 'roman-shield.svg';

  /// map constant roman_toga to roman-toga.svg file
  static const String roman_toga = 'roman-toga.svg';

  /// map constant rooster to rooster.svg file
  static const String rooster = 'rooster.svg';

  /// map constant root_tip to root-tip.svg file
  static const String root_tip = 'root-tip.svg';

  /// map constant rope_bridge to rope-bridge.svg file
  static const String rope_bridge = 'rope-bridge.svg';

  /// map constant rope_coil to rope-coil.svg file
  static const String rope_coil = 'rope-coil.svg';

  /// map constant rope_dart to rope-dart.svg file
  static const String rope_dart = 'rope-dart.svg';

  /// map constant ropeway to ropeway.svg file
  static const String ropeway = 'ropeway.svg';

  /// map constant rosa_shield to rosa-shield.svg file
  static const String rosa_shield = 'rosa-shield.svg';

  /// map constant rose to rose.svg file
  static const String rose = 'rose.svg';

  /// map constant rotary_phone to rotary-phone.svg file
  static const String rotary_phone = 'rotary-phone.svg';

  /// map constant rough_wound to rough-wound.svg file
  static const String rough_wound = 'rough-wound.svg';

  /// map constant round_bottom_flask to round-bottom-flask.svg file
  static const String round_bottom_flask = 'round-bottom-flask.svg';

  /// map constant round_knob to round-knob.svg file
  static const String round_knob = 'round-knob.svg';

  /// map constant round_potion to round-potion.svg file
  static const String round_potion = 'round-potion.svg';

  /// map constant round_shield to round-shield.svg file
  static const String round_shield = 'round-shield.svg';

  /// map constant round_silo to round-silo.svg file
  static const String round_silo = 'round-silo.svg';

  /// map constant round_star to round-star.svg file
  static const String round_star = 'round-star.svg';

  /// map constant round_straw_bale to round-straw-bale.svg file
  static const String round_straw_bale = 'round-straw-bale.svg';

  /// map constant round_struck to round-struck.svg file
  static const String round_struck = 'round-struck.svg';

  /// map constant round_table to round-table.svg file
  static const String round_table = 'round-table.svg';

  /// map constant royal_love to royal-love.svg file
  static const String royal_love = 'royal-love.svg';

  /// map constant rss2 to rss 2.svg file
  static const String rss2 = 'rss 2.svg';

  /// map constant rss to rss.svg file
  static const String rss = 'rss.svg';

  /// map constant rub_el_hizb to rub-el-hizb.svg file
  static const String rub_el_hizb = 'rub-el-hizb.svg';

  /// map constant rubber_boot to rubber-boot.svg file
  static const String rubber_boot = 'rubber-boot.svg';

  /// map constant rugby_conversion to rugby-conversion.svg file
  static const String rugby_conversion = 'rugby-conversion.svg';

  /// map constant rule_book to rule-book.svg file
  static const String rule_book = 'rule-book.svg';

  /// map constant run to run.svg file
  static const String run = 'run.svg';

  /// map constant rune_stone to rune-stone.svg file
  static const String rune_stone = 'rune-stone.svg';

  /// map constant rune_sword to rune-sword.svg file
  static const String rune_sword = 'rune-sword.svg';

  /// map constant running_ninja to running-ninja.svg file
  static const String running_ninja = 'running-ninja.svg';

  /// map constant running_shoe to running-shoe.svg file
  static const String running_shoe = 'running-shoe.svg';

  /// map constant rupee to rupee.svg file
  static const String rupee = 'rupee.svg';

  /// map constant rusty_sword to rusty-sword.svg file
  static const String rusty_sword = 'rusty-sword.svg';

  /// map constant s_brick to s-brick.svg file
  static const String s_brick = 's-brick.svg';

  /// map constant saber_and_pistol to saber-and-pistol.svg file
  static const String saber_and_pistol = 'saber-and-pistol.svg';

  /// map constant saber_slash to saber-slash.svg file
  static const String saber_slash = 'saber-slash.svg';

  /// map constant saber_tooth to saber-tooth.svg file
  static const String saber_tooth = 'saber-tooth.svg';

  /// map constant saber_toothed_cat_head to saber-toothed-cat-head.svg file
  static const String saber_toothed_cat_head = 'saber-toothed-cat-head.svg';

  /// map constant sabers_choc to sabers-choc.svg file
  static const String sabers_choc = 'sabers-choc.svg';

  /// map constant sacrificial_dagger to sacrificial-dagger.svg file
  static const String sacrificial_dagger = 'sacrificial-dagger.svg';

  /// map constant sad_crab to sad-crab.svg file
  static const String sad_crab = 'sad-crab.svg';

  /// map constant saddle to saddle.svg file
  static const String saddle = 'saddle.svg';

  /// map constant safety_pin to safety-pin.svg file
  static const String safety_pin = 'safety-pin.svg';

  /// map constant sagittarius to sagittarius.svg file
  static const String sagittarius = 'sagittarius.svg';

  /// map constant sai to sai.svg file
  static const String sai = 'sai.svg';

  /// map constant sail to sail.svg file
  static const String sail = 'sail.svg';

  /// map constant sailboat to sailboat.svg file
  static const String sailboat = 'sailboat.svg';

  /// map constant saint_basil_cathedral to saint-basil-cathedral.svg file
  static const String saint_basil_cathedral = 'saint-basil-cathedral.svg';

  /// map constant saiyan_suit to saiyan-suit.svg file
  static const String saiyan_suit = 'saiyan-suit.svg';

  /// map constant salamander to salamander.svg file
  static const String salamander = 'salamander.svg';

  /// map constant salmon to salmon.svg file
  static const String salmon = 'salmon.svg';

  /// map constant saloon_doors to saloon-doors.svg file
  static const String saloon_doors = 'saloon-doors.svg';

  /// map constant saloon to saloon.svg file
  static const String saloon = 'saloon.svg';

  /// map constant salt_shaker to salt-shaker.svg file
  static const String salt_shaker = 'salt-shaker.svg';

  /// map constant samara_mosque to samara-mosque.svg file
  static const String samara_mosque = 'samara-mosque.svg';

  /// map constant samurai_helmet to samurai-helmet.svg file
  static const String samurai_helmet = 'samurai-helmet.svg';

  /// map constant samus_helmet to samus-helmet.svg file
  static const String samus_helmet = 'samus-helmet.svg';

  /// map constant sand_castle to sand-castle.svg file
  static const String sand_castle = 'sand-castle.svg';

  /// map constant sand_snake to sand-snake.svg file
  static const String sand_snake = 'sand-snake.svg';

  /// map constant sandal to sandal.svg file
  static const String sandal = 'sandal.svg';

  /// map constant sands_of_time to sands-of-time.svg file
  static const String sands_of_time = 'sands-of-time.svg';

  /// map constant sandstorm to sandstorm.svg file
  static const String sandstorm = 'sandstorm.svg';

  /// map constant sandwich to sandwich.svg file
  static const String sandwich = 'sandwich.svg';

  /// map constant santa_hat to santa-hat.svg file
  static const String santa_hat = 'santa-hat.svg';

  /// map constant saphir to saphir.svg file
  static const String saphir = 'saphir.svg';

  /// map constant sarcophagus to sarcophagus.svg file
  static const String sarcophagus = 'sarcophagus.svg';

  /// map constant sasquatch to sasquatch.svg file
  static const String sasquatch = 'sasquatch.svg';

  /// map constant satellite_communication to satellite-communication.svg file
  static const String satellite_communication = 'satellite-communication.svg';

  /// map constant sattelite to sattelite.svg file
  static const String sattelite = 'sattelite.svg';

  /// map constant saucepan to saucepan.svg file
  static const String saucepan = 'saucepan.svg';

  /// map constant sauropod_head to sauropod-head.svg file
  static const String sauropod_head = 'sauropod-head.svg';

  /// map constant sauropod_skeleton to sauropod-skeleton.svg file
  static const String sauropod_skeleton = 'sauropod-skeleton.svg';

  /// map constant sausage to sausage.svg file
  static const String sausage = 'sausage.svg';

  /// map constant sausages_ribbon to sausages-ribbon.svg file
  static const String sausages_ribbon = 'sausages-ribbon.svg';

  /// map constant save_arrow to save-arrow.svg file
  static const String save_arrow = 'save-arrow.svg';

  /// map constant save to save.svg file
  static const String save = 'save.svg';

  /// map constant saw_claw to saw-claw.svg file
  static const String saw_claw = 'saw-claw.svg';

  /// map constant sawed_off_shotgun to sawed-off-shotgun.svg file
  static const String sawed_off_shotgun = 'sawed-off-shotgun.svg';

  /// map constant saxophone to saxophone.svg file
  static const String saxophone = 'saxophone.svg';

  /// map constant scabbard to scabbard.svg file
  static const String scabbard = 'scabbard.svg';

  /// map constant scale_mail to scale-mail.svg file
  static const String scale_mail = 'scale-mail.svg';

  /// map constant scales to scales.svg file
  static const String scales = 'scales.svg';

  /// map constant scallop to scallop.svg file
  static const String scallop = 'scallop.svg';

  /// map constant scalpel_strike to scalpel-strike.svg file
  static const String scalpel_strike = 'scalpel-strike.svg';

  /// map constant scalpel to scalpel.svg file
  static const String scalpel = 'scalpel.svg';

  /// map constant scar_wound to scar-wound.svg file
  static const String scar_wound = 'scar-wound.svg';

  /// map constant scarab_beetle to scarab-beetle.svg file
  static const String scarab_beetle = 'scarab-beetle.svg';

  /// map constant scarecrow to scarecrow.svg file
  static const String scarecrow = 'scarecrow.svg';

  /// map constant school_bag to school-bag.svg file
  static const String school_bag = 'school-bag.svg';

  /// map constant school_of_fish to school-of-fish.svg file
  static const String school_of_fish = 'school-of-fish.svg';

  /// map constant scissors2 to scissors 2.svg file
  static const String scissors2 = 'scissors 2.svg';

  /// map constant scissors to scissors.svg file
  static const String scissors = 'scissors.svg';

  /// map constant scooter to scooter.svg file
  static const String scooter = 'scooter.svg';

  /// map constant scorpio to scorpio.svg file
  static const String scorpio = 'scorpio.svg';

  /// map constant scorpion_tail to scorpion-tail.svg file
  static const String scorpion_tail = 'scorpion-tail.svg';

  /// map constant scorpion to scorpion.svg file
  static const String scorpion = 'scorpion.svg';

  /// map constant scout_ship to scout-ship.svg file
  static const String scout_ship = 'scout-ship.svg';

  /// map constant screaming to screaming.svg file
  static const String screaming = 'screaming.svg';

  /// map constant screen_impact to screen-impact.svg file
  static const String screen_impact = 'screen-impact.svg';

  /// map constant screw2 to screw 2.svg file
  static const String screw2 = 'screw 2.svg';

  /// map constant screw to screw.svg file
  static const String screw = 'screw.svg';

  /// map constant screwdriver to screwdriver.svg file
  static const String screwdriver = 'screwdriver.svg';

  /// map constant scroll_quill to scroll-quill.svg file
  static const String scroll_quill = 'scroll-quill.svg';

  /// map constant scroll_unfurled to scroll-unfurled.svg file
  static const String scroll_unfurled = 'scroll-unfurled.svg';

  /// map constant scuba_mask to scuba-mask.svg file
  static const String scuba_mask = 'scuba-mask.svg';

  /// map constant scuba_tanks to scuba-tanks.svg file
  static const String scuba_tanks = 'scuba-tanks.svg';

  /// map constant scythe to scythe.svg file
  static const String scythe = 'scythe.svg';

  /// map constant sea_cliff to sea-cliff.svg file
  static const String sea_cliff = 'sea-cliff.svg';

  /// map constant sea_creature to sea-creature.svg file
  static const String sea_creature = 'sea-creature.svg';

  /// map constant sea_dragon to sea-dragon.svg file
  static const String sea_dragon = 'sea-dragon.svg';

  /// map constant sea_serpent to sea-serpent.svg file
  static const String sea_serpent = 'sea-serpent.svg';

  /// map constant sea_star to sea-star.svg file
  static const String sea_star = 'sea-star.svg';

  /// map constant sea_turtle to sea-turtle.svg file
  static const String sea_turtle = 'sea-turtle.svg';

  /// map constant seagull to seagull.svg file
  static const String seagull = 'seagull.svg';

  /// map constant seahorse to seahorse.svg file
  static const String seahorse = 'seahorse.svg';

  /// map constant seated_mouse to seated-mouse.svg file
  static const String seated_mouse = 'seated-mouse.svg';

  /// map constant secret_book to secret-book.svg file
  static const String secret_book = 'secret-book.svg';

  /// map constant secret_door to secret-door.svg file
  static const String secret_door = 'secret-door.svg';

  /// map constant security_gate to security-gate.svg file
  static const String security_gate = 'security-gate.svg';

  /// map constant seedling to seedling.svg file
  static const String seedling = 'seedling.svg';

  /// map constant select to select.svg file
  static const String select = 'select.svg';

  /// map constant self_love to self-love.svg file
  static const String self_love = 'self-love.svg';

  /// map constant sell_card to sell-card.svg file
  static const String sell_card = 'sell-card.svg';

  /// map constant semi_closed_eye to semi-closed-eye.svg file
  static const String semi_closed_eye = 'semi-closed-eye.svg';

  /// map constant sensuousness to sensuousness.svg file
  static const String sensuousness = 'sensuousness.svg';

  /// map constant sentry_gun to sentry-gun.svg file
  static const String sentry_gun = 'sentry-gun.svg';

  /// map constant sergeant to sergeant.svg file
  static const String sergeant = 'sergeant.svg';

  /// map constant serrated_slash to serrated-slash.svg file
  static const String serrated_slash = 'serrated-slash.svg';

  /// map constant server_rack to server-rack.svg file
  static const String server_rack = 'server-rack.svg';

  /// map constant sesame to sesame.svg file
  static const String sesame = 'sesame.svg';

  /// map constant settings_knobs to settings-knobs.svg file
  static const String settings_knobs = 'settings-knobs.svg';

  /// map constant seven_pointed_star to seven-pointed-star.svg file
  static const String seven_pointed_star = 'seven-pointed-star.svg';

  /// map constant severed_hand to severed-hand.svg file
  static const String severed_hand = 'severed-hand.svg';

  /// map constant sewed_shell to sewed-shell.svg file
  static const String sewed_shell = 'sewed-shell.svg';

  /// map constant sewing_machine to sewing-machine.svg file
  static const String sewing_machine = 'sewing-machine.svg';

  /// map constant sewing_needle to sewing-needle.svg file
  static const String sewing_needle = 'sewing-needle.svg';

  /// map constant sewing_string to sewing-string.svg file
  static const String sewing_string = 'sewing-string.svg';

  /// map constant sextant to sextant.svg file
  static const String sextant = 'sextant.svg';

  /// map constant shadow_follower to shadow-follower.svg file
  static const String shadow_follower = 'shadow-follower.svg';

  /// map constant shadow_grasp to shadow-grasp.svg file
  static const String shadow_grasp = 'shadow-grasp.svg';

  /// map constant shaking_hands to shaking-hands.svg file
  static const String shaking_hands = 'shaking-hands.svg';

  /// map constant shambling_mound to shambling-mound.svg file
  static const String shambling_mound = 'shambling-mound.svg';

  /// map constant shambling_zombie to shambling-zombie.svg file
  static const String shambling_zombie = 'shambling-zombie.svg';

  /// map constant shamrock to shamrock.svg file
  static const String shamrock = 'shamrock.svg';

  /// map constant shard_sword to shard-sword.svg file
  static const String shard_sword = 'shard-sword.svg';

  /// map constant share to share.svg file
  static const String share = 'share.svg';

  /// map constant shark_bite to shark-bite.svg file
  static const String shark_bite = 'shark-bite.svg';

  /// map constant shark_fin to shark-fin.svg file
  static const String shark_fin = 'shark-fin.svg';

  /// map constant shark_jaws to shark-jaws.svg file
  static const String shark_jaws = 'shark-jaws.svg';

  /// map constant sharp_axe to sharp-axe.svg file
  static const String sharp_axe = 'sharp-axe.svg';

  /// map constant sharp_crown to sharp-crown.svg file
  static const String sharp_crown = 'sharp-crown.svg';

  /// map constant sharp_halberd to sharp-halberd.svg file
  static const String sharp_halberd = 'sharp-halberd.svg';

  /// map constant sharp_lips to sharp-lips.svg file
  static const String sharp_lips = 'sharp-lips.svg';

  /// map constant sharp_shuriken to sharp-shuriken.svg file
  static const String sharp_shuriken = 'sharp-shuriken.svg';

  /// map constant sharp_smile to sharp-smile.svg file
  static const String sharp_smile = 'sharp-smile.svg';

  /// map constant sharped_teeth_skull to sharped-teeth-skull.svg file
  static const String sharped_teeth_skull = 'sharped-teeth-skull.svg';

  /// map constant shatter to shatter.svg file
  static const String shatter = 'shatter.svg';

  /// map constant shattered_glass to shattered-glass.svg file
  static const String shattered_glass = 'shattered-glass.svg';

  /// map constant shattered_heart to shattered-heart.svg file
  static const String shattered_heart = 'shattered-heart.svg';

  /// map constant shattered_sword to shattered-sword.svg file
  static const String shattered_sword = 'shattered-sword.svg';

  /// map constant shears to shears.svg file
  static const String shears = 'shears.svg';

  /// map constant sheep to sheep.svg file
  static const String sheep = 'sheep.svg';

  /// map constant sheikah_eye to sheikah-eye.svg file
  static const String sheikah_eye = 'sheikah-eye.svg';

  /// map constant shepherds_crook to shepherds-crook.svg file
  static const String shepherds_crook = 'shepherds-crook.svg';

  /// map constant sherlock_holmes to sherlock-holmes.svg file
  static const String sherlock_holmes = 'sherlock-holmes.svg';

  /// map constant shield_bash to shield-bash.svg file
  static const String shield_bash = 'shield-bash.svg';

  /// map constant shield_bounces to shield-bounces.svg file
  static const String shield_bounces = 'shield-bounces.svg';

  /// map constant shield_disabled to shield-disabled.svg file
  static const String shield_disabled = 'shield-disabled.svg';

  /// map constant shield_echoes to shield-echoes.svg file
  static const String shield_echoes = 'shield-echoes.svg';

  /// map constant shield_impact to shield-impact.svg file
  static const String shield_impact = 'shield-impact.svg';

  /// map constant shield_opposition to shield-opposition.svg file
  static const String shield_opposition = 'shield-opposition.svg';

  /// map constant shield_reflect to shield-reflect.svg file
  static const String shield_reflect = 'shield-reflect.svg';

  /// map constant shield to shield.svg file
  static const String shield = 'shield.svg';

  /// map constant shieldcomb to shieldcomb.svg file
  static const String shieldcomb = 'shieldcomb.svg';

  /// map constant shining_claw to shining-claw.svg file
  static const String shining_claw = 'shining-claw.svg';

  /// map constant shining_heart to shining-heart.svg file
  static const String shining_heart = 'shining-heart.svg';

  /// map constant shining_sword to shining-sword.svg file
  static const String shining_sword = 'shining-sword.svg';

  /// map constant shinto_shrine_mirror to shinto-shrine-mirror.svg file
  static const String shinto_shrine_mirror = 'shinto-shrine-mirror.svg';

  /// map constant shinto_shrine to shinto-shrine.svg file
  static const String shinto_shrine = 'shinto-shrine.svg';

  /// map constant shiny_apple to shiny-apple.svg file
  static const String shiny_apple = 'shiny-apple.svg';

  /// map constant shiny_entrance to shiny-entrance.svg file
  static const String shiny_entrance = 'shiny-entrance.svg';

  /// map constant shiny_iris to shiny-iris.svg file
  static const String shiny_iris = 'shiny-iris.svg';

  /// map constant shiny_omega to shiny-omega.svg file
  static const String shiny_omega = 'shiny-omega.svg';

  /// map constant shiny_purse to shiny-purse.svg file
  static const String shiny_purse = 'shiny-purse.svg';

  /// map constant ship_bow to ship-bow.svg file
  static const String ship_bow = 'ship-bow.svg';

  /// map constant ship_wheel to ship-wheel.svg file
  static const String ship_wheel = 'ship-wheel.svg';

  /// map constant ship_wreck to ship-wreck.svg file
  static const String ship_wreck = 'ship-wreck.svg';

  /// map constant shirt_button to shirt-button.svg file
  static const String shirt_button = 'shirt-button.svg';

  /// map constant shirt to shirt.svg file
  static const String shirt = 'shirt.svg';

  /// map constant shoebill_stork to shoebill-stork.svg file
  static const String shoebill_stork = 'shoebill-stork.svg';

  /// map constant shooner_sailboat to shooner-sailboat.svg file
  static const String shooner_sailboat = 'shooner-sailboat.svg';

  /// map constant shop to shop.svg file
  static const String shop = 'shop.svg';

  /// map constant shopping_bag to shopping-bag.svg file
  static const String shopping_bag = 'shopping-bag.svg';

  /// map constant shopping_cart to shopping-cart.svg file
  static const String shopping_cart = 'shopping-cart.svg';

  /// map constant shorts to shorts.svg file
  static const String shorts = 'shorts.svg';

  /// map constant shotgun_rounds to shotgun-rounds.svg file
  static const String shotgun_rounds = 'shotgun-rounds.svg';

  /// map constant shotgun to shotgun.svg file
  static const String shotgun = 'shotgun.svg';

  /// map constant shoulder_armor to shoulder-armor.svg file
  static const String shoulder_armor = 'shoulder-armor.svg';

  /// map constant shoulder_bag to shoulder-bag.svg file
  static const String shoulder_bag = 'shoulder-bag.svg';

  /// map constant shoulder_scales to shoulder-scales.svg file
  static const String shoulder_scales = 'shoulder-scales.svg';

  /// map constant shouting to shouting.svg file
  static const String shouting = 'shouting.svg';

  /// map constant shower to shower.svg file
  static const String shower = 'shower.svg';

  /// map constant shrimp to shrimp.svg file
  static const String shrimp = 'shrimp.svg';

  /// map constant shrug to shrug.svg file
  static const String shrug = 'shrug.svg';

  /// map constant shuriken2 to shuriken 2.svg file
  static const String shuriken2 = 'shuriken 2.svg';

  /// map constant shuriken_aperture to shuriken-aperture.svg file
  static const String shuriken_aperture = 'shuriken-aperture.svg';

  /// map constant shuriken to shuriken.svg file
  static const String shuriken = 'shuriken.svg';

  /// map constant shut_rose to shut-rose.svg file
  static const String shut_rose = 'shut-rose.svg';

  /// map constant shuttlecock to shuttlecock.svg file
  static const String shuttlecock = 'shuttlecock.svg';

  /// map constant sickle to sickle.svg file
  static const String sickle = 'sickle.svg';

  /// map constant sideswipe to sideswipe.svg file
  static const String sideswipe = 'sideswipe.svg';

  /// map constant siege_ram to siege-ram.svg file
  static const String siege_ram = 'siege-ram.svg';

  /// map constant siege_tower to siege-tower.svg file
  static const String siege_tower = 'siege-tower.svg';

  /// map constant sight_disabled to sight-disabled.svg file
  static const String sight_disabled = 'sight-disabled.svg';

  /// map constant silence to silence.svg file
  static const String silence = 'silence.svg';

  /// map constant silenced to silenced.svg file
  static const String silenced = 'silenced.svg';

  /// map constant silex to silex.svg file
  static const String silex = 'silex.svg';

  /// map constant silver_bullet to silver-bullet.svg file
  static const String silver_bullet = 'silver-bullet.svg';

  /// map constant sinagot to sinagot.svg file
  static const String sinagot = 'sinagot.svg';

  /// map constant sing to sing.svg file
  static const String sing = 'sing.svg';

  /// map constant sinking_ship to sinking-ship.svg file
  static const String sinking_ship = 'sinking-ship.svg';

  /// map constant sinking_trap to sinking-trap.svg file
  static const String sinking_trap = 'sinking-trap.svg';

  /// map constant sinusoidal_beam to sinusoidal-beam.svg file
  static const String sinusoidal_beam = 'sinusoidal-beam.svg';

  /// map constant siren to siren.svg file
  static const String siren = 'siren.svg';

  /// map constant sitting_dog to sitting-dog.svg file
  static const String sitting_dog = 'sitting-dog.svg';

  /// map constant six_eyes to six-eyes.svg file
  static const String six_eyes = 'six-eyes.svg';

  /// map constant skateboard to skateboard.svg file
  static const String skateboard = 'skateboard.svg';

  /// map constant skateboarding_01 to skateboarding-01.svg file
  static const String skateboarding_01 = 'skateboarding-01.svg';

  /// map constant skateboarding_02 to skateboarding-02.svg file
  static const String skateboarding_02 = 'skateboarding-02.svg';

  /// map constant skeletal_hand to skeletal-hand.svg file
  static const String skeletal_hand = 'skeletal-hand.svg';

  /// map constant skeleton_inside to skeleton-inside.svg file
  static const String skeleton_inside = 'skeleton-inside.svg';

  /// map constant skeleton_key to skeleton-key.svg file
  static const String skeleton_key = 'skeleton-key.svg';

  /// map constant skeleton to skeleton.svg file
  static const String skeleton = 'skeleton.svg';

  /// map constant ski_boot to ski-boot.svg file
  static const String ski_boot = 'ski-boot.svg';

  /// map constant skid_mark to skid-mark.svg file
  static const String skid_mark = 'skid-mark.svg';

  /// map constant skier to skier.svg file
  static const String skier = 'skier.svg';

  /// map constant skills to skills.svg file
  static const String skills = 'skills.svg';

  /// map constant skipping_rope to skipping-rope.svg file
  static const String skipping_rope = 'skipping-rope.svg';

  /// map constant skirt to skirt.svg file
  static const String skirt = 'skirt.svg';

  /// map constant skis to skis.svg file
  static const String skis = 'skis.svg';

  /// map constant skull_bolt to skull-bolt.svg file
  static const String skull_bolt = 'skull-bolt.svg';

  /// map constant skull_crack to skull-crack.svg file
  static const String skull_crack = 'skull-crack.svg';

  /// map constant skull_crossed_bones to skull-crossed-bones.svg file
  static const String skull_crossed_bones = 'skull-crossed-bones.svg';

  /// map constant skull_in_jar to skull-in-jar.svg file
  static const String skull_in_jar = 'skull-in-jar.svg';

  /// map constant skull_mask to skull-mask.svg file
  static const String skull_mask = 'skull-mask.svg';

  /// map constant skull_ring to skull-ring.svg file
  static const String skull_ring = 'skull-ring.svg';

  /// map constant skull_sabertooth to skull-sabertooth.svg file
  static const String skull_sabertooth = 'skull-sabertooth.svg';

  /// map constant skull_shield to skull-shield.svg file
  static const String skull_shield = 'skull-shield.svg';

  /// map constant skull_signet to skull-signet.svg file
  static const String skull_signet = 'skull-signet.svg';

  /// map constant skull_slices to skull-slices.svg file
  static const String skull_slices = 'skull-slices.svg';

  /// map constant skull_staff to skull-staff.svg file
  static const String skull_staff = 'skull-staff.svg';

  /// map constant skull_with_syringe to skull-with-syringe.svg file
  static const String skull_with_syringe = 'skull-with-syringe.svg';

  /// map constant slalom to slalom.svg file
  static const String slalom = 'slalom.svg';

  /// map constant slap to slap.svg file
  static const String slap = 'slap.svg';

  /// map constant slashed_shield to slashed-shield.svg file
  static const String slashed_shield = 'slashed-shield.svg';

  /// map constant slavery_whip to slavery-whip.svg file
  static const String slavery_whip = 'slavery-whip.svg';

  /// map constant sleeping_bag to sleeping-bag.svg file
  static const String sleeping_bag = 'sleeping-bag.svg';

  /// map constant sleepy to sleepy.svg file
  static const String sleepy = 'sleepy.svg';

  /// map constant sleeveless_jacket to sleeveless-jacket.svg file
  static const String sleeveless_jacket = 'sleeveless-jacket.svg';

  /// map constant sleeveless_top to sleeveless-top.svg file
  static const String sleeveless_top = 'sleeveless-top.svg';

  /// map constant sliced_bread to sliced-bread.svg file
  static const String sliced_bread = 'sliced-bread.svg';

  /// map constant sliced_mushroom to sliced-mushroom.svg file
  static const String sliced_mushroom = 'sliced-mushroom.svg';

  /// map constant sliced_sausage to sliced-sausage.svg file
  static const String sliced_sausage = 'sliced-sausage.svg';

  /// map constant slicing_arrow to slicing-arrow.svg file
  static const String slicing_arrow = 'slicing-arrow.svg';

  /// map constant slime to slime.svg file
  static const String slime = 'slime.svg';

  /// map constant sling to sling.svg file
  static const String sling = 'sling.svg';

  /// map constant slingshot to slingshot.svg file
  static const String slingshot = 'slingshot.svg';

  /// map constant slipknot to slipknot.svg file
  static const String slipknot = 'slipknot.svg';

  /// map constant slippers to slippers.svg file
  static const String slippers = 'slippers.svg';

  /// map constant slot_machine to slot-machine.svg file
  static const String slot_machine = 'slot-machine.svg';

  /// map constant sloth to sloth.svg file
  static const String sloth = 'sloth.svg';

  /// map constant slow_blob to slow-blob.svg file
  static const String slow_blob = 'slow-blob.svg';

  /// map constant slumbering_sanctuary to slumbering-sanctuary.svg file
  static const String slumbering_sanctuary = 'slumbering-sanctuary.svg';

  /// map constant sly to sly.svg file
  static const String sly = 'sly.svg';

  /// map constant small_fire to small-fire.svg file
  static const String small_fire = 'small-fire.svg';

  /// map constant small_fishing_sailboat to small-fishing-sailboat.svg file
  static const String small_fishing_sailboat = 'small-fishing-sailboat.svg';

  /// map constant smart to smart.svg file
  static const String smart = 'smart.svg';

  /// map constant smartphone2 to smartphone 2.svg file
  static const String smartphone2 = 'smartphone 2.svg';

  /// map constant smartphone to smartphone.svg file
  static const String smartphone = 'smartphone.svg';

  /// map constant smash_arrows to smash-arrows.svg file
  static const String smash_arrows = 'smash-arrows.svg';

  /// map constant smitten to smitten.svg file
  static const String smitten = 'smitten.svg';

  /// map constant smoke_bomb to smoke-bomb.svg file
  static const String smoke_bomb = 'smoke-bomb.svg';

  /// map constant smoking_finger to smoking-finger.svg file
  static const String smoking_finger = 'smoking-finger.svg';

  /// map constant smoking_orb to smoking-orb.svg file
  static const String smoking_orb = 'smoking-orb.svg';

  /// map constant smoking_pipe to smoking-pipe.svg file
  static const String smoking_pipe = 'smoking-pipe.svg';

  /// map constant smoking_volcano to smoking-volcano.svg file
  static const String smoking_volcano = 'smoking-volcano.svg';

  /// map constant snail_eyes to snail-eyes.svg file
  static const String snail_eyes = 'snail-eyes.svg';

  /// map constant snail to snail.svg file
  static const String snail = 'snail.svg';

  /// map constant snake_bite to snake-bite.svg file
  static const String snake_bite = 'snake-bite.svg';

  /// map constant snake_egg to snake-egg.svg file
  static const String snake_egg = 'snake-egg.svg';

  /// map constant snake_jar to snake-jar.svg file
  static const String snake_jar = 'snake-jar.svg';

  /// map constant snake_spiral to snake-spiral.svg file
  static const String snake_spiral = 'snake-spiral.svg';

  /// map constant snake_tongue to snake-tongue.svg file
  static const String snake_tongue = 'snake-tongue.svg';

  /// map constant snake_totem to snake-totem.svg file
  static const String snake_totem = 'snake-totem.svg';

  /// map constant snake to snake.svg file
  static const String snake = 'snake.svg';

  /// map constant snatch to snatch.svg file
  static const String snatch = 'snatch.svg';

  /// map constant sniffing_dog to sniffing-dog.svg file
  static const String sniffing_dog = 'sniffing-dog.svg';

  /// map constant snitch_quidditch_ball to snitch-quidditch-ball.svg file
  static const String snitch_quidditch_ball = 'snitch-quidditch-ball.svg';

  /// map constant snorkel to snorkel.svg file
  static const String snorkel = 'snorkel.svg';

  /// map constant snout to snout.svg file
  static const String snout = 'snout.svg';

  /// map constant snow_bottle to snow-bottle.svg file
  static const String snow_bottle = 'snow-bottle.svg';

  /// map constant snowboard to snowboard.svg file
  static const String snowboard = 'snowboard.svg';

  /// map constant snowflake_1 to snowflake-1.svg file
  static const String snowflake_1 = 'snowflake-1.svg';

  /// map constant snowflake_2 to snowflake-2.svg file
  static const String snowflake_2 = 'snowflake-2.svg';

  /// map constant snowing to snowing.svg file
  static const String snowing = 'snowing.svg';

  /// map constant snowman to snowman.svg file
  static const String snowman = 'snowman.svg';

  /// map constant soap_experiment to soap-experiment.svg file
  static const String soap_experiment = 'soap-experiment.svg';

  /// map constant soap to soap.svg file
  static const String soap = 'soap.svg';

  /// map constant soccer_ball to soccer-ball.svg file
  static const String soccer_ball = 'soccer-ball.svg';

  /// map constant soccer_field to soccer-field.svg file
  static const String soccer_field = 'soccer-field.svg';

  /// map constant soccer_kick to soccer-kick.svg file
  static const String soccer_kick = 'soccer-kick.svg';

  /// map constant socks to socks.svg file
  static const String socks = 'socks.svg';

  /// map constant soda_bottle to soda-bottle.svg file
  static const String soda_bottle = 'soda-bottle.svg';

  /// map constant soda_can to soda-can.svg file
  static const String soda_can = 'soda-can.svg';

  /// map constant sofa to sofa.svg file
  static const String sofa = 'sofa.svg';

  /// map constant solar_power to solar-power.svg file
  static const String solar_power = 'solar-power.svg';

  /// map constant solar_system to solar-system.svg file
  static const String solar_system = 'solar-system.svg';

  /// map constant solar_time to solar-time.svg file
  static const String solar_time = 'solar-time.svg';

  /// map constant soldering_iron to soldering-iron.svg file
  static const String soldering_iron = 'soldering-iron.svg';

  /// map constant solid_leaf to solid-leaf.svg file
  static const String solid_leaf = 'solid-leaf.svg';

  /// map constant sombrero to sombrero.svg file
  static const String sombrero = 'sombrero.svg';

  /// map constant sonic_boom to sonic-boom.svg file
  static const String sonic_boom = 'sonic-boom.svg';

  /// map constant sonic_lightning to sonic-lightning.svg file
  static const String sonic_lightning = 'sonic-lightning.svg';

  /// map constant sonic_screech to sonic-screech.svg file
  static const String sonic_screech = 'sonic-screech.svg';

  /// map constant sonic_shoes to sonic-shoes.svg file
  static const String sonic_shoes = 'sonic-shoes.svg';

  /// map constant sonic_shout to sonic-shout.svg file
  static const String sonic_shout = 'sonic-shout.svg';

  /// map constant soul_vessel to soul-vessel.svg file
  static const String soul_vessel = 'soul-vessel.svg';

  /// map constant sound_off to sound-off.svg file
  static const String sound_off = 'sound-off.svg';

  /// map constant sound_on to sound-on.svg file
  static const String sound_on = 'sound-on.svg';

  /// map constant sound_waves to sound-waves.svg file
  static const String sound_waves = 'sound-waves.svg';

  /// map constant south_africa_flag to south-africa-flag.svg file
  static const String south_africa_flag = 'south-africa-flag.svg';

  /// map constant south_africa to south-africa.svg file
  static const String south_africa = 'south-africa.svg';

  /// map constant south_america to south-america.svg file
  static const String south_america = 'south-america.svg';

  /// map constant south_korea to south-korea.svg file
  static const String south_korea = 'south-korea.svg';

  /// map constant space_needle to space-needle.svg file
  static const String space_needle = 'space-needle.svg';

  /// map constant space_shuttle to space-shuttle.svg file
  static const String space_shuttle = 'space-shuttle.svg';

  /// map constant space_suit to space-suit.svg file
  static const String space_suit = 'space-suit.svg';

  /// map constant spaceship to spaceship.svg file
  static const String spaceship = 'spaceship.svg';

  /// map constant spade_skull to spade-skull.svg file
  static const String spade_skull = 'spade-skull.svg';

  /// map constant spade to spade.svg file
  static const String spade = 'spade.svg';

  /// map constant spades to spades.svg file
  static const String spades = 'spades.svg';

  /// map constant spain to spain.svg file
  static const String spain = 'spain.svg';

  /// map constant spanner to spanner.svg file
  static const String spanner = 'spanner.svg';

  /// map constant spark_plug to spark-plug.svg file
  static const String spark_plug = 'spark-plug.svg';

  /// map constant spark_spirit to spark-spirit.svg file
  static const String spark_spirit = 'spark-spirit.svg';

  /// map constant sparkles to sparkles.svg file
  static const String sparkles = 'sparkles.svg';

  /// map constant sparkling_sabre to sparkling-sabre.svg file
  static const String sparkling_sabre = 'sparkling-sabre.svg';

  /// map constant sparky_bomb to sparky-bomb.svg file
  static const String sparky_bomb = 'sparky-bomb.svg';

  /// map constant sparrow to sparrow.svg file
  static const String sparrow = 'sparrow.svg';

  /// map constant spartan_helmet to spartan-helmet.svg file
  static const String spartan_helmet = 'spartan-helmet.svg';

  /// map constant spartan to spartan.svg file
  static const String spartan = 'spartan.svg';

  /// map constant spatter to spatter.svg file
  static const String spatter = 'spatter.svg';

  /// map constant spawn_node to spawn-node.svg file
  static const String spawn_node = 'spawn-node.svg';

  /// map constant speaker_off to speaker-off.svg file
  static const String speaker_off = 'speaker-off.svg';

  /// map constant speaker to speaker.svg file
  static const String speaker = 'speaker.svg';

  /// map constant spear_feather to spear-feather.svg file
  static const String spear_feather = 'spear-feather.svg';

  /// map constant spear_hook to spear-hook.svg file
  static const String spear_hook = 'spear-hook.svg';

  /// map constant spearfishing to spearfishing.svg file
  static const String spearfishing = 'spearfishing.svg';

  /// map constant spears to spears.svg file
  static const String spears = 'spears.svg';

  /// map constant spectacle_lenses to spectacle-lenses.svg file
  static const String spectacle_lenses = 'spectacle-lenses.svg';

  /// map constant spectacles to spectacles.svg file
  static const String spectacles = 'spectacles.svg';

  /// map constant spectre_m4 to spectre-m4.svg file
  static const String spectre_m4 = 'spectre-m4.svg';

  /// map constant spectre to spectre.svg file
  static const String spectre = 'spectre.svg';

  /// map constant speed_boat to speed-boat.svg file
  static const String speed_boat = 'speed-boat.svg';

  /// map constant speedometer to speedometer.svg file
  static const String speedometer = 'speedometer.svg';

  /// map constant spell_book to spell-book.svg file
  static const String spell_book = 'spell-book.svg';

  /// map constant sperm_whale to sperm-whale.svg file
  static const String sperm_whale = 'sperm-whale.svg';

  /// map constant spider_alt to spider-alt.svg file
  static const String spider_alt = 'spider-alt.svg';

  /// map constant spider_bot to spider-bot.svg file
  static const String spider_bot = 'spider-bot.svg';

  /// map constant spider_eye to spider-eye.svg file
  static const String spider_eye = 'spider-eye.svg';

  /// map constant spider_face to spider-face.svg file
  static const String spider_face = 'spider-face.svg';

  /// map constant spider_mask to spider-mask.svg file
  static const String spider_mask = 'spider-mask.svg';

  /// map constant spider_web to spider-web.svg file
  static const String spider_web = 'spider-web.svg';

  /// map constant spikeball to spikeball.svg file
  static const String spikeball = 'spikeball.svg';

  /// map constant spiked_armor to spiked-armor.svg file
  static const String spiked_armor = 'spiked-armor.svg';

  /// map constant spiked_ball to spiked-ball.svg file
  static const String spiked_ball = 'spiked-ball.svg';

  /// map constant spiked_bat to spiked-bat.svg file
  static const String spiked_bat = 'spiked-bat.svg';

  /// map constant spiked_collar to spiked-collar.svg file
  static const String spiked_collar = 'spiked-collar.svg';

  /// map constant spiked_dragon_head to spiked-dragon-head.svg file
  static const String spiked_dragon_head = 'spiked-dragon-head.svg';

  /// map constant spiked_fence to spiked-fence.svg file
  static const String spiked_fence = 'spiked-fence.svg';

  /// map constant spiked_halo to spiked-halo.svg file
  static const String spiked_halo = 'spiked-halo.svg';

  /// map constant spiked_mace to spiked-mace.svg file
  static const String spiked_mace = 'spiked-mace.svg';

  /// map constant spiked_shell to spiked-shell.svg file
  static const String spiked_shell = 'spiked-shell.svg';

  /// map constant spiked_shield to spiked-shield.svg file
  static const String spiked_shield = 'spiked-shield.svg';

  /// map constant spiked_shoulder_armor to spiked-shoulder-armor.svg file
  static const String spiked_shoulder_armor = 'spiked-shoulder-armor.svg';

  /// map constant spiked_snail to spiked-snail.svg file
  static const String spiked_snail = 'spiked-snail.svg';

  /// map constant spiked_tail to spiked-tail.svg file
  static const String spiked_tail = 'spiked-tail.svg';

  /// map constant spiked_tentacle to spiked-tentacle.svg file
  static const String spiked_tentacle = 'spiked-tentacle.svg';

  /// map constant spiked_trunk to spiked-trunk.svg file
  static const String spiked_trunk = 'spiked-trunk.svg';

  /// map constant spiked_wall to spiked-wall.svg file
  static const String spiked_wall = 'spiked-wall.svg';

  /// map constant spikes_full to spikes-full.svg file
  static const String spikes_full = 'spikes-full.svg';

  /// map constant spikes_half to spikes-half.svg file
  static const String spikes_half = 'spikes-half.svg';

  /// map constant spikes_init to spikes-init.svg file
  static const String spikes_init = 'spikes-init.svg';

  /// map constant spikes to spikes.svg file
  static const String spikes = 'spikes.svg';

  /// map constant spiky_eclipse to spiky-eclipse.svg file
  static const String spiky_eclipse = 'spiky-eclipse.svg';

  /// map constant spiky_explosion to spiky-explosion.svg file
  static const String spiky_explosion = 'spiky-explosion.svg';

  /// map constant spiky_field to spiky-field.svg file
  static const String spiky_field = 'spiky-field.svg';

  /// map constant spiky_pit to spiky-pit.svg file
  static const String spiky_pit = 'spiky-pit.svg';

  /// map constant spiky_wing to spiky-wing.svg file
  static const String spiky_wing = 'spiky-wing.svg';

  /// map constant spill to spill.svg file
  static const String spill = 'spill.svg';

  /// map constant spinal_coil to spinal-coil.svg file
  static const String spinal_coil = 'spinal-coil.svg';

  /// map constant spine_arrow to spine-arrow.svg file
  static const String spine_arrow = 'spine-arrow.svg';

  /// map constant spinning_blades to spinning-blades.svg file
  static const String spinning_blades = 'spinning-blades.svg';

  /// map constant spinning_ribbons to spinning-ribbons.svg file
  static const String spinning_ribbons = 'spinning-ribbons.svg';

  /// map constant spinning_sword to spinning-sword.svg file
  static const String spinning_sword = 'spinning-sword.svg';

  /// map constant spinning_top to spinning-top.svg file
  static const String spinning_top = 'spinning-top.svg';

  /// map constant spinning_wheel to spinning-wheel.svg file
  static const String spinning_wheel = 'spinning-wheel.svg';

  /// map constant spiral_arrow to spiral-arrow.svg file
  static const String spiral_arrow = 'spiral-arrow.svg';

  /// map constant spiral_bloom to spiral-bloom.svg file
  static const String spiral_bloom = 'spiral-bloom.svg';

  /// map constant spiral_bottle to spiral-bottle.svg file
  static const String spiral_bottle = 'spiral-bottle.svg';

  /// map constant spiral_hilt to spiral-hilt.svg file
  static const String spiral_hilt = 'spiral-hilt.svg';

  /// map constant spiral_lollipop to spiral-lollipop.svg file
  static const String spiral_lollipop = 'spiral-lollipop.svg';

  /// map constant spiral_shell to spiral-shell.svg file
  static const String spiral_shell = 'spiral-shell.svg';

  /// map constant spiral_tentacle to spiral-tentacle.svg file
  static const String spiral_tentacle = 'spiral-tentacle.svg';

  /// map constant spiral_thrust to spiral-thrust.svg file
  static const String spiral_thrust = 'spiral-thrust.svg';

  /// map constant splash2 to splash 2.svg file
  static const String splash2 = 'splash 2.svg';

  /// map constant splash to splash.svg file
  static const String splash = 'splash.svg';

  /// map constant splashy_stream to splashy-stream.svg file
  static const String splashy_stream = 'splashy-stream.svg';

  /// map constant split_arrows to split-arrows.svg file
  static const String split_arrows = 'split-arrows.svg';

  /// map constant split_body to split-body.svg file
  static const String split_body = 'split-body.svg';

  /// map constant split_cross to split-cross.svg file
  static const String split_cross = 'split-cross.svg';

  /// map constant splurt to splurt.svg file
  static const String splurt = 'splurt.svg';

  /// map constant spock_hand to spock-hand.svg file
  static const String spock_hand = 'spock-hand.svg';

  /// map constant spooky_house to spooky-house.svg file
  static const String spooky_house = 'spooky-house.svg';

  /// map constant spoon to spoon.svg file
  static const String spoon = 'spoon.svg';

  /// map constant sport_medal to sport-medal.svg file
  static const String sport_medal = 'sport-medal.svg';

  /// map constant spoted_flower to spoted-flower.svg file
  static const String spoted_flower = 'spoted-flower.svg';

  /// map constant spotted_arrowhead to spotted-arrowhead.svg file
  static const String spotted_arrowhead = 'spotted-arrowhead.svg';

  /// map constant spotted_bug to spotted-bug.svg file
  static const String spotted_bug = 'spotted-bug.svg';

  /// map constant spotted_mushroom to spotted-mushroom.svg file
  static const String spotted_mushroom = 'spotted-mushroom.svg';

  /// map constant spotted_wound to spotted-wound.svg file
  static const String spotted_wound = 'spotted-wound.svg';

  /// map constant spoutnik to spoutnik.svg file
  static const String spoutnik = 'spoutnik.svg';

  /// map constant spray to spray.svg file
  static const String spray = 'spray.svg';

  /// map constant spring to spring.svg file
  static const String spring = 'spring.svg';

  /// map constant sprint to sprint.svg file
  static const String sprint = 'sprint.svg';

  /// map constant sprout_disc to sprout-disc.svg file
  static const String sprout_disc = 'sprout-disc.svg';

  /// map constant sprout to sprout.svg file
  static const String sprout = 'sprout.svg';

  /// map constant spy to spy.svg file
  static const String spy = 'spy.svg';

  /// map constant spyglass to spyglass.svg file
  static const String spyglass = 'spyglass.svg';

  /// map constant square_bottle to square-bottle.svg file
  static const String square_bottle = 'square-bottle.svg';

  /// map constant square to square.svg file
  static const String square = 'square.svg';

  /// map constant squib to squib.svg file
  static const String squib = 'squib.svg';

  /// map constant squid_head to squid-head.svg file
  static const String squid_head = 'squid-head.svg';

  /// map constant squid to squid.svg file
  static const String squid = 'squid.svg';

  /// map constant squirrel to squirrel.svg file
  static const String squirrel = 'squirrel.svg';

  /// map constant sri_lanka to sri-lanka.svg file
  static const String sri_lanka = 'sri-lanka.svg';

  /// map constant stabbed_note to stabbed-note.svg file
  static const String stabbed_note = 'stabbed-note.svg';

  /// map constant stable to stable.svg file
  static const String stable = 'stable.svg';

  /// map constant stack to stack.svg file
  static const String stack = 'stack.svg';

  /// map constant stag_head to stag-head.svg file
  static const String stag_head = 'stag-head.svg';

  /// map constant stahlhelm to stahlhelm.svg file
  static const String stahlhelm = 'stahlhelm.svg';

  /// map constant stairs_cake to stairs-cake.svg file
  static const String stairs_cake = 'stairs-cake.svg';

  /// map constant stairs_goal to stairs-goal.svg file
  static const String stairs_goal = 'stairs-goal.svg';

  /// map constant stairs to stairs.svg file
  static const String stairs = 'stairs.svg';

  /// map constant stake_hammer to stake-hammer.svg file
  static const String stake_hammer = 'stake-hammer.svg';

  /// map constant stakes_fence to stakes-fence.svg file
  static const String stakes_fence = 'stakes-fence.svg';

  /// map constant stalactites to stalactites.svg file
  static const String stalactites = 'stalactites.svg';

  /// map constant stalagtite to stalagtite.svg file
  static const String stalagtite = 'stalagtite.svg';

  /// map constant stamper to stamper.svg file
  static const String stamper = 'stamper.svg';

  /// map constant standing_potion to standing-potion.svg file
  static const String standing_potion = 'standing-potion.svg';

  /// map constant stapler_heavy_duty to stapler-heavy-duty.svg file
  static const String stapler_heavy_duty = 'stapler-heavy-duty.svg';

  /// map constant stapler_pneumatic to stapler-pneumatic.svg file
  static const String stapler_pneumatic = 'stapler-pneumatic.svg';

  /// map constant stapler to stapler.svg file
  static const String stapler = 'stapler.svg';

  /// map constant star_altar to star-altar.svg file
  static const String star_altar = 'star-altar.svg';

  /// map constant star_cycle to star-cycle.svg file
  static const String star_cycle = 'star-cycle.svg';

  /// map constant star_flag to star-flag.svg file
  static const String star_flag = 'star-flag.svg';

  /// map constant star_formation to star-formation.svg file
  static const String star_formation = 'star-formation.svg';

  /// map constant star_gate to star-gate.svg file
  static const String star_gate = 'star-gate.svg';

  /// map constant star_key to star-key.svg file
  static const String star_key = 'star-key.svg';

  /// map constant star_medal to star-medal.svg file
  static const String star_medal = 'star-medal.svg';

  /// map constant star_prominences to star-prominences.svg file
  static const String star_prominences = 'star-prominences.svg';

  /// map constant star_pupil to star-pupil.svg file
  static const String star_pupil = 'star-pupil.svg';

  /// map constant star_sattelites to star-sattelites.svg file
  static const String star_sattelites = 'star-sattelites.svg';

  /// map constant star_shuriken to star-shuriken.svg file
  static const String star_shuriken = 'star-shuriken.svg';

  /// map constant star_skull to star-skull.svg file
  static const String star_skull = 'star-skull.svg';

  /// map constant star_struck to star-struck.svg file
  static const String star_struck = 'star-struck.svg';

  /// map constant star_swirl to star-swirl.svg file
  static const String star_swirl = 'star-swirl.svg';

  /// map constant starfighter to starfighter.svg file
  static const String starfighter = 'starfighter.svg';

  /// map constant stars_stack to stars-stack.svg file
  static const String stars_stack = 'stars-stack.svg';

  /// map constant staryu to staryu.svg file
  static const String staryu = 'staryu.svg';

  /// map constant static_guard to static-guard.svg file
  static const String static_guard = 'static-guard.svg';

  /// map constant static_waves to static-waves.svg file
  static const String static_waves = 'static-waves.svg';

  /// map constant static_ to static.svg file
  static const String static_ = 'static.svg';

  /// map constant steak to steak.svg file
  static const String steak = 'steak.svg';

  /// map constant stealth_bomber to stealth-bomber.svg file
  static const String stealth_bomber = 'stealth-bomber.svg';

  /// map constant steam_blast to steam-blast.svg file
  static const String steam_blast = 'steam-blast.svg';

  /// map constant steam_locomotive to steam-locomotive.svg file
  static const String steam_locomotive = 'steam-locomotive.svg';

  /// map constant steam to steam.svg file
  static const String steam = 'steam.svg';

  /// map constant steampunk_goggles to steampunk-goggles.svg file
  static const String steampunk_goggles = 'steampunk-goggles.svg';

  /// map constant steamroller to steamroller.svg file
  static const String steamroller = 'steamroller.svg';

  /// map constant steel_claws2 to steel-claws 2.svg file
  static const String steel_claws2 = 'steel-claws 2.svg';

  /// map constant steel_claws to steel-claws.svg file
  static const String steel_claws = 'steel-claws.svg';

  /// map constant steel_door to steel-door.svg file
  static const String steel_door = 'steel-door.svg';

  /// map constant steeltoe_boots to steeltoe-boots.svg file
  static const String steeltoe_boots = 'steeltoe-boots.svg';

  /// map constant steelwing_emblem to steelwing-emblem.svg file
  static const String steelwing_emblem = 'steelwing-emblem.svg';

  /// map constant steering_wheel to steering-wheel.svg file
  static const String steering_wheel = 'steering-wheel.svg';

  /// map constant stegosaurus_scales to stegosaurus-scales.svg file
  static const String stegosaurus_scales = 'stegosaurus-scales.svg';

  /// map constant stethoscope to stethoscope.svg file
  static const String stethoscope = 'stethoscope.svg';

  /// map constant steyr_aug to steyr-aug.svg file
  static const String steyr_aug = 'steyr-aug.svg';

  /// map constant stick_frame to stick-frame.svg file
  static const String stick_frame = 'stick-frame.svg';

  /// map constant stick_grenade to stick-grenade.svg file
  static const String stick_grenade = 'stick-grenade.svg';

  /// map constant stick_splitting to stick-splitting.svg file
  static const String stick_splitting = 'stick-splitting.svg';

  /// map constant sticking_plaster to sticking-plaster.svg file
  static const String sticking_plaster = 'sticking-plaster.svg';

  /// map constant sticky_boot to sticky-boot.svg file
  static const String sticky_boot = 'sticky-boot.svg';

  /// map constant stigmata to stigmata.svg file
  static const String stigmata = 'stigmata.svg';

  /// map constant stiletto2 to stiletto 2.svg file
  static const String stiletto2 = 'stiletto 2.svg';

  /// map constant stiletto to stiletto.svg file
  static const String stiletto = 'stiletto.svg';

  /// map constant stitched_wound to stitched-wound.svg file
  static const String stitched_wound = 'stitched-wound.svg';

  /// map constant stockpiles to stockpiles.svg file
  static const String stockpiles = 'stockpiles.svg';

  /// map constant stomach to stomach.svg file
  static const String stomach = 'stomach.svg';

  /// map constant stomp_tornado to stomp-tornado.svg file
  static const String stomp_tornado = 'stomp-tornado.svg';

  /// map constant stomp to stomp.svg file
  static const String stomp = 'stomp.svg';

  /// map constant stone_axe to stone-axe.svg file
  static const String stone_axe = 'stone-axe.svg';

  /// map constant stone_block to stone-block.svg file
  static const String stone_block = 'stone-block.svg';

  /// map constant stone_bridge to stone-bridge.svg file
  static const String stone_bridge = 'stone-bridge.svg';

  /// map constant stone_bust to stone-bust.svg file
  static const String stone_bust = 'stone-bust.svg';

  /// map constant stone_crafting to stone-crafting.svg file
  static const String stone_crafting = 'stone-crafting.svg';

  /// map constant stone_path to stone-path.svg file
  static const String stone_path = 'stone-path.svg';

  /// map constant stone_pile to stone-pile.svg file
  static const String stone_pile = 'stone-pile.svg';

  /// map constant stone_spear to stone-spear.svg file
  static const String stone_spear = 'stone-spear.svg';

  /// map constant stone_sphere to stone-sphere.svg file
  static const String stone_sphere = 'stone-sphere.svg';

  /// map constant stone_stack to stone-stack.svg file
  static const String stone_stack = 'stone-stack.svg';

  /// map constant stone_tablet to stone-tablet.svg file
  static const String stone_tablet = 'stone-tablet.svg';

  /// map constant stone_throne to stone-throne.svg file
  static const String stone_throne = 'stone-throne.svg';

  /// map constant stone_tower to stone-tower.svg file
  static const String stone_tower = 'stone-tower.svg';

  /// map constant stone_wall to stone-wall.svg file
  static const String stone_wall = 'stone-wall.svg';

  /// map constant stone_wheel to stone-wheel.svg file
  static const String stone_wheel = 'stone-wheel.svg';

  /// map constant stoned_skull to stoned-skull.svg file
  static const String stoned_skull = 'stoned-skull.svg';

  /// map constant stop_sign to stop-sign.svg file
  static const String stop_sign = 'stop-sign.svg';

  /// map constant stopwatch2 to stopwatch 2.svg file
  static const String stopwatch2 = 'stopwatch 2.svg';

  /// map constant stopwatch to stopwatch.svg file
  static const String stopwatch = 'stopwatch.svg';

  /// map constant stork_delivery to stork-delivery.svg file
  static const String stork_delivery = 'stork-delivery.svg';

  /// map constant strafe to strafe.svg file
  static const String strafe = 'strafe.svg';

  /// map constant straight_pipe to straight-pipe.svg file
  static const String straight_pipe = 'straight-pipe.svg';

  /// map constant strawberry to strawberry.svg file
  static const String strawberry = 'strawberry.svg';

  /// map constant street_light to street-light.svg file
  static const String street_light = 'street-light.svg';

  /// map constant striking_arrows to striking-arrows.svg file
  static const String striking_arrows = 'striking-arrows.svg';

  /// map constant striking_balls to striking-balls.svg file
  static const String striking_balls = 'striking-balls.svg';

  /// map constant striking_clamps to striking-clamps.svg file
  static const String striking_clamps = 'striking-clamps.svg';

  /// map constant striking_diamonds to striking-diamonds.svg file
  static const String striking_diamonds = 'striking-diamonds.svg';

  /// map constant striking_splinter to striking-splinter.svg file
  static const String striking_splinter = 'striking-splinter.svg';

  /// map constant striped_sun to striped-sun.svg file
  static const String striped_sun = 'striped-sun.svg';

  /// map constant striped_sword to striped-sword.svg file
  static const String striped_sword = 'striped-sword.svg';

  /// map constant strong_man to strong-man.svg file
  static const String strong_man = 'strong-man.svg';

  /// map constant strong to strong.svg file
  static const String strong = 'strong.svg';

  /// map constant strongbox to strongbox.svg file
  static const String strongbox = 'strongbox.svg';

  /// map constant stump_regrowth to stump-regrowth.svg file
  static const String stump_regrowth = 'stump-regrowth.svg';

  /// map constant stun_grenade to stun-grenade.svg file
  static const String stun_grenade = 'stun-grenade.svg';

  /// map constant submarine_missile to submarine-missile.svg file
  static const String submarine_missile = 'submarine-missile.svg';

  /// map constant submarine to submarine.svg file
  static const String submarine = 'submarine.svg';

  /// map constant subway_pass to subway-pass.svg file
  static const String subway_pass = 'subway-pass.svg';

  /// map constant subway_train to subway-train.svg file
  static const String subway_train = 'subway-train.svg';

  /// map constant subway to subway.svg file
  static const String subway = 'subway.svg';

  /// map constant suckered_tentacle to suckered-tentacle.svg file
  static const String suckered_tentacle = 'suckered-tentacle.svg';

  /// map constant sugar_cane to sugar-cane.svg file
  static const String sugar_cane = 'sugar-cane.svg';

  /// map constant suicide to suicide.svg file
  static const String suicide = 'suicide.svg';

  /// map constant suitcase to suitcase.svg file
  static const String suitcase = 'suitcase.svg';

  /// map constant suits to suits.svg file
  static const String suits = 'suits.svg';

  /// map constant summits to summits.svg file
  static const String summits = 'summits.svg';

  /// map constant sun_cloud to sun-cloud.svg file
  static const String sun_cloud = 'sun-cloud.svg';

  /// map constant sun_priest to sun-priest.svg file
  static const String sun_priest = 'sun-priest.svg';

  /// map constant sun_radiations to sun-radiations.svg file
  static const String sun_radiations = 'sun-radiations.svg';

  /// map constant sun_spear to sun-spear.svg file
  static const String sun_spear = 'sun-spear.svg';

  /// map constant sun to sun.svg file
  static const String sun = 'sun.svg';

  /// map constant sunbeams to sunbeams.svg file
  static const String sunbeams = 'sunbeams.svg';

  /// map constant sundial to sundial.svg file
  static const String sundial = 'sundial.svg';

  /// map constant sunflower to sunflower.svg file
  static const String sunflower = 'sunflower.svg';

  /// map constant sunglasses to sunglasses.svg file
  static const String sunglasses = 'sunglasses.svg';

  /// map constant sunken_eye to sunken-eye.svg file
  static const String sunken_eye = 'sunken-eye.svg';

  /// map constant sunrise2 to sunrise 2.svg file
  static const String sunrise2 = 'sunrise 2.svg';

  /// map constant sunrise to sunrise.svg file
  static const String sunrise = 'sunrise.svg';

  /// map constant sunset to sunset.svg file
  static const String sunset = 'sunset.svg';

  /// map constant super_mushroom to super-mushroom.svg file
  static const String super_mushroom = 'super-mushroom.svg';

  /// map constant supersonic_arrow to supersonic-arrow.svg file
  static const String supersonic_arrow = 'supersonic-arrow.svg';

  /// map constant supersonic_bullet to supersonic-bullet.svg file
  static const String supersonic_bullet = 'supersonic-bullet.svg';

  /// map constant surf_board to surf-board.svg file
  static const String surf_board = 'surf-board.svg';

  /// map constant surfer_van to surfer-van.svg file
  static const String surfer_van = 'surfer-van.svg';

  /// map constant surprised_skull to surprised-skull.svg file
  static const String surprised_skull = 'surprised-skull.svg';

  /// map constant surprised to surprised.svg file
  static const String surprised = 'surprised.svg';

  /// map constant surrounded_eye to surrounded-eye.svg file
  static const String surrounded_eye = 'surrounded-eye.svg';

  /// map constant surrounded_shield to surrounded-shield.svg file
  static const String surrounded_shield = 'surrounded-shield.svg';

  /// map constant sushis to sushis.svg file
  static const String sushis = 'sushis.svg';

  /// map constant suspension_bridge to suspension-bridge.svg file
  static const String suspension_bridge = 'suspension-bridge.svg';

  /// map constant suspicious to suspicious.svg file
  static const String suspicious = 'suspicious.svg';

  /// map constant sverd_i_fjell to sverd-i-fjell.svg file
  static const String sverd_i_fjell = 'sverd-i-fjell.svg';

  /// map constant swallow2 to swallow 2.svg file
  static const String swallow2 = 'swallow 2.svg';

  /// map constant swallow to swallow.svg file
  static const String swallow = 'swallow.svg';

  /// map constant swallower to swallower.svg file
  static const String swallower = 'swallower.svg';

  /// map constant swamp_bat to swamp-bat.svg file
  static const String swamp_bat = 'swamp-bat.svg';

  /// map constant swamp to swamp.svg file
  static const String swamp = 'swamp.svg';

  /// map constant swan_breeze to swan-breeze.svg file
  static const String swan_breeze = 'swan-breeze.svg';

  /// map constant swan to swan.svg file
  static const String swan = 'swan.svg';

  /// map constant swap_bag to swap-bag.svg file
  static const String swap_bag = 'swap-bag.svg';

  /// map constant swimfins to swimfins.svg file
  static const String swimfins = 'swimfins.svg';

  /// map constant swipe_card to swipe-card.svg file
  static const String swipe_card = 'swipe-card.svg';

  /// map constant swirl_ring to swirl-ring.svg file
  static const String swirl_ring = 'swirl-ring.svg';

  /// map constant swirl_string to swirl-string.svg file
  static const String swirl_string = 'swirl-string.svg';

  /// map constant swirled_shell to swirled-shell.svg file
  static const String swirled_shell = 'swirled-shell.svg';

  /// map constant swiss_army_knife to swiss-army-knife.svg file
  static const String swiss_army_knife = 'swiss-army-knife.svg';

  /// map constant switch_weapon to switch-weapon.svg file
  static const String switch_weapon = 'switch-weapon.svg';

  /// map constant switchblade to switchblade.svg file
  static const String switchblade = 'switchblade.svg';

  /// map constant switzerland to switzerland.svg file
  static const String switzerland = 'switzerland.svg';

  /// map constant sword_altar to sword-altar.svg file
  static const String sword_altar = 'sword-altar.svg';

  /// map constant sword_array to sword-array.svg file
  static const String sword_array = 'sword-array.svg';

  /// map constant sword_brandish to sword-brandish.svg file
  static const String sword_brandish = 'sword-brandish.svg';

  /// map constant sword_break to sword-break.svg file
  static const String sword_break = 'sword-break.svg';

  /// map constant sword_clash to sword-clash.svg file
  static const String sword_clash = 'sword-clash.svg';

  /// map constant sword_hilt to sword-hilt.svg file
  static const String sword_hilt = 'sword-hilt.svg';

  /// map constant sword_in_stone to sword-in-stone.svg file
  static const String sword_in_stone = 'sword-in-stone.svg';

  /// map constant sword_mold to sword-mold.svg file
  static const String sword_mold = 'sword-mold.svg';

  /// map constant sword_slice to sword-slice.svg file
  static const String sword_slice = 'sword-slice.svg';

  /// map constant sword_smithing to sword-smithing.svg file
  static const String sword_smithing = 'sword-smithing.svg';

  /// map constant sword_spade to sword-spade.svg file
  static const String sword_spade = 'sword-spade.svg';

  /// map constant sword_spin to sword-spin.svg file
  static const String sword_spin = 'sword-spin.svg';

  /// map constant sword_tie to sword-tie.svg file
  static const String sword_tie = 'sword-tie.svg';

  /// map constant sword_wound to sword-wound.svg file
  static const String sword_wound = 'sword-wound.svg';

  /// map constant swordman to swordman.svg file
  static const String swordman = 'swordman.svg';

  /// map constant swords_emblem to swords-emblem.svg file
  static const String swords_emblem = 'swords-emblem.svg';

  /// map constant swords_power to swords-power.svg file
  static const String swords_power = 'swords-power.svg';

  /// map constant swordwoman to swordwoman.svg file
  static const String swordwoman = 'swordwoman.svg';

  /// map constant sydney_opera_house to sydney-opera-house.svg file
  static const String sydney_opera_house = 'sydney-opera-house.svg';

  /// map constant syringe2 to syringe 2.svg file
  static const String syringe2 = 'syringe 2.svg';

  /// map constant syringe to syringe.svg file
  static const String syringe = 'syringe.svg';

  /// map constant t_brick to t-brick.svg file
  static const String t_brick = 't-brick.svg';

  /// map constant t_rex_skull to t-rex-skull.svg file
  static const String t_rex_skull = 't-rex-skull.svg';

  /// map constant t_shirt to t-shirt.svg file
  static const String t_shirt = 't-shirt.svg';

  /// map constant tabi_boot to tabi-boot.svg file
  static const String tabi_boot = 'tabi-boot.svg';

  /// map constant table to table.svg file
  static const String table = 'table.svg';

  /// map constant tablet to tablet.svg file
  static const String tablet = 'tablet.svg';

  /// map constant tabletop_players to tabletop-players.svg file
  static const String tabletop_players = 'tabletop-players.svg';

  /// map constant tacos to tacos.svg file
  static const String tacos = 'tacos.svg';

  /// map constant tadpole to tadpole.svg file
  static const String tadpole = 'tadpole.svg';

  /// map constant take_my_money to take-my-money.svg file
  static const String take_my_money = 'take-my-money.svg';

  /// map constant talk to talk.svg file
  static const String talk = 'talk.svg';

  /// map constant tall_bridge to tall-bridge.svg file
  static const String tall_bridge = 'tall-bridge.svg';

  /// map constant tambourine to tambourine.svg file
  static const String tambourine = 'tambourine.svg';

  /// map constant tangerine to tangerine.svg file
  static const String tangerine = 'tangerine.svg';

  /// map constant tank_top to tank-top.svg file
  static const String tank_top = 'tank-top.svg';

  /// map constant tank_tread to tank-tread.svg file
  static const String tank_tread = 'tank-tread.svg';

  /// map constant tank to tank.svg file
  static const String tank = 'tank.svg';

  /// map constant tanzania to tanzania.svg file
  static const String tanzania = 'tanzania.svg';

  /// map constant tap to tap.svg file
  static const String tap = 'tap.svg';

  /// map constant tapir to tapir.svg file
  static const String tapir = 'tapir.svg';

  /// map constant target_arrows to target-arrows.svg file
  static const String target_arrows = 'target-arrows.svg';

  /// map constant target_dummy to target-dummy.svg file
  static const String target_dummy = 'target-dummy.svg';

  /// map constant target_laser to target-laser.svg file
  static const String target_laser = 'target-laser.svg';

  /// map constant target_poster to target-poster.svg file
  static const String target_poster = 'target-poster.svg';

  /// map constant target_prize to target-prize.svg file
  static const String target_prize = 'target-prize.svg';

  /// map constant target_shot to target-shot.svg file
  static const String target_shot = 'target-shot.svg';

  /// map constant targeted to targeted.svg file
  static const String targeted = 'targeted.svg';

  /// map constant targeting to targeting.svg file
  static const String targeting = 'targeting.svg';

  /// map constant tattered_banner to tattered-banner.svg file
  static const String tattered_banner = 'tattered-banner.svg';

  /// map constant taurus to taurus.svg file
  static const String taurus = 'taurus.svg';

  /// map constant tavern_sign to tavern-sign.svg file
  static const String tavern_sign = 'tavern-sign.svg';

  /// map constant teacher to teacher.svg file
  static const String teacher = 'teacher.svg';

  /// map constant team_downgrade to team-downgrade.svg file
  static const String team_downgrade = 'team-downgrade.svg';

  /// map constant team_idea to team-idea.svg file
  static const String team_idea = 'team-idea.svg';

  /// map constant team_upgrade to team-upgrade.svg file
  static const String team_upgrade = 'team-upgrade.svg';

  /// map constant teapot_leaves to teapot-leaves.svg file
  static const String teapot_leaves = 'teapot-leaves.svg';

  /// map constant teapot to teapot.svg file
  static const String teapot = 'teapot.svg';

  /// map constant tear_tracks to tear-tracks.svg file
  static const String tear_tracks = 'tear-tracks.svg';

  /// map constant tearing to tearing.svg file
  static const String tearing = 'tearing.svg';

  /// map constant tec_9 to tec-9.svg file
  static const String tec_9 = 'tec-9.svg';

  /// map constant techno_heart to techno-heart.svg file
  static const String techno_heart = 'techno-heart.svg';

  /// map constant tee_pipe to tee-pipe.svg file
  static const String tee_pipe = 'tee-pipe.svg';

  /// map constant telefrag to telefrag.svg file
  static const String telefrag = 'telefrag.svg';

  /// map constant telepathy to telepathy.svg file
  static const String telepathy = 'telepathy.svg';

  /// map constant teleport to teleport.svg file
  static const String teleport = 'teleport.svg';

  /// map constant telescopic_baton to telescopic-baton.svg file
  static const String telescopic_baton = 'telescopic-baton.svg';

  /// map constant teller_mine to teller-mine.svg file
  static const String teller_mine = 'teller-mine.svg';

  /// map constant templar_eye to templar-eye.svg file
  static const String templar_eye = 'templar-eye.svg';

  /// map constant templar_heart to templar-heart.svg file
  static const String templar_heart = 'templar-heart.svg';

  /// map constant templar_shield to templar-shield.svg file
  static const String templar_shield = 'templar-shield.svg';

  /// map constant temple_door to temple-door.svg file
  static const String temple_door = 'temple-door.svg';

  /// map constant temple_gate to temple-gate.svg file
  static const String temple_gate = 'temple-gate.svg';

  /// map constant temporary_shield to temporary-shield.svg file
  static const String temporary_shield = 'temporary-shield.svg';

  /// map constant temptation to temptation.svg file
  static const String temptation = 'temptation.svg';

  /// map constant tennis_ball to tennis-ball.svg file
  static const String tennis_ball = 'tennis-ball.svg';

  /// map constant tennis_court to tennis-court.svg file
  static const String tennis_court = 'tennis-court.svg';

  /// map constant tennis_racket to tennis-racket.svg file
  static const String tennis_racket = 'tennis-racket.svg';

  /// map constant tension_snowflake to tension-snowflake.svg file
  static const String tension_snowflake = 'tension-snowflake.svg';

  /// map constant tentacle_heart to tentacle-heart.svg file
  static const String tentacle_heart = 'tentacle-heart.svg';

  /// map constant tentacle_strike to tentacle-strike.svg file
  static const String tentacle_strike = 'tentacle-strike.svg';

  /// map constant tentacles_barrier to tentacles-barrier.svg file
  static const String tentacles_barrier = 'tentacles-barrier.svg';

  /// map constant tentacles_skull to tentacles-skull.svg file
  static const String tentacles_skull = 'tentacles-skull.svg';

  /// map constant tentacurl to tentacurl.svg file
  static const String tentacurl = 'tentacurl.svg';

  /// map constant terror to terror.svg file
  static const String terror = 'terror.svg';

  /// map constant tesla_coil2 to tesla-coil 2.svg file
  static const String tesla_coil2 = 'tesla-coil 2.svg';

  /// map constant tesla_coil to tesla-coil.svg file
  static const String tesla_coil = 'tesla-coil.svg';

  /// map constant tesla_turret to tesla-turret.svg file
  static const String tesla_turret = 'tesla-turret.svg';

  /// map constant tesla to tesla.svg file
  static const String tesla = 'tesla.svg';

  /// map constant test_tube_held to test-tube-held.svg file
  static const String test_tube_held = 'test-tube-held.svg';

  /// map constant test_tube_rack to test-tube-rack.svg file
  static const String test_tube_rack = 'test-tube-rack.svg';

  /// map constant test_tubes to test-tubes.svg file
  static const String test_tubes = 'test-tubes.svg';

  /// map constant texas to texas.svg file
  static const String texas = 'texas.svg';

  /// map constant theater_curtains to theater-curtains.svg file
  static const String theater_curtains = 'theater-curtains.svg';

  /// map constant theater to theater.svg file
  static const String theater = 'theater.svg';

  /// map constant thermometer_cold to thermometer-cold.svg file
  static const String thermometer_cold = 'thermometer-cold.svg';

  /// map constant thermometer_hot to thermometer-hot.svg file
  static const String thermometer_hot = 'thermometer-hot.svg';

  /// map constant thermometer_scale to thermometer-scale.svg file
  static const String thermometer_scale = 'thermometer-scale.svg';

  /// map constant think to think.svg file
  static const String think = 'think.svg';

  /// map constant third_eye to third-eye.svg file
  static const String third_eye = 'third-eye.svg';

  /// map constant thompson_m1 to thompson-m1.svg file
  static const String thompson_m1 = 'thompson-m1.svg';

  /// map constant thompson_m1928 to thompson-m1928.svg file
  static const String thompson_m1928 = 'thompson-m1928.svg';

  /// map constant thor_fist to thor-fist.svg file
  static const String thor_fist = 'thor-fist.svg';

  /// map constant thor_hammer to thor-hammer.svg file
  static const String thor_hammer = 'thor-hammer.svg';

  /// map constant thorn_helix to thorn-helix.svg file
  static const String thorn_helix = 'thorn-helix.svg';

  /// map constant thorned_arrow to thorned-arrow.svg file
  static const String thorned_arrow = 'thorned-arrow.svg';

  /// map constant thorny_tentacle to thorny-tentacle.svg file
  static const String thorny_tentacle = 'thorny-tentacle.svg';

  /// map constant thorny_vine to thorny-vine.svg file
  static const String thorny_vine = 'thorny-vine.svg';

  /// map constant three_burning_balls to three-burning-balls.svg file
  static const String three_burning_balls = 'three-burning-balls.svg';

  /// map constant three_friends to three-friends.svg file
  static const String three_friends = 'three-friends.svg';

  /// map constant three_keys to three-keys.svg file
  static const String three_keys = 'three-keys.svg';

  /// map constant three_leaves to three-leaves.svg file
  static const String three_leaves = 'three-leaves.svg';

  /// map constant three_pointed_shuriken to three-pointed-shuriken.svg file
  static const String three_pointed_shuriken = 'three-pointed-shuriken.svg';

  /// map constant throne_king to throne-king.svg file
  static const String throne_king = 'throne-king.svg';

  /// map constant throwing_ball to throwing-ball.svg file
  static const String throwing_ball = 'throwing-ball.svg';

  /// map constant thrown_charcoal to thrown-charcoal.svg file
  static const String thrown_charcoal = 'thrown-charcoal.svg';

  /// map constant thrown_daggers to thrown-daggers.svg file
  static const String thrown_daggers = 'thrown-daggers.svg';

  /// map constant thrown_knife to thrown-knife.svg file
  static const String thrown_knife = 'thrown-knife.svg';

  /// map constant thrown_spear to thrown-spear.svg file
  static const String thrown_spear = 'thrown-spear.svg';

  /// map constant thrust_bend to thrust-bend.svg file
  static const String thrust_bend = 'thrust-bend.svg';

  /// map constant thrust to thrust.svg file
  static const String thrust = 'thrust.svg';

  /// map constant thumb_down to thumb-down.svg file
  static const String thumb_down = 'thumb-down.svg';

  /// map constant thumb_up to thumb-up.svg file
  static const String thumb_up = 'thumb-up.svg';

  /// map constant thunder_blade to thunder-blade.svg file
  static const String thunder_blade = 'thunder-blade.svg';

  /// map constant thunder_skull to thunder-skull.svg file
  static const String thunder_skull = 'thunder-skull.svg';

  /// map constant thunder_struck to thunder-struck.svg file
  static const String thunder_struck = 'thunder-struck.svg';

  /// map constant thunderball to thunderball.svg file
  static const String thunderball = 'thunderball.svg';

  /// map constant thwomp to thwomp.svg file
  static const String thwomp = 'thwomp.svg';

  /// map constant tiara to tiara.svg file
  static const String tiara = 'tiara.svg';

  /// map constant tic_tac_toe to tic-tac-toe.svg file
  static const String tic_tac_toe = 'tic-tac-toe.svg';

  /// map constant tick to tick.svg file
  static const String tick = 'tick.svg';

  /// map constant ticket to ticket.svg file
  static const String ticket = 'ticket.svg';

  /// map constant tie to tie.svg file
  static const String tie = 'tie.svg';

  /// map constant tied_scroll to tied-scroll.svg file
  static const String tied_scroll = 'tied-scroll.svg';

  /// map constant tiger_head to tiger-head.svg file
  static const String tiger_head = 'tiger-head.svg';

  /// map constant tiger to tiger.svg file
  static const String tiger = 'tiger.svg';

  /// map constant tightrope to tightrope.svg file
  static const String tightrope = 'tightrope.svg';

  /// map constant time_bomb to time-bomb.svg file
  static const String time_bomb = 'time-bomb.svg';

  /// map constant time_dynamite to time-dynamite.svg file
  static const String time_dynamite = 'time-dynamite.svg';

  /// map constant time_synchronization to time-synchronization.svg file
  static const String time_synchronization = 'time-synchronization.svg';

  /// map constant time_trap to time-trap.svg file
  static const String time_trap = 'time-trap.svg';

  /// map constant tinker to tinker.svg file
  static const String tinker = 'tinker.svg';

  /// map constant tipi to tipi.svg file
  static const String tipi = 'tipi.svg';

  /// map constant tire_iron_cross to tire-iron-cross.svg file
  static const String tire_iron_cross = 'tire-iron-cross.svg';

  /// map constant tire_iron to tire-iron.svg file
  static const String tire_iron = 'tire-iron.svg';

  /// map constant tire_tracks to tire-tracks.svg file
  static const String tire_tracks = 'tire-tracks.svg';

  /// map constant tired_eye to tired-eye.svg file
  static const String tired_eye = 'tired-eye.svg';

  /// map constant toad_teeth to toad-teeth.svg file
  static const String toad_teeth = 'toad-teeth.svg';

  /// map constant toaster to toaster.svg file
  static const String toaster = 'toaster.svg';

  /// map constant toggles to toggles.svg file
  static const String toggles = 'toggles.svg';

  /// map constant token to token.svg file
  static const String token = 'token.svg';

  /// map constant tomahawk to tomahawk.svg file
  static const String tomahawk = 'tomahawk.svg';

  /// map constant tomato to tomato.svg file
  static const String tomato = 'tomato.svg';

  /// map constant tombstone2 to tombstone 2.svg file
  static const String tombstone2 = 'tombstone 2.svg';

  /// map constant tombstone to tombstone.svg file
  static const String tombstone = 'tombstone.svg';

  /// map constant tongue to tongue.svg file
  static const String tongue = 'tongue.svg';

  /// map constant toolbox to toolbox.svg file
  static const String toolbox = 'toolbox.svg';

  /// map constant tooth to tooth.svg file
  static const String tooth = 'tooth.svg';

  /// map constant toothbrush to toothbrush.svg file
  static const String toothbrush = 'toothbrush.svg';

  /// map constant top_hat to top-hat.svg file
  static const String top_hat = 'top-hat.svg';

  /// map constant top_paw to top-paw.svg file
  static const String top_paw = 'top-paw.svg';

  /// map constant topaz to topaz.svg file
  static const String topaz = 'topaz.svg';

  /// map constant torc to torc.svg file
  static const String torc = 'torc.svg';

  /// map constant torch to torch.svg file
  static const String torch = 'torch.svg';

  /// map constant tornado_discs to tornado-discs.svg file
  static const String tornado_discs = 'tornado-discs.svg';

  /// map constant tornado to tornado.svg file
  static const String tornado = 'tornado.svg';

  /// map constant torpedo to torpedo.svg file
  static const String torpedo = 'torpedo.svg';

  /// map constant tortoise to tortoise.svg file
  static const String tortoise = 'tortoise.svg';

  /// map constant totem_head to totem-head.svg file
  static const String totem_head = 'totem-head.svg';

  /// map constant totem_mask to totem-mask.svg file
  static const String totem_mask = 'totem-mask.svg';

  /// map constant totem to totem.svg file
  static const String totem = 'totem.svg';

  /// map constant toucan to toucan.svg file
  static const String toucan = 'toucan.svg';

  /// map constant tow_truck to tow-truck.svg file
  static const String tow_truck = 'tow-truck.svg';

  /// map constant towel to towel.svg file
  static const String towel = 'towel.svg';

  /// map constant tower_bridge to tower-bridge.svg file
  static const String tower_bridge = 'tower-bridge.svg';

  /// map constant tower_fall to tower-fall.svg file
  static const String tower_fall = 'tower-fall.svg';

  /// map constant tower_flag to tower-flag.svg file
  static const String tower_flag = 'tower-flag.svg';

  /// map constant toy_mallet to toy-mallet.svg file
  static const String toy_mallet = 'toy-mallet.svg';

  /// map constant tracked_robot to tracked-robot.svg file
  static const String tracked_robot = 'tracked-robot.svg';

  /// map constant trade to trade.svg file
  static const String trade = 'trade.svg';

  /// map constant traffic_cone to traffic-cone.svg file
  static const String traffic_cone = 'traffic-cone.svg';

  /// map constant traffic_lights_green to traffic-lights-green.svg file
  static const String traffic_lights_green = 'traffic-lights-green.svg';

  /// map constant traffic_lights_orange to traffic-lights-orange.svg file
  static const String traffic_lights_orange = 'traffic-lights-orange.svg';

  /// map constant traffic_lights_ready_to_go to traffic-lights-ready-to-go.svg file
  static const String traffic_lights_ready_to_go = 'traffic-lights-ready-to-go.svg';

  /// map constant traffic_lights_red to traffic-lights-red.svg file
  static const String traffic_lights_red = 'traffic-lights-red.svg';

  /// map constant trail to trail.svg file
  static const String trail = 'trail.svg';

  /// map constant trample to trample.svg file
  static const String trample = 'trample.svg';

  /// map constant transform to transform.svg file
  static const String transform = 'transform.svg';

  /// map constant transfuse to transfuse.svg file
  static const String transfuse = 'transfuse.svg';

  /// map constant transparent_slime to transparent-slime.svg file
  static const String transparent_slime = 'transparent-slime.svg';

  /// map constant transparent_tubes to transparent-tubes.svg file
  static const String transparent_tubes = 'transparent-tubes.svg';

  /// map constant transportation_rings to transportation-rings.svg file
  static const String transportation_rings = 'transportation-rings.svg';

  /// map constant trap_mask to trap-mask.svg file
  static const String trap_mask = 'trap-mask.svg';

  /// map constant trash_can to trash-can.svg file
  static const String trash_can = 'trash-can.svg';

  /// map constant travel_dress to travel-dress.svg file
  static const String travel_dress = 'travel-dress.svg';

  /// map constant tread to tread.svg file
  static const String tread = 'tread.svg';

  /// map constant treasure_map to treasure-map.svg file
  static const String treasure_map = 'treasure-map.svg';

  /// map constant trebuchet to trebuchet.svg file
  static const String trebuchet = 'trebuchet.svg';

  /// map constant tree_beehive to tree-beehive.svg file
  static const String tree_beehive = 'tree-beehive.svg';

  /// map constant tree_branch to tree-branch.svg file
  static const String tree_branch = 'tree-branch.svg';

  /// map constant tree_door to tree-door.svg file
  static const String tree_door = 'tree-door.svg';

  /// map constant tree_face to tree-face.svg file
  static const String tree_face = 'tree-face.svg';

  /// map constant tree_growth to tree-growth.svg file
  static const String tree_growth = 'tree-growth.svg';

  /// map constant tree_roots to tree-roots.svg file
  static const String tree_roots = 'tree-roots.svg';

  /// map constant tree_swing to tree-swing.svg file
  static const String tree_swing = 'tree-swing.svg';

  /// map constant treehouse to treehouse.svg file
  static const String treehouse = 'treehouse.svg';

  /// map constant trefoil_lily to trefoil-lily.svg file
  static const String trefoil_lily = 'trefoil-lily.svg';

  /// map constant trefoil_shuriken to trefoil-shuriken.svg file
  static const String trefoil_shuriken = 'trefoil-shuriken.svg';

  /// map constant trench_assault to trench-assault.svg file
  static const String trench_assault = 'trench-assault.svg';

  /// map constant trench_body_armor to trench-body-armor.svg file
  static const String trench_body_armor = 'trench-body-armor.svg';

  /// map constant trench_knife to trench-knife.svg file
  static const String trench_knife = 'trench-knife.svg';

  /// map constant trench_spade to trench-spade.svg file
  static const String trench_spade = 'trench-spade.svg';

  /// map constant triangle_target to triangle-target.svg file
  static const String triangle_target = 'triangle-target.svg';

  /// map constant tribal_gear to tribal-gear.svg file
  static const String tribal_gear = 'tribal-gear.svg';

  /// map constant tribal_mask to tribal-mask.svg file
  static const String tribal_mask = 'tribal-mask.svg';

  /// map constant tribal_pendant to tribal-pendant.svg file
  static const String tribal_pendant = 'tribal-pendant.svg';

  /// map constant tribal_shield to tribal-shield.svg file
  static const String tribal_shield = 'tribal-shield.svg';

  /// map constant tribunal_jury to tribunal-jury.svg file
  static const String tribunal_jury = 'tribunal-jury.svg';

  /// map constant triceratops_head to triceratops-head.svg file
  static const String triceratops_head = 'triceratops-head.svg';

  /// map constant trident_shield to trident-shield.svg file
  static const String trident_shield = 'trident-shield.svg';

  /// map constant trident to trident.svg file
  static const String trident = 'trident.svg';

  /// map constant triforce to triforce.svg file
  static const String triforce = 'triforce.svg';

  /// map constant trigger_hurt to trigger-hurt.svg file
  static const String trigger_hurt = 'trigger-hurt.svg';

  /// map constant trilobite to trilobite.svg file
  static const String trilobite = 'trilobite.svg';

  /// map constant trinacria to trinacria.svg file
  static const String trinacria = 'trinacria.svg';

  /// map constant triorb to triorb.svg file
  static const String triorb = 'triorb.svg';

  /// map constant triple_beak to triple-beak.svg file
  static const String triple_beak = 'triple-beak.svg';

  /// map constant triple_claws to triple-claws.svg file
  static const String triple_claws = 'triple-claws.svg';

  /// map constant triple_corn to triple-corn.svg file
  static const String triple_corn = 'triple-corn.svg';

  /// map constant triple_gate to triple-gate.svg file
  static const String triple_gate = 'triple-gate.svg';

  /// map constant triple_lock to triple-lock.svg file
  static const String triple_lock = 'triple-lock.svg';

  /// map constant triple_needle to triple-needle.svg file
  static const String triple_needle = 'triple-needle.svg';

  /// map constant triple_plier to triple-plier.svg file
  static const String triple_plier = 'triple-plier.svg';

  /// map constant triple_scratches to triple-scratches.svg file
  static const String triple_scratches = 'triple-scratches.svg';

  /// map constant triple_shells to triple-shells.svg file
  static const String triple_shells = 'triple-shells.svg';

  /// map constant triple_skulls to triple-skulls.svg file
  static const String triple_skulls = 'triple-skulls.svg';

  /// map constant triple_yin to triple-yin.svg file
  static const String triple_yin = 'triple-yin.svg';

  /// map constant tripwire to tripwire.svg file
  static const String tripwire = 'tripwire.svg';

  /// map constant triquetra to triquetra.svg file
  static const String triquetra = 'triquetra.svg';

  /// map constant trireme to trireme.svg file
  static const String trireme = 'trireme.svg';

  /// map constant triton_head to triton-head.svg file
  static const String triton_head = 'triton-head.svg';

  /// map constant troglodyte to troglodyte.svg file
  static const String troglodyte = 'troglodyte.svg';

  /// map constant trojan_horse to trojan-horse.svg file
  static const String trojan_horse = 'trojan-horse.svg';

  /// map constant troll to troll.svg file
  static const String troll = 'troll.svg';

  /// map constant trombone to trombone.svg file
  static const String trombone = 'trombone.svg';

  /// map constant tron_arrow to tron-arrow.svg file
  static const String tron_arrow = 'tron-arrow.svg';

  /// map constant trophies_shelf to trophies-shelf.svg file
  static const String trophies_shelf = 'trophies-shelf.svg';

  /// map constant trophy_cup to trophy-cup.svg file
  static const String trophy_cup = 'trophy-cup.svg';

  /// map constant trophy to trophy.svg file
  static const String trophy = 'trophy.svg';

  /// map constant tropical_fish to tropical-fish.svg file
  static const String tropical_fish = 'tropical-fish.svg';

  /// map constant trousers2 to trousers 2.svg file
  static const String trousers2 = 'trousers 2.svg';

  /// map constant trousers to trousers.svg file
  static const String trousers = 'trousers.svg';

  /// map constant trowel to trowel.svg file
  static const String trowel = 'trowel.svg';

  /// map constant truce to truce.svg file
  static const String truce = 'truce.svg';

  /// map constant truck to truck.svg file
  static const String truck = 'truck.svg';

  /// map constant trumpet_flag to trumpet-flag.svg file
  static const String trumpet_flag = 'trumpet-flag.svg';

  /// map constant trumpet to trumpet.svg file
  static const String trumpet = 'trumpet.svg';

  /// map constant trunk_mushroom to trunk-mushroom.svg file
  static const String trunk_mushroom = 'trunk-mushroom.svg';

  /// map constant tuba to tuba.svg file
  static const String tuba = 'tuba.svg';

  /// map constant tumbleweed to tumbleweed.svg file
  static const String tumbleweed = 'tumbleweed.svg';

  /// map constant tumor to tumor.svg file
  static const String tumor = 'tumor.svg';

  /// map constant tumulus to tumulus.svg file
  static const String tumulus = 'tumulus.svg';

  /// map constant tune_pitch to tune-pitch.svg file
  static const String tune_pitch = 'tune-pitch.svg';

  /// map constant tunisia to tunisia.svg file
  static const String tunisia = 'tunisia.svg';

  /// map constant turban to turban.svg file
  static const String turban = 'turban.svg';

  /// map constant turbine to turbine.svg file
  static const String turbine = 'turbine.svg';

  /// map constant turd to turd.svg file
  static const String turd = 'turd.svg';

  /// map constant turnstile to turnstile.svg file
  static const String turnstile = 'turnstile.svg';

  /// map constant turret to turret.svg file
  static const String turret = 'turret.svg';

  /// map constant turtle_shell to turtle-shell.svg file
  static const String turtle_shell = 'turtle-shell.svg';

  /// map constant turtle to turtle.svg file
  static const String turtle = 'turtle.svg';

  /// map constant tusks_flag to tusks-flag.svg file
  static const String tusks_flag = 'tusks-flag.svg';

  /// map constant tv_remote to tv-remote.svg file
  static const String tv_remote = 'tv-remote.svg';

  /// map constant tv_tower to tv-tower.svg file
  static const String tv_tower = 'tv-tower.svg';

  /// map constant tv to tv.svg file
  static const String tv = 'tv.svg';

  /// map constant twin_shell to twin-shell.svg file
  static const String twin_shell = 'twin-shell.svg';

  /// map constant twirl_center to twirl-center.svg file
  static const String twirl_center = 'twirl-center.svg';

  /// map constant twirly_flower to twirly-flower.svg file
  static const String twirly_flower = 'twirly-flower.svg';

  /// map constant twister to twister.svg file
  static const String twister = 'twister.svg';

  /// map constant two_coins to two-coins.svg file
  static const String two_coins = 'two-coins.svg';

  /// map constant two_feathers to two-feathers.svg file
  static const String two_feathers = 'two-feathers.svg';

  /// map constant two_handed_sword to two-handed-sword.svg file
  static const String two_handed_sword = 'two-handed-sword.svg';

  /// map constant two_shadows to two-shadows.svg file
  static const String two_shadows = 'two-shadows.svg';

  /// map constant tyre to tyre.svg file
  static const String tyre = 'tyre.svg';

  /// map constant ubisoft_sun to ubisoft-sun.svg file
  static const String ubisoft_sun = 'ubisoft-sun.svg';

  /// map constant udder to udder.svg file
  static const String udder = 'udder.svg';

  /// map constant ufo to ufo.svg file
  static const String ufo = 'ufo.svg';

  /// map constant ultrasound to ultrasound.svg file
  static const String ultrasound = 'ultrasound.svg';

  /// map constant uluru to uluru.svg file
  static const String uluru = 'uluru.svg';

  /// map constant umbrella_bayonet to umbrella-bayonet.svg file
  static const String umbrella_bayonet = 'umbrella-bayonet.svg';

  /// map constant umbrella to umbrella.svg file
  static const String umbrella = 'umbrella.svg';

  /// map constant unbalanced to unbalanced.svg file
  static const String unbalanced = 'unbalanced.svg';

  /// map constant uncertainty to uncertainty.svg file
  static const String uncertainty = 'uncertainty.svg';

  /// map constant underground_cave to underground-cave.svg file
  static const String underground_cave = 'underground-cave.svg';

  /// map constant underhand to underhand.svg file
  static const String underhand = 'underhand.svg';

  /// map constant underwear_shorts to underwear-shorts.svg file
  static const String underwear_shorts = 'underwear-shorts.svg';

  /// map constant underwear to underwear.svg file
  static const String underwear = 'underwear.svg';

  /// map constant unfriendly_fire to unfriendly-fire.svg file
  static const String unfriendly_fire = 'unfriendly-fire.svg';

  /// map constant unicorn to unicorn.svg file
  static const String unicorn = 'unicorn.svg';

  /// map constant unicycle to unicycle.svg file
  static const String unicycle = 'unicycle.svg';

  /// map constant union_jack to union-jack.svg file
  static const String union_jack = 'union-jack.svg';

  /// map constant unlit_bomb to unlit-bomb.svg file
  static const String unlit_bomb = 'unlit-bomb.svg';

  /// map constant unlit_candelabra to unlit-candelabra.svg file
  static const String unlit_candelabra = 'unlit-candelabra.svg';

  /// map constant unlocking to unlocking.svg file
  static const String unlocking = 'unlocking.svg';

  /// map constant unplugged to unplugged.svg file
  static const String unplugged = 'unplugged.svg';

  /// map constant unstable_orb to unstable-orb.svg file
  static const String unstable_orb = 'unstable-orb.svg';

  /// map constant unstable_projectile to unstable-projectile.svg file
  static const String unstable_projectile = 'unstable-projectile.svg';

  /// map constant up_card to up-card.svg file
  static const String up_card = 'up-card.svg';

  /// map constant upgrade to upgrade.svg file
  static const String upgrade = 'upgrade.svg';

  /// map constant uprising to uprising.svg file
  static const String uprising = 'uprising.svg';

  /// map constant ursa_major to ursa-major.svg file
  static const String ursa_major = 'ursa-major.svg';

  /// map constant uruguay to uruguay.svg file
  static const String uruguay = 'uruguay.svg';

  /// map constant usa_flag to usa-flag.svg file
  static const String usa_flag = 'usa-flag.svg';

  /// map constant usable to usable.svg file
  static const String usable = 'usable.svg';

  /// map constant usb_key to usb-key.svg file
  static const String usb_key = 'usb-key.svg';

  /// map constant ushanka to ushanka.svg file
  static const String ushanka = 'ushanka.svg';

  /// map constant uzi to uzi.svg file
  static const String uzi = 'uzi.svg';

  /// map constant vacuum_cleaner to vacuum-cleaner.svg file
  static const String vacuum_cleaner = 'vacuum-cleaner.svg';

  /// map constant valley to valley.svg file
  static const String valley = 'valley.svg';

  /// map constant valve to valve.svg file
  static const String valve = 'valve.svg';

  /// map constant vampire_cape to vampire-cape.svg file
  static const String vampire_cape = 'vampire-cape.svg';

  /// map constant vampire_dracula to vampire-dracula.svg file
  static const String vampire_dracula = 'vampire-dracula.svg';

  /// map constant van_damme_split to van-damme-split.svg file
  static const String van_damme_split = 'van-damme-split.svg';

  /// map constant vanilla_flower to vanilla-flower.svg file
  static const String vanilla_flower = 'vanilla-flower.svg';

  /// map constant velocipede to velocipede.svg file
  static const String velocipede = 'velocipede.svg';

  /// map constant velociraptor_tracks to velociraptor-tracks.svg file
  static const String velociraptor_tracks = 'velociraptor-tracks.svg';

  /// map constant velociraptor to velociraptor.svg file
  static const String velociraptor = 'velociraptor.svg';

  /// map constant vending_machine to vending-machine.svg file
  static const String vending_machine = 'vending-machine.svg';

  /// map constant venezuela to venezuela.svg file
  static const String venezuela = 'venezuela.svg';

  /// map constant venus_flytrap to venus-flytrap.svg file
  static const String venus_flytrap = 'venus-flytrap.svg';

  /// map constant venus_of_willendorf to venus-of-willendorf.svg file
  static const String venus_of_willendorf = 'venus-of-willendorf.svg';

  /// map constant vertical_banner to vertical-banner.svg file
  static const String vertical_banner = 'vertical-banner.svg';

  /// map constant vertical_flip to vertical-flip.svg file
  static const String vertical_flip = 'vertical-flip.svg';

  /// map constant vhs to vhs.svg file
  static const String vhs = 'vhs.svg';

  /// map constant vial to vial.svg file
  static const String vial = 'vial.svg';

  /// map constant vibrating_ball to vibrating-ball.svg file
  static const String vibrating_ball = 'vibrating-ball.svg';

  /// map constant vibrating_shield to vibrating-shield.svg file
  static const String vibrating_shield = 'vibrating-shield.svg';

  /// map constant vibrating_smartphone to vibrating-smartphone.svg file
  static const String vibrating_smartphone = 'vibrating-smartphone.svg';

  /// map constant video_camera to video-camera.svg file
  static const String video_camera = 'video-camera.svg';

  /// map constant video_conference to video-conference.svg file
  static const String video_conference = 'video-conference.svg';

  /// map constant viking_church to viking-church.svg file
  static const String viking_church = 'viking-church.svg';

  /// map constant viking_head to viking-head.svg file
  static const String viking_head = 'viking-head.svg';

  /// map constant viking_helmet to viking-helmet.svg file
  static const String viking_helmet = 'viking-helmet.svg';

  /// map constant viking_longhouse to viking-longhouse.svg file
  static const String viking_longhouse = 'viking-longhouse.svg';

  /// map constant viking_shield to viking-shield.svg file
  static const String viking_shield = 'viking-shield.svg';

  /// map constant vile_fluid to vile-fluid.svg file
  static const String vile_fluid = 'vile-fluid.svg';

  /// map constant village to village.svg file
  static const String village = 'village.svg';

  /// map constant vine_flower to vine-flower.svg file
  static const String vine_flower = 'vine-flower.svg';

  /// map constant vine_leaf to vine-leaf.svg file
  static const String vine_leaf = 'vine-leaf.svg';

  /// map constant vine_whip to vine-whip.svg file
  static const String vine_whip = 'vine-whip.svg';

  /// map constant vines to vines.svg file
  static const String vines = 'vines.svg';

  /// map constant vintage_robot to vintage-robot.svg file
  static const String vintage_robot = 'vintage-robot.svg';

  /// map constant viola to viola.svg file
  static const String viola = 'viola.svg';

  /// map constant violin to violin.svg file
  static const String violin = 'violin.svg';

  /// map constant virgo to virgo.svg file
  static const String virgo = 'virgo.svg';

  /// map constant virtual_marker to virtual-marker.svg file
  static const String virtual_marker = 'virtual-marker.svg';

  /// map constant virus to virus.svg file
  static const String virus = 'virus.svg';

  /// map constant visored_helm to visored-helm.svg file
  static const String visored_helm = 'visored-helm.svg';

  /// map constant vitruvian_man to vitruvian-man.svg file
  static const String vitruvian_man = 'vitruvian-man.svg';

  /// map constant volcano to volcano.svg file
  static const String volcano = 'volcano.svg';

  /// map constant volleyball_ball to volleyball-ball.svg file
  static const String volleyball_ball = 'volleyball-ball.svg';

  /// map constant vomiting to vomiting.svg file
  static const String vomiting = 'vomiting.svg';

  /// map constant voodoo_doll to voodoo-doll.svg file
  static const String voodoo_doll = 'voodoo-doll.svg';

  /// map constant vortex to vortex.svg file
  static const String vortex = 'vortex.svg';

  /// map constant vote to vote.svg file
  static const String vote = 'vote.svg';

  /// map constant vr_headset to vr-headset.svg file
  static const String vr_headset = 'vr-headset.svg';

  /// map constant vulture to vulture.svg file
  static const String vulture = 'vulture.svg';

  /// map constant vuvuzelas to vuvuzelas.svg file
  static const String vuvuzelas = 'vuvuzelas.svg';

  /// map constant walk to walk.svg file
  static const String walk = 'walk.svg';

  /// map constant walkie_talkie to walkie-talkie.svg file
  static const String walkie_talkie = 'walkie-talkie.svg';

  /// map constant walking_boot to walking-boot.svg file
  static const String walking_boot = 'walking-boot.svg';

  /// map constant walking_scout to walking-scout.svg file
  static const String walking_scout = 'walking-scout.svg';

  /// map constant walking_turret to walking-turret.svg file
  static const String walking_turret = 'walking-turret.svg';

  /// map constant wall_light to wall-light.svg file
  static const String wall_light = 'wall-light.svg';

  /// map constant wallet to wallet.svg file
  static const String wallet = 'wallet.svg';

  /// map constant walrus_head to walrus-head.svg file
  static const String walrus_head = 'walrus-head.svg';

  /// map constant walther_ppk to walther-ppk.svg file
  static const String walther_ppk = 'walther-ppk.svg';

  /// map constant wanted_reward to wanted-reward.svg file
  static const String wanted_reward = 'wanted-reward.svg';

  /// map constant war_axe to war-axe.svg file
  static const String war_axe = 'war-axe.svg';

  /// map constant war_bonnet to war-bonnet.svg file
  static const String war_bonnet = 'war-bonnet.svg';

  /// map constant war_pick to war-pick.svg file
  static const String war_pick = 'war-pick.svg';

  /// map constant warhammer to warhammer.svg file
  static const String warhammer = 'warhammer.svg';

  /// map constant warlock_eye to warlock-eye.svg file
  static const String warlock_eye = 'warlock-eye.svg';

  /// map constant warlock_hood to warlock-hood.svg file
  static const String warlock_hood = 'warlock-hood.svg';

  /// map constant warlord_helmet to warlord-helmet.svg file
  static const String warlord_helmet = 'warlord-helmet.svg';

  /// map constant warp_pipe to warp-pipe.svg file
  static const String warp_pipe = 'warp-pipe.svg';

  /// map constant washing_machine to washing-machine.svg file
  static const String washing_machine = 'washing-machine.svg';

  /// map constant wasp_sting to wasp-sting.svg file
  static const String wasp_sting = 'wasp-sting.svg';

  /// map constant watch to watch.svg file
  static const String watch = 'watch.svg';

  /// map constant watchtower to watchtower.svg file
  static const String watchtower = 'watchtower.svg';

  /// map constant water_bolt to water-bolt.svg file
  static const String water_bolt = 'water-bolt.svg';

  /// map constant water_bottle to water-bottle.svg file
  static const String water_bottle = 'water-bottle.svg';

  /// map constant water_diviner_stick to water-diviner-stick.svg file
  static const String water_diviner_stick = 'water-diviner-stick.svg';

  /// map constant water_drop to water-drop.svg file
  static const String water_drop = 'water-drop.svg';

  /// map constant water_flask to water-flask.svg file
  static const String water_flask = 'water-flask.svg';

  /// map constant water_fountain to water-fountain.svg file
  static const String water_fountain = 'water-fountain.svg';

  /// map constant water_gallon to water-gallon.svg file
  static const String water_gallon = 'water-gallon.svg';

  /// map constant water_gun to water-gun.svg file
  static const String water_gun = 'water-gun.svg';

  /// map constant water_mill to water-mill.svg file
  static const String water_mill = 'water-mill.svg';

  /// map constant water_polo to water-polo.svg file
  static const String water_polo = 'water-polo.svg';

  /// map constant water_recycling to water-recycling.svg file
  static const String water_recycling = 'water-recycling.svg';

  /// map constant water_splash to water-splash.svg file
  static const String water_splash = 'water-splash.svg';

  /// map constant water_tank to water-tank.svg file
  static const String water_tank = 'water-tank.svg';

  /// map constant water_tower to water-tower.svg file
  static const String water_tower = 'water-tower.svg';

  /// map constant waterfall to waterfall.svg file
  static const String waterfall = 'waterfall.svg';

  /// map constant watering_can to watering-can.svg file
  static const String watering_can = 'watering-can.svg';

  /// map constant watermelon to watermelon.svg file
  static const String watermelon = 'watermelon.svg';

  /// map constant wave_crest to wave-crest.svg file
  static const String wave_crest = 'wave-crest.svg';

  /// map constant wave_strike to wave-strike.svg file
  static const String wave_strike = 'wave-strike.svg';

  /// map constant wave_surfer to wave-surfer.svg file
  static const String wave_surfer = 'wave-surfer.svg';

  /// map constant waves to waves.svg file
  static const String waves = 'waves.svg';

  /// map constant wavy_chains to wavy-chains.svg file
  static const String wavy_chains = 'wavy-chains.svg';

  /// map constant wavy_itinerary to wavy-itinerary.svg file
  static const String wavy_itinerary = 'wavy-itinerary.svg';

  /// map constant wax_seal to wax-seal.svg file
  static const String wax_seal = 'wax-seal.svg';

  /// map constant wax_tablet to wax-tablet.svg file
  static const String wax_tablet = 'wax-tablet.svg';

  /// map constant web_spit to web-spit.svg file
  static const String web_spit = 'web-spit.svg';

  /// map constant weight_crush to weight-crush.svg file
  static const String weight_crush = 'weight-crush.svg';

  /// map constant weight_lifting_down to weight-lifting-down.svg file
  static const String weight_lifting_down = 'weight-lifting-down.svg';

  /// map constant weight_lifting_up to weight-lifting-up.svg file
  static const String weight_lifting_up = 'weight-lifting-up.svg';

  /// map constant weight_scale to weight-scale.svg file
  static const String weight_scale = 'weight-scale.svg';

  /// map constant weight to weight.svg file
  static const String weight = 'weight.svg';

  /// map constant well to well.svg file
  static const String well = 'well.svg';

  /// map constant werewolf to werewolf.svg file
  static const String werewolf = 'werewolf.svg';

  /// map constant western_hat to western-hat.svg file
  static const String western_hat = 'western-hat.svg';

  /// map constant whale_tail to whale-tail.svg file
  static const String whale_tail = 'whale-tail.svg';

  /// map constant wheat to wheat.svg file
  static const String wheat = 'wheat.svg';

  /// map constant wheelbarrow to wheelbarrow.svg file
  static const String wheelbarrow = 'wheelbarrow.svg';

  /// map constant whip to whip.svg file
  static const String whip = 'whip.svg';

  /// map constant whiplash to whiplash.svg file
  static const String whiplash = 'whiplash.svg';

  /// map constant whirlpool_shuriken to whirlpool-shuriken.svg file
  static const String whirlpool_shuriken = 'whirlpool-shuriken.svg';

  /// map constant whirlwind to whirlwind.svg file
  static const String whirlwind = 'whirlwind.svg';

  /// map constant whisk to whisk.svg file
  static const String whisk = 'whisk.svg';

  /// map constant whistle to whistle.svg file
  static const String whistle = 'whistle.svg';

  /// map constant white_book to white-book.svg file
  static const String white_book = 'white-book.svg';

  /// map constant white_tower to white-tower.svg file
  static const String white_tower = 'white-tower.svg';

  /// map constant wide_arrow_dunk to wide-arrow-dunk.svg file
  static const String wide_arrow_dunk = 'wide-arrow-dunk.svg';

  /// map constant wifi_router to wifi-router.svg file
  static const String wifi_router = 'wifi-router.svg';

  /// map constant wildfires to wildfires.svg file
  static const String wildfires = 'wildfires.svg';

  /// map constant william_tell_skull to william-tell-skull.svg file
  static const String william_tell_skull = 'william-tell-skull.svg';

  /// map constant william_tell to william-tell.svg file
  static const String william_tell = 'william-tell.svg';

  /// map constant willow_tree to willow-tree.svg file
  static const String willow_tree = 'willow-tree.svg';

  /// map constant winchester_rifle to winchester-rifle.svg file
  static const String winchester_rifle = 'winchester-rifle.svg';

  /// map constant wind_hole to wind-hole.svg file
  static const String wind_hole = 'wind-hole.svg';

  /// map constant wind_slap to wind-slap.svg file
  static const String wind_slap = 'wind-slap.svg';

  /// map constant wind_turbine to wind-turbine.svg file
  static const String wind_turbine = 'wind-turbine.svg';

  /// map constant windchimes to windchimes.svg file
  static const String windchimes = 'windchimes.svg';

  /// map constant windmill to windmill.svg file
  static const String windmill = 'windmill.svg';

  /// map constant window_bars to window-bars.svg file
  static const String window_bars = 'window-bars.svg';

  /// map constant window to window.svg file
  static const String window = 'window.svg';

  /// map constant windpump to windpump.svg file
  static const String windpump = 'windpump.svg';

  /// map constant windsock to windsock.svg file
  static const String windsock = 'windsock.svg';

  /// map constant windy_stripes to windy-stripes.svg file
  static const String windy_stripes = 'windy-stripes.svg';

  /// map constant wine_bottle to wine-bottle.svg file
  static const String wine_bottle = 'wine-bottle.svg';

  /// map constant wine_glass to wine-glass.svg file
  static const String wine_glass = 'wine-glass.svg';

  /// map constant wing_cloak to wing-cloak.svg file
  static const String wing_cloak = 'wing-cloak.svg';

  /// map constant winged_arrow to winged-arrow.svg file
  static const String winged_arrow = 'winged-arrow.svg';

  /// map constant winged_emblem to winged-emblem.svg file
  static const String winged_emblem = 'winged-emblem.svg';

  /// map constant winged_leg to winged-leg.svg file
  static const String winged_leg = 'winged-leg.svg';

  /// map constant winged_scepter to winged-scepter.svg file
  static const String winged_scepter = 'winged-scepter.svg';

  /// map constant winged_shield to winged-shield.svg file
  static const String winged_shield = 'winged-shield.svg';

  /// map constant winged_sword to winged-sword.svg file
  static const String winged_sword = 'winged-sword.svg';

  /// map constant wingfoot to wingfoot.svg file
  static const String wingfoot = 'wingfoot.svg';

  /// map constant winter_gloves to winter-gloves.svg file
  static const String winter_gloves = 'winter-gloves.svg';

  /// map constant winter_hat to winter-hat.svg file
  static const String winter_hat = 'winter-hat.svg';

  /// map constant wire_coil to wire-coil.svg file
  static const String wire_coil = 'wire-coil.svg';

  /// map constant wireframe_globe to wireframe-globe.svg file
  static const String wireframe_globe = 'wireframe-globe.svg';

  /// map constant wisdom to wisdom.svg file
  static const String wisdom = 'wisdom.svg';

  /// map constant witch_face to witch-face.svg file
  static const String witch_face = 'witch-face.svg';

  /// map constant witch_flight to witch-flight.svg file
  static const String witch_flight = 'witch-flight.svg';

  /// map constant wizard_face to wizard-face.svg file
  static const String wizard_face = 'wizard-face.svg';

  /// map constant wizard_staff to wizard-staff.svg file
  static const String wizard_staff = 'wizard-staff.svg';

  /// map constant wok to wok.svg file
  static const String wok = 'wok.svg';

  /// map constant wolf_head to wolf-head.svg file
  static const String wolf_head = 'wolf-head.svg';

  /// map constant wolf_howl to wolf-howl.svg file
  static const String wolf_howl = 'wolf-howl.svg';

  /// map constant wolf_trap to wolf-trap.svg file
  static const String wolf_trap = 'wolf-trap.svg';

  /// map constant wolverine_claws2 to wolverine-claws 2.svg file
  static const String wolverine_claws2 = 'wolverine-claws 2.svg';

  /// map constant wolverine_claws to wolverine-claws.svg file
  static const String wolverine_claws = 'wolverine-claws.svg';

  /// map constant woman_elf_face to woman-elf-face.svg file
  static const String woman_elf_face = 'woman-elf-face.svg';

  /// map constant wood_axe to wood-axe.svg file
  static const String wood_axe = 'wood-axe.svg';

  /// map constant wood_beam to wood-beam.svg file
  static const String wood_beam = 'wood-beam.svg';

  /// map constant wood_cabin to wood-cabin.svg file
  static const String wood_cabin = 'wood-cabin.svg';

  /// map constant wood_canoe to wood-canoe.svg file
  static const String wood_canoe = 'wood-canoe.svg';

  /// map constant wood_club to wood-club.svg file
  static const String wood_club = 'wood-club.svg';

  /// map constant wood_frame to wood-frame.svg file
  static const String wood_frame = 'wood-frame.svg';

  /// map constant wood_pile to wood-pile.svg file
  static const String wood_pile = 'wood-pile.svg';

  /// map constant wood_stick to wood-stick.svg file
  static const String wood_stick = 'wood-stick.svg';

  /// map constant wooden_chair to wooden-chair.svg file
  static const String wooden_chair = 'wooden-chair.svg';

  /// map constant wooden_clogs to wooden-clogs.svg file
  static const String wooden_clogs = 'wooden-clogs.svg';

  /// map constant wooden_crate to wooden-crate.svg file
  static const String wooden_crate = 'wooden-crate.svg';

  /// map constant wooden_door to wooden-door.svg file
  static const String wooden_door = 'wooden-door.svg';

  /// map constant wooden_fence to wooden-fence.svg file
  static const String wooden_fence = 'wooden-fence.svg';

  /// map constant wooden_helmet to wooden-helmet.svg file
  static const String wooden_helmet = 'wooden-helmet.svg';

  /// map constant wooden_pegleg to wooden-pegleg.svg file
  static const String wooden_pegleg = 'wooden-pegleg.svg';

  /// map constant wooden_pier to wooden-pier.svg file
  static const String wooden_pier = 'wooden-pier.svg';

  /// map constant wooden_sign to wooden-sign.svg file
  static const String wooden_sign = 'wooden-sign.svg';

  /// map constant wool to wool.svg file
  static const String wool = 'wool.svg';

  /// map constant world to world.svg file
  static const String world = 'world.svg';

  /// map constant worm_mouth to worm-mouth.svg file
  static const String worm_mouth = 'worm-mouth.svg';

  /// map constant worms to worms.svg file
  static const String worms = 'worms.svg';

  /// map constant worried_eyes to worried-eyes.svg file
  static const String worried_eyes = 'worried-eyes.svg';

  /// map constant wrapped_heart to wrapped-heart.svg file
  static const String wrapped_heart = 'wrapped-heart.svg';

  /// map constant wrapped_sweet to wrapped-sweet.svg file
  static const String wrapped_sweet = 'wrapped-sweet.svg';

  /// map constant wrapping_star to wrapping-star.svg file
  static const String wrapping_star = 'wrapping-star.svg';

  /// map constant wrecking_ball to wrecking-ball.svg file
  static const String wrecking_ball = 'wrecking-ball.svg';

  /// map constant wrench to wrench.svg file
  static const String wrench = 'wrench.svg';

  /// map constant wyvern to wyvern.svg file
  static const String wyvern = 'wyvern.svg';

  /// map constant xylophone to xylophone.svg file
  static const String xylophone = 'xylophone.svg';

  /// map constant yarn to yarn.svg file
  static const String yarn = 'yarn.svg';

  /// map constant yin_yang to yin-yang.svg file
  static const String yin_yang = 'yin-yang.svg';

  /// map constant yunluo to yunluo.svg file
  static const String yunluo = 'yunluo.svg';

  /// map constant z_brick to z-brick.svg file
  static const String z_brick = 'z-brick.svg';

  /// map constant zat_gun to zat-gun.svg file
  static const String zat_gun = 'zat-gun.svg';

  /// map constant zebra_shield to zebra-shield.svg file
  static const String zebra_shield = 'zebra-shield.svg';

  /// map constant zeppelin to zeppelin.svg file
  static const String zeppelin = 'zeppelin.svg';

  /// map constant zeus_sword to zeus-sword.svg file
  static const String zeus_sword = 'zeus-sword.svg';

  /// map constant zig_arrow to zig-arrow.svg file
  static const String zig_arrow = 'zig-arrow.svg';

  /// map constant zigzag_cage to zigzag-cage.svg file
  static const String zigzag_cage = 'zigzag-cage.svg';

  /// map constant zigzag_hieroglyph to zigzag-hieroglyph.svg file
  static const String zigzag_hieroglyph = 'zigzag-hieroglyph.svg';

  /// map constant zigzag_leaf to zigzag-leaf.svg file
  static const String zigzag_leaf = 'zigzag-leaf.svg';

  /// map constant zigzag_tune to zigzag-tune.svg file
  static const String zigzag_tune = 'zigzag-tune.svg';

  /// map constant zipper to zipper.svg file
  static const String zipper = 'zipper.svg';
}
